/*
 * Classified Tydeman Consulting Proprietary
 * Copyright (C) 1998, 2012 Tydeman Consulting.  All rights reserved.
 *
 * Fred J. Tydeman	tydeman@tybor.com
 *
 * Top level configuration file for sample FPCE tests.
 *
 * MODIFICATION HISTORY:
 *
 * 2000/03/01 - Make classification explicit in each file.
 * 2000/03/01 - Remove confidential so can post to public ftp site.
 * 2004/08/03 - Update to align with TC1 (DR 202) of C99.
 * 2012/06/05 - Add Gnu C as an example of a (mostly) C99 compiler.
 * 2012/07/20 - Check magic symbols to find level of C supported.
 *
 ***********************************************************************/

/*
 * Because everything is compiled at once, some lint errors show up
 * that are not there if each file is compiled by itself.
 */
/*lint -e537 // Repeated include file */
/*lint -e578 // Local var hides global var */
/*lint -e760 // Identically defined macro */
/*lint -e801 // Use of goto is deprecated */
/*lint -e953 // Var could be const */
/*lint -e962 // Macro defined identically */

/*
 * What level of FPCE are we testing?  See mydefs.h around lines 648
 * to 786 for choices.
 */
#define FPCE_TEST_LVL 20010901uL	/* C99 + TC1 */


#ifdef __STDC__
  #ifdef __STDC_VERSION__
    #if   201100L < __STDC_VERSION__
      #define VERSION 2011	/* 4th ISO Standard C */
    #elif 199900L < __STDC_VERSION__
      #define VERSION 1999	/* 3rd ISO Standard C */
    #elif 199400L < __STDC_VERSION__
      #define VERSION 1995	/* 2nd ISO Standard C */
    #else
      #error __STDC_VERSION__ has bad value
      #define VERSION (__STDC_VERSION__ / 100L)
    #endif
  #else
    #define VERSION 1990	/* 1st ISO Standard C */
  #endif
#else
  #define VERSION 1985		/* Not Standard C conformant compiler */
#endif

/* 
 * Cause mydefs.h to include sample.bug (another configuration file)
 *
 * Cause myfloat.h to include sample.flt (the last configuration file)
 */
#if 1
  #define FPCE_SAMPLE
#else
  #undef  FPCE_SAMPLE		/* Use your own *.bug and *.flt files */
#endif


/* 
 * Disable or Enable the debug print statements in t0120200.fjt
 * They are disabled by default so a clean run has only one line of output.
 */
#if 0
  #define DEBUG			/* Extra output in tests */
#endif


/* 
 * Enable the #define FIX_* statements in sample.bug
 */
#ifndef   WANT_CLEAN		/* In case defined via compiler option */
  #define WANT_CLEAN
#endif


/*
 * Where can isnan(), isfinite(), fetestexcept(), feclearexcept(),
 * feraiseexcept(), and fegetround() be found?
 *
 * If your compiler (mostly) supports C99 or C11, then change '0' to '1'
 * in the next #if.
 */
#if 0 || (defined __GNUC__) || (1999 <= VERSION)	/* Gnu C mostly supports C99 */

  #define SAMPLE_MISSING (-1)	/* nothing missing */

#elif (defined __SC__)		/* Symantec supports these, but in <fp.h> */

  #undef  FPCE_TEST_LVL
  #define FPCE_TEST_LVL 19940630uL	/* Need <fp.h> */
  #define SAMPLE_MISSING (-1)	/* nothing missing */

#else				/* Missing => try to use the samples */

  /*
   * Change these, as required, to #undef SAMPLE_* if the given feature
   * is supported by the compiler you are testing and hence, you do not
   * need the sample version.
   */
  #define SAMPLE_isnan		/* Need the sample isnan macro */
  #define SAMPLE_isfinite	/* Need the sample isfinite macro */
  #define SAMPLE_fetestexcept	/* Need the sample fetestexcept function */
  #define SAMPLE_feclearexcept	/* Need the sample feclearexcept function */
  #define SAMPLE_feraiseexcept	/* Need the sample feraiseexcept function */
  #define SAMPLE_fegetround	/* Need the sample fegetround function */

  /*
   * If the compiler you are testing is missing the FPCE functions, you
   * have a choice of which sample ones to use.  Either dummy functions
   * that do nothing, or ones tailored for specific hardware.
   *
   * If you use the dummy ones, then the code should compile, link and run.
   * But, you should get many error messages at run time about missing
   * expected exception flags.  
   *
   *   Test t1150001 will still be useful as an accuracy check on sin().
   *   Test t1150000 will be somewhat useful as an accuracy check on sin().
   *   Test t0120200 will be of very little value since it is checking for 
   *   exception flags more so than values.
   *
   * If you try to use the samples tailored for specific hardware, your
   * choices are limited.  The Intel x87 versions are based upon the
   * _clear87(), _status87(), and _control87() extensions that are common
   * to many DOS, Windows, and OS/2 (but not Linux) compilers.
   *
   * The Sun versions have not been used tested (I have no access to a Sun),
   * but should work based upon the documentation I have seen.
   *
   * -1 => Nothing missing
   *  0 => dummy
   *  1 => Intel x87
   *  2 => Sun
   */
  #define SAMPLE_MISSING 0	/* dummy versions */

#endif
