/*
 *  Classified Tydeman Consulting Proprietary
 *  Copyright (C) 1994, 2021 Tydeman Consulting.  All rights reserved.
 *
 *  Fred J. Tydeman	tydeman@tybor.com
 *
 * - -- --- ---- ----- -------------------------------------------------
 *
 *    We wish to acknowledge Taligent, Inc., for their support of this
 *	   test suite.  Taligent was early to recognize
 *	   the value and need for a comprehensive test suite of the
 *	   floating point support in C compilers.  Taligent funded the
 *	   original version of this test suite, and has graciously
 *	   released it to us to allow continued extensions and to
 *	   promote wider compliance with the ANSI C Floating-Point
 *	   C Extensions (FPCE).
 *
 *    This code is copyrighted.  Under the copyright laws, this code may
 *         not be copied, in whole or part, without prior written
 *         consent of Tydeman Consulting.
 *
 *    RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the
 *         government is subject to restrictions as set forth in
 *         subparagraph (c)(1)(ii) of the Rights in Technical Data and
 *         Computer Software clause at DFARS 252.227-7013 and
 *         FAR 52.227-19.
 *
 *    TRADEMARKS: Taligent and the Taligent Design Mark are registered
 *         trademarks of Taligent, Inc.
 *
 * - -- --- ---- ----- -------------------------------------------------
 * $Revision: 2.1 $
 ***********************************************************************
 *  FILE: mydefs.h
 *
 *  Description:	  Define macro symbols used in rest of test suite.
 *
 *  It is assumed that mydefs.h is the first #include file, so it can
 *  define anything needed by the other #include files.  This header
 *  should NOT include any other header (except for the configuration /
 *  bug bypass definition header).  Otherwise, the tests of standard
 *  headers will be misleading.
 *
 *  All of the following defines should be put into a separate file that
 *  is then included by this file.  That way, you can hide your compiler's
 *  bugs and this file (shipped to everyone) does not need to be modified
 *  as you fix those bugs or release different versions of your compiler.
 *
 *  To add a new system (hardware and software combination), add another
 *	#elif (defined hardware) && (defined software)
 *		#include hardsoft.bug
 *  section.  'hardsoft.bug' is a name you make up that should indicate
 *  the hardware platform, operating system, and compiler being tested.
 *  If there are different versions of the compiler being tested, the
 *  determination of which bugs exist in which version should be done in
 *  the hardsoft.bug file (not here).  The hardsoft.bug file could include
 *  a separate bug file for each version of the compiler or for each
 *  language (C or C++) being tested.
 *
 *  There are sample*.bug files that you may use as a starting point for
 *  your own use.
 *
 *  The following symbols may be defined by the compiler itself, compiler
 *  command line options, or the 'make' facility.
 *
 *	FPCE_TEST_LVL	  What level of FPCE is being tested.  Default
 *			  is the most current level.
 *
 *	hardware symbolic See myfloat.h for the list.  No default.
 *
 *	software symbolic See myfloat.h for the list.  No default.
 *
 *	FPCE_SAMPLE	  Compiling sample FPCE tests with support functions.
 *			  Default is separate compiles along with linkedit
 *			  for the production tests and combined compile of
 *			  test and support functions for sample tests.
 *
 *	FENV_MISSING	  Compiling FPCE tests with a compiler that has never
 *			  heard of <fenv.h>.  This causes a dummy fenv.h to
 *			  be used that defines all required C99 FPCE items to
 *			  be "reasonable" or nothing via macros.
 *
 *	__cplusplus	  Define for C++, Undef for C testing.
 *			  Compiler may set based upon file extension.
 *
 *	__STDC_IEC_559__  Should be predefined by compiler (Annex F)
 *
 *	WANT_CLEAN	  Used to allow FIX_* and NEED_* macros to be
 *			  defined so that the tests compile and run without
 *			  error. That is the intent.  More test cases may
 *			  need to be tailored with more FIX_* or NEED_*
 *			  macros for that to happen if more implementation
 *			  bugs are found.  Default is do all tests and let
 *			  errors happen.
 *
 *	DEBUG		  Enable debugging printf statements in tests.
 *			  Default is no debugging prints.
 *
 *  The preceding symbols may be defined by the compiler itself, compiler
 *  command line options, or the 'make' facility.
 *
 *
 *  The following symbols may be #define'ed or #undef'ed in the bug file
 *  included by this file.
 *
 *  A place to #define if doing standalone main() C/C++ testing.
 *
 *	STANDALONE_TEST	  Define to be 1 for standalone main() C/C++ testing.
 *			  Undef for integrated C++ member function testing.
 *			  Was Taligent_LEAF for their C++ test environment.
 *
 *  A place to #define if test case output goes to console or file.
 *
 *	REDIRECT	  If you want the test programs to redirect stdout
 *			  to __FILE__ SUFFIX, then define REDIRECT.  If the
 *			  test program driver, e.g., make, can do the
 *			  redirection, then undefine REDIRECT (this is best).
 *
 *  A place to #define non-standard file modes.
 *
 *	*MODE		  If your compiler's file open mode is different
 *			  than the standard 'r', 'w', 'a'; such as needing
 *			  a 't' for text, eg, 'rt', 'wt', 'at'.
 *
 *  A place to #define additional setup declarations or statements needed.
 *
 *	SETUP1		  Any file scope variables or internal functions
 *			  needed.  Declares the file pointer (if needed)
 *			  to redirect stdout. SETUP1 will be used before
 *			  main() and any other functions.
 *
 *	SETUP2		  Any variables or setup code needed by main().
 *			  Includes the code (if needed) to do the redirection
 *			  of stdout. Includes the code (if needed) to clear
 *			  exception flags, disable traps, set rounding, and/or
 *			  set precision control modes. SETUP2 will be used in
 *			  main() after all declarations and before any
 *			  executable statements.
 *
 *	FPU_*		  Startup code needed to change the FPU to match the
 *			  expected FPCE environment.  Most common problem is
 *			  traps are enabled, so need to be disabled.
 *
 *  A place to #define if testing optional features.
 *
 *	TEST_*		  If these symbols are defined, then optional tests
 *			  will be run.  These tests are for things beyond the
 *			  scope of Standard C or FPCE.
 *
 *  A place to #define implementation defined behavior choices.
 *
 *	IMPL_*		  A few places in the FPCE or C99 specifications,
 *			  an implementation is allowed choices on the
 *			  behavior.  These macros allow you to define
 *			  which behavior was chosen.
 *
 *  A place to #define if bypassing implementation limitations (bugs).
 *
 *			  If you discover other bugs not bypassed,
 *			  please feed them back to Fred J. Tydeman.
 *
 *	FIX_*		  Bypass tests of certain features so that the tests
 *			  run clean.  This is a way around compiler bugs.
 *			  In general, this removes code from test cases.
 *			  This idea came from Tom Plum of Plum-Hall.
 *
 *	NEED_*		  If these symbols are defined, then optional code,
 *			  to bypass compiler bugs, will be enabled.
 *			  In general, this adds code to test cases.
 *			  FIX_MISSING_* would be another way to encode
 *			  this macro symbol.
 *
 *	REMAP_*		  Change meaning of LDBL or DBL, FP literals, and
 *			  function names.  Described later.
 *
 *  A place to #define the overrides of the math library test vectors.
 *
 *	t????00?	  Name of file to include that has assignment
 *			  statements to override the argument and expected
 *			  results values of the math library test vectors.
 *			  This is needed if the compiler's decimal to binary
 *			  conversion is so bad that it interferes with the
 *			  testing of the math library.  This assumes that
 *			  you have some function that can correctly convert
 *			  from a decimal string to the internal representation.
 *			  These symbols end up being mapped to OVERRIDE_TV
 *			  in the g*.h files.
 *
 *  A place to #define (if not defined in proper place):
 *
 *    From 1996/02/26 version of FPCE for C99:
 *
 *	__STDC_IEC_559__  Should be predefined by compiler (Annex F)
 *
 *	FLT_EVAL_METHOD	  Should be in <float.h> (5.2.4.2.2)
 *
 *    From 1994/06/30 version of FPCE for Technical Report:
 *
 *	__FPCE__	  Should be predefined by compiler (3.6)
 *
 *	__FPCE_IEEE__	  Should be predefined by compiler (3.6)
 *
 *	_MIN_EVAL_FORMAT  Should be in <float.h> (2.3.1)
 *
 *	_WIDEST_NEED_EVAL Should be in <float.h> (2.3.1)
 *
 *  plus any other #defines needed.
 *
 *  MODIFICATION HISTORY:
 *
 * 1994/09/07 - Create from myfloat.h
 * 1994/10/01 - Add HP PA: C (first pass)
 * 1994/10/01 - Add IBM RS/6000: xlc: IBM C
 * 1994/10/02 - Add IBM RS/6000: xlC: IBM C/C++ in C mode
 * 1994/10/03 - Add IBM RS/6000: xlC: IBM C/C++ in C++ mode
 * 1994/10/04 - Add x86 PC: IBM C (first pass)
 * 1994/10/04 - Add x86 PC: IBM C/C++ (first pass)
 * 1995/01/17 - Add x86 PC: Symantec C/C++ 7.0 in C mode
 * 1995/02/02 - Add WANT_CLEAN
 * 1995/02/19 - Add x86 PC: Borland C/C++ 4 (first pass)
 * 1995/02/19 - Move #define FIX_* to their own includes
 * 1995/02/24 - Separate xlc from xlC.
 * 1995/12/08 - Changed copyright from Taligent to Tydeman.
 * 1996/01/13 - Start adding FIXes for library testing
 * 1996/01/15 - Change FIX_MISSING_* to FIX_FUNCS_*
 * 1996/02/24 - Add several symbols for dec2bin conversion bugs
 * 1996/03/14 - Allow for Signaling NaNs to be an extension.
 * 1996/05/27 - Add DO_106_113 so can lint/compile other hardware.
 * 1996/06/03 - Add GNU C/C++ 2.5.7 + emx 0.8h for OS/2 in C mode.
 * 1996/07/15 - Add FPCE_TEST_LVL.
 * 1996/07/15 - Move #pragmas to here and myfloat.h; made optional.
 * 1996/07/15 - Add FP_H for either <math.h> or <fp.h>.
 * 1996/07/15 - Move #undef/#define of REDIRECT from myfloat.h
 * 1996/07/15 - Upgrade to C9X proposal WG14/N546.
 * 1996/07/21 - Added _CRAYIEEE for Cray Research.
 * 1996/08/19 - Changed *_NAN_COMPARE_* to *_NAN_COMP_*.
 * 1996/08/21 - Added INTTYPES_H to map to <inttypes.h>.
 * 1996/11/09 - Update acknowledge words as per Taligent VP & CTO.
 * 1996/11/12 - Added TEST_* concept of optional tests.
 * 1996/11/13 - Added proposed new form of Standard C pragmas.
 * 1996/11/15 - Hide each compiler's bugs in its own include file.
 * 1996/11/15 - Add NEED_EXIT_SYMS.
 * 1996/11/16 - Add FIX_FUNC_* and FIX_FUNCS_*.
 * 1996/11/17 - Moved definitions of SUFFIX, MODE from myfloat.h
 * 1996/11/17 - Moved definitions of NEED_FP_H_4_* from myfloat.h
 * 1996/11/17 - Moved definitions of SETUP1, SETUP2 from myfloat.h
 * 1996/11/17 - Add FPU_* to SETUP2.
 * 1996/11/19 - Add get prototypes for startup FPU fixup code.
 * 1996/11/21 - Moved definitions of REMAP_* from myfloat.h
 * 1997/01/16 - Improve documentation / configuration.
 * 1997/01/17 - Remove #undef FPCE_SAMPLE and #define WANT_CLEAN.
 * 1997/01/21 - __MyDefs_H -> MYDEFS_H_ (out of C's namespace).
 * 1997/01/21 - Added TEST_WIDE_*.
 * 1997/01/26 - <fenv.h> -> FENV_H (so can use one in local directory).
 * 1997/01/31 - *_MAX reserved by POSIX.2 => Rename local macro symbols.
 * 1997/02/23 - Added TG_MATH_H for <tgmath.h> -- Type Generic Math Functions.
 * 1997/09/05 - Added IMPL_* description and first macro.
 * 1997/09/05 - FIX_INEXACT_feraiseexcept -> IMPL_OVERUNDER_ALSO_INEXACT.
 * 1997/09/18 - 97/06/27 meeting changes.
 * 1997/10/03 - IMPL_INEXACT_*.
 * 1997/10/04 - FIX_DEN_UNDER -> IMPL_UNDERFLOW_DEN_LOSS.
 * 1998/04/07 - Add FIX_NORMAL_RETURN_hypot.
 * 1998/06/06 - Add OVERRIDE_TV and v????00? symbols.
 * 1998/07/10 - Move location of PC-Lint override files.
 * 1998/07/11 - Add FIX_MATH_PI (due to gcc 2.7.2 on Linux).
 * 1998/07/11 - Add FIX_FE_FLAGS.
 * 1998/07/20 - Add FIX_FENV_FUNCTIONS.
 * 1998/07/21 - Add FENV_MISSING as a "hardware/software" symbolic.
 * 1998/07/22 - Add FIX_RND_fesetround and FIX_FE_RND.
 * 1998/07/22 - Add FIX_NAN_FLOAT.
 * 1998/07/24 - Add FIX_CHANGE_STDC_IEC_559.
 * 1998/07/24 - Add _MSC_VER for Microsoft C/C++.
 * 1998/07/28 - Split BIGGER_THAN_FPMAX into constants and expressions.
 * 1998/07/28 - Split SMALLER_THAN_FPMAX into constants and expressions.
 * 1998/07/30 - Add FIX_NEG_FLIP_SIGN.
 * 1998/08/04 - Add FIX_RANDOM_SIGNED_ZERO.
 * 1998/08/05 - Add FIX_SCAN/PRINT_INF/NAN.
 * 1998/08/05 - Add IMPL_GETEXCEPT_TOO_MANY.
 * 1998/08/07 - Add FIX_TRI_OP_OF_FP.
 * 1998/08/08 - Add FIX_NOISY_HUGE_VAL.
 * 1998/09/03 - Add __DCC__ for Diab Data.
 * 1998/09/10 - Add FIX_NAN_IN_ARRAY and FIX_INF_IN_ARRAY.
 * 1998/09/10 - Add IMPL_mNAN_IS_POS.
 * 1998/09/13 - Add FIX_STATIC_VECTORS.
 * 1998/09/30 - Add IMPL_IGNORE_EXTRA_DIGITS.
 * 1998/10/23 - Add FIX_strto_EQ_scanf, FIX_scanf_ROUNDS.
 * 1998/10/25 - Add FIX_DEC2BIN_ZERO, _LARGE, _INF.
 * 1998/11/09 - Add __MWERKS__ for MetroWerks CodeWarrior.
 * 1998/11/12 - Add FIX_BY_0.
 * 1998/11/15 - Add FIX_BAD_NAN_COMP_FLAG_VARCON.
 * 1998/11/15 - Add FIX_OPT_DIV_TO_MUL.
 * 1998/11/15 - Add FIX_OPT_0_MINUS_Y_TO_mY.
 * 1998/11/15 - Add FIX_STRTO_INF, FIX_STRTO_NAN.
 * 1998/11/18 - Add FIX_CONST_VAR_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_0_OVER_0_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_1_OVER_0_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_MAX_TIMES_MAX_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_MIN_TIMES_MIN_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_1_OVER_3_EXP_AT_TRANS.
 * 1998/12/12 - Add isinf().
 * 1998/12/12 - Bump FPCE_TEST_LVL to 19971024uL.
 * 1998/12/18 - Add FIX_LINK_NAME_SPACE.  Add signbit().
 * 1998/12/19 - Bump FPCE_TEST_LVL to 19980626uL.
 * 1999/02/23 - Add FIX_1_OVER_mINF.
 * 1999/03/03 - Add LARGE_ARG_* and ULP_LARGE_ARG_* for 3 trig functions.
 * 1999/03/18 - Add __TANDEM for Compaq-Tandem.
 * 1999/03/29 - Bump FPCE_TEST_LVL to 19990202uL.
 * 1999/03/30 - Add *_SCAN2BIN_* based upon *_DEC2BIN_*; runtime vs compile time.
 * 1999/04/02 - Remove sample.bug setup from here; replaced with include yourfile.bug.
 * 1999/04/09 - Add FIX_WRONG_*_DIG.
 * 1999/04/17 - nextafterx -> nexttoward.
 * 1999/04/30 - FIX ACCEPT_BAD_BIT_FIELD_SIZE -> IMPL_...
 * 1999/04/30 - FIX ACCEPT_BAD_ENUM_VAL -> IMPL_...
 * 1999/04/30 - FIX ACCEPT_BAD_ARRAY_BOUND -> IMPL_...
 * 1999/04/30 - FIX ACCEPT_BAD_CASE_VAL -> IMPL_...
 * 1999/04/30 - FIX EXTRA_DIGITS -> IMPL_IGNORE_EXTRA_DIGITS
 * 1999/05/03 - Add __WATCOMC__ for Watcom C/C++.
 * 1999/05/04 - Add FIX_INIT_SHORT_WITH_FP.
 * 1999/05/04 - Add FIX_INIT_CHAR_WITH_FP.
 * 1999/05/05 - Add __IBMC__ for IBM VisualAge for C/C++.
 * 1999/05/06 - Add FIX_EVAL_CONST_AT_LEAST_MIN.
 * 1999/05/06 - Add FIX_ULLI_FROM_POS.
 * 1999/05/06 - Add FIX_FMA_NEG_ZERO.
 * 1999/05/06 - Add FIX_INF2_type_SET_INVALID.
 * 1999/05/09 - Add IMPL_COMP_FE_DFL_ENV.
 * 1999/05/10 - Add IMPL_OK_fesetprec.
 * 1999/05/12 - FIX LDBL_GT_DBL -> IMPL_LDBL_EQ_DBL
 * 1999/05/13 - Add FIX_OPT_0_DIV_Y_TO_0.
 * 1999/05/17 - Add FIX_NAN_GOT_*.
 * 1999/05/20 - Add FIX_ZERO_GOT_*.
 * 1999/05/20 - Add FIX_INF_GOT_*.
 * 1999/05/27 - Add FIX_PRINT_mZERO, FIX_SCAN_mZERO.
 * 1999/05/29 - Add FIX_HUGE_VAL*_IS_INF.
 * 1999/06/05 - Add FIX_BIN2DEC2BIN_TWICE.
 * 1999/06/05 - Add *_BIN2DEC2BIN_ULPS (* = LD, D, and F).
 * 1999/06/08 - Add FIX_QUOT_remquo.
 * 1999/06/08 - Add FIX_MODES_*.
 * 1999/06/10 - Add more FIX_WRONG_*.
 * 1999/06/10 - Add FIX_CLOSE_*.
 * 1999/07/06 - Add FIX_PRINT_JUNK.
 * 1999/07/08 - Add FIX_OPT_INF_SUB_INF_TO_0.
 * 1999/07/09 - Add FIX_2LARGE_IS_FINITE.
 * 1999/07/10 - Add FIX_VERY_BIG_EXPONENTS.
 * 1999/07/12 - Add FIX_OPT_0_TIMES_m1_TO_p0, FIX_OPT_0_DIV_m1_TO_p0.
 * 1999/07/18 - Add FIX_ULL_2_DBL.
 * 1999/07/18 - Add FIX_LL_PP_CONSTANTS.
 * 1999/07/19 - Add LONGONG and ULONGLONG (you can define in your *.bug file).
 * 1999/07/19 - Add SLL_C and ULL_C (you can define in your *.bug file).
 * 1999/07/20 - Add FIX_POSITIVE_LLONG_MIN.
 * 1999/07/20 - Add FIX_VALID_FP_2_ULLONG.
 * 1999/08/29 - Add many FIX_PRINTF_* symbols.
 * 1999/09/19 - Add FIX_strto_RND_THEN_NEG.
 * 1999/11/02 - FIX_FUNCS_nan_0_BY_0 -> IMPL_INCONSISTENT_nan
 * 1999/11/02 - Add MODE, A_MODE, R_MODE, W_MODE.
 * 1999/12/01 - Add IMPL_MAX_*_RADIX, FIX_SMALL_PRINTF_ENV_LIMIT.
 * 2000/03/01 - Make classification explicit in each file.
 * 2000/03/01 - Remove confidential so can post to public ftp site.
 * 2000/03/14 - Add IBM S/390 MVS symbols.
 * 2000/06/16 - Add IMPL_(UCE/SCE/USE/SSE/UIE/SIE)_IS_(UCHAR/SCHAR/USHORT/SSHORT/UINT/SINT).
 * 2000/06/16 - Del FIX_ENUM_IS_INT; replaced by above line.
 * 2000/07/24 - Add FIX_NAMESPACE_STD.
 * 2000/12/03 - Add FIX_CLASS_UNNORMALS, FIX_CLASS_MIN_NORMALS.
 * 2000/12/03 - Add FIX_CLASS_PSEUDO_INF, FIX_CLASS_PSEUDO_NAN.
 * 2000/12/03 - Add FIX_HEX_FP_PRAGMA, FIX_FE_MACROS.
 * 2000/12/10 - Add Sun Sparc/x86/ia64 to elif chain.
 * 2001/01/16 - Add another HP to elif chain.
 * 2001/03/06 - Add IMPL_MZERO_EXP.
 * 2001/03/07 - Add IMPL_ODD_UP, IMPL_EVEN_UP.
 * 2001/03/07 - Add FIX_PRINTF_SHARP_RND.
 * 2001/03/11 - Redo location of PC-Lint.
 * 2001/03/14 - Add FIX_PRINTF_e_RND.
 * 2001/06/23 - Add x86 PC: Digital Mars C/C++ 8 in C mode.
 * 2001/06/23 - Add FIX_FP_IN_MATH_H.
 * 2001/06/24 - Add FIX_ARG_GOT_*.
 * 2001/06/26 - Del #undef FIX_SYM_* after #include user.bug file.
 * 2001/12/27 - Mod FPCE_TEST_LVL to C99 TC1 date.
 * 2001/12/29 - Add (void) to some uses of feclearexcept in t2*.fjt.
 * 2002/01/07 - Add FIX_USABLE_FE_DFL_ENV to here (added to code in '96).
 * 2002/01/13 - Add FIX_CONST_IN_TYPEDEF_STRUCT.
 * 2002/01/15 - Add FIX_HEX_PI.
 * 2002/01/15 - Add FIX_MYFLOAT_*.
 * 2002/01/17 - Add FIX_MINUS_EQUAL, FIX_MINUS_MINUS.
 * 2002/01/23 - Add FIX_DIG_LET_PP_NUMBER.
 * 2002/01/24 - Add FIX_ULI_FROM_FLT, FIX_ULLI_FROM_FLT.
 * 2002/01/24 - Add FIX_ENUM_TO_ANDAND, FIX_ENUM_TO_OROR.
 * 2002/01/28 - Add FIX_type_FROM_FP, where type is one of ULI, SLI, UI, SI, ...
 * 2002/01/28 - Add FIX_ULLI_op_EQ_FP, where op is PLUS, MINUS, STAR, DIV.
 * 2002/01/28 - Add FIX_SLLI_op_EQ_FP, where op is PLUS, MINUS, STAR, DIV.
 * 2002/01/29 - FIX_MINUS_EQUAL -> FIX_FP_MINUS_EQ_FP.
 * 2002/01/29 - FIX_MINUS_MINUS -> FIX_FP_MINUS_MINUS.
 * 2002/01/29 - FIX_ULL_2_DBL -> FIX_DBL_FROM_ULLI, and FIX_FP_FROM_ULLI.
 * 2002/01/29 - Add FIX_LDBL_MINUS_EQ_FP, FIX_LDBL_MINUS_EQ_INT.
 * 2002/02/10 - Add LCC to elif chain.
 * 2002/04/24 - Add FIX_FP_PLUS_PLUS.
 * 2002/05/07 - Add FIX_DEC2BIN_NAN.
 * 2002/05/21 - Add filename to SETUP 1.
 * 2002/05/21 - Setup for Perennial.
 * 2002/05/29 - Add FIX_*_RANDOM_INVALID.
 * 2002/06/26 - Add FIX_SCANF_LDBL.
 * 2002/11/26 - Add FIX_SCAN_F and FIX_PRINT_F.
 * 2002/11/26 - Add FIX_SCAN_aA and FIX_PRINT_aA.
 * 2002/12/01 - Add FIX_PRINTF_aA_HAS_EXPONENT.
 * 2002/12/01 - Add FIX_PRINTF_aA_HEX_DOT.
 * 2002/12/07 - Add IMPL_RAISE_WITH_IMPLIED_INEXACT.
 * 2002/12/12 - Add FIX_PRINTF_aA_HAS_EXP_SIGN.
 * 2003/01/16 - Add WG14/N782 to list of FPCE_TEST_LVL changes.
 * 2003/01/16 - Add FIX_AGG_INIT_IS_STATIC.
 * 2003/01/23 - Add Intel's ICC to elif chain.
 * 2003/01/26 - Add FIX_BAD_HEX_SMALL.
 * 2003/01/29 - Add another FIX_NAN_GOT_*.
 * 2003/01/29 - Add another FIX_INF_GOT_*.
 * 2003/02/03 - Add FIX_SIZEOF_BIT_FIELD.
 * 2003/02/05 - Add another FIX_NORMAL_RETURN_*.
 * 2003/02/05 - Add FIX_OVERLOAD_* (where * is each math function).
 * 2003/02/07 - Add FIX_PP_EXP.
 * 2003/02/07 - Add FIX_INT_ANDAND_FLT.
 * 2003/02/07 - Add FIX_BROKEN_PP.
 * 2003/02/07 - Add FIX_BAD_COMP_VAR_CON.
 * 2003/02/07 - Add FIX_BAD_COMP_VAR_VAR.
 * 2003/02/07 - Add FIX_BAD_COMP_CON_VAR.
 * 2003/02/08 - Add FIX_SIZEOF_* (* is one of classification macros).
 * 2003/02/09 - Add FIX_CLASS_SIGNAL_NAN.
 * 2003/02/15 - Add FIX_0F_OVER_0F_IS_NAN.
 * 2003/02/15 - Add FIX_0D_OVER_0D_IS_NAN.
 * 2003/02/16 - Add Comeau Computing and Edison Design Group to elif chain.
 * 2003/02/17 - Add FIX_CLOSE_MAXm1_LDBL.
 * 2003/02/19 - Add FIX_IMPLICIT_FLUSH.
 * 2003/02/27 - Add FIX_OPT_COMMON_FACTOR.
 * 2003/03/01 - Add FIX_LONGLONG_WITH_FP_CONSTS.
 * 2003/03/01 - Add FIX_MATH_FUNC_OF_INTEGER.
 * 2003/03/08 - Add FIX_printf_ROUNDS.
 * 2003/03/10 - Add IMPL_MAX_E_DIGITS.
 * 2003/03/23 - Add FIX_MINUS_DBL_signbit.
 * 2003/03/23 - Add FIX_MINUS_LDBL_signbit.
 * 2003/04/17 - Add FIX_BIN2DEC_LARGE.
 * 2003/05/11 - FIX_NEG_NAN -> IMPL_pNAN_IS_NEG.
 * 2003/05/11 - FIX_mNAN_IS_POS -> IMPL_mNAN_IS_POS.
 * 2003/05/11 - Add IMPL_mNAN_EQ_pNAN.
 * 2003/05/11 - Add IMPL_BAD_ROUNDTRIP_OF_NAN.
 * 2003/06/24 - Add description of ULP_*_sum.
 * 2003/07/01 - Fix several spelling errors.
 * 2003/07/10 - Add FIX_INVALID_OCTAL.
 * 2003/07/11 - Add FIX_FPZERO_OROR_VAR.
 * 2003/07/11 - Add FIX_INT_PLUS_EQ_FP.
 * 2003/07/11 - Add FIX_INT_MINUS_EQ_FP.
 * 2003/07/11 - Add FIX_INT_STAR_EQ_FP.
 * 2003/07/11 - Add FIX_INT_DIV_EQ_FP.
 * 2003/07/11 - Add FIX_signbit_NON_VAR.
 * 2003/07/16 - Add FIX_SEMIBROKEN_PP.
 * 2003/08/08 - Only do pragma fp_wide_* if user does TEST_WIDE_*.
 * 2003/08/21 - Mention feholdexcept() as another way to disable traps.
 * 2003/08/30 - Redo FIX_*_IS_A_MACRO to use true case of name.
 * 2003/11/17 - Add FIX_SCAN_LOOKAHEAD, FIX_STRTO_LOOKAHEAD.
 * 2003/11/17 - Add FIX_SCAN_PERCENT_n.
 * 2003/12/01 - Add ULP_strto*.
 * 2003/12/01 - Add FIX_BAD_EXPONENT, FIX_BAD_BIN_EXPONENT.
 * 2003/12/01 - Add FIX_BAD_0X, FIX_BAD_INF, FIX_BAD_NAN.
 * 2003/12/01 - Add FIX_STRTO_ZERO_PTR_DIFF, FIX_BAD_SIGNS.
 * 2003/12/02 - Add FIX_SCAN_JUNK, FIX_SCAN_NODIGITS.
 * 2003/12/02 - Add FIX_C99_freopen, FIX_TEST_fscanf, FIX_TEST_ftell.
 * 2003/12/03 - Add FIX_SCAN_NODOT_E, FIX_SCANF_FLT.
 * 2003/12/03 - Add FIX_SCAN_FP_WS.
 * 2003/12/28 - Add FIX_STDBOOL.
 * 2003/12/30 - Add FIX_BOOL.
 * 2003/12/30 - Add FIX_BOOL, FIX_TRUE_BOOL.
 * 2003/12/30 - Add FIX_aA_LEADING_ZEROS.
 * 2003/12/30 - Add FIX_PRINTF_RC.
 * 2004/01/02 - Add FIX_IMPLICIT_CHAR_PTR.
 * 2004/01/03 - Add FIX_SCAN_EOF.
 * 2004/01/03 - Add FIX_INT_MINUS_EQ_FPCONST.
 * 2004/01/04 - Add FIX_ASSIGN_TO_BOOL.
 * 2004/01/04 - Add FIX_OP_BOOL_BIT_FIELD.
 * 2004/01/05 - Add FIX_BIN2HEX2BIN_TWICE.
 * 2004/01/06 - Add *_BIN2HEX_A_ULPS.
 * 2004/01/06 - Add FIX_BAD_BITFIELD_PROMOTION.
 * 2004/01/06 - Add FIX_BAD_BOOLBITFIELD_PROMOTION.
 * 2004/01/06 - Add FIX_QUIET_ASSIGN_TO_BOOL.
 * 2004/01/06 - Add FIX_BOOL_FROM_PTR.
 * 2004/01/06 - Add FIX_BOOL_FROM_FLT.
 * 2004/01/06 - Add FIX_BOOL_FROM_DBL.
 * 2004/01/06 - Add FIX_BOOL_FROM_LDBL.
 * 2004/01/06 - Add FIX_EQUALEQUAL_BOOL_PLUSEQUAL.
 * 2004/01/07 - Change FIX_INTTYPES -> FIX_INTTYPES_H.
 * 2004/01/07 - Change FIX_ISO646 -> FIX_ISO646_H.
 * 2004/01/07 - Change FIX_LOCALE_HEADER -> FIX_LOCALE_H.
 * 2004/01/07 - Change FIX_STDBOOL -> FIX_STDBOOL_H.
 * 2004/01/07 - Add FIX_COMPLEX_H, STDINT_H, WCHAR_H, WCTYPE_H.
 * 2004/01/07 - Add FIX_REG_VARS.
 * 2004/01/09 - Add FIX_BIG_BITFIELD.
 * 2004/01/09 - Add FIX_BAD_INTEGER_PROMOTION.
 * 2004/01/10 - Add IMPL_MIX_BOOL_AND_INT.
 * 2004/01/10 - Add FIX_ZERO_WIDTH_BOOL.
 * 2004/01/10 - Add FIX_OFFSETOF.
 * 2004/01/11 - Add FIX_ACC_BAD_BOOL_BITFIELD_WIDTH.
 * 2004/01/11 - Add FIX_ACC_BAD_BOOL_BITFIELD_DECL.
 * 2004/01/14 - Add FIX_BOOL_FROM_FRACTION.
 * 2004/01/14 - Add FIX_BOOL_BITFIELD.
 * 2004/01/24 - Add FIX_BAD_RET_fesetround.
 * 2004/01/24 - Add FIX_BAD_RET_feupdateenv.
 * 2004/01/28 - Add FIX_PRINT_aA_SMALL_PREC.
 * 2004/01/29 - FIX_PRINTF_p_RND -> FIX_PRINTF_aA_RND
 * 2004/04/23 - Add uses of CLEAR_ALL and RAISE_ALL.
 * 2004/05/01 - Add IMPL_FLT_EVAL_CONST, IMPL_FLT_EVAL_CONST_EXP, IMPL_FLT_EVAL_OP
 * 2004/05/08 - Add IMPL_FLT_EVAL_STRTO.
 * 2004/05/10 - Add FIX_WRONG_FLT_EPS.
 * 2004/05/27 - Add FIX_OPT_MAX_x_MAX, FIX_OPT_MIN_x_MIN.
 * 2004/05/28 - Add FIX_FLAG_hypot_EVENODD.
 * 2004/05/28 - Add IMPL_FLT_EVAL_OP_ANON.
 * 2004/05/30 - Add FIX_PLUS_EQ_FP_FUNC.
 * 2004/05/30 - Add FIX_FP_PTR_PLUS_EQ_BOOL.
 * 2004/05/30 - Add FIX_EQUALEQUAL_FP_PLUSEQUAL.
 * 2004/05/30 - Add FIX_EQUALEQUAL_FP_MINUSEQUAL.
 * 2004/05/30 - Add FIX_EQUALEQUAL_FP_STAREQUAL.
 * 2004/05/30 - Add FIX_EQUALEQUAL_FP_DIVEQUAL.
 * 2004/06/03 - Add IMPL_MAX_SCAN_BEFORE_RADIX, IMPL_MAX_SCAN_AFTER_RADIX.
 * 2004/06/03 - Add IMPL_MAX_PRINT_S.
 * 2004/06/11 - Add FIX_VLA, FIX_VLA_CONST_EXP, FIX_TRUE_VLA.
 * 2004/06/12 - Add FIX_TYPEDEF_VLA_ONCE.
 * 2004/06/13 - Add FIX_ACC_*VLA*.
 * 2004/06/13 - Add FIX_COMPOUND_LIT.
 * 2004/07/11 - Add FIX_FLEX_ARRAY.
 * 2004/07/13 - Add FIX_OFFSET_FLEX.
 * 2004/07/13 - Add FIX_ACC_*FLEX_ARRAY*.
 * 2004/07/17 - ULP_strtold -> LD_STRTOBIN_ULPS.
 * 2004/07/17 - ULP_strtod -> D_STRTOBIN_ULPS.
 * 2004/07/17 - ULP_strtof -> F_STRTOBIN_ULPS.
 * 2004/07/19 - Add IMPL_FLT_EVAL_INT2FLT.
 * 2004/07/24 - Add IMPL_pNAN_IS_MIXED, IMPL_mNAN_IS_MIXED.
 * 2004/07/24 - Add FIX_BAD_NAN_EQEQ_FLAG.
 * 2004/07/30 - Add FIX_NEGATIVE_LLONG_MAX.
 * 2004/08/02 - Add __LMPCC__ to elif chain.
 * 2004/08/05 - Add FIX_ZERO_HEX.
 * 2004/08/07 - Add FIX_pEXPf_HEX.
 * 2004/08/07 - Reformat #if's.
 * 2004/08/26 - Add FIX_TOO_HARD_TOO_COMPILE.
 * 2004/09/02 - Add TEST_RND_UP_DECADE.
 * 2004/11/28 - Add FIX_CONCAT_WIDE_AND_NARROW.
 * 2004/11/28 - Add many FIX_WPRINT_*.
 * 2004/11/28 - Add many FIX_WSCAN_*.
 * 2005/01/07 - Add Apple Mac OS X on PowerPC.
 * 2005/01/10 - Add FIX_SYM_*_ENUM.
 * 2005/02/05 - Add list of DRs in TC2 that affect math; bump FPCE_TEST_LVL.
 * 2005/02/13 - Add words about IMPL_INF_FLAGS to FIX_QUIET_INF.
 * 2005/02/24 - Add IMPL_aA_PREC, IMPL_LaA_PREC.
 * 2005/02/25 - Add FIX_[W]PRINTF_NEGATIVE_RC.
 * 2005/02/27 - Add IMPL_aA_BITS, IMPL_LaA_BITS.
 * 2005/03/22 - Add FIX_*PRINTF_aA_HAS_B*_HEX_DIG.
 * 2005/04/07 - Add FIX_NEED_FINAL_NEW_LINE.
 * 2005/05/06 - Add FIX_FILE_SCOPE_FP_INIT, FIX_FP_EXP_IN_INIT.
 * 2005/05/06 - Add FIX_EVAL_CONST_EXP_AT_LEAST_MIN.
 * 2005/05/08 - Add fenvon.h and fpconoff.h.
 * 2005/05/22 - Add FIX_INLINE, FIX_BAD_INLINE_CALL.
 * 2005/05/23 - Add FIX_IGNORE_CAST.
 * 2006/03/16 - Add IEEE-754R Decimal FP related items.
 * 2006/03/20 - Indent #if's.
 * 2006/03/23 - Add FMT_*_SCAN.
 * 2006/03/26 - Add FIX_SCAN_EARLY_EOF.
 * 2006/03/30 - Rename WANT DEC FP macro.
 * 2006/04/07 - Rename FIX_*_RND to IMPL_NO_*_RND.
 * 2006/04/08 - Add FIX_SCAN_LATE_EOF.
 * 2006/05/17 - Move NEED_EXIT_SYMS to myfloat.h (after include std headers).
 * 2006/07/11 - Add FIX_BOTTOM_N_BITS, FIX_BOTTOM_N_DIGS.
 * 2006/07/15 - Add many more IMPL_* symbols.
 * 2006/08/17 - Add Decimal FP complex and imaginary (long term planning).
 * 2006/09/29 - Add IMPL_fopen_wb, IMPL_freopen_wb, and IMPL_freopen_rb.
 * 2007/06/13 - Add ARM.
 * 2008/02/02 - Add many symbols due new code in last 9 months.
 * 2008/02/11 - Change RND_*d64 to RND10_*.
 * 2008/06/18 - Add FIX_CONST_SCALAR_PARM, FIX_CONST_REGISTER.
 * 2008/06/20 - Indent #if's.
 * 2008/07/14 - Shorten marco symbols to less than 32 chars.
 * 2008/08/11 - Add MIN_FLAGS and MIN_FLAGS_OPT.
 * 2008/08/11 - Add IMPL_FLT_EVAL_OP_CONTRACT.
 * 2008/08/24 - Move FP_F(), FP_D(), FP_LD(), FP_F10(), FP_D10(), FP_LD10() from flt.
 * 2008/08/25 - Add IMPL_SPURIOUS_ERRNO.
 * 2008/08/25 - Add IMPL_COHORT_*.
 * 2008/08/26 - Change IMPL_nan*_INCONSISTENT.
 * 2008/08/27 - Add RX, RXm1, RXp1 since needed so many places.
 * 2008/09/10 - Add IMPL_SAME_NAN, IMPL_SAME_2NAN.
 * 2008/09/17 - FIX_* to IMPL_* for real-floating.
 * 2008/09/26 - Add many symbols added for decimal FP testing.
 * 2008/10/04 - Add FIX_SLL_FROM_PTR, FIX_ULL_FROM_PTR.
 * 2008/10/07 - Add FIX_PTR_FROM_SLL, FIX_PTR_FROM_ULL.
 * 2008/11/06 - Add FIX_DEC2DFP_ZERO, *10_DFP2BFP_ULPS.
 * 2008/11/19 - Add FIX_DEC2BIN_SIGN and related symbols.
 * 2008/12/15 - Add DFP_TEST_LVL.
 * 2009/01/14 - Add FIX_PRAGMA_DBL_CONST_DFP64 and related.
 * 2009/01/16 - Fix FP_D() to work with #pragma STDC FLOAT_CONST_DECIMAL64 ON.
 * 2009/02/07 - Add IMPL_FLT_EVAL_RET, IMPL_FLT_EVAL_IN_RET.
 * 2009/04/02 - Add Rf, Rd, Rld.
 * 2009/04/26 - _EVAL_FLOAT -> _EVAL_FLT.
 * 2009/04/26 - _EVAL10_FLOAT -> _EVAL10_F10.
 * 2009/06/19 - _WRONG_F10_ ->  _WRONG_DEC32_; same for _CLOSE_
 * 2009/06/19 - _WRONG_D10_ ->  _WRONG_DEC64_; same for _CLOSE_
 * 2009/06/19 - _WRONG_LD10_ ->  _WRONG_DEC128_; same for _CLOSE_
 * 2009/06/23 - Changed definition of BOOL_CAST().
 * 2009/08/14 - FIX BAD TRANS TIME PREC -> FIX_EVAL_CONST_EXP_AT_LEAST_MIN.
 * 2009/08/20 - Add FIX_DBL_PLUS_DBL_TIMES_DBL.
 * 2009/08/20 - Major reorganization of symbols; try to group similar together.
 * 2009/08/20 - Add FIX_UNKNOWN_LCC.
 * 2009/08/26 - Add FIX_NEED_PARENS_*.
 * 2009/10/08 - RANDOM CONTRACT to IMPL from FIX.
 * 2009/12/11 - Add FIX_BAD_OPT.
 * 2010/02/14 - Add FIX_DUP_TYPE_QUAL, FIX_CLASS_SPEC, FIX_LONG_LONG.
 * 2010/02/16 - Add FIX_DECL_IN_FOR.
 * 2010/03/20 - fpclassify_DEN -> DEN_fpclassify.
 * 2010/03/20 - fpclassify_EXP -> EXP_fpclassify.
 * 2010/03/20 - fpclassify_mZERO -> mZERO_fpclassify.
 * 2010/06/21 - After (defined __STDC WANT DEC FP__), add && (defined __STDC DEC FP__)
 * 2010/06/25 - Add FIX_DOT_ZEROS_DIG and FIX_E_ZEROS_DIG.
 * 2010/07/10 - Add IMPL_SSE and IMPL_ST_LD.
 * 2010/07/21 - IMPL_SAME_2NAN->IMPL_SIGN_2NAN; FIX_SAME_2NAN->IMPL_DIFF_2NAN.
 * 2010/07/21 - IMPL_SAME_NAN->IMPL_SIGN_NAN; FIX_SAME_NAN->IMPL_DIFF_NAN.
 * 2010/07/26 - Add e037*, e437*, e637*.
 * 2010/07/27 - Add __x86_64__.
 * 2010/08/29 - Add FIX_STATIC_0_BY_0, FIX_STATIC_1_BY_0.
 * 2010/09/27 - Add FIX_LONG_PP_FP_NUM.
 * 2010/10/21 - Add IMPL_SUPPRESS_OVER_*.
 * 2011/01/01 - Add many I/O related DFP symbols.
 * 2011/01/18 - Add ASSIGN2().
 * 2011/02/19 - _FROM_LONG -> _FROM_SLI.
 * 2011/03/03 - FIX_..._OF_FLOATS -> FIX_..._OF_FP.
 * 2011/04/22 - Add prgnam[] to SETUP1().
 * 2011/06/06 - Add TEST_*_SHIFT_LARGE.
 * 2011/07/18 - Start adding C1X related items (e.g., _Generic).
 * 2012/01/26 - More complete list of C11 related items.
 * 2012/03/29 - Add QUAD_LDBL related items.
 * 2012/04/11 - Add QUAD_DBL related items.
 * 2012/04/12 - C FP types to FLT, DBL, LDBL.
 * 2012/07/15 - Add IMPL_STRUCT_NE_ARRAY_ALIGN.
 * 2012/12/19 - Add FIX_NEGATIVE_cbrt, FIX_TIME_H.
 * 2013/02/05 - Add use of CMPLX*() macros.
 * 2013/05/12 - Fix spelling of weird.
 * 2013/06/13 - FIX_..._SNAN -> IMPL_..._SNAN.
 * 2013/06/26 - _opEQ_ -> _op_EQ_.
 * 2013/06/27 - Add FIX_CLASS_MACROS and FIX_REL_MACROS.
 * 2013/10/08 - Add new WANT macro.
 * 2013/10/17 - FIX_WEIRD_NON_DIRECTIVE -> TEST_WEIRD_NON_DIRECTIVE.
 * 2013/10/26 - FIX_QUIET_INF -> FIX_NOISY_INF.
 * 2013/10/29 - Add AUTO (due to C++).
 * 2013/10/29 - auto -> AUTO.
 * 2013/10/31 - Add code for C++ complex.
 * 2014/05/25 - Del define of COMPLEX_H.  Remove include of COMPLEX_H.
 * 2014/05/27 - Add back in namespace std for C++ at end.
 * 2014/06/01 - COMPLEX FROM -> CMPLX FROM.
 * 2014/06/01 - FROM COMPLEX -> FROM CMPLX .
 * 2014/06/04 - COMPLEX OP -> CMPLX OP.
 * 2014/06/12 - Add TRIGGER for nan_q().
 * 2014/07/24 - FLUSH_DENORM -> FLUSH_RUN_DEN_BOTH.
 * 2014/10/11 - Add FIX_FLAG10_nan for TRIGGER.
 * 2014/12/24 - Move SIZE() to here from vpatch.h.
 * 2014/12/28 - FIX_SLOPPY_MAX_LDBL -> FIX_SLOPPY_SUP_LDBL.
 * 2015/03/13 - Add IMPL_TOKEN_LINE, IMPL_MAC_INVOK_LINE.
 * 2015/03/15 - Add FIX_MAC_ARG_LINE and others; PreProc bugs.
 * 2015/07/04 - Redo PowerPC __PPC__ on AIX.
 * 2015/08/31 - Add FIX_NAN_EQUALITY_OP, FIX_NAN_TRI_OP, FIX_NAN_IF.
 * 2015/11/26 - Add FIX_INVALID_ICE.
 * 2016/01/09 - Add FIX_PP_*_OP.
 * 2016/09/01 - Add TEST_FUNC_WITH_GENERIC.
 * 2016/12/04 - Add PRTDEBUG.
 * 2017/03/19 - Add FIX_LONG_SYMBOLS_*.
 * 2017/09/17 - Add many symbols for t?06*.
 * 2018/02/09 - Add FIX_FLAG_* for classification macros.
 * 2018/06/18 - Add FIX_ATOMIC, FIX_RESTRICT, FIX_ATOMIC_RESTRICT.
 * 2018/11/21 - FIX_FLAGS_* -> FIX_FLAG_*.
 * 2019/01/09 - Add FIX_ZERO_GOT_*.
 * 2019/01/19 - Move SIZ_* from myfloat.h to mydefs.h (so can be used in your *.flt).
 * 2020/02/20 - Add FIX_*_snprintf symbols.
 * 2020/04/04 - CONST_REGISTER -> REGISTER_CONST.
 * 2020/04/15 - Add FIX_PRAGMA_FENV_ROUND.
 * 2020/04/21 - Add RESTRICT and VOLATILE.
 * 2020/07/22 - Change some FIX_OFFSETOF_* -> TEST_OFFSETOF_*.
 * 2020/10/16 - Add more WG14 Nnnnn papers and update FPCE_TEST_LVL.
 * 2020/11/09 - _ _ _STDC_ -> _STDC_.
 * 2020/11/09 - Some _ _STDC_ -> LMS_.
 *
 ***********************************************************************/

#ifndef MYDEFS_H_			/* not in C's namespace */
  #define MYDEFS_H_

/*
 * The Floating-Point C Extensions (FPCE) has evolved over the years.
 * First it was proposals to Numerical C Extensions Group (NCEG), then
 * to a subgroup of ANSI C (X3J11.1), then to ANSI C (X3J11), and
 * finally to ISO C (WG14).  It has gone into a Technical Report for
 * X3J11, into the draft revision of C (C9X) for WG14, and the final
 * C99 of WG14.  It has since been corrected by Defect Report (DR) 202
 * (part of Technical Corrigendum 1: TC1) and many DRs in TC2 and
 * TC3. C1X (drafts of the next C standard) added some more things
 * related to floating-point.  The C11 (2011) version of the standard
 * has been approved.  Defect Reports against C11 have been
 * processed.  They were finalized in C17.  A binding between
 * IEEE-754-2008 and C11/C17 is being done in parts by a subgroup of WG14
 * and is being called C Floating-Point (CFP).  The binding TS 18661 was
 * broken into 5 parts.  Some of those are being added to C2X.
 *
 * This macro defines the level of FPCE that is being tested:
 *	20201016uL = WG14 meeting
 *					N2570 Feature and want macros for Annex F functions
 *					N2561 TS 18661-3 annex update
 *					N2552 F.3 editorial cleanup
 *					N2548 intmax_t and math functions [prototype change]
 *	20201004uL + WG14/N2573 = C2x draft
 *					N2532 Min-max functions
 *					N2506 Range errors and math functions
 *					N2492 Note about math function properties
 *					N2476 Names and locations of FP entities [major change]
 *					N2446 printf of NaN()
 *					N2416 FP negation
 *					N2406 Signaling NaN
 *					N2384 F.8 update
 *					N2379 *_IS_IEC_60559 macro
 *	20200209uL + WG14/N2478 = C2x draft
 *	20191118uL = WG14/N2454 = C2x draft
 *					N2401 TS 18661-4a for C2X
 *	20190929uL = WG14/N2433 = C2x draft
 *					FP DR 20 changes for obsolescing DECIMAL_DIG
 *					FP DR 21 printf of one-digit character string
 *					FP DR 23 llquantexp invalid case
 *					FP DR 24 remainder NaN case
 *					FP DR 25 totalorder parameters == N2292 [prototype change]
 *					N2271 CR for pow divide-by-zero case
 *					N2326 floating-point zero and other normalization
 *	20190615uL + WG14/N2385 = C2x draft
 *					N2124 and N2319. rounding direction macro
 *						FE_TONEARESTFROMZERO
 *					N2322 preprocessor line numbers unspecified
 *					N2325 DBL_NORM_MAX etc
 *					N2326 floating-point zero and other normalization
 *					N2341 TS 18661-2 Decimal FP
 *					N2356 update for payload functions
 *					? Remove need for __STDC_WANT_IEC_60559_BFP_EXT__
 *	20190317uL + WG14/N2346 = C2x draft
 *					N2314 TS 18661-1 Binary FP
 *	20181111uL + WG14/N2310 = C2x draft
 *	20180425uL + WG14/N2240 = C17 final
 *	20180424uL + WG14/N2244 = C11 Defect Reports =
 *					503: Hexadecimal floating-point and strtod
 *					501: Can DECIMAL_DIG be larger than necessary?
 *					500: Ambiguous specification for FLT_EVAL_METHOD
 *	20171010uL + WG14/N2177 = C17 draft
 *	20160721uL = WG14/N2059 = C11 Defect Reports =
 *					499: Anon struc in union
 *					497: white space character
 *					489: Integer constant expression
 *					483: __LINE__, __FILE__
 *					482: Split macro invocation
 *					477: nan("string")
 *					473: Range error
 *					472: CMPLX
 *					471: cacosh(), ctanh()
 *					467: max finite
 *					464: #line
 *	20150515uL = WG14/N1924 = ISO/IEC TS 18661-2 (Decimal CFP)
 *	20140715uL = WG14/N1809 = ISO/IEC TS 18661-1 (Binary CFP)
 *	20131003uL = WG14/C11 Defect Reports =
 *					448: non-directive is undefined behaviour
 *					447: boolean from complex
 *					432: Is 0.0 required?
 *					426: G.5.1: -yv -x/v ambiguous
 *					418: fmod(0,NaN)
 *					410: ilogb
 *					409: f(inf) is inf => no range error
 *	20130314uL = WG14/N1684 = Draft TS 18661, Floating-point extensions for C - Part 2: Decimal
 *	20130301uL = WG14/N1676 = Draft TS 18661, Floating-point extensions for C - Part 1: Binary
 *	20110404uL = WG14/N1569 = C11 (DIS sent out for ballot)
 *					N1553: National body comments
 *	20101202uL + WG14/N1548 = C11 w/ diff marks against N1256 (final C99)
 *	20101116uL + WG14/N1539 = CD sent out for ballot
 *					N1531: Clarifications for wide evaluation
 *					N1515: Annex F pow special case
 *					N1514: Annex G is conditional normative
 *					N1512: Exceptional conditions vs FP exceptions
 *					N1503: Fix for DR 300 (translation time expression evaluation)
 *					N1502: Fix for DR 334 (comparision macros)
 *					N1497: Clarification to fmod
 *					N1496: Minimal fix to complex divide
 *	20101004uL + WG14/N1516
 *					N1517: Editoral:
 *					  generic selection 6.5.1.1#5
 *					  CMPLX macros in 7.3.9.3#5
 *					  frexp and too large for int result
 *					  strtod and overflow
 *					  Annex G is conditional
 *					  F.4#1: out-of-range integral values
 *					  F.9.3 relational operator optimization
 *					  F.10.11 comparisoin macros
 *	20100625uL + WG14/N1494
 *					N1487: Comparison macro argument conversion
 *					N1486: fabs
 *					N1472: Comparison macro argument conversion
 *					N1468: Assumed types in F.9.2
 *					N1464: Creation of complex value
 *					N1462: errno and threads
 *					N1459: Comparison macros
 *					N1441: Generic macro facility
 *	20091124uL + WG14/N1425
 *					N1398: Treatement of math error conditions
 *					N1396: Wide function return values
 *					N1391: FP to int/_Bool conversions
 *					N1384: *_TRUE_MIN macros
 *					N1383: LIA annex correction
 *	20090928uL + WG14/N1401
 *					N1382: FLT_EVAL_METHOD and return
 *					N1377: *_DECIMAL_DIG macros
 *					N1376: Adding pole error to math library
 *					N1367: Contractions and expression evaluation methods
 *					N1365: Constant expressions
 *					N1361: Remove N1321: Split FLT_EVAL_METHOD into ops and constants
 *					N1357: tgamma range error
 *					N1353: FLT_EVAL_METHOD issues
 *	20090301uL + WG14/N1362
 *					N1346: Split FLT_EVAL_METHOD into ops and constants
 *	20080811uL = WG14/N1336 C1x = C99 + initial changes
 *					N1321: Split FLT_EVAL_METHOD into ops and constants
 *					N1320: C89 DR 25
 *					N1319: EPOLE
 *					N1306: Conversion between pointers and floating types
 *	20070909uL = WG14/N1256 = C99+TC1+TC2+TC3 = Final C99 standard
 *	200?????uL = C99 TC3 (Technical Corrigendum 3)
 *					DR 319: printf("%a",1.0) and trailing zeros
 *					DR 318: (DBL)0.1f w/ FLT_EVAL_METHOD==2
 *					DR 301: Meaning of FE_* macros
 *					DR 300: Translation time exp. eval.
 *					DR 299: Is cabs() type-generic
 *					DR 297: FE_* macros
 *					DR 296: exp(INF)
 *					DR 293: complex
 *					DR 291: inexact
 *					DR 290: FP precision
 *					DR 287: FP flags
 *	20050505uL = WG14/N1124 = C99+TC1+TC2
 *	20041115uL = C99 TC2 (Technical Corrigendum 2)
 *					DR 285: imaginary
 *					DR 275: FE_ALL_EXCEPT
 *					DR 244: tgamma()
 *					DR 243: many math functions
 *					DR 242: logb()
 *					DR 241: pow()
 *					DR 240: ilogb(), *lrint(), *lround()
 *					DR 239: nexttoward()
 *					DR 238: fma()
 *					DR 233: printf using %g
 *					DR 225: strto* of INF, NAN
 *					DR 224: fpclassify
 *					DR 223: FP_FAST_FMA*
 *					DR 218: sign of zero, inf, NaN
 *					DR 211: accuracy of I/O conversions
 *					DR 207: imaginary
 *	20010901uL = C99 TC1 (Technical Corrigendum 1)
 *					DR 210: fprintf %a, %A; strtod of hex
 *					DR 202: fenv.h functions return int
 *	20010731uL = WG14/N949 = C99+TC1
 *	19991216uL + C99, Published by ISO
 *	19990202uL = WG14/N873, J11/99-003, 99/02/02 Disposition of Comments: FCD
 *					pow(+,NAN) = +1  (Post meeting email)
 *					pow(+/-1,+/-INF) = +1
 *					tgamma(+/-0) = +/-INF + divbyzero
 *					lgamma(1) = +0
 *					lgamma(2) = +0
 *					log2(1) = +0
 *	19981010uL = WG14/N845, J11/98-058, 98/10/10 Minutes
 *					nextafterx -> nexttoward
 *					strtod("-number",NULL) and rounding
 *					strtod("0x12",NULL) now valid (no . or p)
 *	19980626uL = WG14/N841, J11/98-040, 98/08/03 Disposition of Comments:
 *					fesetround & feholdexcept return values
 *					DECIMAL_DIG now in <float.h>
 *	"	   = WG14/N829, J11/98-028, 98/05/26 FP & math accuracy
 *	"	   = WG14/N826, J11/98-025, 98/05/29 gamma -> tgamma
 *	"	   = WG14/N782, J11/98-1461, 97/10/20 AUTO aggregate initialization
 *	19971024uL = WG14/N757, X3J11/97-120, 97/09/15 FP Cleanup items:
 *					remove scalb
 *					combinations of FE_* macros are distinct
 *	19970627uL = WG14/N734, X3J11/97-097, 97/06/25 FP Cleanup items:
 *					lgamma(-inf) now returns +inf
 *	"          = WG14/N728, X3J11/97-091, 97/06/25 scalbn/scalbln
 *	"          = WG14/N694, X3J11/97-057, 97/05/23 Enhancements:
 *					INFINITY, NAN to type float
 *					fma()
 *	"          = WG14/N693, X3J11/97-056, 97/05/23 Type-Generic Math
 *	19970207uL = WG14/N674, X3J11/97-037, 97/02/28 C9X Draft 9: has(?) following:
 *	"          = WG14/N657, X3J11/97-020, 97/02/07 Enhancements:
 *					scalb -> scalb/scalbn
 *					logb -> logb/ilogb
 *					(rint/round)tol* -> l*(rint/round)
 *					cbrt
 *	"          = WG14/N638, X3J11/97-001, 97/01/03 Enhancements:
 *					feraise over/under => may do inexact
 *					isinf() macro
 *					x/x is not 1.0 for IEC 559
 *	"          = WG14/N631, X3J11/96-095, 96/11/11 Standard pragmas
 *	19970103uL + WG14/N643, X3J11/97-006, 97/01/03 C9X Draft 8 (on public site)
 *	19960912uL = WG14/N595, X3J11/96-059, 96/09/12 Base FPCE in C9X
 *					(rint/round)toll
 *	19960226uL = WG14/N546, X3J11/96-010, 96/02/26 <fp.h> -> <math.h>
 *	19950417uL + WG14/N403, X3J11/95-004, 95/04/17 NCEG Tech Report
 *	19940630uL = WG14/N364, X3J11/94-049, 94/06/30 Taligent basis; FPCE draft 3
 *	19910417uL =             NCEG/91-015, 91/04/17 Early draft
 *
 * In the above list, '+' means that level is not referenced anywhere.
 *
 */
  #ifndef   FPCE_TEST_LVL
    #define FPCE_TEST_LVL 20201016uL
  #endif

/*
 * The Decimal Floating-Point (DFP) proposal has evolved over the years.
 * This macro defines the level of DFP that is being tested:
 * The first official version was a Technical Report (TR) 24732. [N1312]
 * The second version is Part 2 of Technical Specification (TS) 18661
 * (Floating-point extensions for C = FPEC).
 *	20190310uL = WG14/N2341: TS 18661-2 Decimal FP + CR/DRs for C2X
 *	20160919uL = WG14/N2079: TS 18661-2 C2X proposal
 *	20150413uL = WG14/N1924: TS 18661-2 update for republishing
 *	20140813uL = WG14/N1851: TS 18661 part 2: Final text
 *	20131002uL = WG14/N1766: Changes to TS 18661 Part 2
 *	20130911uL = WG14/N1757: update of TS 18661 Part 2
 *      20130625uL = WG14/N1724: Part 2 of TS: DFP
 *      20130608uL = WG14/N1722: Part 2 of TS: DFP
 *      20130326uL = WG14/N1690: Part 2 of TS: DFP
 *      20130314uL = WG14/N1684: Part 2 of TS: DFP
 *      20130303uL = WG14/N1679: Part 2 of TS: DFP; _ _STDC_IEC_60559_DFP_ _ 201ymmL
 *      20121022uL = WG14/N1657: Part 2 of TS: DFP
 *      20120923uL = WG14/N1632: Part 2 of TS: DFP; DEC*_SUBNORMAL_MIN -> DEC*_TRUE_MIN
 *				 __STDC_DEC_FP__ 201ymmL
 *      20080516uL = WG14/N1312: FLOAT_CONST_DECIMAL64 pragma added; TTDT dropped;
 *				 __STDC_DEC_FP__ 200805L
 *      20080313uL = WG14/N1290  __STDC_DEC_FP__ 200803L
 *      20070527uL = WG14/N1241  __STDC_DEC_FP__ 200704L
 *      20070326uL + WG14/N1212  __STDC_DEC_FP__ 20061110L
 *      20061128uL = WG14/N1201: DEC*_DEN -> DEC*_SUBNORMAL_MIN
 *				 DEC*_MIN_EXP corrected.
 *				 DEC*_MAX_EXP corrected.
 *      20060523uL = WG14/N1176: DFP_MAX_PRECISION pragma dropped; gcc 4.3.2;
 *      20060227uL = WG14/N1154: Explains 'd' and 'D' suffix; __STDC_DEC_FP__ 1
 *      20051026uL = WG14/N1150 TTDT added,
 *				'd' and 'D' suffix added (but not explained)
 *      20050917uL = WG14/N1137 Tech Report 24732
 *      20050307uL = WG14/N1107
 *                        N1092 TTDT proposal
 *      20040927uL = WG14/N1077
 *      20040303uL = WG14/N1057
 *      20030901uL = WG14/N1016 (Decimal Floating-Point)
 *
 */
  #ifndef   DFP_TEST_LVL
    #define DFP_TEST_LVL 20190310uL
  #endif

/*
 * All the t1xx*003 tests need SRC_PATH to know where to read the test
 * vectors from.
 * Two examples are:
 *	"E:\\fpcets\\real\\"
 *	"../real/"
 */
  #undef SRC_PATH		/* t1xx*0003 */

/*
 * If m0100211 or m0210199 need to be run on your system, then, you
 * will need to tailor RES?_PATH, SRC?_PATH, PROG_SUFFIX symbols.
 * They define the path to the source directory and the suffix to add
 * to file names (as strings).
 * Two examples are:
 *	"E:\\fpcets\\manual\\"	".fjt"
 *	"../manual/"		".c"
 */
  #undef RES2_PATH		/* m0100211 */
  #undef SRC2_PATH		/* m0100211 */
  #undef RES3_PATH		/* m0210199 */
  #undef SRC3_PATH		/* m0210199 */
  #undef PROG_SUFFIX		/* m0100211, m0210199 */

/*
 * Pick one of the next two to allow errors to show up or be bypassed.
 * The #undef/#define for this symbol should be done in either the *.bug
 * file included by this file, or in the make or compiler options.
 */
  #if 0
    #undef	WANT_CLEAN	/* Allow errors to show up */
    #define	WANT_CLEAN 1	/* Bypass FIX_* implementation errors */
  #endif

/*
 * If you are compiling each test case along with the support files together
 * in one compile (instead of separate compiles followed by link edit),
 * then this symbol needs to be defined.  Mainly used for sample tests
 * t0120200.c, t1150000.c, t1150001.c; so can NOT be #undef'ed here.
 */
  #if 0
    #define FPCE_SAMPLE	/* Compile test and support code together */
    #undef  FPCE_SAMPLE	/* Separate compiles, followed by link edit */
  #endif

/*
 * Mode used when freopen stdout to write text to a file (if REDIRECTing).
 * Standard C is "w", but some compilers want "wt" to indicate text.
 * In C89, the "t" in "wt" is valid by footnote 115.
 * In C99, the "t" in "wt" is undefined behavior, but footnote 228 allows it.
 */
  #undef MODE

/*
 * Mode used when fopen a file to read text from a file.  This is used in
 * the m0210199.fjt and m0100211.fjt (normally, not run by you).
 * The default is "r".  See MODE above for comments on "t".
 */
  #undef R_MODE

/*
 * Mode used when fopen a file to write text to a file.  This is used in
 * the m0210199.fjt and m0100211.fjt (normally, not run by you).
 * The default is "w".  See MODE above for comments on "t".
 */
  #undef W_MODE

/*
 * Mode used when fopen stdout to append text to a file.  This is used in
 * the DOS program arg2file.fjt which is used as part of the build process.
 * The default is "a".  See MODE above for comments on "t".
 */
  #undef A_MODE

/*
 * Mode used when fopen or freopen a temp binary file in t304* for writing
 * and reading.
 */
  #undef IMPL_fopen_wb
  #undef IMPL_freopen_wb
  #undef IMPL_freopen_rb

/*
 * Test rounding up past a decade boundary in tbin2dec.
 */
  #undef  TEST_RND_UP_DECADE

/*
 * Test optional flags in g1errno.h
 */
  #undef  TEST_OPT_FLAGS

/*
 * Hardware and software support setting the precision dynamically at runtime.
 * This is NOT required by FPCE.  It is used on an Intel 80*87 test case
 * development system to attempt to test running test cases on other hardware.
 * Was FIX_STATIC_PRECISION.  Assumes:
 * Functions
 *	int fegetprec( void );
 *	int fesetprec( int precision );
 * Macros
 *	FE_FLTPREC
 *	FE_DBLPREC
 *	FE_LDBLPREC
 */
  #undef TEST_DYNAMIC_PRECISION

/*
 * Hardware and software support enable and disable of trapping dynamically
 * at runtime. This is NOT required by FPCE.  Assumes:
 * Functions
 *	int fetesttrap( int traps );
 *	int feenabletrap( int traps );
 *	int fedisabletrap( int traps );
 *	void fegettrapflag( fetrap_t *flagp, int traps );
 *	void fesettrapflag( const fetrap_t *flagp, int traps );
 * Macros
 *	FE_TRAP_INVALID
 *	FE_TRAP_DIVBYZERO
 *	FE_TRAP_OVERFLOW
 *	FE_TRAP_UNDERFLOW
 *	FE_TRAP_INEXACT
 *	FE_TRAP_ALL
 * Typedef
 *	fetrap_t
 */
  #undef TEST_TRAPPING

/*
 * If Signaling NaNs ever get supported, this symbol will be defined which
 * should then activate additional code in the test suite.  Until then,
 * Signaling NaNs are replaced with Quiet NaNs.  Was SNAN_ SUPPORTED once.
 */
  #undef TEST_SNAN

/*
 * As FPCE has evolved, there continue to be more proposals to change it.
 * This enables testing those proposals still outstanding.  This mainly
 * affects m0210199.fjt and m0210201.h which are used to generate the
 * e021*.fjt tests of symbols in the correct headers.
 */
  #undef TEST_PROPOSALS

/*
 * The FILE structure members of the form _x (instead of __x or _X) are a
 * possible violation of the user's name space.  But, _x could also be a
 * valid file scope variable or function (which is part of the implementator's
 * name space).  Was FIX_FILE_MEMBERS.
 */
  #undef TEST_FILE_MEMBERS

/*
 * Several functions take pointer arguments.  It is not defined what will
 * happen if those functions are called with NULL pointers.  It is assumed
 * that 6.3.3.2 Address and indirection operators -- dereferencing a NULL
 * pointer is undefined behavior applies.  Also, 7.1.7 Use of library
 * functions -- NULL pointer argument is undefined behavior.  Defining this
 * symbol enables the tests of invoking those functions with NULL pointers.
 */
  #undef TEST_NULL_PTR

/*
 * FPCE for the Technical Report had #pragmas for allowing variables,
 * parameters to functions, and return result from functions to be stored
 * using more precision than was required for the type.  When FPCE got
 * voted into C99, these were dropped.  So, the tests of these features
 * are now optional.
 */
  #undef TEST_WIDE_VARS		/* #pragma fp_wide_variables */
  #undef TEST_WIDE_PARMS	/* #pragma fp_wide_function_parameters */
  #undef TEST_WIDE_RETURNS	/* #pragma fp_wide_function_returns */

/*
 * (expression << large), where 'large' has a value larger than the
 * size of the expression, is undefined.  This tests those.
 */
  #undef TEST_LEFT_SHIFT_LARGE

/*
 * (expression >> large), where 'large' has a value larger than the
 * size of the expression, is undefined.  This tests those.
 */
  #undef TEST_RIGHT_SHIFT_LARGE

/*
 * Mathematically, the remainder operation (M % -1) is 0 for all M.
 * But, the C standard says if M / -1 is not representable,
 * then M % -1 is undefined behaviour.  This tests such operations.
 */
  #undef TEST_REMAINDER_OP

/*
 * '# non-directive' is a valid preprocessor token, yet kills almost
 * all compilers. DR 448 made it undefined behaviour.
 */
  #undef TEST_WEIRD_NON_DIRECTIVE

/*
 * '#if defined' is a syntax error, so undefined.
 * Tested in t0000500
 */
  #undef TEST_BARE_defined

/*
 * '#if _Pragma' is undefined
 * Tested in t0000500
 */
  #undef TEST_BARE_Pragma

/*
 * #undef defined and #define defined 12 should not be allowed (6.10.8#2)
 * Tested in t0000500
 */
  #undef TEST_REDEF_defined

/*
 * '#undef _Pragma' and '#define _Pragma(x)' are undefined
 * Tested in t0000500
 */
  #undef TEST_REDEF_Pragma

/*
 * In _Generic( id, type ), type must be oject type, not function type.
 * Tested in t0400100
 */
  #undef TEST_FUNC_WITH_GENERIC

/*
 * #line in assert() macro invocation is undefined.
 * Tested in t0502300
 */
  #undef TEST_line_IN_assert

/*
 * #line with large integer constants.
 * Tested in t0502400
 */
  #undef TEST_LARGE_line

/*
 * Can parens be used with the type or member in offsetof()?
 * offsetof( (type), (member) ).  Tested in t0400200
 */
  #undef TEST_OFFSETOF_PARENS

/*
 * Can offsetof() define new type?  Is that type useable?
 */
  #undef TEST_OFFSETOF_NEWTYPE

/*
 * Can offsetof() define new type with a comma in the type?
 */
  #undef TEST_OFFSETOF_COMMATYPE

/*
 * Used by Tydeman to have some C11/C17/C2x CFP functions to test as he developes test cases.
 * If an implementation has some of the functions, then define HAVE_FUNC* as needed.
 */
  #undef WANT_FAKE_FUNCS

/*
 * Precision of LDBL should be greater then DBL.  If LDBL is fully
 * supported, but its size and representation are the same as DBL, then
 * this symbol needs to be defined.  Contrast this with REMAP_LDBL.
 * IMPL_LD10_EQ_D10 is for Decimal FP.
 * Implementations that need this:
 *   x86/x87 Win  Microsoft
 *   x86/x87 DOS  Symantec 7
 *   x86/x87 OS/2 Watcom
 */
  #undef IMPL_LDBL_EQ_DBL
  #undef IMPL_LD10_EQ_D10

/*
 * A few implementations implement LDBL as a pair of DBLs, called
 * higher and lower parts, with value = higher+lower.  However,
 * there are at least four possible ways to do that.
 *
 * If the sign bit of lower must be the same as that of higher, then
 * the precision of LDBL would be 2*precision of DBL, or 106.
 *
 * However, if the sign bit of lower can be either + or -, then, it is
 * as if the sign bit of the lower is used as a value bit, so we get
 * one more bit of precision. So, the precision is 107.
 *
 * The maximum finite number could be a normalized (full precision)
 * number (so is just over DBL_MAX and higher==higher+lower), or it
 * could be larger, in which case, it has less than full precision
 * (so is NOT normalized and higher!=higher+lower).
 *
 * 0 < sub-normals < normals < super-normals < infinity
 *
 * Maximum finite number can be:
 *   semi-normalized 106-bit value (pair of 53-bit DBLs w/ 0 between them)
 *   normalized 106-bit value (pair of 53-bit DBLs)
 *   normalized 107-bit value (pair of 53-bit DBLs plus "sign" bit)
 *   2*DBL_MAX (DBL_MAX + DBL_MAX)
 *   2*DBL_MAX {"infinity" - DBL_MAX)
 *   3*DBL_MAX {"infinity" + 0      )
 *   4*DBL_MAX {"infinity" + DBL_MAX)
 *
 * These cover the latter four.
 */
  #undef IMPL_MAX2_LDBL
  #undef IMPL_MAX3_LDBL
  #undef IMPL_MAX4_LDBL

/*
 * LDBL_MIN is required by C to be a normalized (full precision) number.
 * That is: 4.L/3.L == ((4.L/3.L)*LDBL_MIN)/LDBL_MIN
 * If LDBL is a pair of DBLs and LDBL_MIN == DBL_MIN, then LDBL_MIN
 * does not have full precision (so has the wrong value).  In that case,
 * define this symbol.  In addition, in your *.flt file, you will need
 * to define MIN_LDBL as FP_LD(0x1p-969) and also do:
 * #undef  LDBL_MIN_EXP
 * #define LDBL_MIN_EXP -968
 */
  #undef FIX_LDBL_EQ_DBL_MIN

/*
 * The original FPU in the Intel x86 (IA-32) is known as the x87.  By
 * default, it does all operations as 80-bit LDBL.  But, if
 * every x87 operation is followed by a store to type in a temp and a
 * load from the temp, then the x87 acts as if all operations are done
 * to type (FLT_EVAL_METHOD being 0).  Intel's compiler is the only
 * one I have seen that does this.
 */
  #undef IMPL_ST_LD

/*
 * The Intel x86 (IA-32) has two FPUs: the original 80-bit x87 and the
 * later 32/64-bit SSE.  If code generation is for the SSE for FLT and
 * DBL, define this.  This impacts how expressions are evaluated.
 * SSE is to type, while x87 is normally done as 80-bit LDBL.
 */
  #undef IMPL_SSE

/*
 * Assignment (x = y;) to the same format, can be done as a copy or a
 * convertFormat operation.  See C Annex F.3 paragraph [3].
 * It mattes for signaling NaNs; copy not raise invalid.
 */
  #undef IMPL_ASSIGN_IS_COPY	/* all 3 */
  #undef IMPL_ASSIGN_FLT_IS_COPY
  #undef IMPL_ASSIGN_DBL_IS_COPY
  #undef IMPL_ASSIGN_LDBL_IS_COPY
  #undef IMPL_ASSIGN_F10_IS_COPY
  #undef IMPL_ASSIGN_D10_IS_COPY
  #undef IMPL_ASSIGN_LD10_IS_COPY

/*
 * If FLT_EVAL_METHOD < 0 (meaning inconsistent or unknown),
 * If DEC_EVAL_METHOD < 0 (meaning inconsistent or unknown),
 * then allow the implementation to define how it evaluates:
 *   compile time FP constants
 *   compile time FP constant expressions
 *   runtime FP operators
 *   runtime FP operators (contracted)
 *   runtime anonymous (w/o a store) FP operators, eg, FLT_MAX*FLT_MAX;
 *   runtime conversion from integer type to floating type
 *   runtime conversion from "decimal" string to "binary" FP via strto*, *scanf
 *   runtime return stmt.
 *   runtime inline return stmt.
 * Each of these symbols needs to be defined to a value like 0, 1, 2, or 3.
 * 0, 1, and 2 have same meaining as FLT_EVAL_METHOD.
 * 3 => precision is greater than LDBL [Microsoft, Symantec...]
 * and LD_REG_PREC is used to indicate that precision.
 * REG_WIDER_EXP is used for range is greater than LDBL.
 * REG10_WIDER_EXP is used for range is greater than LD10.
 * For example:
 * #define IMPL_FLT_EVAL_CONST       0 // to type
 * #define IMPL_FLT_EVAL_CONST_EXP   2 // to LDBL
 * #define IMPL_FLT_EVAL_OP          2 // to LDBL
 * #define IMPL_FLT_EVAL_OP_CONTRACT 2 // to LDBL
 * #define IMPL_FLT_EVAL_OP_ANON     2 // to LDBL
 * #define IMPL_FLT_EVAL_INT2FLT     2 // to LDBL
 * #define IMPL_FLT_EVAL_RET         0 // to type
 * #define IMPL_FLT_EVAL_IN_RET      0 // to type
 * #define IMPL_FLT_EVAL_STRTO       0 // to type
 *
 * #define IMPL_DEC_EVAL_CONST10     0 // to type
 * #define IMPL_DEC_EVAL_CONST_EXP10 2 // to Dec128
 * #define IMPL_DEC_EVAL_OP10        2 // to Dec128
 * #define IMPL_DEC_EVAL_OP10_CONTRACT 2 // to Dec128
 * #define IMPL_FLT_EVAL_INT2DFP     2 // to Dec128
 * #define IMPL_DEC_EVAL_RET10       0 // to type
 * #define IMPL_DEC_EVAL_IN_RET10    0 // to type
 * #define IMPL_DEC_EVAL_STRTO10     0 // to type
 */
  #undef IMPL_FLT_EVAL_CONST
  #undef IMPL_FLT_EVAL_CONST_EXP
  #undef IMPL_FLT_EVAL_OP
  #undef IMPL_FLT_EVAL_OP_CONTRACT	/* t0140000 */
  #undef IMPL_FLT_EVAL_OP_ANON		/* t0280000 */
  #undef IMPL_FLT_EVAL_INT2FLT		/* t0130100 */
  #undef IMPL_FLT_EVAL_STRTO
  #undef IMPL_FLT_EVAL_RET
  #undef IMPL_FLT_EVAL_IN_RET

  #undef IMPL_DEC_EVAL_CONST10
  #undef IMPL_DEC_EVAL_CONST_EXP10
  #undef IMPL_DEC_EVAL_OP10
  #undef IMPL_DEC_EVAL_OP10_CONTRACT	/* t6140000 */
  #undef IMPL_DEC_EVAL_INT2DFP		/* t6130100 */
  #undef IMPL_DEC_EVAL_STRTO10
  #undef IMPL_DEC_EVAL_RET10
  #undef IMPL_DEC_EVAL_IN_RET10

/*
 * If some (but not all) contracted operations are done, you may need this.
 * You should try (in order):
 * #define IMPL_FLT_EVAL_OP_CONTRACT (IMPL_FLT_EVAL_OP+3)
 * #define IMPL_FLT_EVAL_OP_CONTRACT (IMPL_FLT_EVAL_OP+2)
 * #define IMPL_FLT_EVAL_OP_CONTRACT (IMPL_FLT_EVAL_OP+1)
 * #define IMPL_FLT_EVAL_OP_CONTRACT (IMPL_FLT_EVAL_OP+0)
 *
 * When the first one of those passes, that is the value to use.
 * The above assume that 0 <= IMPL_FLT_EVAL_OP
 *
 * If all fail (in t0140000), then you need:
 * #define IMPL_RANDOM_CONTRACT
 */
  #undef IMPL_RANDOM_CONTRACT

/*
 * The mapping of enum types to integer types is implementation defined.
 * If all enum's map to int, then you do not need any of these.
 * There are 6 different enums tested (each has a different range of values).
 * They can map to one of several kinds of integer types.
 * For both the enum type and the int type, the first letter (U or S)
 * means Unsigned or Signed.  For the enum type the second letter (C, S, I)
 * means Char, Short, or Int and indicates the minimum type needed to
 * represent its values. The int type mapped to should be obvious.
 * In ISO/ANSI C, enum is a synonym for some int type; but each enum
 * constant is of type int (so, at one point, these tests assumed that enums
 * mapped to int).  In C++ enums may be smaller than an int.
 * These next symbols replace FIX_ENUM_IS_INT.
 */
  #undef IMPL_UCE_IS_UCHAR
  #undef IMPL_UCE_IS_SCHAR
  #undef IMPL_UCE_IS_USHORT
  #undef IMPL_UCE_IS_SSHORT
  #undef IMPL_UCE_IS_UINT
  #undef IMPL_UCE_IS_SINT

  #undef IMPL_SCE_IS_SCHAR
  #undef IMPL_SCE_IS_SSHORT

  #undef IMPL_USE_IS_USHORT
  #undef IMPL_USE_IS_SSHORT
  #undef IMPL_USE_IS_UINT
  #undef IMPL_USE_IS_SINT

  #undef IMPL_SSE_IS_SSHORT
  #undef IMPL_SSE_IS_SINT

  #undef IMPL_UIE_IS_UINT
  #undef IMPL_UIE_IS_SINT

  #undef IMPL_SIE_IS_SINT

/*
 * In a function-like macro invocation,
 * 1) what line number does the macro (invoke) have?
 * 2) what line number(s) do the arguments have?
 *    the (physical) line number of the argument (-1), or
 *    the (physical) line number+1 of the argument (-2), or
 *    some line number of the macro invocation (1 or greater)?
 * Also, depends upon if one versus several logical lines.
 * t0500200, t0500500, t0500800, t0502300 are main tests.
 * \	<-- 1: pcc, Intel, edg
 *  \	<-- 2:
 * \
 * M\	<-- 3: Sun
 * A\
 * C\
 * \
 * x\
 * y\
 * z\	<-- 4: pcc
 * \
 * (\	<-- 5:
 * \
 * __LI\<-- 6: pcc
 * NE__\
 * \
 * ,\
 * \
 * LINE\<-- 7: clang, Intel.edg
 * \
 *  \   <-- 8: clang
 * \
 * )\	<-- 9: emx, Watcom, gcc, Microsoft, Intel, edg
 * \
 *  \	<-- 10: Watcom
 * \
 * //	<-- 11:
 *  	<-- 12: Symantec, Digital Mars
 */
  #undef IMPL_MAC_INVOK_LINE
  #undef IMPL_MAC_ARG_LINE

/*
 * PP token of a __LINE__ invocation has which line number?
 * t0500100 is main test.
 *
 * \	<- 1: pcc, Intel, lcc, edg
 *  \	<- 2:
 * \
 *  \	<- 3:
 * \
 * _\	<- 4: Watcom, gcc, Borland, Sun, clang
 * _\
 * L\
 * I\
 * \
 * N\
 * E\
 * _\
 * _\	<- 5:
 * \
 *  \	<- 6: Microsoft, emx
 * \
 *  \	<- 7:
 * \
 * //	<- 8: Symantec, DigitalMars
 */
  #undef IMPL_LINE_LINE

/*
 * PP token of a __LINE__ invocation in a #if has which line number?
 * NOTE: emx is inconsistent with other LINE related cases.
 * t0501900 is main test.
 *
 * #if \<- 1: pcc, Intel, lcc, edg
 *  \	<- 2:
 * \
 *  \	<- 3:
 * \
 * _\	<- 4: Watcom, gcc, Borland, Sun, clang
 * _\
 * L\
 * I\
 * \
 * N\
 * E\
 * _\
 * _\	<- 5:
 * \
 *  \	<- 6: Microsoft
 * \
 *  \	<- 7:
 * \
 * //	<- 8: Symantec, DigitalMars, emx
 */
  #undef IMPL_HASHIF_LINE

/*
 * PP token of a macro symbol invocation has which line number?
 * NOTE: clang is inconsistent with other LINE related cases.
 * t0500300 is main test.
 *
 * \	<- 1: pcc, Intel, lcc, edg
 *  \	<- 2:
 * \
 *  \	<- 3: clang
 * \
 * \
 * L\	<- 4: Watcom, gcc, Borland, Sun
 * I\
 * \
 * N\
 * E\	<- 5:
 * \
 *  \	<- 6: Microsoft, emx
 * \
 *  \	<- 7:
 * \
 * //	<- 8: Symantec, DigitalMars
 */
  #undef IMPL_TOKEN_LINE

/*
 * #line with constant
 * See t0500900 for tests of:
 * \
 * \
 *  #\
 *  \
 * l\
 * i\
 * n\
 * e\
 *  \
 * 8000 \
 *  // Now, what is:
 * __LINE__ is:
 * 1 => 8000: emx, Watcom, gcc, Microsoft, Intel, Sun, edg
 * 2 => 8001: pcc
 * 3 => 8002: clang
 * 4 => 8010: lcc
 */
  #undef IMPL_HASHLINE_CONST

/*
 * #line with __LINE__
 * See t0500500, t0501100 for tests of:
 * #line 9000
 * \
 * \
 *  #\
 * \
 * l\
 * \
 * i\
 * \
 * n\
 * \
 * e\
 *  \
 *  \
 * _\
 * _\
 * \
 * L\
 * \
 * I\
 * \
 * N\
 * \
 * E\
 * _\
 * _\
 * \
 *  \
 * \
 *  //
 *  // Now, what is:
 * __LINE__ is:
 * 1 => 9000 Intel, edg
 * 2 => 9001 pcc
 * 3 => 9013 gcc, Sun
 * 4 => 9014 Watcom
 * 5 => 9026 Microsoft
 * 6 => 9027 emx, Symantec
 * 7 => 9028 clang
 */
  #undef IMPL_HASHLINE___LINE

/*
 * #line with LINE
 * See t0501200 for tests of:
 * #line 5000
 * #line \
 * \
 * \
 * \
 * L\
 * I\
 * \
 * N\
 * E\
 * \
 * \
 * \
 * \
 *  \
 *  // Now, what is:
 * __LINE__ is:
 * 1 => 5000: Intel, edg
 * 2 => 5001: pcc
 * 3 => 5004: gcc, Sun
 * 4 => 5005: Watcom
 * 5 => 5013: Microsoft
 * 6+=> 5014: emx, Symantec, DigitalMars, clang
 */
  #undef IMPL_HASHLINE_LINE

/*
 * #line with function-like MACRO(...)
 * See t0501300, t0501400, t0501500, t0501600, t0501700 for tests of:
 * #line 1000 // This test is in t0501700.
 *   // This is line 1000
 * #line\
 * \
 *  \
 * \
 * xglue(\
 *  EVAL(UN(LINE))\
 *  ,\
 *  2\
 * )\
 * \
 *  \
 * \
 * //
 * Now, what is:
 * __LINE__ is:
 * 1 => 10012 Intel, edg
 * 2 => 10016 pcc
 * 3 => 10052 Sun
 * 4 => 10062 Borland TC2
 * 5 => 10092 gcc, Microsoft
 * 6 => 10114 Watcom
 * 7 => 10132 emx, Symantec, DigitalMars
 * 8 => 10072 clang
 * 9 => 10024 lcc
 */
  #undef IMPL_HASHLINE_MAC

/*
 * Can bool and int bit-fields be mixed in the same storage unit?
 * Or, does mixing them allocate more storage than just bool?
 * Define this if they cannot.
 */
  #undef IMPL_NOMIX_BOOL_AND_INT

/*
 * Binary operators accept integer or pointer operands.
 */
  #undef IMPL_isgreater_ACC_INT_PTR
  #undef IMPL_isgreaterequal_ACC_INT_PTR
  #undef IMPL_isless_ACC_INT_PTR
  #undef IMPL_islessequal_ACC_INT_PTR
  #undef IMPL_islessgreater_ACC_INT_PTR
  #undef IMPL_isunordered_ACC_INT_PTR

/*
 * Binary operators accept complex or imaginary operands.
 */
  #undef IMPL_isgreater_ACC_CX_IM
  #undef IMPL_isgreaterequal_ACC_CX_IM
  #undef IMPL_isless_ACC_CX_IM
  #undef IMPL_islessequal_ACC_CX_IM
  #undef IMPL_islessgreater_ACC_CX_IM
  #undef IMPL_isunordered_ACC_CX_IM

/*
 * Binary operators accept mixed Decimal FP and Binary FP operands.
 */
  #undef IMPL_isgreater_MIX_DFP_BFP
  #undef IMPL_isgreaterequal_MIX_DFP_BFP
  #undef IMPL_isless_MIX_DFP_BFP
  #undef IMPL_islessequal_MIX_DFP_BFP
  #undef IMPL_islessgreater_MIX_DFP_BFP
  #undef IMPL_isunordered_MIX_DFP_BFP

/*
 * Uniary operators accept integer or pointer operands.
 */
  #undef IMPL_fpclassify_ACC_INT_PTR
  #undef IMPL_isfinite_ACC_INT_PTR
  #undef IMPL_isinf_ACC_INT_PTR
  #undef IMPL_isnan_ACC_INT_PTR
  #undef IMPL_isnormal_ACC_INT_PTR
  #undef IMPL_signbit_ACC_INT_PTR

/*
 * Uniary operators accept complex or imaginary operands.
 */
  #undef IMPL_fpclassify_ACC_CX_IM
  #undef IMPL_isfinite_ACC_CX_IM
  #undef IMPL_isinf_ACC_CX_IM
  #undef IMPL_isnan_ACC_CX_IM
  #undef IMPL_isnormal_ACC_CX_IM
  #undef IMPL_signbit_ACC_CX_IM

/*
 * "Invalid" ISO/ANSI C code is accepted as valid. The code in question is:
 * struct b { int b: (INT)(10.0/3.0); } b;
 */
  #undef IMPL_ACC_BAD_BIT_FIELD_SIZE

/*
 * "Invalid" ISO/ANSI C code is accepted as valid. The code in question is:
 * enum b { b = (INT)(10.0/3.0) } b;
 */
  #undef IMPL_ACC_BAD_ENUM_VAL

/*
 * "Invalid" ISO/ANSI C code is accepted as valid. The code in question is:
 * int b[ (INT)(10.0/3.0) ];
 */
  #undef IMPL_ACC_BAD_ARRAY_BOUND

/*
 * "Invalid" ISO/ANSI C code is accepted as valid. The code in question is:
 * switch i { case (INT)(10.0/3.0):; }
 */
  #undef IMPL_ACC_BAD_CASE_VAL

/*
 * Does pragma FENV_ACCESS OFF cause the compiler to fold
 * some expressions (and thereby, not raise FP exceptions
 * at runtime)?
 */
  #undef IMPL_FENV_OFF_FOLDS

/*
 * Complex is optional to freestanding implementations.
 * Imaginary is optional to all implementations.
 * Decimal FP Tech Report currently has no DFP complex or DFP imaginary,
 * but if DFP gets added to Standard C, they must be added also.
 */
  #undef IMPL_MISSING_COMPLEX
  #undef IMPL_MISSING_IMAG
  #undef IMPL_MISSING_DFP_COMPLEX
  #undef IMPL_MISSING_DFP_IMAG

/*
 * Should checking for complex ULP_c* symbols being defined be skipped?
 */
  #undef IMPL_SKIP_ULP_COMPLEX
  #undef IMPL_SKIP_ULP10_COMPLEX

/*
 * What relationship exists between the size of enums and size of int?
 * And size of wchar_t and size of int?  Used in t0160322.
 */
  #undef sizeof_enum_color_LT_sizeof_int
  #undef sizeof_wchar_t_LT_sizeof_int

/*
 * #pragma STDC FLOAT_CONST_DECIMAL64 should be followed by one of
 * DEFAULT | ON | OFF
 * and honored.
 */
  #undef IMPL_DFP64_ACC_NOTHING		/* accepts nothing */
  #undef IMPL_DFP64_ACC_on		/* accepts on */
  #undef IMPL_DFP64_ACC_off		/* accepts off */
  #undef IMPL_DFP64_ACC_default		/* accepts default */
  #undef IMPL_DFP64_ACC_junk		/* accepts junk */
  #undef IMPL_DFP64_ACC_ON2		/* accepts ON ON */
  #undef IMPL_DFP64_ACC_OFF2		/* accepts OFF OFF */
  #undef IMPL_DFP64_ACC_DEFAULT2	/* accepts DEFAULT DEFAULT */
  #undef IMPL_DFP64_ACC_WRONG_PLACE	/* accepted in wrong place */

/*
 * When the compiler converts from decimal (external) to binary (internal)
 * does it look at all the digits in the decimal string, or does it look at
 * just the first DECIMAL_DIG significant digits.  If the extra digits are
 * not used, then define this macro symbol.  This only matters if the symbols
 * *_DEC2BIN_ULPS and *_SCAN2BIN_ULPS are 0, eg, correctly rounded conversions.
 */
  #undef IMPL_IGNORE_EXTRA_DIGITS

/*
 * When printf converts and rounds a number just smaller than 1.0 using %e,
 * does the exponent end up as e-00 (instead of the "expected" e+00)?
 * Some implementations go out of their way to indicate that the number
 * with no limit on precision would have had 9.9e-01, but due to rounding,
 * the number ended up as 1e-00 (this is used by t30701?? tests).
 */
  #undef IMPL_MZERO_EXP

/*
 * When printf converts using %a and %La, is the precision used the
 * mimimum to get an exact representation for this value (in effect,
 * remove trailing zeros; which is how I read C99; this symbol NOT
 * defined), or does the implementation use a fixed precision?  If the
 * latter, then used these symbols to defined the number of hex digits
 * after the radix point.  Affects t30703*, t34704*, t311, t312, t313.
 */
  #undef IMPL_aA_PREC	/* (DBL)FLT and DBL */
  #undef IMPL_LaA_PREC	/* LDBL */
  #undef IMPL_FaA_PREC	/* strfromf(FLT) */

/*
 * When printf converts using %.0a and %.0La, is the first hex digit always
 * 4-7 (3 bits), 2-3 (2 bits), 1 (1 bit)?  If so, then the result may suffer
 * an underserved rounding error when there are other representations that
 * have no rounding error; the first hex digit is 8-f (4 bits).  If these
 * symbols are undefined, the tests assume that the first hex digit is 8-f.
 * Affects t30703*, t34703*, t0240509, t0450900, t311, t312, t313
 */
  #undef IMPL_aA_BITS	/* (DBL)FLT and DBL */
  #undef IMPL_LaA_BITS	/* LDBL */
  #undef IMPL_FaA_BITS	/* strfromf(FLT) */

/*
 * When printf converts and rounds a number that is at the midpoint
 * (so it either rounds up or rounds down), what happens?  Some systems
 * use the digit before the round point to determine how to round.
 * Systems that follow IEEE-754 and round to nearest even would have:
 *   #define IMPL_ODD_UP
 *   #undef  IMPL_EVEN_UP
 * Systems that add 0.5 and truncate would have:
 *   #define IMPL_ODD_UP
 *   #define IMPL_EVEN_UP
 * This may need to be expanded if we find that the sign of the number
 * is also used to determine rounding.
 * These are used by t30701??, t30702?? and t305* tests.
 */
  #define IMPL_ODD_UP	/* assume IEEE-754 round to nearest as default */
  #undef IMPL_EVEN_UP

/*
 * The maximum number of characters that can be printed with %s.
 * If not defined, 4095 is used.  Needed in t3041000.
 */
  #undef IMPL_MAX_PRINT_S
  #undef IMPL_MAX_WPRINT_S

/*
 * The maximum number of digits processed in a translation time FP
 * constant before double rounding happens.
 */
  #undef IMPL_MAX_FLT_DIGITS
  #undef IMPL_MAX_DBL_DIGITS
  #undef IMPL_MAX_LDBL_DIGITS
  #undef IMPL_MAX_F10_DIGITS
  #undef IMPL_MAX_D10_DIGITS
  #undef IMPL_MAX_LD10_DIGITS

/*
 * The maximum number of digits before and after the radix point
 * allowed by printf using %f format.  If not defined, 32766 is used.
 * This shows up in test t0250800/t3041000.  As long as they are about
 * LDBL_MAX_10_EXP and DECIMAL_DIG-LDBL_MIN_10_EXP, there will be no
 * problems.  Some implementations have a limit on the total number of
 * digits (counts both before and after radix).
 */
  #undef IMPL_MAX_BEFORE_RADIX
  #undef IMPL_MAX_AFTER_RADIX
  #undef IMPL_MAX_TOTAL_RADIX

/*
 * The maximum number of digits before and after the radix point
 * allowed by scanf using %f format.  If not defined, 32766 is used.
 * This shows up in tests t0250800/t3041000.  As long as they are
 * about LDBL_MAX_10_EXP and DECIMAL_DIG-LDBL_MIN_10_EXP, there will
 * be no problems.
 */
  #undef IMPL_MAX_SCAN_BEFORE_RADIX
  #undef IMPL_MAX_WSCAN_BEFORE_RADIX
  #undef IMPL_MAX_SCAN_AFTER_RADIX
  #undef IMPL_MAX_WSCAN_AFTER_RADIX

/*
 * The maximum number of significant digits correctly rounded by
 * printf using %e format.  If not defined, DECIMAL_DIG is used.  This
 * shows up in test t305*.  This is for testing more than DECIMAL_DIG.
 */
  #undef IMPL_MAX_E_DIGITS

/*
 * Library functions of NaN argument should return the same NaN (as
 * per Annex F.9, paragraph 13 in Recommended practice; Change in sign
 * of NaN is OK as same paragraph.)
 * Some bad libraries return a fixed (constant) NaN independent of NaN argument.
 * Either check for same identical NaN, or same NaN (w/o signs) or some NaN.
 */
  #undef IMPL_DIFF_NAN	/* if defined => some NaN */
  #undef IMPL_SIGN_NAN	/* if defined => ignore signs */

/*
 * Library functions of two NaN arguments should return one of them.
 * Some bad libraries return a fixed (constant) NaN independent of NaN argument.
 * Either check for either NaN (w/o signs), either NaN (w/ signs) or some NaN.
 */
  #undef IMPL_DIFF_2NAN	/* if defined => some NaN */
  #undef IMPL_SIGN_2NAN	/* if defined => ignore signs */

/*
 * nan("") should be same as 0.0/0.0 (and INF/INF, INF-INF, 0.0*INF).
 * There is no such requirement in either IEEE-754 or C99, but it
 * makes for a more consistent system.  Same for nand64("").
 */
  #undef IMPL_INCONSISTENT_nan
  #undef IMPL_INCONSISTENT10_nan

/*
 * Expressions that produce a NaN:
 *    0./0., inf/inf, inf*0, inf-inf, inf+-inf
 * have mixed signs, or not consistent with NAN_LDBL, NAN_DBL, NAN_FLT.
 */
  #undef IMPL_NAN_EXP_SIGN
  #undef IMPL_NAN10_EXP_SIGN

/*
 * Expressions that produce a NaN:
 *    0./0., inf/inf, inf*0, inf-inf, inf+-inf
 * have mixed values, or not consistent with NAN_LDBL, NAN_DBL, NAN_FLT.
 */
  #undef IMPL_NAN_EXP_VALUE
  #undef IMPL_NAN10_EXP_VALUE

/*
 * +NAN, +NAN_FLT, +NAN_DBL, +NAN_LDBL are negative.  This causes the
 * expected value of fabs(NAN) to be wrong.  With this defined, the
 * NAN bit patterns are cleaned up first.  This also affects copysign.
 * Symbol was FIX_NEG_NAN.
 */
  #undef IMPL_pNAN_IS_NEG
  #undef IMPL_pDEC_NAN_IS_NEG

/*
 * +NAN, +NAN_FLT, +NAN_DBL, +NAN_LDBL are a mixture of positive and
 * negative.  This causes the expected value of fabs(NAN) to be wrong.
 * With this defined, the NAN bit patterns are cleaned up first.  This
 * also affects copysign.
 */
  #undef IMPL_pNAN_IS_MIXED
  #undef IMPL_pDEC_NAN_IS_MIXED

/*
 * -NAN, -NAN_FLT, -NAN_DBL, -NAN_LDBL are positive.  This causes the
 * expected value of copysign(-NAN) to be wrong.  With this defined,
 * the NAN bit patterns are cleaned up first.  Symbol was FIX_mNAN or
 * FIX_mNAN_IS_POS.
 */
  #undef IMPL_mNAN_IS_POS
  #undef IMPL_mDEC_NAN_IS_POS

/*
 * -NAN, -NAN_FLT, -NAN_DBL, -NAN_LDBL are a mixture of positive and
 * negative.  This causes the expected value of copysign(-NAN) to be
 * wrong.  With this defined, the NAN bit patterns are cleaned up
 * first.
 */
  #undef IMPL_mNAN_IS_MIXED
  #undef IMPL_mDEC_NAN_IS_MIXED

/*
 * -NAN is same as +NAN.
 */
  #undef IMPL_mNAN_EQ_pNAN
  #undef IMPL_mDEC_NAN_EQ_pDEC_NAN

/*
 * NAN, converted from smaller precision to larger precision and back
 * to original precision should have the same bit pattern.  This is not
 * required by any standard, but makes for consistent FP operations.
 * It is mentioned in IEEE-854 in 6.2.  This affects nexttoward.
 * Same for DEC_NAN.
 */
  #undef IMPL_BAD_ROUNDTRIP_OF_NAN
  #undef IMPL_BAD_ROUNDTRIP_OF_NAN10

/*
 * This matters for func(den).
 * Underflow depends upon tininess and loss of accuracy.
 * Loss of accuracy is either denormalization loss or inexact.
 * There are three choices for the math functions actions when
 * the result is denormal:
 * 1) Tiny and inexact always is underflow:  #undef IMPL_UNDERFLOW_DEN_LOSS
 * 2) Tiny and denorm. loss always is underflow, tiny and inexact is never
 *    underflow:                             #define IMPL_UNDERFLOW_DEN_LOSS 1
 * 3) Tiny and inexact or denorm. loss sometimes is underflow:
 *                                           #define IMPL_UNDERFLOW_DEN_LOSS -1
 * This symbol sets DEN_FLAGS and DEN_FLAGS_OPT in myfloat.h
 */
  #undef IMPL_UNDERFLOW_DEN_LOSS

/*
 * This matters for func(min).
 * Underflow depends upon tininess and loss of accuracy.
 * Tininess is detected either before or after rounding.
 * There are three choices for the math functions actions when
 * the result is denormal:
 * 1) Tiny detected before rounding:  #undef IMPL_UNDERFLOW_MIN_LOSS (or 0)
 * 2) Tiny detected after rounding:  #define IMPL_UNDERFLOW_MIN_LOSS 1
 * 3) Tiny detection inconsistent:   #define IMPL_UNDERFLOW_MIN_LOSS -1
 * This symbol sets MIN_FLAGS and MIN_FLAGS_OPT in myfloat.h
 * The IMPL_* symbol applies to binary FP.
 * The FIX_* symbol applies to decimal FP (which is supposed to be before rnd).
 */
  #undef IMPL_UNDERFLOW_MIN_LOSS
  #undef FIX_DFP_UNDERFLOW_MIN_LOSS

/*
 * If denorms are flushed at runtime, what flags are raised?
 */
  #undef IMPL_FLUSHED_FLAGS

/*
 * Does overflow produce an infinity (as required by IEEE-754), or some
 * finite number (such as IBM S/360 which wraps the exponent).
 * So far, only used in t0000000/t6000000.
 */
  #undef IMPL_DBL_OVER_IS_NOT_INF
  #undef IMPL_D10_OVER_IS_NOT_INF
  #undef IMPL_LDBL_OVER_IS_NOT_INF
  #undef IMPL_LD10_OVER_IS_NOT_INF

/*
 * What is the success return code from the optional fesetprec() function?
 * At one time it was 1, now it is 0 to match the UK CD comments.
 */
  #undef IMPL_OK_fesetprec

/*
 * Is *FE_DFL_ENV comparable (bit for bit) to the result of fegetenv
 * of the default environment (the one at startup).  With this defined,
 * the compare will not be done.
 */
  #undef IMPL_COMP_FE_DFL_ENV

/*
 * Is *FE_DFL_MODE comparable (bit for bit) to the result of fegetmode
 * of the default environment (the one at startup).  With this defined,
 * the compare will not be done.
 */
  #undef IMPL_COMP_FE_DFL_MODE

/*
 * Is FPU environment, as returned by fegetenv, comparable (bit for bit)
 * to the environment from feholdexcept or another fegetenv.
 * With this defined, the compare will not be done.
 */
  #undef IMPL_COMP_FE_GET_ENV

/*
 * Does fegetexceptflag get just the exceptions requested (via the 2nd
 * argument), or does it get more?
 */
  #undef IMPL_GETEXCEPT_TOO_MANY

/*
 * Do feraiseexcept(FE_OVERFLOW) and feraiseexcept(FE_UNDERFLOW) also
 * raise inexact?
 */
  #undef IMPL_OVERUNDER_ALSO_INEXACT	/* both raise inexact */
  #undef IMPL_OVER_ALSO_INEXACT		/* just overflow raises inexact */
  #undef IMPL_UNDER_ALSO_INEXACT	/* just underflow raises inexact */

/*
 * Do feraiseexcept(FE_OVERFLOW) and feraiseexcept(FE_UNDERFLOW) also
 * raise inexact and return zero, as if, feraise*(over/under+inexact)?
 * This only works if IMPL_OVERUNDER_ALSO_INEXACT also defined.
 * Affects test t2121000.
 */
  #undef IMPL_RAISE_WITH_IMPLIED_INEXACT

/*
 * Do trig, hyperbolic, base-e exp, base-e log, error, and lgamma functions
 * always or sometimes raise inexact when value is inexact?  Choices:
 *   #define IMPL_INEXACT_xxx FE_INEXACT -- always (default)
 *   #define IMPL_INEXACT_xxx 0 -- sometimes
 * These are the required setting of inexact.  Inexact will always be optional
 * (except for cbrt for exact cases, where it is optional).
 */
  #undef IMPL_INEXACT_acos
  #undef IMPL_INEXACT_acosh
  #undef IMPL_INEXACT_acospi
  #undef IMPL_INEXACT_asin
  #undef IMPL_INEXACT_asinh
  #undef IMPL_INEXACT_asinpi
  #undef IMPL_INEXACT_atan
  #undef IMPL_INEXACT_atan2
  #undef IMPL_INEXACT_atanh
  #undef IMPL_INEXACT_atanpi
  #undef IMPL_INEXACT_cabs
  #undef IMPL_INEXACT_cacos
  #undef IMPL_INEXACT_cacosh
  #undef IMPL_INEXACT_carg
  #undef IMPL_INEXACT_casin
  #undef IMPL_INEXACT_casinh
  #undef IMPL_INEXACT_catan
  #undef IMPL_INEXACT_catanh
  #undef IMPL_INEXACT_ccos
  #undef IMPL_INEXACT_ccosh
  #undef IMPL_INEXACT_cexp
  #undef IMPL_INEXACT_cimag
  #undef IMPL_INEXACT_clog
  #undef IMPL_INEXACT_compoundn
  #undef IMPL_INEXACT_conj
  #undef IMPL_INEXACT_cos
  #undef IMPL_INEXACT_cosh
  #undef IMPL_INEXACT_cpow
  #undef IMPL_INEXACT_cproj
  #undef IMPL_INEXACT_creal
  #undef IMPL_INEXACT_csin
  #undef IMPL_INEXACT_csinh
  #undef IMPL_INEXACT_csqrt
  #undef IMPL_INEXACT_ctan
  #undef IMPL_INEXACT_ctanh
  #undef IMPL_INEXACT_erf
  #undef IMPL_INEXACT_erfc
  #undef IMPL_INEXACT_exp
  #undef IMPL_INEXACT_exp10
  #undef IMPL_INEXACT_exp10m1
  #undef IMPL_INEXACT_exp2
  #undef IMPL_INEXACT_exp2m1
  #undef IMPL_INEXACT_expm1
  #undef IMPL_INEXACT_lgamma
  #undef IMPL_INEXACT_log
  #undef IMPL_INEXACT_log10
  #undef IMPL_INEXACT_log10p1
  #undef IMPL_INEXACT_log1p
  #undef IMPL_INEXACT_log2
  #undef IMPL_INEXACT_log2p1
  #undef IMPL_INEXACT_logp1
  #undef IMPL_INEXACT_sin
  #undef IMPL_INEXACT_sinh
  #undef IMPL_INEXACT_tan
  #undef IMPL_INEXACT_tanh

  #undef IMPL_OPT_INEXACT_cbrt

  #undef IMPL_INEXACT10_acos
  #undef IMPL_INEXACT10_acosh
  #undef IMPL_INEXACT10_acospi
  #undef IMPL_INEXACT10_asin
  #undef IMPL_INEXACT10_asinh
  #undef IMPL_INEXACT10_asinpi
  #undef IMPL_INEXACT10_atan
  #undef IMPL_INEXACT10_atan2
  #undef IMPL_INEXACT10_atanh
  #undef IMPL_INEXACT10_atanpi
  #undef IMPL_INEXACT10_cabs
  #undef IMPL_INEXACT10_cacos
  #undef IMPL_INEXACT10_cacosh
  #undef IMPL_INEXACT10_carg
  #undef IMPL_INEXACT10_casin
  #undef IMPL_INEXACT10_casinh
  #undef IMPL_INEXACT10_catan
  #undef IMPL_INEXACT10_catanh
  #undef IMPL_INEXACT10_cbrt
  #undef IMPL_INEXACT10_ccos
  #undef IMPL_INEXACT10_ccosh
  #undef IMPL_INEXACT10_ceil
  #undef IMPL_INEXACT10_cexp
  #undef IMPL_INEXACT10_cimag
  #undef IMPL_INEXACT10_clog
  #undef IMPL_INEXACT10_compoundn
  #undef IMPL_INEXACT10_conj
  #undef IMPL_INEXACT10_copysign
  #undef IMPL_INEXACT10_cos
  #undef IMPL_INEXACT10_cosh
  #undef IMPL_INEXACT10_cpow
  #undef IMPL_INEXACT10_cproj
  #undef IMPL_INEXACT10_creal
  #undef IMPL_INEXACT10_csin
  #undef IMPL_INEXACT10_csinh
  #undef IMPL_INEXACT10_csqrt
  #undef IMPL_INEXACT10_ctan
  #undef IMPL_INEXACT10_ctanh
  #undef IMPL_INEXACT10_erf
  #undef IMPL_INEXACT10_erfc
  #undef IMPL_INEXACT10_exp
  #undef IMPL_INEXACT10_exp10
  #undef IMPL_INEXACT10_exp10m1
  #undef IMPL_INEXACT10_exp2
  #undef IMPL_INEXACT10_exp2m1
  #undef IMPL_INEXACT10_expm1
  #undef IMPL_INEXACT10_fabs
  #undef IMPL_INEXACT10_fdim
  #undef IMPL_INEXACT10_floor
  #undef IMPL_INEXACT10_fma
  #undef IMPL_INEXACT10_fmax
  #undef IMPL_INEXACT10_fmin
  #undef IMPL_INEXACT10_fmod
  #undef IMPL_INEXACT10_frexp
  #undef IMPL_INEXACT10_hypot
  #undef IMPL_INEXACT10_ilogb
  #undef IMPL_INEXACT10_ldexp
  #undef IMPL_INEXACT10_lgamma
  #undef IMPL_INEXACT10_llrint
  #undef IMPL_INEXACT10_llround
  #undef IMPL_INEXACT10_log
  #undef IMPL_INEXACT10_log10
  #undef IMPL_INEXACT10_log10p1
  #undef IMPL_INEXACT10_log1p
  #undef IMPL_INEXACT10_log2
  #undef IMPL_INEXACT10_log2p1
  #undef IMPL_INEXACT10_logb
  #undef IMPL_INEXACT10_logp1
  #undef IMPL_INEXACT10_lrint
  #undef IMPL_INEXACT10_lround
  #undef IMPL_INEXACT10_modf
  #undef IMPL_INEXACT10_nan
  #undef IMPL_INEXACT10_nearbyint
  #undef IMPL_INEXACT10_nextafter
  #undef IMPL_INEXACT10_nexttoward
  #undef IMPL_INEXACT10_pow
  #undef IMPL_INEXACT10_quantexp
  #undef IMPL_INEXACT10_quantize
  #undef IMPL_INEXACT10_remainder
  #undef IMPL_INEXACT10_rint
  #undef IMPL_INEXACT10_round
  #undef IMPL_INEXACT10_rsqrt
  #undef IMPL_INEXACT10_scalbln
  #undef IMPL_INEXACT10_scalbn
  #undef IMPL_INEXACT10_sin
  #undef IMPL_INEXACT10_sinh
  #undef IMPL_INEXACT10_sqrt
  #undef IMPL_INEXACT10_tan
  #undef IMPL_INEXACT10_tanh
  #undef IMPL_INEXACT10_tgamma
  #undef IMPL_INEXACT10_trunc

/*
 * Should a decimal function be allowed to return the same value, but
 * with a different quantum (exponent) in the same cohort?
 */
  #undef IMPL_COHORT_frexp
  #undef IMPL_COHORT_ldexp
  #undef IMPL_COHORT_logb
  #undef IMPL_COHORT_rsqrt
  #undef IMPL_COHORT_scalbn
  #undef IMPL_COHORT_scalbln

/* Should a decimal function be allowed to return any representation
 * of zero (there are lots), or the expected bit pattern?  Same idea
 * for non-zero results (mainly, one).
 *   sin(+/-0.) is +/-0.
 *   cos(+/-0.) is +1.
 * IEEE-754 2008 says, in 9.1, that it is language defined as to the
 * preferred quantum (exponent).
 */
  #undef IMPL_COHORT_ZERO
  #undef IMPL_COHORT_NONZERO

/*
 * If these symbols are macros, but they are not usable in #if, #elif,
 * then define these symbol.
 */
  #undef IMPL_POOR_math_errhandling
  #undef IMPL_POOR_FP_ILOGB0
  #undef IMPL_POOR_FP_ILOGBNAN

/*
 * When checking consistentcy between errno and the FP exception flags,
 * do not use the actual flags (use expected flags).
 * See g1errno.h
 */
  #undef IMPL_NO_TEST_ACTUAL_FLAGS

/*
 * When checking consistentcy between errno and the FP exception flags,
 * do not use the actual critical flags (use expected flags).
 * See g1errno.h
 */
  #undef IMPL_NO_TEST_CRIT_FLAGS

/*
 * If (math_errhandling & MATH_ERRNO) is zero (meaning FP exceptions
 * are done with flags), is errno (sometimes) also altered (rather
 * than being left alone)?  With this defined, the spurious errno
 * value is checked to make sure it is consistent with the flags.
 */
  #undef IMPL_SPURIOUS_ERRNO

/*
 * errno should be consistent with FP exception flags when
 * directed rounding is used, eg, other than default rounding mode.
 */
  #undef IMPL_NO_ERRNO_RND_acos
/* ... */
  #undef IMPL_NO_ERRNO_RND_trunc
  #undef IMPL_NO_ERRNO_RND10_acos
/* ... */
  #undef IMPL_NO_ERRNO_RND10_trunc

/*
 * If ERANGE is not raised for underflow, then define this symbol for the
 * appropriate function.
 */
  #undef IMPL_UF_WEIRD_acos
/* ... */
  #undef IMPL_UF_WEIRD_trunc
  #undef IMPL_UF_WEIRD10_acos
/* ... */
  #undef IMPL_UF_WEIRD10_trunc

/*
 * Function result should be dependent upon current rounding direction.
 * Difference between f(UP) and f(DOWN) should be exactly 1 ulp.
 * Should have: f(DOWN) < f(UP)
 */
  #undef IMPL_NO_STRONG_RND_acos
/* ... */
  #undef IMPL_NO_STRONG_RND_trunc
  #undef IMPL_NO_STRONG_RND10_acos
/* ... */
  #undef IMPL_NO_STRONG_RND10_trunc

/*
 * Function result should be dependent upon current rounding direction.
 * Should have: f(DOWN) <= f(UP)
 */
  #undef IMPL_NO_WEAK_RND_acos
/* ... */
  #undef IMPL_NO_WEAK_RND_trunc
  #undef IMPL_NO_WEAK_RND10_acos
/* ... */
  #undef IMPL_NO_WEAK_RND10_trunc

/*
 * Allow or suppress the printout of the maximum ULP error found in t1..*003 tests.
 */
  #undef IMPL_SUPPRESS_MAX_ULP_acos
/* ... */
  #undef IMPL_SUPPRESS_MAX_ULP_tgamma
  #undef IMPL_SUPPRESS_MAX_ULP10_acos
/* ... */
  #undef IMPL_SUPPRESS_MAX_ULP10_tgamma

/*
 * Allow or suppress the printout of the x value when overflow first happens.
 */
  #undef IMPL_SUPPRESS_OVER_cosh
  #undef IMPL_SUPPRESS_OVER_exp
  #undef IMPL_SUPPRESS_OVER_exp2
  #undef IMPL_SUPPRESS_OVER_expm1
  #undef IMPL_SUPPRESS_OVER_lgamma
  #undef IMPL_SUPPRESS_OVER_sinh
  #undef IMPL_SUPPRESS_OVER_tgamma
  #undef IMPL_SUPPRESS_OVER10_cosh
  #undef IMPL_SUPPRESS_OVER10_exp
  #undef IMPL_SUPPRESS_OVER10_exp2
  #undef IMPL_SUPPRESS_OVER10_expm1
  #undef IMPL_SUPPRESS_OVER10_lgamma
  #undef IMPL_SUPPRESS_OVER10_sinh
  #undef IMPL_SUPPRESS_OVER10_tgamma

/*
 * Function is supposed to be monotonic is a given (limited) domain.
 */
  #undef IMPL_MONOTONIC_cbrt
  #undef IMPL_MONOTONIC_lgamma
  #undef IMPL_MONOTONIC_tgamma
  #undef IMPL_MONOTONIC10_cbrt
  #undef IMPL_MONOTONIC10_lgamma
  #undef IMPL_MONOTONIC10_tgamma

/*
 * Does an array of LDBLs and a struct of LDBLs have the same
 * alignment and padding in a union?  Used in t0100002.
 */
  #undef IMPL_STRUCT_NE_ARRAY_ALIGN

/*
 * Any / ( 0.0 + 0.0*I ) should be treated as if the zero were on the
 * x-axis (so that the angle of the zero matches atan2 and carg).
 */
  #undef IMPL_CMPLX_DIV_ZERO_NOT_XAXIS

/*
 * Operations involving complex and real should not trigger the imaginary SNaN.
 * Operations involving complex and imaginary should not trigger the real SNaN.
 * It is implementation defined if the SNaN should trigger.
 */
  #undef IMPL_CMPLX_ADD_SNAN	/* SNaN triggered in + */
  #undef IMPL_CMPLX_DIV_SNAN	/* SNaN triggered in / */
  #undef IMPL_CMPLX_MUL_SNAN	/* SNaN triggered in * */
  #undef IMPL_CMPLX_SUB_SNAN	/* SNaN triggered in - */

/*
 * Conversion of SNAN to bool is implementation defined if the SNaN is
 * triggered.
 */
  #undef IMPL_REAL_BOOL_SNAN	/* SNaN triggered in conversion to bool */
  #undef IMPL_DFP_BOOL_SNAN	/* SNaN triggered in conversion to bool */
  #undef IMPL_IMAG_BOOL_SNAN	/* SNaN triggered in conversion to bool */
  #undef IMPL_CMPLX_BOOL_SNAN	/* SNaN triggered in conversion to bool */

/*
 * The error in the unit in the last place of the various arithmetic
 * operators.
 */
  #undef ULPS_REAL_ADD_DBL	/* Used in t0000800 */
  #undef ULPS_REAL_ADD_LDBL	/* Used in t0000800 */
  #undef ULPS_REAL_MUL_DBL	/* Used in t0010300, t0010600 */
  #undef ULPS_REAL_MUL_LDBL	/* Used in t0000700 for dbl_dbl */
  #undef ULPS_REAL_DIV_DBL	/* Used in t0010400, t0010700 */
  #undef ULPS_REAL_DIV_LDBL	/* Used in t0010100 for dbl_dbl in (a*b)/a == b */
  #undef ULPS_CMPLX_MUL_FLT	/* Used in t40301mm */
  #undef ULPS_CMPLX_MUL_LDBL	/* Used in t40301mm */
  #undef ULPS_CMPLX_DIV_FLT	/* Used in t40302mm,ss,ww */
  #undef ULPS_CMPLX_DIV_DBL	/* Used in t40302mm,ss,ww */
  #undef ULPS_CMPLX_DIV_LDBL	/* Used in t40302mm,rr,ss,ww */
  #undef ULPS_REAL_MUL_D10	/* Used in t6010300 */
  #undef ULPS_REAL_MUL_LD10	/* Used in t6010300 for dbl_dbl */
  #undef ULPS_REAL_DIV_D10	/* Used in t6010400 */
  #undef ULPS_REAL_DIV_LD10	/* Used in t6010400 for dbl_dbl */

/*
 * The error in the unit in the last place of the various math functions.
 */
  #undef ULP_acos
/* ... thru ... */
  #undef ULP_trunc
  #undef ULP10_acos
/* ... thru ... */
  #undef ULP10_trunc

/*
 * The error in the unit in the last place of the various math functions.
 * This is for special "identities".
 */
  #undef ULP_acos_sum	/* f(x) + f(-x) vs pi */
  #undef ULP_acospi_sum	/* f(x) + f(-x) vs 1 */
  #undef ULP_atan_sum	/* f(x) + f(1/x) vs pi/2 */
  #undef ULP_cacos_sum
  #undef ULP_compoundn_sum /* f(x,y) vs pow(1+x,y) */
  #undef ULP_cpow_sum	/* f(x,-y) vs 1/f(x,y) */
  #undef ULP_erfc_sum	/* 2-f(-x) vs f(x) */
  #undef ULP_exp10_sum	/* 1/f(-x) vs f(x) */
  #undef ULP_exp10m1_sum/* 1/f(-x) vs f(x) */
  #undef ULP_exp2_sum	/* 1/f(-x) vs f(x) */
  #undef ULP_exp2m1_sum	/* f(x) vs expm1(x*ln(2)) */
  #undef ULP_exp_sum	/* 1/f(-x) vs f(x) */
  #undef ULP_expm1_sum	/* f(-x) vs f(x) and 1/(f(-x)-1) vs f(x) */
  #undef ULP_fdiv_sum	/* 1/f(y/x) vs f(x/y) */
  #undef ULP_fsqrt_sum	/* 1/f(1/x) vs f(x) */
  #undef ULP_log10_sum	/* -f(1/x) vs f(x) */
  #undef ULP_log10p1_sum/* -f(1/x) vs f(x) and -f(1/(x+1)-1) vs f(x) */
  #undef ULP_log1p_sum	/* -f(-x) vs f(x) and -f(1/(x+1)-1) vs f(x) */
  #undef ULP_log2_sum	/* -f(1/x) vs f(x) */
  #undef ULP_log2p1_sum	/* -f(1/x) vs f(x) and -f(1/(x+1)-1) vs f(x) */
  #undef ULP_log_sum	/* -f(1/x) vs f(x) */
  #undef ULP_logp1_sum	/* -f(-x) vs f(x) and -f(1/(x+1)-1) vs f(x) */
  #undef ULP_pow_sum	/* 1/f(x,-y) vs f(x,y) and f(1/x,-y) vs f(x,y) and 1/f(1/x,y) vs f(x,y) */
  #undef ULP_rsqrt_sum	/* 1/f(1/x) vs f(x) */
  #undef ULP_sqrt_sum	/* 1/f(1/x) vs f(x) */

/*
 * The error in the unit in the last place of the various math functions.
 * This is for special "identities".
 */
  #undef ULP_acospi_ident	/* f(x) vs acos(x)/pi */
  #undef ULP_compoundn_ident	/* f(x,y) vs 1/f(x,-n) */
  #undef ULP_rsqrt_ident	/* f(x) vs 1/sqrt(x) */

/*
 * Certain math functions are supposed to be exact at certain values.
 * This changes tests to use ULP_* instead of BIT4BIT for accuracy.
 */
  #undef FIX_SLOPPY_acospi	/* f(1) [and f(0), f(-1)] */
  #undef FIX_SLOPPY_asinpi	/* f(1) [and f(0), f(-1)] */
  #undef FIX_SLOPPY_atanpi	/* f(1) [and f(0), f(-1)] */

/*
 * The error in the unit in the last place of the three trig math
 * functions for large arguments.
 */
  #undef ULP_LARGE_ARG10_cos
  #undef ULP_LARGE_ARG10_sin
  #undef ULP_LARGE_ARG10_tan
  #undef ULP_LARGE_ARG_cos
  #undef ULP_LARGE_ARG_sin
  #undef ULP_LARGE_ARG_tan

/*****************
 * These show up as translation time errors that ends compile, or maybe
 * missing function implementation that ends link edit.
 * First are the old (ISO/ANSI) C89/C90/C95 violations.
 * Second are Standard C99 violations.
 * Third are Decimal Floating-Point (DFP) Tech Report violations.
 * Fourth are C11 violations.
 ****************/

/*** Translate time: C89/C90/C95 ***/

/*
 * <iso646.h> is a required ISO/ANSI C header.
 * <locale.h> header is part of ISO/ANSI C.
 * <time.h> is a required ISO/ANSI C header.
 * <wchar.h> is a header new with C95.
 * <wctype.h> is a header new with C95.
 */
  #undef FIX_ISO646_H
  #undef FIX_LOCALE_H
  #undef FIX_TIME_H
  #undef FIX_WCHAR_H
  #undef FIX_WCTYPE_H
  #undef FIX_CHAR_H		/* g008/g308 synch */

/*
 * Wide chars, L'c', are part of ISO/ANSI C.
 */
  #undef FIX_WIDE_CHAR

/*
 * Wide character string, L"c", are part of ISO/ANSI C.
 */
  #undef FIX_WIDE_STR

/*
 * Quoted (via \ char) characters, eg \", in char or string.
 */
  #undef FIX_QUOTE_QUOTE

/*
 * char is a different type from both signed char and unsigned char.
 * Matters for (at least) _Generic().
 */
  #undef FIX_3_CHARS

/*
 * !else may be valid or invalid depending upon context.
 */
  #undef FIX_BANG_ELSE

/*
 * 'ch' is valid C code whose value is implementation defined.
 */
  #undef FIX_MANY_CHAR

/*
 * '\x00000008' is not liked by some compilers
 * '\x0080' is not liked by some compilers
 * '\x0100' is not liked by some compilers
 */
  #undef FIX_MANY_HEX_DIGS
  #undef FIX_BAD_HEX_128
  #undef FIX_BAD_HEX_256

/*
 * index[array] is same as array[index], eg, 1[a] == a[1]; This is ISO/ANSI C.
 */
  #undef FIX_INT_BRACKET_ARRAY

/*
 * static unsigned long int uli = 1.0; is valid ISO/ANSI C code.
 */
  #undef FIX_ULI_EQ_FP

/*
 * Prototypes in headers should not violate the user's name space by ISO/ANSI C.
 */
  #undef FIX_NAME_SPACE

/*
 * Compiler's libraries should not violate the user's name space by ISO/ANSI C.
 */
  #undef FIX_LINK_NAME_SPACE
  #undef FIX_LINK10_NAME_SPACE

/*
 * Link edit program (linker) is limited to 6 character names.
 * Used by decmath.h
 */
  #undef FIX_6CHAR_LINK_NAME

/*
 * Either math.h or float.h defines math related values such as PI or PI2.
 * That violates the user's name space (and interferes with my definitions
 * of those values done in myfloat.h).
 */
  #undef FIX_MATH_PI

/*
 * macro(d++) should be legal by ISO/ANSI C.
 */
  #undef FIX_BAD_MACROS

/*
 * offsetof() macro missing
 */
  #undef FIX_OFFSETOF

/*
 * Can offsetof() use "->" to access member?
 */
  #undef FIX_OFFSETOF_ARROW

/*
 * When offsetof() defines new type, is that type useable at function scope?
 */
  #undef FIX_OFFSETOF_FUNC_SCOPE

/*
 * When offsetof() defines new type, is that type useable?
 */
  #undef FIX_OFFSETOF_NEWTYPE_USEABLE

/*
 * When offsetof() defines new type in do...while(offsetof()), is that type useable?
 */
  #undef FIX_OFFSETOF_NEWTYPE_DO_USEABLE

/*
 * When offsetof() defines new type in if(), is that type useable?
 */
  #undef FIX_OFFSETOF_NEWTYPE_IF_USEABLE

/*
 * sizeof(1/0), sizeof(0/0) are legal by ISO/ANSI C.
 */
  #undef FIX_SIZEOF_DIV_BY_ZERO

/*
 * sizeof(1.0/0.0), sizeof(0.0/0.0) are legal by ISO/ANSI C.
 */
  #undef FIX_SIZEOF_DIV_BY_0

/*
 * sizeof *(func(), &vla) kills some compilers.
 * This is a way to find out if sizeof is runtime evaluation.
 */
  #undef  FIX_SIZEOF_COMMA_VLA

/*
 * int ary[(int)2.0]; is valid ISO/ANSI C.
 */
  #undef FIX_ARRAY_BOUND_INT_CAST

/*
 * struct bits { int b : (int)2.0; } bb; is valid ISO/ANSI C.
 */
  #undef FIX_BIT_FIELD_SIZE_INT_CAST

/*
 * enum c { red = (int)0.0 } cc ; is valid ISO/ANSI C.
 */
  #undef FIX_ENUM_VAL_INT_CAST

/*
 * enum c { red = -0xfff0u };
 * While the value is unsigned, the enum const must be signed int.
 */
  #undef FIX_ENUM_CONST_IS_SIGNED_INT

/*
 * enum c { blue = -1, red = -0xfff0u };
 * While the red value is unsigned, blue is negative, so c must be signed.
 */
  #undef FIX_ENUM_IS_SIGNED_INT

/*
 * switch (i){ case (int)2.0:; } is valid ISO/ANSI C.
 */
  #undef FIX_CASE_INT_CAST

/*
 * LDBL is a valid ISO/ANSI C type.  This changes LDBL to DBL
 * for a few specific tests.  REMAP_LDBL is more general.
 * LD10 is the Decimal FP version of LDBL (should not be used).
 */
  #undef FIX_LDBL
  #undef FIX_LD10

/*
 * Change LDBL to be DBL, do not append "L" to floating-point literals,
 * and change name of function called (do not append "l").  This is useful
 * if compiler is missing LDBL functions or does not like LDBL
 * literals or type.  More information is available later in this file
 * (look for REMAP_).  Contrast this with IMPL_LDBL_EQ_DBL.
 * REMAP_LD10 is for decimal FP.
 */
  #undef REMAP_LDBL
  #undef REMAP_LD10

/*
 * Change DBL to be LDBL, do append "L" to floating-point 'DBL'
 * literals, and change name of 'DBL' function called (do append "l").
 * This has not been tested yet (idea was added when added REMAP_LDBL).
 * Would only be useful if system has DBL and FLT being the same.
 * REMAP_D10 is for decimal FP.
 */
  #undef REMAP_DBL
  #undef REMAP_D10

/*
 * volatile is a valid ISO/ANSI C qualifier.
 */
  #undef FIX_VOLATILE

/*
 * short signed int ... is valid.
 */
  #undef FIX_SHORT_SIGNED

/*
 * long signed int ... is valid.
 */
  #undef FIX_LONG_SIGNED

/*
 * 1e-10##f and #1e-10 in macro usage are valid ISO/ANSI C.
 * Something to do with minus sign in exponent causes problems.
 */
  #undef FIX_MINUS_EXP

/*
 * PP expression causes problems to at least one compiler.
 *  #elif( PC_PREC == SC_PREC )
 */
  #undef FIX_PP_EXP

/*
 * #if 0 && (0/0) is valid.
 */
  #undef FIX_PP_ANDAND_OP

/*
 * #if 1 || (0/0) is valid.
 */
  #undef FIX_PP_OROR_OP

/*
 * #if 1 ? 2 : (0/0) is valid
 */
  #undef FIX_PP_TRI_OP

/*
 * 1 ? 1 : ICE (Integer Constant Expression) is valid.
 */
  #undef FIX_TRI_OP_ICE

/*
 * PP macros with actual arguments having imbedded commas
 * are done wrong.  For tflt2int and tint2flt.
 */
  #undef FIX_BROKEN_PP
  #undef FIX_SEMIBROKEN_PP

/*
 * PreProcessor ## (to concatenate) should work with blanks/spaces around it.
 */
  #undef FIX_SHARPSHARP_BLANK

/*
 * / * * / should be treated as a blank in #define.
 */
  #undef FIX_COMMENT_AS_BLANK

/*
 * #define on multiple physical lines should work.
 */
  #undef FIX_SPLIT_DEFINE

/*
 * #line on multiple physical lines should work.
 */
  #undef FIX_SPLIT_HASHLINE

/*
 * #if on multiple physical lines should work.
 */
  #undef FIX_SPLIT_IF

/*
 * Macro invocation split across two files should work.
 */
  #undef FIX_MAC_IN_2_FILES

/*
 * #line nnnn __FILE__ is not liked by at least one compiler.
 */
  #undef FIX_line_WITH_FILE

/*
 * #line nnnn __FILE__ is not liked by at least one compiler
 * when  nnnn is split across many lines.
 */
  #undef FIX_line_WITH_SPLIT_NUMBER

/*
 * #line nnnn blank is not liked by at least one compiler
 * when blank is a blank after line continues.
 */
  #undef FIX_line_WITH_BLANK_FILE

/*
 * PreProcessor # (to make a string) should work as per the standard.
 */
  #undef FIX_SHARP_STR

/*
 * PreProcessor macro invoking another macro should work to expand argument.
 * The xFPK() macros in this file are tested in t00004000.
 */
  #undef FIX_xFPK

/*
 * PP-number used as a PP-token in token pasting to create an
 * identifier causes problems to at least one compiler.
 * The specific case is:  mac(pp,3_aut); where mac(a,b) does a ## b
 */
  #undef FIX_DIG_LET_PP_NUMBER

/*
 * 000e96 is a valid FP constant, yet some compilers think it is invalid.
 */
  #undef  FIX_NODOT_E

/*
 * FP constants of the form x000000...000000Ey get converted to the wrong value.
 * That is, non-zero digit(s) followed by many zeros followed by exponent.
 */
  #undef  FIX_DIG_ZEROS_EXP

/*
 * FP constants of the form .000000...000000x get converted to the wrong value.
 * That is, a dot followed by many zeros followed by non-zero digits.
 */
  #undef  FIX_DOT_ZEROS_DIG

/*
 * FP constants of the form xE000000...000000y get converted to the wrong value.
 * That is, an exponent with many leading zeros.
 */
  #undef  FIX_E_ZEROS_DIG

/*
 * 08.5, 09.f, 09e0L are valid ISO/ANSI C floating-point constants,
 * yet some lints and compilers think they are invalid octal integers.
 */
  #undef FIX_OCTAL_FLOATS

/*
 * mac(08) and mac(09) are considered invalid octal constants in a
 * macro expansion.
 */
  #undef FIX_INVALID_OCTAL

/*
 * Implicit promotion of FLT to DBL in [w]printf is valid
 * ISO/ANSI C, yet it causes some compilers problems.
 * For F10, it is NOT promoted (unless there is a bug in the compiler).
 */
  #undef FIX_IMPLICIT_FLT2DBL_IN_PRINTF
  #undef FIX_IMPLICIT_F102D10_IN_PRINTF

/*
 * Explicit cast (char *) needed to convert const char array.
 */
  #undef FIX_IMPLICIT_CHAR_PTR

/*
 * DBL + DBL * DBL should be valid, eg, 1.0 + ulp * 4.0
 */
  #undef FIX_DBL_PLUS_DBL_TIMES_DBL
  #undef FIX_D10_PLUS_D10_TIMES_D10

/*
 * int func();  ....; int func(int) should be accepted.
 */
  #undef  FIX_OLD_STYLE_NO_PARMS

/*
 * int func(v1,v2); int v1; int v2; {...} should be accepted before C2X.
 * With C2X, it is no longer valid C code.
 */
  #undef  FIX_OLD_STYLE_ID_LIST

/*
 * int func( const struct st ) should be accepted.
 */
  #undef  FIX_CONST_STRUCT_PARM

/*
 * static const DBL d[] = { 1.0 - ULP_DBL/2.0 } is valid ISO/ANSI C,
 * yet it causes some systems to core dump at runtime or give syntax
 * errors at compile time.  This removes the static and/or const.
 */
  #undef FIX_STATIC_CONST

/*
 * static LDBL ld[] = { 1.L - ULP_LDBL/2.L } is valid ISO/ANSI C,
 * yet it causes some systems to core dump at runtime or give syntax
 * errors at compile time.
 */
  #undef FIX_STATIC_LDBL_EXP

/*
 * register const DBL d = ULP_DBL; is valid ISO/ANSI C, yet it causes
 * some systems to give syntax errors at compile time.  This removes
 * the const.
 */
  #undef FIX_REGISTER_CONST

/*
 * static DBL d[] = { 0.0/0.0, 1.0/0.0 } is valid C99 w/ IEEE-754,
 * yet it causes some systems to core dump at runtime or give syntax
 * errors at compile time.  This removes the static in the math library
 * test vector array declaration.  Mainly needed for NAN_* and INF_*.
 */
  #undef FIX_STATIC_VECTORS

/*
 * static DBL d = 3.1416/2; is valid C89, yet it causes some
 * systems to core dump at runtime or give syntax errors at compile
 * time.  This removes the static.
 */
  #undef FIX_STATIC_SCALAR

/*
 * File scope static FLT d[] = { FLT_MIN*FLT_MIN/FLT_MIN } is valid
 * ISO/ANSI C, yet it causes some systems to give syntax errors at
 * compile time.  Seems to happen only if expression has over/underflow.
 * This removes the var and tests of that var.
 */
  #undef FIX_FILE_SCOPE_FP_INIT

/*
 * File scope static DBL d[] = { 1.0 - ULP_DBL/2.0 } is valid
 * ISO/ANSI C, yet it causes some systems to give syntax errors at
 * compile time.  This adds compiler specific pragmas around dcl.
 */
  #undef FIX_FP_EXP_IN_INIT

/*
 * DBL d[] = { 1.0 - ULP_DBL/2.0 } is valid ISO/ANSI C, yet it causes
 * some systems to complain at translate time about invalid initializer.
 */
  #undef FIX_CONST_EXP_IN_INIT

/*
 * struct bits{ int a:3; } = { 1 } is valid ISO/ANSI C, yet it causes
 * some systems to complain at translate time about invalid initializer.
 */
  #undef FIX_STRUCT_INIT

/*
 * Having a const member of a struct that is a typedef kills some C++
 * compilers (even though that typedef will be used in a POD --
 * Plain Old Data, eg, an array).
 */
  #undef FIX_CONST_IN_TYPEDEF_STRUCT

/*
 * static short si = 1.0; is valid ISO/ANSI C, yet it causes some
 * systems to complain at translate time about invalid initializer.
 */
  #undef FIX_INIT_SHORT_WITH_FP

/*
 * static char c = 1.0; is valid ISO/ANSI C, yet it causes some
 * systems to complain at translate time about invalid initializer.
 */
  #undef FIX_INIT_CHAR_WITH_FP

/*
 * xglue and glue macros are valid ISO/ANSI C code.
 */
  #undef FIX_XGLUE

/*
 * xstr and str macros are valid ISO/ANSI C code.
 * Symantec core dumps with t0080000.
 */
  #undef FIX_XSTR

/*
 * Macro invocation of +x or -x ends up with + x or - x, ie, an extra
 * blank is added.  That is bad.
 */
  #undef FIX_EXTRA_BLANK

/*
 * Macro invocation of F()B, where both F() and B are macro symbols ends
 * up without a blank between them.  That is bad.
 */
  #undef FIX_MISSING_BLANK

/*
 * '#' is a valid preprocessor statement, yet it kills some compilers.
 * Just having the above '#' without the "'" chars in this comment
 * kills some compilers.
 */
  #undef FIX_EMPTY_PP

/*
 * Define of macro symbol split across many lines kills some compilers.
 */
  #undef FIX_SPLIT_MAC_SYMBOL_DEF

/*
 * Reference of macro symbol split across many lines kills some compilers.
 */
  #undef FIX_SPLIT_MAC_SYMBOL_REF

/*
 * __LINE__ split across many lines kills some compilers.
 */
  #undef FIX_SPLIT_LINE

/*
 * '...' is a valid preprocessor token, yet having more than 4 chars
 * in a character constant kills some compilers.
 */
  #undef FIX_4CHAR_IN_PPTOKEN

/*
 * "# 2 line 250"  is a valid preprocessor token, yet kills some compilers.
 */
  #undef FIX_WEIRD_PP_LINE

/*
 * Preprocessor macro symbols greater than 31 characters cause random
 * behaviour with some compilers (sometimes honor, sometimes ignore,
 * #ifdef, #ifndef, #if defined, #if !defined).
 */
  #undef FIX_LONG_SYMBOLS
  #undef FIX_LONG_SYMBOLS_32
  #undef FIX_LONG_SYMBOLS_64

/*
 * #elif( 1 ) is a valid preprocessor statement, yet it kills some compilers.
 * They think function f( 1 ) is being invoked.  #elif ( 1 ) works OK.
 */
  #undef FIX_ELIF_AS_FUNCTION

/*
 * t030* have some multi-line macro definitions.
 * Some compilers (DigMars) die when they try to expand those macros.
 */
  #undef FIX_2_HARD_4_PP

/*
 * Multi-line FP numbers that are used in PreProcessor macros kill some compilers.
 */
  #undef FIX_LONG_PP_FP_NUM

/*
 * PreProcessor "keywords" are not reserved, so can be used in other contexts.
 * Tested in t0000500.
 */
  #undef FIX_FUNNY_PP_TOKENS

/*
 * PreProcessor "keywords" are not reserved, so can be used in other contexts.
 * Tested in t0000500.
 */
  #undef FIX_if_TOKEN
  #undef FIX_else_TOKEN

/*
 * PreProcessor "keywords" are not reserved, so can be used in other contexts.
 * Tested in t0000500.
 */
  #undef FIX_defined_IN_MACRO

/*
 * Macro definition like #define DBL_MIN_10_EXP -307
 * followed by usage like i = -DBL_MIN_10_EXP;
 * causes some compilers to think the expansion i = --307; is an attempt
 * to apply the prefix decrement operator '--' to something other than
 * a modifiable lvalue.  But, there is no '--' operator.  There are two
 * '-' operators, each coming from separate pp-tokens.  The fix for that
 * compiler is to do #define DBL_MIN_10_EXP (-307)
 */
  #undef FIX_NEG_NEG

/*
 * Macro definition like #define DBL_MAX_10_EXP +307
 * followed by usage like i = +DBL_MAX_10_EXP;
 * causes some compilers to think the expansion i = ++307; is an attempt
 * to apply the prefix increment operator '++' to something other than
 * a modifiable lvalue.  But, there is no '++' operator.  There are two
 * '+' operators, each coming from separate pp-tokens.  The fix for that
 * compiler is to do #define DBL_MAX_10_EXP (+307)
 */
  #undef FIX_PLUS_PLUS

/*
 * Some macro symbols in the headers are missing or have such poor
 * definitions that they are unusable to t035*.
 */
  #undef FIX_SYM_BUFSIZ
  #undef FIX_SYM_CLOCKS_PER_SEC
  #undef FIX_SYM_EILSEQ
  #undef FIX_SYM_EOF
  #undef FIX_SYM_EXIT_FAILURE
  #undef FIX_SYM_EXIT_SUCCESS
  #undef FIX_SYM_LLONG_MAX
  #undef FIX_SYM_LLONG_MIN
  #undef FIX_SYM_L_tmpnam
  #undef FIX_SYM_NULL
  #undef FIX_SYM_ULLONG_MAX
  #undef FIX_SYM_WCHAR_MAX
  #undef FIX_SYM_WCHAR_MIN
  #undef FIX_SYM_WEOF
  #undef FIX_SYM_va_arg

/*
 * Expressions with (integer && floating) done wrong.
 */
  #undef FIX_INT_ANDAND_FLT
  #undef FIX_INT_ANDAND_F10

/*
 * Expressions with (floating && floating) done wrong.
 */
  #undef FIX_FLT_ANDAND_FLT
  #undef FIX_F10_ANDAND_F10

/*
 * Expressions with (floating || floating) done wrong.
 */
  #undef FIX_FLT_OROR_FLT
  #undef FIX_F10_OROR_F10

/*
 * Expressions with (any && FP constant) done wrong.
 */
  #undef FIX_ANDAND_FLT_CONST
  #undef FIX_ANDAND_F10_CONST

/*
 * Expressions with (0 && weird Integer Constant Expression) done wrong.
 */
  #undef FIX_0_ANDAND_ICE

/*
 * Expressions with (1 || weird Integer Constant Expression) done wrong.
 */
  #undef FIX_1_OROR_ICE

/*
 * Expressions with (any || FP constant) done wrong.
 */
  #undef FIX_OROR_FLT_CONST
  #undef FIX_OROR_F10_CONST

/*
 * Pointer && floating-point should be valid.
 */
  #undef FIX_PTR_ANDAND_FP
  #undef FIX_PTR_ANDAND_FP10

/*
 * Pointer || floating-point should be valid.
 */
  #undef FIX_PTR_OROR_FP
  #undef FIX_PTR_OROR_FP10

/*
 * (Complex && any) should be valid.
 */
  #undef FIX_CMPLX_ANDAND

/*
 * 0.0 || var done wrong.
 */
  #undef FIX_FPZERO_OROR_VAR

/*
 * Some C++ compilers disallow using enums to && and || operators.
 */
  #undef FIX_ENUM_TO_ANDAND
  #undef FIX_ENUM_TO_OROR

/*
 * FP function and compare used together fail w/ several compilers.
 */
  #undef FIX_FPFUNC_AND_COMP

/*
 * Integer arguments passed to math library functions is valid, eg, exp(3uL)
 */
  #undef FIX_MATH_FUNC_OF_INTEGER
  #undef FIX_MATH10_FUNC_OF_INTEGER

/*
 * Strings made via # with 509 chars are valid in C89.
 * Used in t0090000, t0100200.
 */
  #undef FIX_509_CHARS

/*
 * Floating-point numbers with 509 (or 4095) digits are valid ISO/ANSI C.
 * Define this macro symbol to the number of digits compiler allows.
 * Used in v0080110 and t0088000.
 */
  #undef FIX_MANY_DIGITS

/*
 * EXIT_FAILURE and EXIT_SUCCESS missing from <stdlib.h>, so define some
 * value so the code can compile and run.  0 is the same as success.
 * There is no standard value for failure.
 */
  #undef NEED_EXIT_SYMS

/*
 * Too much data.  x86 PC's are limited to 64K total data per segment.
 * Standard C limit is 32K per object for hosted environment
 * (operating system + compiler/interpreter).
 * There appears to be no limit on freestanding environments.
 */
  #undef FIX_64K_DATA

/*
 * Too big to compile. ISO/ANSI C requires that must compile
 * as long as do not violate translation limits.
 */
  #undef FIX_TOO_BIG_TOO_COMPILE

/*
 * Too complicated to compile. ISO/ANSI C requires that must compile
 * as long as do not violate translation limits.
 */
  #undef FIX_TOO_HARD_TOO_COMPILE

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * #if (INT)1  or  #if (INT)1.0  or  #if (INT)(1.0/1.0)
 */
  #undef FIX_ACC_BAD_IF_VAL

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * #undef  defined
 * #define defined 11
 */
  #undef FIX_ACC_REDEF_defined

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * #if defined
 */
  #undef FIX_ACC_BARE_defined

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * #if defined defined
 * #ifdef defined
 * #ifndef defined
 */
  #undef FIX_ACC_defined_defined

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * #if _Pragma
 */
  #undef FIX_ACC_BARE__Pragma

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * ) ## eval
 * that is a result of macro expansion
 */
  #undef FIX_ACC_BAD_PP_TOKEN

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * #if (1,2,3)
 * It is a constraint violation in 6.6 Constant expression.
 */
  #undef FIX_ACC_PP_COMMA_OP

/*
 * (& * var) is accepted and var is not a pointer.  e01627*.fjt
 */
  #undef FIX_ADDR_OR_INDIR_ACC_NON_PTR

/*
 * struc.bits.uibf is correct and struc.uibf is accepted.  e01628*.fjt
 */
  #undef FIX_DOT_ACC_NON_MEMBER

/*
 * p0 -> bits.uibf is correct and p0 -> uibf is accepted.  e01629*.fjt
 */
  #undef FIX_ARROW_ACC_NON_MEMBER

/*
 * array[floating] is accepted.  e01630*.fjt
 */
  #undef FIX_ARRAY_ACC_FLOAT

/*
 * array[ptr] is accepted.  e01630*.fjt
 */
  #undef FIX_ARRAY_SUBSCRIPT_ACC_PTR

/*
 * sizeof( bit-field member ) is accepted.
 */
  #undef FIX_SIZEOF_ACC_BIT_FIELD_MEMBER

/*
 * ~flt, ~ptr, +ptr, -ptr accepted.
 */
  #undef FIX_UNI_BIT_COMP_ACC_FLOAT
  #undef FIX_UNI_BIT_COMP_ACC_PTR
  #undef FIX_UNI_POS_OR_NEG_ACC_PTR

/*
 * Binary operators accept non-integer operands.
 */
  #undef FIX_BIN_BIT_AND_ACC_FLOAT
  #undef FIX_BIN_BIT_AND_ACC_PTR
  #undef FIX_BIN_BIT_AND_EQ_ACC_FLOAT
  #undef FIX_BIN_BIT_AND_EQ_ACC_PTR
  #undef FIX_BIN_BIT_OR_ACC_FLOAT
  #undef FIX_BIN_BIT_OR_ACC_PTR
  #undef FIX_BIN_BIT_OR_EQ_ACC_FLOAT
  #undef FIX_BIN_BIT_OR_EQ_ACC_PTR
  #undef FIX_BIN_BIT_XOR_ACC_FLOAT
  #undef FIX_BIN_BIT_XOR_ACC_PTR
  #undef FIX_BIN_BIT_XOR_EQ_ACC_FLOAT
  #undef FIX_BIN_BIT_XOR_EQ_ACC_PTR
  #undef FIX_BIN_LEFT_SHFT_ACC_FLOAT
  #undef FIX_BIN_LEFT_SHFT_ACC_PTR
  #undef FIX_BIN_LEFT_SHFT_EQ_ACC_FLOAT
  #undef FIX_BIN_LEFT_SHFT_EQ_ACC_PTR
  #undef FIX_BIN_RIGHT_SHFT_ACC_FLOAT
  #undef FIX_BIN_RIGHT_SHFT_ACC_PTR
  #undef FIX_BIN_RIGHT_SHFT_EQ_ACC_FLOAT
  #undef FIX_BIN_RIGHT_SHFT_EQ_ACC_PTR
  #undef FIX_BIN_REM_ACC_FLOAT
  #undef FIX_BIN_REM_ACC_PTR
  #undef FIX_BIN_REM_EQ_ACC_FLOAT
  #undef FIX_BIN_REM_EQ_ACC_PTR

/*
 * FLT_ROUNDS is dynamic => need to call external routine which might
 * not be found by linker.  Try adding math library (-lm).
 */
  #undef FIX_FLT_RND

/*
 * wchar_t is supposed to be in <stddef.h>, <stdlib.h>, <wchar.h>
 * If it is missing, this symbol will have me define a value for it.
 */
  #undef FIX_wchar_t

/*
 * strtof, strtold should not be declared if <stdlib.h> has not been
 * included.
 */
  #undef FIX_strtof_HEADER
  #undef FIX_strtod_HEADER
  #undef FIX_strtold_HEADER
  #undef FIX_strtod32_HEADER
  #undef FIX_strtod64_HEADER
  #undef FIX_strtod128_HEADER

/*
 * sizeof( + bitfield ) is valid in that the '+' promotes the bitfield to an int.
 * Many compilers ignore the '+' and complain about sizeof a bitfield.
 */
  #undef FIX_IGNORE_UNARY_PLUS

/*
 * sizeof( - bitfield ) is valid in that the '-' promotes the bitfield to an int.
 * Some compilers ignore the '-' and complain about sizeof a bitfield.
 */
  #undef FIX_IGNORE_UNARY_NEGATE

/*
 * Conversion of ptr to/from a small/large int should be accepted.
 */
  #undef FIX_SLL_FROM_PTR
  #undef FIX_ULL_FROM_PTR
  #undef FIX_SL_FROM_PTR
  #undef FIX_UL_FROM_PTR
  #undef FIX_SI_FROM_PTR
  #undef FIX_UI_FROM_PTR
  #undef FIX_WCHAR_FROM_PTR
  #undef FIX_SMALL_INT_FROM_PTR
  #undef FIX_PTR_FROM_BOOL
  #undef FIX_PTR_FROM_PC
  #undef FIX_PTR_FROM_SC
  #undef FIX_PTR_FROM_UC
  #undef FIX_PTR_FROM_SS
  #undef FIX_PTR_FROM_US
  #undef FIX_PTR_FROM_SLL
  #undef FIX_PTR_FROM_ULL

/*
 * Integer division by zero (1/0 and 0/0).
 */
  #undef FIX_DIV_BY_ZERO

/*
 * 0.0 / 0.0 is a valid expression which should raise invalid.
 * Some compilers allow this for auto, but not static, usage.
 */
  #undef FIX_0_BY_0
  #undef FIX_0_BY10_0
  #undef FIX_STATIC_0_BY_0
  #undef FIX_STATIC_0_BY10_0

/*
 * 1.0 / 0.0 is a valid expression which should raise divide by zero.
 * Some compilers allow this for auto, but not static, usage.
 */
  #undef FIX_1_BY_0
  #undef FIX_1_BY10_0
  #undef FIX_STATIC_1_BY_0
  #undef FIX_STATIC_1_BY10_0

/*
 * x /= 0.0 is a valid expression which should raise divide by zero or invalid.
 */
  #undef FIX_BY_0

/*
 * Unsigned int type / bool kills some compilers
 */
  #undef FIX_UI_DIV_BOOL
  #undef FIX_ULI_DIV_BOOL

/*
 * Are floating-point constants bigger than *_MAX converted to finite values?
 * So far, only needed for certain LDBL values.
 */
  #undef FIX_2LARGE_IS_FINITE

/*
 * Are floating-point constants very much bigger than *_MAX allowed,
 * eg, 1.0e99999999 or 0x1.0p999999999?
 * They are supposed to be allowed and should be INFINITY.
 * Only affects t0080100 and t3080100, t0100200.
 */
  #undef FIX_VERY_BIG_EXPONENTS

/*
 * Are floating-point constants bigger than *_MAX allowed,
 * eg, 1.0e99999 or 0x1.0p99999?
 * They are supposed to be allowed and should be INFINITY.
 * (Was FIX_BIGGER_THAN_MAX -- POSIX.2 reserves *_MAX)
 */
  #undef FIX_BIGGER_THAN_FPMAX

/*
 * Are floating-point constant expressions bigger than *_MAX allowed,
 * eg, MAX_FLT * MAX_FLT or MAX_FLT / MIN_FLT.
 * They are supposed to be allowed and should be INFINITY.
 */
  #undef FIX_EXP_BIGGER_THAN_FPMAX

/*
 * Are floating-point constants smaller than *_MIN allowed,
 * eg, 1.0e-99999999 or 0x1.0p-999999999?
 * They are supposed to be allowed and should be zero or denormal.
 * (Was FIX_SMALLER_THAN_MIN)
 */
  #undef FIX_SMALLER_THAN_FPMIN

/*
 * Are floating-point constant expressions smaller than *_MIN allowed,
 * eg, MIN_FLT * MIN_FLT or MIN_FLT / MAX_FLT.
 * They are supposed to be allowed and should be zero or denormal.
 */
  #undef FIX_EXP_SMALLER_THAN_FPMIN

/*
 * If the LDBL functions are missing and the DBL versions are
 * used instead, then need to limit the domain to valid DBL numbers.
 */
  #undef LIMIT_DOMAIN

/*
 * The overloaded functions are undefined for enum's as arguments.
 */
  #undef FIX_ENUM_2_OVERLOAD
  #undef FIX_ENUM_2_OVERLOAD10

/*
 * Cause a #error to be done so can check translator listing for warnings.
 */
  #undef FIX_FORCE_WARNING_AS_ERROR

/*
 * __FILE__, __LINE__, __DATE__, __TIME__, __STDC__ can't be
 * #undef nor #define by ISO/ANSI C.
 */
  #undef FIX_CHANGE_ANSI

/*
 * Parameters are declared const (because function only reads them)
 * causes problems for some compilers.  With these defined, 'const'
 * is removed from the prototype/definition.
 */
  #undef FIX_CONST_ARRAY_PARM
  #undef FIX_CONST_VLA_PARM
  #undef FIX_CONST_SCALAR_PARM

/*
 * Declarations can have multiple type qualifiers, e.g., const const int i=0;
 * Some compilers die with duplicate type qualifiers.
 */
  #undef FIX_DUP_TYPE_QUAL

/*
 * Type specifier in unusual place and/or repeated kills compile.
 */
  #undef FIX_TYPE_SPEC

/*
 * Declarations can have storage class specifier after the 1st token, eg,
 * long int typedef const t1;
 */
  #undef FIX_CLASS_SPEC

/*
 * signgam is in user's name space, not something special to lgamma.
 * But, the use of lgamma is outside of ISO/ANSI C.
 */
  #undef FIX_SIGNGAM

/*
 * Tests of invalid combinations of keywords in declarations.
 * Define these if the compiler accepts these invalid forms.
 * Real binary types.
 */
  #undef FIX_ACC_e0360001
  /* thru */
  #undef FIX_ACC_e0360291

/*
 * Tests of invalid combinations of keywords in 'for' declarations.
 * Define these if the compiler accepts these invalid forms.
 * Real binary types.
 */
  #undef FIX_ACC_e0361001
  /* thru */
  #undef FIX_ACC_e0361105

/*
 * Tests of sizeof type, where type is NOT in ().
 */
  #undef FIX_ACC_e0371000
  /* thru */
  #undef FIX_ACC_e0371031

/*
 * Tests of invalid combination of keywords in 'switch'.
 */
  #undef FIX_ACC_SWITCH_CASE_DEFAULT	/* e0181404 */

/*
 * Integer value larger than INT_MAX accepted as valid enum value.
 */
  #undef FIX_ACC_LARGE_INT_ENUM		/* e0110300 */

/*
 * #if 1
 * ...
 * #elif junk more junk // should be skipped -- t0560000
 */
  #undef FIX_BAD_ELIF

/*
 * "Nothing" (via a macro) around a label kills the label.
 * #define B
 * B goto B label B ;
 * B label B : B ;
 */
  #undef FIX_BLANK_LABEL


/*** Translate time: C99 ***/

/*
 * If startup code (SETUP2) runs fenv.h functions to set the FPU into the
 * expected state, then need <fenv.h> for function prototypes.
 */
  #undef NEED_STARTUP_FENV_H

/*
 * If startup code (SETUP2) runs float.h functions to set the FPU into the
 * expected state, then need <float.h> for function prototypes.  This is
 * useful on DOS, Windows, OS/2 systems that use _control87().
 */
  #undef NEED_STARTUP_FLOAT_H

/*
 * If NAN_FLT, NAN_DBL, or NAN_LDBL (all in myfloat.h) must be defined in
 * terms of NAN, then this symbol needs to be defined.
 * Same for NAN_F10, NAN_D10, NAN_LD10 in terms of DEC_NAN.
 */
  #undef NEED_FP_H_4_NAN
  #undef NEED_FP_H_4_NAN10

/*
 * If INF_FLT, INF_DBL, or INF_LDBL (all in myfloat.h) must be defined in
 * terms of INFINITY, then this symbol needs to be defined.
 * Same for INF_F10, INF_D10, INF_LD10 in terms of DEC_INFINITY.
 */
  #undef NEED_FP_H_4_INFINITY
  #undef NEED_FP_H_4_INF10

/*
 * <inttypes.h> is a header new with C99.
 * <stdbool.h> is a header new with C99.
 * <stdint.h> is a header new with C99.
 * <complex.h> is a header new with C99.
 *  FIX_COMPLEX_H is used to control if #include <complex.h> is done.
 *  COMPLEX_H is used to control if #include COMPLEX_H is done (mainly for C++)
 *  COMPLEX_H can be one of <complex>, <ccomplex>, <complex.h>
 */
  #undef FIX_INTTYPES_H
  #undef FIX_STDBOOL_H
  #undef FIX_STDINT_H
  #undef FIX_COMPLEX_H

/*
 * NCEG added many new math functions above and beyond C89.  For a while,
 * they had their own header <fp.h>.  Later, when NCEG got absorbed into
 * C99, that header became part of <math.h>.  For compilers that have BOTH
 * <fp.h> and <math.h>, you need to define this symbol.
 */
  #undef FIX_FP_IN_MATH_H

/*
 * <fp.h> is missing or not compatible with C.
 */
  #undef FIX_FP_H

/*
 * <math.h> is not compatible with fp.h.
 */
  #undef FIX_MATH_H

/*
 * The math functions are supposed to come in three flavors: FLT,
 * DBL, and LDBL via overloaded functions (type generic
 * functions).  This disables using all of them.  This applies to
 * the header <tgmath.h>.  This should have been FIX_TGMATH_H.
 */

  #undef FIX_OVERLOAD
  #undef FIX_OVERLOAD10

/*
 * The math functions are supposed to come in three flavors: FLT,
 * DBL, and LDBL via overloaded functions.  This disables
 * just the ones you chose.  One problem found with overloaded
 * functions is: pow(LDBL,DBL) complains about ambiguous
 * overload.
 */
  #undef FIX_OVERLOAD_acos
/* ... thru ... */
  #undef FIX_OVERLOAD_trunc
  #undef FIX_OVERLOAD10_acos
/* ... thru ... */
  #undef FIX_OVERLOAD10_trunc

/*
 * The FLT versions of the math functions are supposed to exist.
 */
  #undef FIX_FLT_OVERLOADS
  #undef FIX_F10_OVERLOADS

/*
 * The DBL versions of the math functions are supposed to exist.
 */
  #undef FIX_DBL_OVERLOADS
  #undef FIX_D10_OVERLOADS

/*
 * The overloaded functions are undefined for LDBL's as arguments.
 */
  #undef FIX_LDBL_OVERLOADS
  #undef FIX_LD10_OVERLOADS

/*
 * The two argument type generic overloaded math functions should work
 * with mixed types, e.g., a FLT and an int argument.
 */
  #undef FIX_MIXED_2_OVERLOAD
  #undef FIX_MIXED_2_OVERLOAD10

/*
 * Prototypes need to have the correct types for parameters.
 * Matters most for assignment to function pointer.
 * (Only list the bad ones found so far).
 */
  #undef FIX_BAD_PROTO_feholdexcept
  #undef FIX_BAD_PROTO_fesetexceptflag
  #undef FIX_BAD_PROTO_feupdateenv

/*
 * Invalid FPCE C code is accepted as valid. The code in question is:
 * Missing symbols defined in FP_H or FENV_H.  When upgraded the FPCE
 * tests for C99, these were expanded (since have sin(), sinf(), sinl(), eg,
 * must now have all three floating types for each math function).
 * At one time these symbols were the name of the file (e0210234 would
 * become FIX_ACC_e0210234) being tested.  This is now split into
 * two sections:  functions and others (macros and typedefs) and each
 * section has its own form.  The examples of each form are elsewhere in
 * this header.
 *
 * Functions are done as: FIX_TRUE_name, where name is the exact
 * spelling of the function that is missing.  These symbols are used in
 * the e021* tests.  In the rest of the test suite, use *_FUNCS_gname,
 * where gname is the generic name (without trailing f or l).
 *
 * The others are done as: FIX_name, where name is the exact spelling
 * of the macro or typedef that is missing. These symbols are used in both
 * the e021* tests and the rest of the test suite (to disable using something
 * that is missing).
 *
 * These missing symbols may show up at compiler time, link edit time, or
 * run time, depending upon the test and the usage of the symbol.
 */

/*
 * If all versions (FLT, DBL, LDBL, masking macro, overload)
 * of individual functions are missing, then define these symbols to bypass
 * using or testing them.  These cover multiple functions with one symbol.
 * FUNCS > FUNC > TRUE; or TRUE is subset of FUNC is subset of FUNCS.
 *
 * These symbols cover overloaded functions.
 *  acos(0.5f),    acos(0.5),   acos(0.5l), == overload
 *  acosf(0.5f),                acosl(0.5l), == masking macro
 * (acosf)(0.5f), (acos)(0.5), (acosl)(0.5l), == true function
 * are usages covered by these symbols.
 */
  #undef FIX_FUNCS_acos		/* acosf, acos, acosl */
/* ... thru ... */
  #undef FIX_FUNCS_trunc
  #undef FIX_FUNCS10_acos	/* acosd32, acosd64, acosd128 */
/* ... thru ... */
  #undef FIX_FUNCS10_trunc
  #undef FIX_FUNCS_strtod	/* strtof, strtod, strtold */
  #undef FIX_FUNCS10_strtod	/* strtod32, strtod64, strtod128 */

/*
 * The FLT versions of the FPCE functions are supposed to exist.
 * If all of them are missing, then define FIX_FUNCS_F (was
 * FIX_MISSING_F).  If just some of them are missing, then do
 * not define FIX_FUNCS_F, but, define the individual ones for
 * each missing function: FIX_FUNC_name, where name is the
 * exact spelling of the missing function (lower case with trailing f).
 * Was FIX_FUNCS_F_* (without trailing f) for the individual ones.
 *
 * These symbols cover masking macros and true functions.
 * acosf(0.5f), (acosf)(0.5f), strtof() are usages covered by these symbols.
 */
  #undef FIX_FUNCS_F
  #undef FIX_FUNCS10_F

  #undef FIX_FUNC_acosf
/* ... thru ... */
  #undef FIX_FUNC_truncf
  #undef FIX_FUNC_acosd32
/* ... thru ... */
  #undef FIX_FUNC_truncd32
  #undef FIX_FUNC_strtof

/*
 * There are several macros/functions in FP_H that are not overloaded
 * that take/return DBL.  They should exist.  Was FIX_MISSING_D.
 * These symbols cover masking macros and true functions.
 * nan(""), (nan)(""), strtod() are usages covered by these symbols.
 * Also applies to [non]overloaded DBL versions of the Decimal FP TR functions.
 */
  #undef FIX_FUNCS_D
  #undef FIX_FUNCS10_D

  #undef FIX_FUNC_modf
  #undef FIX_FUNC_nan
  #undef FIX_FUNC_nextafterd

  #undef FIX_FUNC_acosd64
/* ... thru ... */
  #undef FIX_FUNC_truncd64
  #undef FIX_FUNC_strtod

/*
 * The LDBL versions of the FPCE functions are supposed to exist.
 * If all of them are missing, then define FIX_FUNCS_L (was
 * FIX_MISSING_L).  If just some of them are missing, then do
 * not define FIX_FUNCS_L, but, define the individual ones for
 * each missing function: FIX_FUNC_name, where name is the
 * exact spelling of the missing function (lower case with trailing l).
 * Was FIX_FUNCS_L_* (without trailing l) for the individual ones.
 *
 * These symbols cover masking macros and true functions.
 * acosl(0.5l), (acosl)(0.5l), strtold() are usages covered by these symbols.
 */
  #undef FIX_FUNCS_L
  #undef FIX_FUNCS10_L

  #undef FIX_FUNC_acosl
/* ... thru ... */
  #undef FIX_FUNC_truncl
  #undef FIX_FUNC_acosd128
/* ... thru ... */
  #undef FIX_FUNC_truncd128
  #undef FIX_FUNC_strtold

/*
 * The headers may have masking/mapping macros from the user's expected
 * function name to an implementor's name of the true function.
 * Is there a true function by the expected name?
 * (acos)(0.5), (acosf)(0.5f), (acosl)(0.5l) are usages covered.
 */
  #undef FIX_TRUE_acos
  #undef FIX_TRUE_acosf
  #undef FIX_TRUE_acosl
/* ... thru ... */
  #undef FIX_TRUE_trunc
  #undef FIX_TRUE_truncf
  #undef FIX_TRUE_truncl

  #undef FIX_TRUE_acosd64
  #undef FIX_TRUE_acosd32
  #undef FIX_TRUE_acosd128
/* ... thru ... */
  #undef FIX_TRUE_truncd64
  #undef FIX_TRUE_truncd32
  #undef FIX_TRUE_truncd128

/*
 * FPCE added many new <math.h> functions above and beyond C89.  Most of
 * them are supposed to be overloaded.  This disables checking all of them.
 * You can disable checking certain ones by using the above methods
 * (one or more of FIX_ FUNCS / FUNC / TRUE _name).
 */
  #undef FIX_FPCE_FUNCTIONS

/*
 * sizeof(macro()) should be legal by ISO/ANSI C.
 */
  #undef FIX_SIZEOF_fpclassify
  #undef FIX_SIZEOF_signbit
  #undef FIX_SIZEOF_isfinite
  #undef FIX_SIZEOF_isnormal
  #undef FIX_SIZEOF_isnan
  #undef FIX_SIZEOF_isinf
  #undef FIX_SIZEOF_isgreater
  #undef FIX_SIZEOF_isgreaterequal
  #undef FIX_SIZEOF_isless
  #undef FIX_SIZEOF_islessequal
  #undef FIX_SIZEOF_islessgreater
  #undef FIX_SIZEOF_isunordered

/*
 * -macro should be legal by ISO/ANSI C and is same as -(macro).
 * sizeof macro should be legal by ISO/ANSI C and is same as sizeof(macro).
 */
  #undef FIX_NEED_PARENS_FE_DFL_ENV
  #undef FIX_NEED_PARENS_L_tmpnam
  #undef FIX_NEED_PARENS_NULL
  #undef FIX_NEED_PARENS_WCHAR_MAX
  #undef FIX_NEED_PARENS_WCHAR_MIN
  #undef FIX_NEED_PARENS_WEOF
  #undef FIX_NEED_PARENS_va_arg

/*
 * sizeof(func(bit.field)) is legal by ISO/ANSI C.
 */
  #undef FIX_SIZEOF_BIT_FIELD

/*
 * [s]scanf should not accept all of 'nans' as a [signalling] nan;
 * It should accept the 'nan' and stop on the 's'.
 */
  #undef FIX_SCAN_nans
  #undef FIX_SCAN10_nans
  #undef FIX_WSCAN_nans
  #undef FIX_WSCAN10_nans

/*
 * Expressions with (short and long long) and various op= operators done wrong.
 */
  #undef FIX_SHORT_ADD_EQ_LONGLONG
  #undef FIX_SHORT_AND_EQ_LONGLONG
  #undef FIX_SHORT_DIV_EQ_LONGLONG
  #undef FIX_SHORT_MUL_EQ_LONGLONG
  #undef FIX_SHORT_OR_EQ_LONGLONG
  #undef FIX_SHORT_REM_EQ_LONGLONG
  #undef FIX_SHORT_SUB_EQ_LONGLONG
  #undef FIX_SHORT_XOR_EQ_LONGLONG

/*
 * Wide char strings can be concatenated with narrow char strings in C99.
 */
  #undef FIX_CONCAT_WIDE_AND_NARROW

/*
 * PreProcessor math is supposed to be 64-bit (or bigger).
 * Many compilers are using 32-bit and a few are using 16-bit.
 * t0502400 is main test.
 */
  #undef FIX_16BIT_PP_MATH
  #undef FIX_32BIT_PP_MATH

/*
 * Can a struct have a declaration like:
 *   bool b8 : 1; : 0, b9 : 1;
 * That is, a member with no ident in the middle of the list.
 */
  #undef FIX_NO_ID_IN_MID

/*
 * _Bool is a new type with C99.
 * This does a: typedef unsigned int _Bool; to allow code to compile.
 */
  #undef FIX_BOOL

/*
 * Having a small bool bit-field member of a struct kills some compilers.
 */
  #undef FIX_BOOL_BITFIELD

/*
 * Can multiple comma separated bool bit-fields be declared with one bool declaration?
 */
  #undef FIX_MULTIPLE_BOOLS

/*
 * _Bool bit-field are a new type with C99.  They can be any size
 * up to the number of bits in a _Bool (most likely, CHAR_BIT).
 * This bypasses bit-fields with "large" number of bits.
 * But, it has been pointed out to me (and Tom Plum) that _Bool
 * bit fields are limited to the number of VALUE bits in a _Bool,
 * (not the total bits which includes padding).  So, this symbol is
 * no longer used.
 */
  #undef FIX_BIG_BITFIELD

/*
 * Can zero width _Bool bit-fields be declared?  bool : 0;
 */
  #undef FIX_ZERO_WIDTH_BOOL

/*
 * _Bool is a new type with C99.
 * But, some compilers will not allow assignment to bools.
 */
  #undef FIX_ASSIGN_TO_BOOL

/*
 * Expressions with arith operator on bool bit field done wrong.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_OP_BOOL_BIT_FIELD

/*
 * Expressions with arith operator on _Bool done wrong.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_OP_BOOL

/*
 * ++bool  or bool++ not liked.
 */
  #undef FIX_BOOL_ADDADD

/*
 * --bool  or bool-- not liked.
 */
  #undef FIX_BOOL_SUBSUB

/*
 * Function call with int operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_INT

/*
 * Function call with char operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_CHAR

/*
 * Cast or Function call with complex operands should be convertable
 * to bit-field member of struct.
 */
  #undef FIX_BITS_FROM_CMPLX

/*
 * Cast or Function call with complex operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_CMPLX

/*
 * Cast or Function call with imaginary operands should be convertable
 * to bit-field member of struct.
 */
  #undef FIX_BITS_FROM_IMAG

/*
 * Cast or Function call with imaginary operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_IMAG

/*
 * Bools should be convertable to ints.
 */
  #undef FIX_INT_FROM_BOOL

/*
 * bool cast to some type (such as long int) is not liked.
 */
  #undef FIX_CAST_FROM_BOOL

/*
 * Function call with bit-field operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_BITFIELD

/*
 * Function call with bool operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_BOOL

/*
 * Conversion to enum from bool not liked.
 */
  #undef FIX_ENUM_FROM_BOOL

/*
 * _Bool should promote when used with floating-point vars.
 * Some compilers die with things like: bool += 2.0;
 */
  #undef FIX_BOOL_FROM_DBL
  #undef FIX_BOOL_FROM_D10
  #undef FIX_BOOL_FROM_FLT
  #undef FIX_BOOL_FROM_F10
  #undef FIX_BOOL_FROM_LDBL
  #undef FIX_BOOL_FROM_LD10

/*
 * Conversion of a floating-point NaN to _Bool should be 1, not 0
 * (since NaN != 0), and raise no FP exceptions.
 */
  #undef FIX_BOOL_FROM_NAN
  #undef FIX_BOOL_FROM_NAN10

/*
 * Conversion of a floating-point Inf to _Bool should be 1, not 0
 * (since Inf != 0), and raise no FP exceptions.
 */
  #undef FIX_BOOL_FROM_INF

/*
 * Conversion of a floating-point fraction, e.g, 0.2, to _Bool
 * should be 1, not 0.  The semantics are different than
 * conversion to unsigned int.
 */
  #undef FIX_BOOL_FROM_FRACTION

/*
 * Conversion of a floating-point positive zero, e.g, +0., to _Bool
 * should be 0, not 1.
 */
  #undef FIX_BOOL_FROM_ZERO
  #undef FIX_BOOL_FROM_STATIC_ZERO

/*
 * Conversion of a floating-point negative zero, e.g, -0., to _Bool
 * should be 0, not 1.
 */
  #undef FIX_BOOL_FROM_NEG_ZERO

/*
 * -bool should leave the value unchanged.
 */
  #undef FIX_NEG_BOOL

/*
 * Pointers are a special case for assignment to _Bool.  Some compilers
 * do not allow it:  bool = &c;
 */
  #undef FIX_BOOL_FROM_PTR

/*
 * C++ not like conversion from void * to an integer type.
 */
  #undef FIX_INT_FROM_VOID_PTR

/*
 * int bf : 3 = (_Bool)1; causes some compilers to complain.
 */
  #undef FIX_BITFIELD_FROM_BOOL

/*
 * bool b = (_Bool)1; causes some compilers to complain.
 */
  #undef FIX_BOOL_CAST

/*
 * static bool b = (_Bool)1; causes some compilers to complain.
 */
  #undef FIX_STATIC_BOOL_CAST

/*
 * return bool from complex is OK in C11, but not C++.
 */
  #undef FIX_RETURN_TO_BOOL

/*
 * Expressions with (bool && floating) done wrong.
 */
  #undef FIX_BOOL_ANDAND_FLT
  #undef FIX_BOOL_ANDAND_F10

/*
 * Expressions with (bool || floating) done wrong.
 */
  #undef FIX_BOOL_OROR_FLT
  #undef FIX_BOOL_OROR_F10

/*
 * Expressions with unsigned % bool kills compile.
 */
  #undef FIX_UNSIGNED_REMAINDER_BOOL

/*
 * ! complex should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_BANG_CMPLX

/*
 * complex == double should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_CMPLX_EQEQ_FP

/*
 * (complex)bit-field should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_CMPLX_FROM_BIT

/*
 * (complex)bool should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_CMPLX_FROM_BOOL

/*
 * (complex)enum should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_CMPLX_FROM_ENUM

/*
 * (complex)int should be accepted in C code.
 * (int)complex should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_CMPLX_FROM_INT
  #undef FIX_INT_FROM_CMPLX
  #undef FIX_IMAG_FROM_INT

/*
 * complex op int should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_CMPLX_OP_INT

/*
 * complex op pointer should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_CMPLX_OP_PTR

/*
 * complex in union should be accepted in C code.
 * Not(?) valid in C++ code.
 */
  #undef FIX_COMPLEX_UNION

/*
 * (double)complex should be accepted in C code.
 * double op complex should be accepted in C code.
 * Not(?) valid in C++ code.
 * FCX = float complex
 * DCX = double complex
 * LDCX = long double complex
 */
  #undef FIX_DBL_FROM_DCX
  #undef FIX_DBL_FROM_FCX
  #undef FIX_DBL_FROM_LDCX
  #undef FIX_DBL_OP_FCX
  #undef FIX_DBL_OP_LDCX
  #undef FIX_DCX_ANDAND_DBL
  #undef FIX_DCX_ANDAND_DCX
  #undef FIX_DCX_FROM_DBL
  #undef FIX_DCX_FROM_DCX
  #undef FIX_DCX_FROM_FCX
  #undef FIX_DCX_FROM_FLT
  #undef FIX_DCX_FROM_LDBL
  #undef FIX_DCX_FROM_LDCX
  #undef FIX_DCX_FROM_SLI
  #undef FIX_DCX_FROM_SLLI
  #undef FIX_DCX_FROM_UI
  #undef FIX_DCX_FROM_ULI
  #undef FIX_DCX_FROM_ULLI
  #undef FIX_DCX_OP_FCX
  #undef FIX_DCX_OP_FLT
  #undef FIX_DCX_OP_LDBL
  #undef FIX_DCX_OP_LDCX
  #undef FIX_DCX_OROR_DBL
  #undef FIX_DCX_OROR_DCX
  #undef FIX_FCX_ANDAND_FCX
  #undef FIX_FCX_ANDAND_FLT
  #undef FIX_FCX_FROM_DBL
  #undef FIX_FCX_FROM_DCX
  #undef FIX_FCX_FROM_FCX
  #undef FIX_FCX_FROM_FLT
  #undef FIX_FCX_FROM_LDBL
  #undef FIX_FCX_FROM_LDCX
  #undef FIX_FCX_FROM_SI
  #undef FIX_FCX_FROM_SLI
  #undef FIX_FCX_FROM_SLLI
  #undef FIX_FCX_FROM_UI
  #undef FIX_FCX_FROM_ULI
  #undef FIX_FCX_FROM_ULLI
  #undef FIX_FCX_OP_DBL
  #undef FIX_FCX_OP_DCX
  #undef FIX_FCX_OP_LDBL
  #undef FIX_FCX_OP_LDCX
  #undef FIX_FCX_OROR_FCX
  #undef FIX_FCX_OROR_FLT
  #undef FIX_FLT_FROM_DCX
  #undef FIX_FLT_FROM_FCX
  #undef FIX_FLT_FROM_LDCX
  #undef FIX_FLT_OP_DCX
  #undef FIX_FLT_OP_LDCX
  #undef FIX_FP_FROM_CMPLX
  #undef FIX_LDBL_FROM_DCX
  #undef FIX_LDBL_FROM_FCX
  #undef FIX_LDBL_FROM_LDCX
  #undef FIX_LDBL_OP_DCX
  #undef FIX_LDBL_OP_FCX
  #undef FIX_LDCX_ANDAND_LDBL
  #undef FIX_LDCX_ANDAND_LDCX
  #undef FIX_LDCX_FROM_DBL
  #undef FIX_LDCX_FROM_DCX
  #undef FIX_LDCX_FROM_FCX
  #undef FIX_LDCX_FROM_FLT
  #undef FIX_LDCX_FROM_LDBL
  #undef FIX_LDCX_FROM_LDCX
  #undef FIX_LDCX_FROM_SLLI
  #undef FIX_LDCX_FROM_UI
  #undef FIX_LDCX_FROM_ULI
  #undef FIX_LDCX_FROM_ULLI
  #undef FIX_LDCX_OP_DBL
  #undef FIX_LDCX_OP_DCX
  #undef FIX_LDCX_OP_FCX
  #undef FIX_LDCX_OP_FLT
  #undef FIX_LDCX_OROR_LDBL
  #undef FIX_LDCX_OROR_LDCX

/*
 * inline is a new feature of C99.
 */
  #undef FIX_INLINE

/*
 * _Pragma() operator is new with C99.
 * Tested in t0000500, t0020100.
 */
  #undef FIX_Pragma

/*
 * Following symbols are from FPCE draft 1996/02/26
 */
  #undef FIX_SYM_STDC_IEC_559__	/* predefined by compiler */
  #undef FIX_SYM_FLT_EVAL_METHOD	/* in <float.h> */

/*
 * Following symbols are from FPCE draft 1994/06/30
 */
  #undef FIX_SYM___FPCE__		/* predefined by compiler */
  #undef FIX_SYM___FPCE_IEEE__		/* predefined by compiler */
  #undef FIX_SYM__MIN_EVAL_FORMAT	/* in <float.h> */
  #undef FIX_SYM__WIDEST_NEED_EVAL	/* in <float.h> */

/*
 * FLT_EVAL_METHOD is supposed to be defined in <float.h>.
 */
  #undef FIX_FLT_EVAL_IN_HEADER

/*
 * _MIN_EVAL_FORMAT is supposed to be defined in <float.h>.
 */
  #undef FIX_MIN_EVAL_IN_HEADER

/*
 * _WIDEST_NEED_EVAL is supposed to be defined in <float.h>.
 */
  #undef FIX_WIDE_NEED_IN_HEADER

/*
 * Translation directives have gone back and forth between pragmas and
 * macros.  The FPCE technical report had more than C99.  Here are all
 * the choices.  They are defined before mydefs.h is included, so they
 * can NOT be undef'ed here.
 *
 * Use these symbols if the pragma causes translation to stop.
 */
/* #undef FIX_PRAGMAS		*/
/* #undef FIX_PRAGMA_FENV_ACCESS	*/
/* #undef FIX_PRAGMA_CONTRACT	*/
/* #undef FIX_PRAGMA_CX_LIMIT	*/
/* #undef FIX_PRAGMA_WIDE_RETURNS	*/
/* #undef FIX_PRAGMA_WIDE_PARMS	*/
/* #undef FIX_PRAGMA_WIDE_VARS	*/
/* #undef FIX_PRAGMA_FENV_ROUND	*/

/*
 * #pragma STDC FLOAT_CONST_DECIMAL64 ... is unknown or ignored
 */
  #undef FIX_DFP64_PRAGMA

/*
 * pragma 0x4.1p-10 causes a compiler to core dump (t0100100)
 */
  #undef FIX_HEX_FP_PRAGMA

/*
 * pragma fenv_access default causes a compiler to core dump
 */
  #undef FIX_ACCESS_DEFAULT

/*
 * pragma fp_contract default causes a compiler to core dump
 */
  #undef FIX_CONTRACT_DEFAULT

/*
 * pragma fp_wide_function_returns default causes a compiler to core dump
 */
  #undef FIX_RETURNS_DEFAULT

/*
 * pragma fp_wide_function_parameters default causes a compiler to core dump
 */
  #undef FIX_PARAMETERS_DEFAULT

/*
 * pragma fp_wide_variables default causes a compiler to core dump
 */
  #undef FIX_VARIABLES_DEFAULT

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * #pragma STDC FENV_ACCESS ON in wrong place.
 */
  #undef FIX_ACC_BAD_pragma_STDC

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * _Pragma( "STDC FENV_ACCESS ON" ) in wrong place.
 */
  #undef FIX_ACC_BAD_Pragma_STDC

/*
 * Does the translator support FPCE hexadecimal floating constants?
 */
  #undef FIX_FPCE_HEX

/*
 * Does the translator support FPCE hexadecimal floating constants
 * for the value zero: 0x0p0?
 */
  #undef FIX_ZERO_HEX

/*
 * Does the translator support FPCE hexadecimal floating constants
 * for type float with a '+': 0x1p+0f
 */
  #undef FIX_pEXPf_HEX

/*
 * Some valid FPCE hexadecimal floating constants are not liked.
 * Some die with 0x.1234p0 (they are OK with 0x0.1234p0)
 */
  #undef FIX_VALID_FPCE_HEX

/*
 * Some valid FPCE hexadecimal floating constants are not liked.
 * Some die with 0X0.1234p0 (they are OK with lower case 'x').
 */
  #undef FIX_CAP_X_FPCE_HEX

/*
 * Valid FPCE hexadecimal floating constants with 'E' in them are rejected.
 * Thinks 'E' in 0xabcdEf0123456789p0 is exponent.
 */
  #undef FIX_E_IN_HEXFP

/*
 * FPCE added floating-point environment <fenv.h> functions.
 * This disables checking all of them.
 * Use this if <fenv.h> is missing.
 * You can disable checking certain ones by using the above methods
 * (one or more of FIX_  FUNC / TRUE _name).
 * Better is to use:
 *   #define FENV_H "fenvdumy.h"
 * so that masking macros exist and are used.
 */
  #undef FIX_FENV_FUNCTIONS
  #undef FIX_FENV10_FUNCTIONS

/*
 * fetestexcept(), feclearexcept() should exist and work.
 * If either of these are missing, there is no way to see which exceptions
 * a given operation caused.  This disables those tests.
 */
  #undef FIX_FE_FLAGS

/*
 * fegetround(), fesetround() should exist and work.
 * Since hardware must do some rounding, dummy macros (like in fenvdumy.h)
 * can be created to indicate the fixed rounding, so this should never
 * need to be used.  Should only need FIX_RND_fesetround.
 */
  #undef FIX_FE_RND

/*
 * fegetenv(), fesetenv(), feupdateenv(), and feholdexcept() should exist
 * and work.
 */
  #undef FIX_FE_ENV

/*
 * fegetexceptflag() and fesetexceptflag() should exist and work.
 */
  #undef FIX_FE_EXCEPT

/*
 * nan*() functions are supposed to be defined.
 * Was FIX_ nan at one point.
 */
  #undef FIX_FUNCS_nan
  #undef FIX_FUNCS10_nan

/*
 * One vendor has a nans() function, which violates user's name space.
 * Was FIX_ nans at one point.
 */
  #undef FIX_FUNC_nans

/*
 * There are several "overloaded" function-like macros.
 * They should take args like d++.
 * Classification macros
 * Relational macros
 */
  #undef FIX_MACF_fpclassify
  #undef FIX_MACF_isfinite
  #undef FIX_MACF_isinf
  #undef FIX_MACF_isnan
  #undef FIX_MACF_isnormal
  #undef FIX_MACF_issubnormal
  #undef FIX_MACF_iszero
  #undef FIX_MACF_signbit

  #undef FIX_MACF_isgreater
  #undef FIX_MACF_isgreaterequal
  #undef FIX_MACF_isless
  #undef FIX_MACF_islessequal
  #undef FIX_MACF_islessgreater
  #undef FIX_MACF_isunordered

/*
 * There are several "overloaded" function-like macros.
 * For non-NaN arguments, they are the same as relational operators.
 * This is superset of next.
 */
  #undef FIX_isgreater_EQUAL_GT
  #undef FIX_isgreaterequal_EQUAL_GE
  #undef FIX_isless_EQUAL_LT
  #undef FIX_islessequal_EQUAL_LE
  #undef FIX_islessgreater_EQUAL_LG

/*
 * There are several "overloaded" function-like macros.
 * They act like built-in operators in that they are supposed to
 * honor the floating-point evaluation method.  This is subset of
 * previous.
 */
  #undef FIX_FLT_EVAL_isgreater
  #undef FIX_FLT_EVAL_isgreaterequal
  #undef FIX_FLT_EVAL_isless
  #undef FIX_FLT_EVAL_islessequal
  #undef FIX_FLT_EVAL_islessgreater

  #undef FIX_DEC_EVAL_isgreater
  #undef FIX_DEC_EVAL_isgreaterequal
  #undef FIX_DEC_EVAL_isless
  #undef FIX_DEC_EVAL_islessequal
  #undef FIX_DEC_EVAL_islessgreater

/*
 * There are several "overloaded" function-like macros.
 * If they work ok for single constants and variables, but
 * fail for expressions, define these symbols.
 */
  #undef FIX_EXP_fpclassify

/*
 * There are several "overloaded" function-like macros.
 * If they fail for denormal/subnormal numbers, define these symbols.
 */
  #undef  FIX_DEN_fpclassify
  #undef  FIX_DEN10_fpclassify
  #undef  FIX_DEN_isnormal
  #undef  FIX_DEN10_isnormal

/*
 * There are several "overloaded" function-like macros.
 * If they fail with -zero, define these symbols.
 */
  #undef  FIX_mZERO_fpclassify
  #undef  FIX_mZERO10_fpclassify

/*
 * There are several "overloaded" function-like macros.
 * If they raise or clear FP exception flags, define these symbols.
 */
  #undef  FIX_FLAG_fpclassify
  #undef  FIX_FLAG_isfinite
  #undef  FIX_FLAG_isinf
  #undef  FIX_FLAG_isnan
  #undef  FIX_FLAG_isnormal
  #undef  FIX_FLAG_issubnormal
  #undef  FIX_FLAG_iszero
  #undef  FIX_FLAG_signbit

  #undef  FIX_FLAG10_fpclassify
  #undef  FIX_FLAG10_isfinite
  #undef  FIX_FLAG10_isinf
  #undef  FIX_FLAG10_isnan
  #undef  FIX_FLAG10_isnormal
  #undef  FIX_FLAG10_issubnormal
  #undef  FIX_FLAG10_iszero
  #undef  FIX_FLAG10_signbit

/*
 * islessgreater cannot be used as an argument to a macro
 */
  #undef FIX_LTGT_2_MACRO

/*
 * There are several macros that should return
 * (or are) a signed int type.
 */
  #undef FIX_unsigned_FP_INFINITE
  #undef FIX_unsigned_FP_NAN
  #undef FIX_unsigned_FP_NORMAL
  #undef FIX_unsigned_FP_SUBNORMAL
  #undef FIX_unsigned_FP_ZERO
  #undef FIX_unsigned_fpclassify
  #undef FIX_unsigned_isfinite
  #undef FIX_unsigned_isgreater
  #undef FIX_unsigned_isgreaterequal
  #undef FIX_unsigned_isinf
  #undef FIX_unsigned_isless
  #undef FIX_unsigned_islessequal
  #undef FIX_unsigned_islessgreater
  #undef FIX_unsigned_isnan
  #undef FIX_unsigned_isnormal
  #undef FIX_unsigned_issignaling
  #undef FIX_unsigned_isunordered
  #undef FIX_unsigned_math_errhandling
  #undef FIX_unsigned_signbit
  #undef FIX_unsigned_STDC_IEC_559__
  #undef FIX_unsigned_STDC_DEC_FP__

/*
 * There are several "overloaded" function-like macros.
 * They should take constants and expressions, that is,
 * things different than variables.
 */
  #undef FIX_signbit_NON_VAR

/*
 * The signbit macro does the wrong thing for -0.0 and -0.0L,
 * and +1.0 and +1.0L.
 */
  #undef FIX_MINUS_DBL_signbit
  #undef FIX_MINUS_LDBL_signbit
  #undef FIX_PLUS_DBL_signbit
  #undef FIX_PLUS_LDBL_signbit
  #undef FIX_MINUS_D10_signbit
  #undef FIX_MINUS_LD10_signbit
  #undef FIX_PLUS_D10_signbit
  #undef FIX_PLUS_LD10_signbit

/*
 * The "overloaded" function-like macros are macros
 * (not generic or builtin functions).
 */
  #undef FIX_isinf_IS_A_MACRO
  #undef FIX_isnan_IS_A_MACRO
  #undef FIX_isfinite_IS_A_MACRO
  #undef FIX_isnormal_IS_A_MACRO
  #undef FIX_signbit_IS_A_MACRO
  #undef FIX_fpclassify_IS_A_MACRO
  #undef FIX_isless_IS_A_MACRO
  #undef FIX_islessequal_IS_A_MACRO
  #undef FIX_isgreater_IS_A_MACRO
  #undef FIX_isgreaterequal_IS_A_MACRO
  #undef FIX_islessgreater_IS_A_MACRO
  #undef FIX_isunordered_IS_A_MACRO

/*
 * <math.h> (was <fp.h>) object-like symbolic macros are supposed to be defined.
 */
  #undef FIX_SYM_HUGE_VAL
  #undef FIX_SYM_HUGE_VALF
  #undef FIX_SYM_HUGE_VALL
  #undef FIX_SYM_DECIMAL_DIG	/* in <float.h> as of 1998/06/26 */
  #undef FIX_SYM_DECIMAL_DIG_ENUM
  #undef FIX_SYM_INFINITY
  #undef FIX_SYM_NAN
  #undef FIX_SYM_FP_ILOGB0
  #undef FIX_SYM_FP_ILOGBNAN
  #undef FIX_SYM_FP_LLOGB0
  #undef FIX_SYM_FP_LLOGBNAN
  #undef FIX_SYM_FP_NAN	/* One vendor has FP_NANQ and FP_NANS. */
  #undef FIX_SYM_FP_INFINITE
  #undef FIX_SYM_FP_NORMAL
  #undef FIX_SYM_FP_SUBNORMAL
  #undef FIX_SYM_FP_ZERO
  #undef FIX_SYM_FP_NAN_ENUM
  #undef FIX_SYM_FP_INFINITE_ENUM
  #undef FIX_SYM_FP_NORMAL_ENUM
  #undef FIX_SYM_FP_SUBNORMAL_ENUM
  #undef FIX_SYM_FP_ZERO_ENUM
  #undef FIX_SYM_MATH_ERREXCEPT
  #undef FIX_SYM_MATH_ERRNO
  #undef FIX_SYM_math_errhandling

/*
 * <math.h> should NOT define INT_MAX, INT_MIN (used by FP_ILOGB*).
 */
  #undef FIX_MATH_INT_MAX
  #undef FIX_MATH_INT_MIN

/*
 * The FP_ILOGB* macro symbols need <limits.h> for INT_MIN
 */
  #undef FIX_FP_ILOGB_NEEDS_LIMITS_H

/*
 * <fenv.h> object-like symbolic macros are supposed to be #defined
 * (if supported).
 */
  #undef FIX_SYM_FE_INVALID
  #undef FIX_SYM_FE_DIVBYZERO
  #undef FIX_SYM_FE_OVERFLOW
  #undef FIX_SYM_FE_UNDERFLOW
  #undef FIX_SYM_FE_INEXACT
  #undef FIX_SYM_FE_ALL_EXCEPT

  #undef FIX_SYM_FE_INVALID_ENUM
  #undef FIX_SYM_FE_DIVBYZERO_ENUM
  #undef FIX_SYM_FE_OVERFLOW_ENUM
  #undef FIX_SYM_FE_UNDERFLOW_ENUM
  #undef FIX_SYM_FE_INEXACT_ENUM
  #undef FIX_SYM_FE_ALL_EXCEPT_ENUM

  #undef FIX_SYM_FE_TONEAREST
  #undef FIX_SYM_FE_UPWARD
  #undef FIX_SYM_FE_DOWNWARD
  #undef FIX_SYM_FE_TOWARDZERO

  #undef FIX_SYM_FE_DEC_TONEAREST
  #undef FIX_SYM_FE_DEC_TONEARESTFROMZERO
  #undef FIX_SYM_FE_DEC_UPWARD
  #undef FIX_SYM_FE_DEC_DOWNWARD
  #undef FIX_SYM_FE_DEC_TOWARDZERO

  #undef FIX_SYM_FE_TONEAREST_ENUM
  #undef FIX_SYM_FE_UPWARD_ENUM
  #undef FIX_SYM_FE_DOWNWARD_ENUM
  #undef FIX_SYM_FE_TOWARDZERO_ENUM

  #undef FIX_SYM_FE_DEC_TONEAREST_ENUM
  #undef FIX_SYM_FE_DEC_TONEARESTFROMZERO_ENUM
  #undef FIX_SYM_FE_DEC_UPWARD_ENUM
  #undef FIX_SYM_FE_DEC_DOWNWARD_ENUM
  #undef FIX_SYM_FE_DEC_TOWARDZERO_ENUM

  #undef FIX_SYM_FE_DFL_ENV

  #undef FIX_SYM_FE_FLTPREC		/* optional */
  #undef FIX_SYM_FE_DBLPREC		/* optional */
  #undef FIX_SYM_FE_LDBLPREC		/* optional */

  #undef FIX_SYM_FE_FLTPREC_ENUM	/* optional */
  #undef FIX_SYM_FE_DBLPREC_ENUM	/* optional */
  #undef FIX_SYM_FE_LDBLPREC_ENUM	/* optional */

  #undef FIX_SYM_FE_TRAP_INVALID	/* optional */
  #undef FIX_SYM_FE_TRAP_DIVBYZERO	/* optional */
  #undef FIX_SYM_FE_TRAP_OVERFLOW	/* optional */
  #undef FIX_SYM_FE_TRAP_UNDERFLOW	/* optional */
  #undef FIX_SYM_FE_TRAP_INEXACT	/* optional */
  #undef FIX_SYM_FE_TRAP_ALL		/* optional */

  #undef FIX_SYM_FE_TRAP_INVALID_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_DIVBYZERO_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_OVERFLOW_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_UNDERFLOW_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_INEXACT_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_ALL_ENUM	/* optional */

/*
 * The FE_* macros, when used in #if must not be 0.
 * One implementation first defines the FE_* symbols via enums.
 * Then defines the FE_* macros as itself.
 * They show up as defined, but have the value 0 to #if.
 */
  #undef FIX_FE_MACROS

/*
 * <math.h> (was <fp.h>) typedefs are supposed to be defined.
 */
  #undef FIX_TYPEDEF_float_t
  #undef FIX_TYPEDEF_double_t
  #undef FIX_TYPEDEF__Decimal32_t
  #undef FIX_TYPEDEF__Decimal64_t

/*
 * <fenv.h> typedefs are supposed to be defined.
 */
  #undef FIX_TYPEDEF_fenv_t
  #undef FIX_TYPEDEF_fexcept_t
  #undef FIX_TYPEDEF_fetrap_t	/* optional */

/*
 * FE_DFL_ENV is supposed to be usable.  With this defined,
 * IMPL_COMP_FE_DFL_ENV will be defined in myfloat.h
 */
  #undef FIX_USABLE_FE_DFL_ENV

/*
 * FE_DFL_MODE is supposed to be usable.
 */
  #undef FIX_USABLE_FE_DFL_MODE

/*
 * FE_DFL_ENV is supposed to be const qualified.  Either it is not const,
 * or compiler allows pointer to r/w to point to it.
 */
  #undef FIX_MODIFY_FE_DFL_ENV

/*
 * static bool b = INF; should be usable for static and
 * aggregate initialization.
 */
  #undef FIX_STATIC_REAL_CONST

/*
 * ONEm1_FLT, ONEm1_DBL, ONEm1_LDBL should be usable for static and aggregate
 * initialization.  They are sometimes done as 1.0-eps/2.0 (which is a valid
 * arithmetic constant expression).
 */
  #undef FIX_ONEm1_LD10_IN_ARRAY
  #undef FIX_ONEm1_LDBL_IN_ARRAY
  #undef FIX_STATIC_ONEm1_LD10
  #undef FIX_STATIC_ONEm1_LDBL

/*
 * ONEp1_FLT, ONEp1_DBL, ONEp1_LDBL should be usable for static and aggregate
 * initialization.  They are sometimes done as 1.0+eps (which is a valid
 * arithmetic constant expression).
 */
  #undef FIX_ONEp1_LD10_IN_ARRAY
  #undef FIX_ONEp1_LDBL_IN_ARRAY
  #undef FIX_STATIC_ONEp1_LD10
  #undef FIX_STATIC_ONEp1_LDBL

/*
 * INF should be usable for static and aggregate initialization.
 * This is a should, not a shall, so is optional in FPCE.
 * When added to C99, it became a shall.
 */
  #undef FIX_STATIC_INF
  #undef FIX_STATIC_INF10

/*
 * INF_FLT, INF_DBL, INF_LDBL should be usable for static and aggregate
 * initialization.  They are sometimes done as 1.0/0.0 (which is a valid
 * arithmetic constant expression).  Some compilers allow:
 *   DBL d = 1.0/0.0;
 * but not:
 *   DBL d[1] = { 1.0/0.0 };
 * This is mainly needed in the math library tests for compilers that
 * do not support infinity via 1e999999.
 */
  #undef FIX_INF_IN_ARRAY
  #undef FIX_INF10_IN_ARRAY

/*
 * SUP_LDBL shall be usable for static and aggregate initialization.
 * Problem with dbl_dbl: #define SUP_LDBL ((LDBL)DBL_MAX+(LDBL)DBL_MAX)
 */
  #undef FIX_STATIC_SUP_LDBL

/*
 * NAN should be usable for static and aggregate initialization.
 * This is a should, not a shall, so is optional in FPCE.
 * When added to C99, it became a shall.
 */
  #undef FIX_STATIC_NAN
  #undef FIX_STATIC_NAN10

/*
 * NAN_FLT, NAN_DBL, NAN_LDBL should be usable for static and aggregate
 * initialization.  They are typically done as 0.0/0.0 (which is a valid
 * arithmetic constant expression).  Some compilers allow:
 *   DBL d = 0.0/0.0;
 * but not:
 *   DBL d[1] = { 0.0/0.0 };
 * This is mainly needed in the math library tests.
 * Same for NAN_F10, NAN_D10, NAN_LD10.
 */
  #undef FIX_NAN_IN_ARRAY
  #undef FIX_NAN10_IN_ARRAY

/*
 * NAN_FLT, NAN_DBL, NAN_LDBL should be usable in mixed FP type expressions.
 * Causes a couple of compilers to core dump during translation.
 * Same for DEC_NAN, NAN_F10, NAN_D10, NAN_LD10.
 */
  #undef FIX_NAN_MATH
  #undef FIX_NAN10_MATH

/*
 * using namespace std; is needed to compile these tests as C++ code
 * (so do not need to do std::sin() or std::printf()).
 * Some older C++ compilers do not have that namespace.
 */
  #undef FIX_NAMESPACE_STD

/*
 * [static] struct fp{ FLT f; DBL d; } = { .d=1., .f=2. } is valid C99, yet it
 * causes some systems to complain at translate time about invalid
 * designated initializer.
 */
  #undef FIX_DESIGNATED_INIT
  #undef FIX_STATIC_DESIGNATED_INIT

/*
 * int vla[(int)x]; is a variable length array, new with C99.
 * If you get compile time errors (because the compiler does
 * not support vla's), define this symbol.
 */
  #undef FIX_VLA

/*
 * int vla[(int)(x*y)]; is a variable length array with
 * expression using floating-point variables. If the you get
 * compiler time errors (because the compiler does
 * not support vla's with variables), define this symbol.
 */
  #undef FIX_TRUE_VLA

/*
 * Compound literals are new with C99.
 */
  #undef FIX_COMPOUND_LIT

/*
 * Compound literals with bool members are not liked.
 */
  #undef FIX_BOOL_COMPOUND_LIT

/*
 * (struct bits){1, 1, 1}.member not liked by some compilers.
 */
  #undef FIX_COMPOUND_LIT_MEMBER

/*
 * struct flex { int n; DBL d[]; }; is a flexible array, new with C99.
 * If you get compile time errors (because the compiler does
 * not support flex arrays), define this symbol.
 */
  #undef FIX_FLEX_ARRAY

/*
 * offsetof() appiled to flexible array should be the same as with a
 * fixed size array.
 */
  #undef FIX_OFFSET_FLEX

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * struct stx { bool bx : 0; ...   bx should not be there.
 */
  #undef FIX_ACC_BAD_BOOL_BITFIELD_DECL

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * struct stx { bool bx : BOOL_PREC+1; ...   width is too big.
 */
  #undef FIX_ACC_BAD_BOOL_BITFIELD_WIDTH

/*
 * Variable length array (VLA) has many restrictions on them.
 * Many compilers accept invalid code.  Define these to force
 * a failure in the corresponding e018*00 or e018*02 test.
 */
  #undef FIX_ACC_VLA_IN_STRUCT	/* e01806 */
  #undef FIX_ACC_VLA_IN_UNION	/* e01807 */
  #undef FIX_ACC_STATIC_VLA	/* e01808 */
  #undef FIX_ACC_EXTERN_VLA	/* e01809 */
  #undef FIX_ACC_FILESCOPE_VLA	/* e01810 */
  #undef FIX_ACC_FILE_TYPEDEF_VLA	/* e01811 */
  #undef FIX_ACC_INITIALIZE_VLA	/* e01812 */
  #undef FIX_ACC_VLA_IN_COMPOUND_LIT	/* e01813 */
  #undef FIX_ACC_SWITCH_VLA	/* e01814 */
  #undef FIX_ACC_GOTO_VLA	/* e01815 */
  #undef FIX_VLA_SUBSCRIPT_ACC_FLOAT
  #undef FIX_VLA_SUBSCRIPT_ACC_PTR

/*
 * Flexible arrays have many restrictions on them.
 * Many compilers accept invalid code.  Define these to force
 * a failure in the corresponding e018*03 test.
 */
  #undef FIX_ACC_FLEX_ARRAY_IN_STRUCT	/* e0180603 */
  #undef FIX_ACC_FLEX_ARRAY_IN_UNION	/* e0180703 */
  #undef FIX_ACC_STATIC_FLEX_ARRAY	/* e0180803 */
  #undef FIX_ACC_EXTERN_FLEX_ARRAY	/* e0180903 */
  #undef FIX_ACC_FILESCOPE_FLEX_ARRAY	/* e0181003 */
  #undef FIX_ACC_FILE_TYPEDEF_FLEX_ARRAY	/* e0181103 */
  #undef FIX_ACC_INITIALIZE_FLEX_ARRAY	/* e0181203 */
  #undef FIX_ACC_FLEX_ARAY_IN_COMPND_LIT	/* e0181303 */
  #undef FIX_ACC_SWITCH_FLEX_ARRAY	/* e0181403 */
  #undef FIX_ACC_GOTO_FLEX_ARRAY	/* e0181503 */
  #undef FIX_FLEX_ACC_FLOAT
  #undef FIX_FLEX_SUBSCRIPT_ACC_PTR

/*
 * Invalid FPCE C code is accepted as valid. The code in question is:
 * Invalid FPCE hex floating-point constant.  When upgraded the FPCE test
 * suite for C99, the files were renumbered to a better range.
 */
  #if FPCE_TEST_LVL >= 19960226uL
    #undef FIX_ACC_e0100300
   /* ... thru ... */
    #undef FIX_ACC_e0100370
  #else		/* 19940630uL */
    #undef FIX_ACC_e0100212
   /* ... thru ... */
    #undef FIX_ACC_e0100282
  #endif

/*
 * Uniary operators accept incomplete types
 */
  #undef FIX_POST_INC_DEC_ACC_INCOMPLETE
  #undef FIX_PRE_INC_DEC_ACC_INCOMPLETE

/*
 * Uniary operators accept complex or imaginary operands.
 */
  #undef FIX_POST_INC_DEC_ACC_CX_IM
  #undef FIX_PRE_INC_DEC_ACC_CX_IM

/*
 * Binary operators accept complex or imaginary operands.
 */
  #undef FIX_BIN_GE_ACC_CX_IM
  #undef FIX_BIN_GT_ACC_CX_IM
  #undef FIX_BIN_LE_ACC_CX_IM
  #undef FIX_BIN_LT_ACC_CX_IM

/*
 * int func();  ....; int func(FLT imag) should be accepted.
 */
  #undef  FIX_OLD_STYLE_FLT_IMAG

/*
 * Is 'long long int' supported?  Matters for t036* tests.
 * See later about LONGLONG (which might be alternate spelling).
 */
  #undef  FIX_LONG_LONG

/*
 * Is a declaration in a 'for' supported: for( declaration; ; ){}
 */
  #undef  FIX_DECL_IN_FOR

/*
 * Tests of invalid combinations of keywords in declarations.
 * Define these if the compiler accepts these invalid forms.
 * Complex real types.
 */
  #undef FIX_ACC_e4360001
  /* thru */
  #undef FIX_ACC_e4360291

/*
 * Tests of invalid combinations of keywords in 'for' declarations.
 * Define these if the compiler accepts these invalid forms.
 * Complex real types.
 */
  #undef FIX_ACC_e4361001
  /* thru */
  #undef FIX_ACC_e4361105

/*
 * Tests of sizeof type, where type is NOT in ().
 */
  #undef FIX_ACC_e4371021
  /* thru */
  #undef FIX_ACC_e4371026

/*
 * Some macro symbols in <complex.h> are missing or have such poor
 * definitions that they are unusable.
 */
  #undef FIX_SYM_complex
  #undef FIX_SYM__Complex_I
  #undef FIX_SYM_imaginary
  #undef FIX_SYM__Imaginary_I
  #undef FIX_SYM_I

/*
 * If I is complex, then I*INFINITY becomes (0+i)*inf becomes
 * 0*inf+i*inf and ends up producing NAN+i*INFINITY.  (so is not
 * usable).
 */
  #undef FIX_I_WITH_INF

/*
 * static double _Complex d =  1.0 + 1.0*I ; is valid ISO/ANSI C,
 * yet it causes some systems to give syntax errors at compile time.
 * This removes the initializer or var.
 */
  #undef FIX_STATIC_CMPLX_CONST

/*
 * static double _Imaginary d =  1.0*I ; is valid ISO/ANSI C,
 * yet it causes some systems to give syntax errors at compile time.
 * This removes the initializer.
 */
  #undef FIX_STATIC_IMAG_CONST

/*
 * __VA_ARGS__ can only be used in replacement list of macro.
 * Most compiles accept it in the wrong place.
 */
  #undef FIX_ACC_BAD_VA_ARGS

/*
 * restrict is a new keyword with C99.
 */
  #undef FIX_RESTRICT

/*** Translate time: DFP: ***/

/*
 * Decimal FP TR added many new <math.h> functions above and beyond
 * C99.  Most of them are supposed to be overloaded.  This disables
 * checking all of them.
 * You can disable checking certain ones by using the above methods
 * (one or more of FIX_ FUNCS10 / FUNC / TRUE _name).
 */
  #undef FIX_DECFP_FUNCTIONS

/*
 * Decimal FP TR added many new macros and functions above and beyond C99.
 * They may end up in existing standard headers, or be in their own headers.
 * For compilers that have them outside of standard headers, you need to
 * define these symbols (as appropriate).
 */
  #undef FIX_DECFP_IN_FENV_H
  #undef FIX_DECFP_IN_FLOAT_H
  #undef FIX_DECFP_IN_MATH_H
  #undef FIX_DECFP_IN_STDLIB_H
  #undef FIX_DECFP_IN_WCHAR_H

/*
 * An implementation of DFP is supposed to defined this symbol.
 */
  #undef FIX_SYM_STDC_DEC_FP__

/*
 * DEC_EVAL_METHOD is supposed to be defined in <float.h>.
 */
  #undef FIX_DEC_EVAL_IN_HEADER

/*
 * The DFP symbols in headers are only defined with the first usage
 * of that header and with __STDC WANT DEC FP__ defined before that
 * first usage. See t6060200.
 */
  #undef FIX_DFP_SYMBOLS_IN_HEADER

/*
 * To prevent the Decimal FP support functions in s0000000 from being defined,
 * you need to #define this symbol.  This is for implementations that are
 * starting to support DFP, but too much is still missing.
 */
  #undef FIX_DEC_FP

/*
 * The Decimal FP Tech Spec changed a few things.
 * The Decimal FP Tech Report is adding many new symbols to <float.h>.
 *
 * The symbol to represent the smallest denormal/subnormal number.
 * Its name changed as the TR/TS evolved.
 * DEC*_DEN -> DEC*_SUBNORMAL_MIN -> DEC*_TRUE_MIN
 */
  #undef FIX_SYM_DEC32_TRUE_MIN
  #undef FIX_SYM_DEC64_TRUE_MIN
  #undef FIX_SYM_DEC128_TRUE_MIN
  #undef FIX_SYM_DEC32_SUBNORMAL_MIN
  #undef FIX_SYM_DEC64_SUBNORMAL_MIN
  #undef FIX_SYM_DEC128_SUBNORMAL_MIN
  #undef FIX_SYM_DEC32_DEN
  #undef FIX_SYM_DEC64_DEN
  #undef FIX_SYM_DEC128_DEN

/*
 * DFP TR added some more symbols to <fenv.h>
 */
  #undef FIX_SYM_FE_DEC_DOWNWARD
  #undef FIX_SYM_FE_DEC_TONEAREST
  #undef FIX_SYM_FE_DEC_TONEARESTFROMZERO
  #undef FIX_SYM_FE_DEC_TOWARDZERO
  #undef FIX_SYM_FE_DEC_UPWARD

/*
 * DFP TR added some more symbols to <math.h>
 */
  #undef FIX_SYM_DEC_INFINITY
  #undef FIX_SYM_DEC_NAN
  #undef FIX_SYM_HUGE_VAL_D128
  #undef FIX_SYM_HUGE_VAL_D32
  #undef FIX_SYM_HUGE_VAL_D64

/*
 * Binary operators accept mixed Decimal FP and Binary FP operands.
 */
  #undef FIX_BIN_ADD_MIX_DFP_BFP
  #undef FIX_BIN_SUB_MIX_DFP_BFP
  #undef FIX_BIN_MULT_MIX_DFP_BFP
  #undef FIX_BIN_DIV_MIX_DFP_BFP
  #undef FIX_BIN_EQ_MIX_DFP_BFP
  #undef FIX_BIN_GE_MIX_DFP_BFP
  #undef FIX_BIN_GT_MIX_DFP_BFP
  #undef FIX_BIN_LE_MIX_DFP_BFP
  #undef FIX_BIN_LT_MIX_DFP_BFP
  #undef FIX_BIN_NE_MIX_DFP_BFP
  #undef FIX_BIN_PLUS_EQ_MIX_DFP_BFP
  #undef FIX_BIN_SUB_EQ_MIX_DFP_BFP
  #undef FIX_BIN_MULT_EQ_MIX_DFP_BFP
  #undef FIX_BIN_DIV_EQ_MIX_DFP_BFP
  #undef FIX_TRI_COND_OP_MIX_DFP_BFP

/*
 * To distinguish BFP from DFP for unsuffixed DBL constants,
 * the DFP TR add a 'd' and 'D' suffix to make sure that the
 * FP constant is 'DBL'.  Some compilers that support DFP TR,
 * do not yet support this suffix (causes translation to stop).
 */
  #undef FIX_D_SUFFIX

/*
 * The DFP constants in the system headers cause translation to end.
 */
  #undef FIX_D10_CONSTS

/*
 * Tests of invalid suffixes on DFP constants.
 * Define these if the compiler accepts these invalid forms.
 */
  #undef FIX_ACC_e6100400
  /* thru */
  #undef FIX_ACC_e6100419

/*
 * Tests of invalid combinations of keywords in declarations.
 * Define these if the compiler accepts these invalid forms.
 * Real and complex decimal types.
 */
  #undef FIX_ACC_e6360001
  /* thru */
  #undef FIX_ACC_e6360291
  #undef FIX_ACC_e7360001
  /* thru */
  #undef FIX_ACC_e7360291

/*
 * Tests of invalid combinations of keywords in 'for' declarations.
 * Define these if the compiler accepts these invalid forms.
 * Real and complex decimal types.
 */
  #undef FIX_ACC_e6361001
  /* thru */
  #undef FIX_ACC_e6361105
  #undef FIX_ACC_e7361001
  /* thru */
  #undef FIX_ACC_e7361105

/*
 * Tests of sizeof type, where type is NOT in ().
 */
  #undef FIX_ACC_e6371027
  #undef FIX_ACC_e6371028
  #undef FIX_ACC_e6371029

/*
 * #pragma STDC FLOAT_CONST_DECIMAL64 should be followed by one of
 * DEFAULT | ON | OFF
 * and honored.
 */
  #undef FIX_DFP64_PRAGMA		/* ignored */
  #undef FIX_DFP64_ACC_MIXED		/* works, but accepts mixed DFP/BFP */
  #undef FIX_DFP64_ACC_HEXFP		/* applied to unsuffixed hexadecimal FP const */

/*** Translate time: C11 (was C1x) ***/

/*
 * Headers new with C11.
 */
  #undef FIX_STDALIGN_H			/* <stdalign.h> */
  #undef FIX_STDATOMIC_H		/* <stdatomic.h> */
  #undef FIX_STDNORETURN_H		/* <stdnoreturn.h> */
  #undef FIX_THREADS_H			/* <threads.h> */
  #undef FIX_UCHAR_H			/* <uchar.h> */

/*
 * <stdint.h> has new typedefs.
 */
  #undef FIX_TYPEDEF_intmax_t
  #undef FIX_TYPEDEF_uintmax_t

/*
 * clang limits universal character constants to just one.
 */
  #undef FIX_MANY_UCHAR

/*
 * universal character name (\u0024, \U00000024) not known
 */
  #undef FIX_UNI_CHAR_NAME

/*
 * universal character constants (u'z', U'z') not known
 */
  #undef FIX_UNI_CHAR_CONST

/*
 * universal character string constants (u"z", U"z") not known
 */
  #undef FIX_UNI_STR_CONST

/*
 * 8-bit unicode string constants (U8"string") not known
 */
  #undef FIX_U8_STR_CONST

/*
 * anonymous struct not known
 */
  #undef FIX_ANON_STRUCT

/*
 * anonymous union not known
 */
  #undef FIX_ANON_UNION

/*
 * anonymous duplicate member
 */
  #undef FIX_ANON_DUP_MEMBER

/*
 * anonymous extension
 */
  #undef FIX_ANON_EXTENSION

/*
 * _Atomic is not known to the compiler.
 */
  #undef FIX_ATOMIC

/*
 * _Atomic with restrict not supported.
 */
  #undef FIX_ATOMIC_RESTRICT

/*
 * _Atomic with _Generic done wrong
 */
  #undef FIX_ATOMIC_GENERIC

/*
 * _Generic is not known to the compiler.
 */
  #undef FIX_GENERIC

/*
 * _Generic is supposed to work with a struct type.
 */
  #undef FIX_GENERIC_STRUCT

/*
 * There are several function-like macros in <complex.h>
 * They should be usable for static initialization.
 */
  #undef FIX_MACF_CMPLX
  #undef FIX_MACF_CMPLXF
  #undef FIX_MACF_CMPLXL

/*
 * <float.h> is missing the symbols added by C11.
 * You can do: #define C11FLOAT_H "c11float.h"
 * along with this to get them.
 */
  #undef  FIX_C11_IN_FLOAT_H

/*
 * *_HAS_SUBNORM missing from <float.h>
 */
  #undef FIX_SYM_FLT_HAS_SUBNORM
  #undef FIX_SYM_DBL_HAS_SUBNORM
  #undef FIX_SYM_LDBL_HAS_SUBNORM
  #undef FIX_SYM_DEC32_HAS_SUBNORM
  #undef FIX_SYM_DEC64_HAS_SUBNORM
  #undef FIX_SYM_DEC128_HAS_SUBNORM

/*
 * *_TRUE_MIN missing from <float.h>
 */
  #undef FIX_SYM_FLT_TRUE_MIN
  #undef FIX_SYM_DBL_TRUE_MIN
  #undef FIX_SYM_LDBL_TRUE_MIN

/*
 * *_DECIMAL_DIG missing from <float.h>
 */
  #undef FIX_SYM_FLT_DECIMAL_DIG
  #undef FIX_SYM_DBL_DECIMAL_DIG
  #undef FIX_SYM_LDBL_DECIMAL_DIG

/*** Translate time: C17 ***/

/*** Translate time: CFP: ***/

/*
 * C Floating Point (CFP) group is adding support for IEEE-754-2008
 * to C11/C17/C2X.  This is for the math functions.
 * You can disable checking certain ones by using the above methods
 * (one or more of FIX_ FUNCS10 / FUNC / TRUE _name).
 */
  #undef FIX_OVERLOAD_CFP
  #undef FIX_OVERLOAD10_CFP
  #undef FIX_CFP_FUNCTIONS
  #undef FIX_FUNC_strfromf
  #undef FIX_FUNC_strfromd
  #undef FIX_FUNC_strfroml

/*
 * Are functions in correct header?
 */
  #undef FIX_strfromf_HEADER
  #undef FIX_strfromd_HEADER
  #undef FIX_strfroml_HEADER

/*
 * Support for signaling NaNs was added to CFP and C2X via the symbols:
 * SNANF, SNAN, and SNANL; SNAND32, SNAND64, SNAND128.
 */
  #undef FIX_SNAN
  #undef FIX_SNAN10

/*
 * SNAN used in expression must be triggered and converted into a QNAN.
 * Some compilers leave it as a SNAN.
 */
  #undef FIX_SNAN10_EXPRESSION

/*
 * FP_INT_* missing from <math.h>
 */
  #undef FIX_SYM_FP_INT_DOWNWARD

/*
 * *_WIDTH missing from <limits.h>
 */
  #undef FIX_SYM_INT_WIDTH
  #undef FIX_SYM_UINT_WIDTH

/*** Translate time: C2X ***/

/*
 * 8-bit unicode character constants (u8'z') not known
 */
  #undef FIX_U8_CHAR_CONST


/*****************
 * These show up as runtime errors that cause test case failure.
 * These are normally due to bad code generation or bad translation time
 * conversions or bad library functions.
 *
 * First are the old (ISO/ANSI) C89/C90/C95 violations.
 * Second are the Standard C99 violations.
 * Third are the Decimal Floating-Point (DFP) Tech Report violations.
 * Fourth are C11 violations.
 ****************/

/*** Run time: C89/C90/C95 ***/
/*** Run time: C89/C90/C95: value of constant problems ***/

/*
 * Units Last Place error allowed for decimal (or hex FP) to binary conversion.
 * Must be an integer, since used in preprocessor #if
 *  0 => converted value must match round to nearest (rn) value
 * -1 => converted value is either round -INF (rm) or round +INF (rp) value
 *  j => converted value is in rn +/- j ULPs, inclusive of end points;
 *	 (Std C is 1 ulp except at power of base, where -1/radix ulp ... +1 ulp)
 * rm <= rn, rn <= rp, rm + 1 ulp = rp
 * Undefined will be treated like 0
 * *_DEC2BIN_* is for compile time conversions.
 * *_SCAN2BIN_* is for runtime conversions (scanf and strto*).
 * *_WSCAN2BIN_* is for runtime conversions (wscanf and wcsto*).
 * *_STRTOBIN_ULPS is for runtime conversions (strto*).
 * *_WCSTOBIN_ULPS is for runtime conversions (wcsto*).
 * *_BIN2DEC2BIN_ULPS is for binary to decimal to binary (printf & scanf);
 * *_BIN2HEX2BIN_ULPS is for binary to hexadecimal to binary (printf & scanf);
 *   the roundtrip ULP error must be zero or positive.
 * Symbols with '10' or 'DFP' are for Decimal FP types.
 */
  #undef LD_DEC2BIN_ULPS
  #undef  D_DEC2BIN_ULPS
  #undef  F_DEC2BIN_ULPS
  #undef LD10_DEC2DFP_ULPS
  #undef  D10_DEC2DFP_ULPS
  #undef  F10_DEC2DFP_ULPS

  #undef LD_SCAN2BIN_ULPS
  #undef  D_SCAN2BIN_ULPS
  #undef  F_SCAN2BIN_ULPS
  #undef LD10_SCAN2DFP_ULPS
  #undef  D10_SCAN2DFP_ULPS
  #undef  F10_SCAN2DFP_ULPS

  #undef LD_WSCAN2BIN_ULPS
  #undef  D_WSCAN2BIN_ULPS
  #undef  F_WSCAN2BIN_ULPS

  #undef LD_STRTOBIN_ULPS
  #undef  D_STRTOBIN_ULPS
  #undef  F_STRTOBIN_ULPS
  #undef LD10_STRTODFP_ULPS
  #undef  D10_STRTODFP_ULPS
  #undef  F10_STRTODFP_ULPS

  #undef LD_WCSTOBIN_ULPS
  #undef  D_WCSTOBIN_ULPS
  #undef  F_WCSTOBIN_ULPS

  #undef LD_BIN2DEC2BIN_ULPS
  #undef  D_BIN2DEC2BIN_ULPS
  #undef  F_BIN2DEC2BIN_ULPS
  #undef LD10_DFP2DEC2DFP_ULPS
  #undef  D10_DFP2DEC2DFP_ULPS
  #undef  F10_DFP2DEC2DFP_ULPS

  #undef LD_BIN2HEX2BIN_ULPS
  #undef  D_BIN2HEX2BIN_ULPS
  #undef  F_BIN2HEX2BIN_ULPS

/*
 * If the maximum finite value depends upon either the operation (+, *, or /),
 * rounding, or the operands, then define this symbol.  So far, only needed for dbl_dbl.
 */
  #undef FIX_SLOPPY_SUP_LDBL

/*
 * If a value of a macro symbol in <float.h> or yourfile.flt is wrong and
 * cannot be fixed (because the decimal to binary conversion is too sloppy)
 * this bypasses tests and some uses of that symbol.  Shown here are just the
 * FLT versions of the symbols, but you can also use DBL and LDBL versions.
 * This mainly effects t0000000/t6000000.
 */
  #undef	FIX_WRONG_DBL_EPS
  #undef	FIX_WRONG_DBL_TRUE_MIN
  #undef	FIX_WRONG_DEC32_DIG		/* <decfloat.h> symbols */
  #undef	FIX_WRONG_DEC32_EPS
  #undef	FIX_WRONG_DEC32_MAX
  #undef	FIX_WRONG_DEC32_MAX_EXP
  #undef	FIX_WRONG_DEC32_MIN
  #undef	FIX_WRONG_DEC32_TRUE_MIN
  #undef	FIX_WRONG_DEC32_MIN_EXP
  #undef	FIX_WRONG_DECIMAL_DIG		/* Has wrong value (too small) */
  #undef	FIX_WRONG_FLT_DECIMAL_DIG	/* C11 added */
  #undef	FIX_WRONG_FLT_DIG		/* <float.h> symbols */
  #undef	FIX_WRONG_FLT_EPS
  #undef	FIX_WRONG_FLT_MAX
  #undef	FIX_WRONG_FLT_MAX_EXP
  #undef	FIX_WRONG_FLT_MIN
  #undef	FIX_WRONG_FLT_MIN_EXP
  #undef	FIX_WRONG_FLT_TRUE_MIN
  #undef	FIX_WRONG_LDBL_EPS
  #undef	FIX_WRONG_LDBL_TRUE_MIN

  #undef	FIX_WRONG_DEN_F10
  #undef	FIX_WRONG_DEN_FLT
  #undef	FIX_WRONG_INF_F10		/* yourfile.flt symbols */
  #undef	FIX_WRONG_INF_FLT		/* yourfile.flt symbols */
  #undef	FIX_WRONG_MAX_F10
  #undef	FIX_WRONG_MAX_FLT
  #undef	FIX_WRONG_MAXm1_F10
  #undef	FIX_WRONG_MAXm1_FLT
  #undef	FIX_WRONG_MIN_F10
  #undef	FIX_WRONG_MIN_FLT
  #undef	FIX_WRONG_MINp1_D10
  #undef	FIX_WRONG_MINp1_DBL
  #undef	FIX_WRONG_MINp1_F10
  #undef	FIX_WRONG_MINp1_FLT
  #undef	FIX_WRONG_MINp1_LD10
  #undef	FIX_WRONG_MINp1_LDBL
  #undef	FIX_WRONG_ONEm1_F10
  #undef	FIX_WRONG_ONEm1_FLT
  #undef	FIX_WRONG_ONEp1_F10
  #undef	FIX_WRONG_ONEp1_FLT
  #undef	FIX_WRONG_SUP_DBL
  #undef	FIX_WRONG_SUP_FLT
  #undef	FIX_WRONG_SUP_LDBL
  #undef	FIX_WRONG_TRD_D_F10
  #undef	FIX_WRONG_TRD_D_FLT
  #undef	FIX_WRONG_TRD_U_F10
  #undef	FIX_WRONG_TRD_U_FLT
  #undef	FIX_WRONG_ULP_F10
  #undef	FIX_WRONG_ULP_FLT

/*
 * If a value of a macro symbol in <float.h> or yourfile.flt is close, but
 * not exact, this bypasses some tests.  It may happen that when the decimal
 * constant is assigned to a var of its type, the value is correct, but if
 * the decimal constant is used in an expression, then its value may differ
 * a little from the correct value.  This mainly effects t0000000/t6000000.
 */
  #undef	FIX_CLOSE_DBL_EPS		/* <float.h> symbols */
  #undef	FIX_CLOSE_DBL_MAX
  #undef	FIX_CLOSE_DBL_MIN
  #undef	FIX_CLOSE_DBL_TRUE_MIN
  #undef	FIX_CLOSE_DEC128_EPS
  #undef	FIX_CLOSE_DEC128_MAX
  #undef	FIX_CLOSE_DEC128_MIN
  #undef	FIX_CLOSE_DEC128_TRUE_MIN
  #undef	FIX_CLOSE_DEC32_EPS
  #undef	FIX_CLOSE_DEC32_MAX
  #undef	FIX_CLOSE_DEC32_MIN
  #undef	FIX_CLOSE_DEC32_TRUE_MIN
  #undef	FIX_CLOSE_DEC64_EPS		/* <decfloat.h> symbols */
  #undef	FIX_CLOSE_DEC64_MAX
  #undef	FIX_CLOSE_DEC64_MIN
  #undef	FIX_CLOSE_DEC64_TRUE_MIN
  #undef	FIX_CLOSE_FLT_DEN
  #undef	FIX_CLOSE_FLT_EPS
  #undef	FIX_CLOSE_FLT_MAX
  #undef	FIX_CLOSE_FLT_MIN
  #undef	FIX_CLOSE_FLT_TRUE_MIN
  #undef	FIX_CLOSE_LDBL_EPS
  #undef	FIX_CLOSE_LDBL_MAX
  #undef	FIX_CLOSE_LDBL_MIN
  #undef	FIX_CLOSE_LDBL_TRUE_MIN

  #undef	FIX_CLOSE_DEN_D10
  #undef	FIX_CLOSE_DEN_DBL		/* yourfile.flt symbols */
  #undef	FIX_CLOSE_DEN_F10
  #undef	FIX_CLOSE_DEN_FLT
  #undef	FIX_CLOSE_DEN_LDBL
  #undef	FIX_CLOSE_DEN_LD10
  #undef	FIX_CLOSE_MAX_D10
  #undef	FIX_CLOSE_MAX_DBL
  #undef	FIX_CLOSE_MAX_F10
  #undef	FIX_CLOSE_MAX_FLT
  #undef	FIX_CLOSE_MAX_LD10
  #undef	FIX_CLOSE_MAX_LDBL
  #undef	FIX_CLOSE_MAXm1_D10
  #undef	FIX_CLOSE_MAXm1_DBL
  #undef	FIX_CLOSE_MAXm1_F10
  #undef	FIX_CLOSE_MAXm1_FLT
  #undef	FIX_CLOSE_MAXm1_LD10
  #undef	FIX_CLOSE_MAXm1_LDBL
  #undef	FIX_CLOSE_MIN_D10
  #undef	FIX_CLOSE_MIN_DBL
  #undef	FIX_CLOSE_MIN_F10
  #undef	FIX_CLOSE_MIN_FLT
  #undef	FIX_CLOSE_MIN_LD10
  #undef	FIX_CLOSE_MIN_LDBL
  #undef	FIX_CLOSE_MINp1_D10
  #undef	FIX_CLOSE_MINp1_DBL
  #undef	FIX_CLOSE_MINp1_F10
  #undef	FIX_CLOSE_MINp1_FLT
  #undef	FIX_CLOSE_MINp1_LD10
  #undef	FIX_CLOSE_MINp1_LDBL
  #undef	FIX_CLOSE_ONEm1_D10
  #undef	FIX_CLOSE_ONEm1_DBL
  #undef	FIX_CLOSE_ONEm1_F10
  #undef	FIX_CLOSE_ONEm1_FLT
  #undef	FIX_CLOSE_ONEm1_LD10
  #undef	FIX_CLOSE_ONEm1_LDBL
  #undef	FIX_CLOSE_ONEp1_D10
  #undef	FIX_CLOSE_ONEp1_DBL
  #undef	FIX_CLOSE_ONEp1_F10
  #undef	FIX_CLOSE_ONEp1_FLT
  #undef	FIX_CLOSE_ONEp1_LD10
  #undef	FIX_CLOSE_ONEp1_LDBL
  #undef	FIX_CLOSE_SUP_DBL
  #undef	FIX_CLOSE_SUP_FLT
  #undef	FIX_CLOSE_SUP_LDBL
  #undef	FIX_CLOSE_TRD_D10
  #undef	FIX_CLOSE_TRD_DBL
  #undef	FIX_CLOSE_TRD_D_DBL
  #undef	FIX_CLOSE_TRD_D_FLT
  #undef	FIX_CLOSE_TRD_D_LDBL
  #undef	FIX_CLOSE_TRD_D_D10
  #undef	FIX_CLOSE_TRD_D_F10
  #undef	FIX_CLOSE_TRD_D_LD10
  #undef	FIX_CLOSE_TRD_F10
  #undef	FIX_CLOSE_TRD_FLT
  #undef	FIX_CLOSE_TRD_LD10
  #undef	FIX_CLOSE_TRD_LDBL	/* dbl_dbl 1.L/3.L has more accuracy than expected */
  #undef	FIX_CLOSE_TRD_U_DBL
  #undef	FIX_CLOSE_TRD_U_FLT
  #undef	FIX_CLOSE_TRD_U_LDBL
  #undef	FIX_CLOSE_TRD_U_D10
  #undef	FIX_CLOSE_TRD_U_F10
  #undef	FIX_CLOSE_TRD_U_LD10
  #undef	FIX_CLOSE_ULP_D10
  #undef	FIX_CLOSE_ULP_DBL
  #undef	FIX_CLOSE_ULP_F10
  #undef	FIX_CLOSE_ULP_FLT
  #undef	FIX_CLOSE_ULP_LD10
  #undef	FIX_CLOSE_ULP_LDBL

/*
 * Conversion from numeric constants to internal FP of my values in
 * myfloat.h are done so bad, that you need to use your own versions.
 * This is most likely due to too many digits in the myfloat.h versions.
 */
  #undef FIX_MYFLOAT_PI
  #undef FIX_MYFLOAT_PI34
  #undef FIX_MYFLOAT_PI2
  #undef FIX_MYFLOAT_PI4
  #undef FIX_MYFLOAT_LN2
  #undef FIX_MYFLOAT_LN10
  #undef FIX_MYFLOAT_LOG2
  #undef FIX_MYFLOAT_SQRT2
  #undef FIX_MYFLOAT_M_e
  #undef FIX_MYFLOAT_TWORPI

/*
 * Conversion from numeric constants to internal FP of values in
 * t0130100 are done so bad, that you need to use workarounds.
 * This is most likely due to too many digits in the myfloat.h versions.
 */
  #undef FIX_CLOSE_THIRD_DBL
  #undef FIX_CLOSE_THIRD_FLT
  #undef FIX_CLOSE_THIRD_LDBL
  #undef FIX_CLOSE_THIRD_D10
  #undef FIX_CLOSE_THIRD_F10
  #undef FIX_CLOSE_THIRD_LD10

/*
 * Conversion from numeric constants to internal FP is bad for t1* vectors.
 */
  #undef FIX_WRONG_DEC2BIN
  #undef FIX_WRONG_DEC2DFP

/*
 * The *_MIN values in <limits.h> are one too high, eg, *_MIN == -*_MAX
 * instead of -*_MAX-1; a symptom of this is invalid is not raised for
 * a floating-point value of *_MIN-1 converted to integral.
 */
  #undef FIX_HI_MIN

/*
 * 1.57 should be equal to 1.570; that is, adding a trailing zero should
 * not change the converted value.  This is Tydeman wish (not Std C).
 * It is FPCE requirement if FPCE requires round nearest.
 */
  #undef FIX_F_EQ_F0

/*
 * -max * max is +inf for Watcom 1.8
 */
  #undef FIX_mINFINITY
  #undef FIX_mDEC_INFINITY

/*
 * 0.0e9999999 is zero, not infinity nor pseudo-infinity nor NaN.
 */
  #undef FIX_ZERO_INFINITY
  #undef FIX_ZERO10_INF10

/*
 * 0.0e-9999999 is zero.  Caused infinite loop in one lint/compiler.
 */
  #undef FIX_ZERO_MINFINITY
  #undef FIX_ZERO10_MINF10

/*
 * -0.0 should compare equal to zero.
 */
  #undef FIX_ZERO_EQ_NEG_ZERO

/*
 * Decimal (external) to binary (internal) conversion by implementation must
 * produce one of 3 values:  nearest, nearest+ulp, nearest-ulp.  Some
 * implementations produce zero for non-zero finite representable numbers.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_ZERO	/* compile time translation */
  #undef FIX_DEC2DFP_ZERO	/* compile time translation */
  #undef FIX_SCAN2BIN_ZERO
  #undef FIX_SCAN2DFP_ZERO
  #undef FIX_WSCAN2BIN_ZERO
  #undef FIX_WSCAN2DFP_ZERO
  #undef FIX_STR2BIN_ZERO	/* strto* */
  #undef FIX_STR2DFP_ZERO	/* strto* */
  #undef FIX_WCS2BIN_ZERO	/* wcsto* */
  #undef FIX_WCS2DFP_ZERO	/* wcsto* */

/*
 * Decimal (external) to binary (internal) conversion by implementation must
 * produce result with same sign as source.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_SIGN	/* compile time translation */
  #undef FIX_DEC2DFP_SIGN	/* compile time translation */
  #undef FIX_SCAN2BIN_SIGN
  #undef FIX_SCAN2DFP_SIGN
  #undef FIX_WSCAN2BIN_SIGN
  #undef FIX_WSCAN2DFP_SIGN
/*  #undef FIX_STR2BIN_SIGN	// strto* */
/*  #undef FIX_WCS2BIN_SIGN	// wcsto* */

/*
 * If the error in decimal (external) to binary (internal) conversion
 * is so large that it cannot be represented as a long int (used during
 * pre-processor), then define this symbol as a DBL value, eg,
 * #define FIX_DEC2BIN_LARGE 2.0e9
 * This is useful if most conversions have a small error (bypassed by
 * *_DEC2BIN_ULPS) and a few conversions with large error (bypassed by
 * this symbol).  This ignores errors LARGER than the macro's value.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_LARGE
  #undef FIX_DEC2DFP_LARGE
  #undef FIX_SCAN2BIN_LARGE
  #undef FIX_SCAN2DFP_LARGE
  #undef FIX_WSCAN2BIN_LARGE
  #undef FIX_WSCAN2DFP_LARGE
  #undef FIX_STRTO2BIN_LARGE
  #undef FIX_STRTO2DFP_LARGE
  #undef FIX_WCSTO2BIN_LARGE
  #undef FIX_WCSTO2DFP_LARGE

/*
 * Some conversion tests result in one of the two numbers being compared
 * being infinity and the other being a large finite.  The two numbers
 * are the expected correctly rounded value and the actual value.
 * That condition results in an infinite ulps error.  This symbol
 * allows those failures to be bypassed.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_INF
  #undef FIX_DEC2DFP_INF
  #undef FIX_DFP2BFP_INF
  #undef FIX_SCAN2BIN_INF
  #undef FIX_SCAN2DFP_INF
  #undef FIX_WSCAN2BIN_INF
  #undef FIX_WSCAN2DFP_INF

/*
 * Decimal (external) to binary (internal) conversion by implementation must
 * produce one of 3 values:  nearest, nearest+ulp, nearest-ulp.  Some
 * implementations produce NaN for non-zero normal numbers.  Others produce
 * a NaN ulps error.  This symbol allows those failures to be bypassed.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_NAN
  #undef FIX_DEC2DFP_NAN
  #undef FIX_SCAN2BIN_NAN
  #undef FIX_SCAN2DFP_NAN
  #undef FIX_WSCAN2BIN_NAN
  #undef FIX_WSCAN2DFP_NAN

/*
 * Decimal (external) to binary (internal) conversion by compiler of
 * value and -value should produce the same absolute value.
 */
  #undef FIX_DEC2BIN_OF_NEG
  #undef FIX_DEC2DFP_OF_NEG

/*
 * Decimal (external) to binary (internal) conversion by compiler must
 * produce one of 3 values:  nearest-ulp, nearest, nearest+ulp.  Some
 * compilers cannot even do that which is ISO/ANSI C requirement.
 */
  #undef FIX_DEC2BIN_3
  #undef FIX_SCAN2BIN_3
  #undef FIX_SCAN2DFP_3
  #undef FIX_WSCAN2BIN_3
  #undef FIX_WSCAN2DFP_3

/*
 * At least one compiler treats (int)7.9999999... as the value zero.
 */
  #undef FIX_INT_OF_DBL_IS_ZERO

/*
 * Decimal (external) to binary (internal) conversion by compiler of
 * minimum normal LDBL number (MIN_LDBL) is not same as LDBL_MIN.
 */
  #undef FIX_MIN_LDBL
  #undef FIX_MIN_LD10

/*
 * If the error in binary (internal) to decimal (external) conversion
 * is so large that it cannot be represented as a long int (used during
 * pre-processor), then define this symbol as a DBL value, eg,
 * #define FIX_BIN2DEC_LARGE 2.0e9
 * This is useful if most conversions have a small error (bypassed by
 * *_BIN2DEC_*_ULPS) and a few conversions with large error (bypassed by
 * this symbol).  This ignores errors LARGER than the macros value.
 */
  #undef FIX_BIN2DEC_LARGE
  #undef FIX_DFP2DEC_LARGE

/*
 * '\x0004' is converted wrong; as if '\0' '4'
 */
  #undef FIX_BAD_HEX_CHAR

/*
 * L'c' is supposed to be of type wchar_t.
 */
  #undef FIX_Lchar_IS_WCHAR

/*
 * Integer Constant Expression (ICE) with ',' op: (1,2,3)
 */
  #undef FIX_ICE_COMMA_OP


/*** Run time: C89/C90/C95: code generation problems ***/

/*
 * Conversion/promotion/cast/assignment from one type (y) to another
 * type (x) should be supported, e.g., x=y, or (x)y.  It either kills
 * compile if not supported, or produces the wrong result at run time.
 * x, y may be one of: LDBL, DBL, FLT, [U|S]LLI, [U|S]LI, [U|S]I, [U|S]SI,
 * [U|S|P]C, ENUM, [U|S]B{its}.  Use FP if all of LDBL/DBL/FLT apply.
 * Use INT if any of the integer types apply.
 */
  #undef FIX_DBL_FROM_SI
  #undef FIX_DBL_FROM_SLI
  #undef FIX_DBL_FROM_SLLI
  #undef FIX_DBL_FROM_UI
  #undef FIX_DBL_FROM_ULI
  #undef FIX_DBL_FROM_ULLI
  #undef FIX_ENUM_FROM_BITFIELD
  #undef FIX_ENUM_FROM_FP
  #undef FIX_ENUM_FROM_INT_TYPE
  #undef FIX_INT_FROM_BITFIELD
  #undef FIX_LDBL_FROM_SLI
  #undef FIX_LDBL_FROM_UI
  #undef FIX_LDBL_FROM_ULI
  #undef FIX_PC_FROM_FP
  #undef FIX_SB_FROM_FP
  #undef FIX_SC_FROM_FP
  #undef FIX_SI_FROM_FP
  #undef FIX_SLI_FROM_FP
  #undef FIX_SSI_FROM_FP
  #undef FIX_UB_FROM_FP
  #undef FIX_UC_FROM_FP
  #undef FIX_UI_FROM_FP
  #undef FIX_ULI_FROM_FLT
  #undef FIX_ULI_FROM_FP
  #undef FIX_INT_FROM_LARGE_FP_CONST
  #undef FIX_ULI_FROM_LARGE_FP_CONST
  #undef FIX_USI_FROM_FP

/*
 * Expressions involving constants are evaluated during translation
 * time, but done wrong.  If force to runtime, done OK.
 */
  #undef FIX_BAD_TRANS_TIME_MATH

/*
 * constant*constant != var*var for same value
 */
  #undef FIX_CONST_CONST_EQ_VAR_VAR

/*
 * Static constant expression should be same as automatic constant expression
 * in all precisions.
 */
  #undef FIX_STATIC_EQ_AUTO

/*
 * Static constant expression should be same as automatic constant expression
 * in LDBL precision.  Or, translation time math should be the same as
 * run-time math.
 */
  #undef FIX_STATIC_EQ_AUTO_LDBL
  #undef FIX_STATIC_EQ_AUTO_LD10

/*
 * FP expressions in RHS should be context independent in LHS = RHS;
 * Yet, gcc 4.4.1 for DFP evaluates RHS differently depending upon the
 * type of LHS (so called widest need).
 */
  #undef FIX_WIDEST_NEED
  #undef FIX_WIDEST_NEED10

/*
 * If FP expressions do not obey FLT_EVAL_METHOD, nor do widest need, then
 * they are random as to how they are done.
 */
  #undef FIX_RANDOM_FLT_EVAL
  #undef FIX_RANDOM_DEC_EVAL

/*
 * FP expressions using const VAR's should be run-time time, not
 * translation time, unless under pragma fenv_access off.
 */
  #undef FIX_CONST_VAR_EXP_AT_TRANS

/*
 * FP constant expressions should be run-time, not translation time,
 * unless under pragma fenv_access off.  This covers all five:
 * 0.0/0.0, 1.0/0.0, MAX*MAX, MIN*MIN, 1.0/3.0
 * For finer control see the next five items
 */
  #undef FIX_CONSTANT_EXP_AT_TRANS

/*
 * FP constant expression for invalid, eg, 0.0 / 0.0, should be run-time,
 * not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_0_OVER_0_EXP_AT_TRANS

/*
 * FP constant expression for divide by zero, eg, 1.0 / 0.0, should be
 * run-time, not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_1_OVER_0_EXP_AT_TRANS

/*
 * FP constant expression for overflow, eg, MAX * MAX, should be
 * run-time, not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_MAX_TIMES_MAX_EXP_AT_TRANS

/*
 * FP constant expression for underflow, eg, MIN * MIN, should be
 * run-time, not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_MIN_TIMES_MIN_EXP_AT_TRANS

/*
 * FP constant expression for inexact, eg, 1.0 / 3.0, should be
 * run-time, not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_1_OVER_3_EXP_AT_TRANS

/*
 * !"string" should be 0, not 1 by ISO/ANSI C.
 */
  #undef FIX_BANG_STR

/*
 * ! &ptr should be 0, not 1 by ISO/ANSI C.
 */
  #undef FIX_BANG_ADDR

/*
 * !1.f should be 0, not 1 by ISO/ANSI C.
 */
  #undef FIX_BANG_ONE

/*
 * !0.f should be 1, not 0 by ISO/ANSI C.
 */
  #undef FIX_BANG_ZERO

/*
 * !-0.f should be 1, not 0 by ISO/ANSI C.
 */
  #undef FIX_BANG_MINUS_ZERO

/*
 * The trinary operation (?:) i = 0.0 ? 1.0 : 0.0 ; should be 0 by ISO/ANSI C.
 */
  #undef FIX_TRI_OP_OF_FP

/*
 * The remainder operation: 1 % 1 should be 0 by ISO/ANSI C.
 */
  #undef FIX_REMAINDER_OP

/*
 * 'for' loop with downward decrement of FP var [for(r=0.0;min<r;r--) ] done wrong.
 */
  #undef FIX_DOWNWARD_FOR_LOOP

/*
 * Code generation for 'ldbl -= ulp;' done wrong.  So use ldbl = ldbl - ulp;
 * (Only a few uses of this bypass have been done).
 * Same problem applies to other similar operators: +=, *=, and /=.
 */
  #undef FIX_BITFIELD_MINUS_EQ_CMPLX
  #undef FIX_BITFIELD_MINUS_EQ_IMAG
  #undef FIX_BOOL_MINUS_EQ_CMPLX
  #undef FIX_BOOL_MINUS_EQ_IMAG
  #undef FIX_CMPLX_MINUS_EQ_CMPLX
  #undef FIX_CMPLX_MINUS_EQ_FP
  #undef FIX_CMPLX_MINUS_EQ_IMAG
  #undef FIX_CMPLX_MINUS_EQ_INT
  #undef FIX_ENUM_MINUSEQ_ENUM
  #undef FIX_FP10_MINUS_EQ_FP10
  #undef FIX_FP_MINUS_EQ_CMPLX
  #undef FIX_FP_MINUS_EQ_FP
  #undef FIX_FP_MINUS_EQ_IMAG
  #undef FIX_IMAG_MINUS_EQ_CMPLX
  #undef FIX_IMAG_MINUS_EQ_FP
  #undef FIX_IMAG_MINUS_EQ_IMAG
  #undef FIX_IMAG_MINUS_EQ_INT
  #undef FIX_INT_MINUS_CMPLX
  #undef FIX_INT_MINUS_EQ_CMPLX
  #undef FIX_INT_MINUS_EQ_DFP
  #undef FIX_INT_MINUS_EQ_FP
  #undef FIX_INT_MINUS_EQ_FPCONST
  #undef FIX_INT_MINUS_EQ_IMAG
  #undef FIX_LD10_MINUS_EQ_FP
  #undef FIX_LD10_MINUS_EQ_INT
  #undef FIX_LDBL_MINUS_EQ_FP
  #undef FIX_LDBL_MINUS_EQ_INT
  #undef FIX_SB_MINUS_EQ_FP
  #undef FIX_SLLI_MINUS_EQ_FP
  #undef FIX_UB_MINUS_EQ_FP
  #undef FIX_ULLI_MINUS_EQ_FP

  #undef FIX_BITFIELD_PLUS_EQ_CMPLX
  #undef FIX_BITFIELD_PLUS_EQ_IMAG
  #undef FIX_BOOL_PLUS_EQ_CMPLX
  #undef FIX_BOOL_PLUS_EQ_FP10
  #undef FIX_BOOL_PLUS_EQ_IMAG
  #undef FIX_CMPLX_PLUS_EQ_CMPLX
  #undef FIX_CMPLX_PLUS_EQ_FP
  #undef FIX_CMPLX_PLUS_EQ_IMAG
  #undef FIX_CMPLX_PLUS_EQ_INT
  #undef FIX_FP_PLUS_EQ_CMPLX
  #undef FIX_FP_PLUS_EQ_FP
  #undef FIX_FP_PLUS_EQ_IMAG
  #undef FIX_FP_PLUS_EQ_INT
  #undef FIX_FP_PTR_PLUS_EQ_BOOL	/* *fp += b */
  #undef FIX_IMAG_PLUS_EQ_CMPLX
  #undef FIX_IMAG_PLUS_EQ_FP
  #undef FIX_IMAG_PLUS_EQ_IMAG
  #undef FIX_IMAG_PLUS_EQ_INT
  #undef FIX_INT_PLUS_EQ_CMPLX
  #undef FIX_INT_PLUS_EQ_FP
  #undef FIX_INT_PLUS_EQ_IMAG
  #undef FIX_PLUS_EQ_FP_FUNC		/* fp += fp_fn() */
  #undef FIX_SB_PLUS_EQ_FP
  #undef FIX_SLLI_PLUS_EQ_FP
  #undef FIX_UB_PLUS_EQ_FP
  #undef FIX_ULLI_PLUS_EQ_FP

  #undef FIX_BITFIELD_STAR_EQ_CMPLX
  #undef FIX_BITFIELD_STAR_EQ_IMAG
  #undef FIX_BOOL_STAR_EQ_CMPLX
  #undef FIX_BOOL_STAR_EQ_IMAG
  #undef FIX_CMPLX_STAR_EQ_CMPLX
  #undef FIX_CMPLX_STAR_EQ_FP
  #undef FIX_CMPLX_STAR_EQ_IMAG
  #undef FIX_CMPLX_STAR_EQ_INT
  #undef FIX_FP_STAR_EQ_CMPLX
  #undef FIX_FP_STAR_EQ_FP
  #undef FIX_FP_STAR_EQ_IMAG
  #undef FIX_IMAG_STAR_EQ_CMPLX
  #undef FIX_IMAG_STAR_EQ_FP
  #undef FIX_IMAG_STAR_EQ_IMAG
  #undef FIX_IMAG_STAR_EQ_INT
  #undef FIX_INT_STAR_EQ_CMPLX
  #undef FIX_INT_STAR_EQ_FP
  #undef FIX_INT_STAR_EQ_IMAG
  #undef FIX_SB_STAR_EQ_FP
  #undef FIX_SLLI_STAR_EQ_FP
  #undef FIX_UB_STAR_EQ_FP
  #undef FIX_ULLI_STAR_EQ_FP

  #undef FIX_BITFIELD_DIV_EQ_CMPLX
  #undef FIX_BITFIELD_DIV_EQ_IMAG
  #undef FIX_BOOL_DIV_EQ_CMPLX
  #undef FIX_BOOL_DIV_EQ_IMAG
  #undef FIX_CMPLX_DIV_EQ_CMPLX
  #undef FIX_CMPLX_DIV_EQ_FP
  #undef FIX_CMPLX_DIV_EQ_IMAG
  #undef FIX_CMPLX_DIV_EQ_INT
  #undef FIX_FP_DIV_EQ_CMPLX
  #undef FIX_FP_DIV_EQ_IMAG
  #undef FIX_IMAG_DIV_EQ_CMPLX
  #undef FIX_IMAG_DIV_EQ_FP
  #undef FIX_IMAG_DIV_EQ_IMAG
  #undef FIX_IMAG_DIV_EQ_INT
  #undef FIX_INT_DIV_CMPLX
  #undef FIX_INT_DIV_EQ_CMPLX
  #undef FIX_INT_DIV_EQ_FP
  #undef FIX_INT_DIV_EQ_IMAG
  #undef FIX_SB_DIV_EQ_FP
  #undef FIX_SLLI_DIV_EQ_FP
  #undef FIX_UB_DIV_EQ_FP
  #undef FIX_ULLI_DIV_EQ_FP

/*
 * Code generation for 'ldbl--;' done wrong.  So use ldbl = ldbl - one;
 * (Only a few uses of this bypass have been done).
 */
  #undef FIX_FP_MINUS_MINUS
  #undef FIX_FP10_MINUS_MINUS

/*
 * Code generation for 'd=ldbl++;' done wrong.  So use two stmts.
 * (Only bypass in t0160100 has been done).
 */
  #undef FIX_FP_PLUS_PLUS

/*
 * Code generation for promotion of integer types with rank less than int
 * are done wrong.  Such as, signed int < unsigned short int.
 */
  #undef FIX_BAD_INTEGER_PROMOTION

/*
 * sizeof FLT constant is DBL (should be FLT by ISO/ANSI C)
 * sizeof FLT expression is DBL (should be FLT by ISO/ANSI C)
 * (This can impact all the classification macros).
 * Was FIX_SIZEOF_FLOAT_CONST_IS_DBL -- confused a compiler.
 */
  #undef FIX_SIZEOF_FLT_CONST_IS_DBL
  #undef FIX_SIZEOF_F10_CONST_IS_D10

/*
 * 'sizeof sizeof var' done wrong; should be sizeof(size_t)
 */
  #undef FIX_SIZEOF_SIZEOF

/*
 * Code generation for res == ( vl += vr) done wrong, where vl is of
 * type floating-point.
 */
  #undef FIX_EQUALEQUAL_FP_PLUSEQUAL

/*
 * Code generation for res == ( vl -= vr) done wrong, where vl is of
 * type floating-point.
 */
  #undef FIX_EQUALEQUAL_FP_MINUSEQUAL

/*
 * Code generation for res == ( vl *= vr) done wrong, where vl is of
 * type floating-point.
 */
  #undef FIX_EQUALEQUAL_FP_STAREQUAL

/*
 * Code generation for res == ( vl /= vr) done wrong, where vl is of
 * type floating-point.
 */
  #undef FIX_EQUALEQUAL_FP_DIVEQUAL

/*
 *     vl << vr;
 *     vl >> vr;
 * done wrong, where vl is of type bit-field.
 */
  #undef FIX_BITFIELD_LEFTSHIFT
  #undef FIX_BITFIELD_RIGHTSHIFT

/*
 * Code generation for:
 *     vl &= vr;
 *     vl /= vr;
 *     vl <<= vr;
 *     vl -= vr;
 *     vl |= vr;
 *     vl += vr;
 *     vl %= vr;
 *     vl >>= vr;
 *     vl *= vr;
 *     vl ^= vr;
 * done wrong, where vl is of type bit-field.
 */
  #undef FIX_BITFIELD_AND_EQUAL
  #undef FIX_BITFIELD_DIV_EQUAL
  #undef FIX_BITFIELD_LEFTSH_EQUAL
  #undef FIX_BITFIELD_MINUS_EQUAL
  #undef FIX_BITFIELD_OR_EQUAL
  #undef FIX_BITFIELD_PLUS_EQUAL
  #undef FIX_BITFIELD_REM_EQUAL
  #undef FIX_BITFIELD_RIGHTSH_EQUAL
  #undef FIX_BITFIELD_STAR_EQUAL
  #undef FIX_BITFIELD_XOR_EQUAL

/*
 * Code generation for call to function with FLT expression(s) messes
 * up stack, so return crashes system.
 */
  #undef FIX_FUNC_WITH_FLT_EXPRESSION
  #undef FIX_FUNC_WITH_F10_EXPRESSION

/*
 * Equivalent code done different ways produces different results.
 * Shows up in g192, g193.
 */
  #undef FIX_SLOPPY_ARITH

/*
 * Some valid ISO/ANSI C code causes runtime problems and is not covered
 * by any other disallow.  Not currently used.
 *  #undef FIX_BUGGY_CODE
 */

/*
 * Adding extra code allows some test cases to run.  Without the dummy code,
 * it should run as per ISO/ANSI C.  This may indicate a compiler bug, or a
 * test case bug: bad pointer, bad array index.
 */
  #undef FIX_T0330000

/*
 * Adding extra code allows some test cases to run.  Without the dummy code,
 * it should run as per ISO/ANSI C.  This may indicate a compiler bug, or a
 * test case bug: bad pointer, bad array index.
 */
  #undef NEED_DUMMY_CODE

/*
 * Assignments must do the store as per ISO/ANSI C.  But, in some cases,
 * making the variable volatile is needed to force that store.
 */
  #undef NEED_VOLATILE

/*
 * Assignments must do the store as per ISO/ANSI C.  But, in some cases,
 * need to call a function with the address of the var to force that store.
 */
  #undef NEED_FORCE_STORE

/*
 * Assignments must do a load and store instead of a move.  This is needed
 * if the rounding direction has been changed.
 */
  #undef FIX_LOAD_STORE

/*
 * Complicated expressions that cause spilling of intermediate values
 * must preserve the full precision of the value spilled.
 * If t0130000 detects varying precision for FLT ops, define this symbol.
 * If t6130000 detects varying precision for F10 ops, define this symbol.
 */
  #undef FIX_SPILL_FLT
  #undef FIX_SPILL_F10

/*
 * Assignments must store to memory to perform their specified
 * conversions, eg, cannot use the wider value in the register.  This
 * is an ISO/ANSI C requirement.
 */
  #undef FIX_USE_REG_VAL

/*
 * Assignment must store to memory to perform their specified conversions,
 * eg, cannot use the wider value in the register.  This is an
 * ISO/ANSI C requirement.
 */
  #undef FIX_IGNORE_ASSIGN

/*
 * Casts must store to memory to perform their specified conversions,
 * eg, cannot use the wider value in the register.  This is an
 * ISO/ANSI C requirement.
 */
  #undef FIX_IGNORE_CAST

/*
 * Casts must be the same as a store to the same type,
 */
  #undef FIX_ASSIGN_EQ_CAST

/*
 * FP constants cast to lower precision should do the cast at run-time
 * (and raise inexact), not translation time (which bypasses inexact).
 */
  #undef FIX_CAST_AT_TRANS

/*
 * FP constants cast to int should get the correct value.
 */
  #undef FIX_CAST_2_INT_OF_FP_CONST

/*
 * Some casts work, some fail.  This bypasses the known failures.
 * Needed for gcc 333, 412 in t0310200.
 */
  #undef FIX_UNKNOWN_CAST

/*
 * LDBL arrays should be done right.  In one case, the array was stored
 * and initialized correctly, but the runtime array references were done
 * as if it were DBL in size instead of LDBL.
 */
  #undef FIX_LDBL_ARRAY
  #undef FIX_LD10_ARRAY

/*
 * <float.h> might be shared between several compilers, some of which have
 * LDBL == DBL, and others have LDBL > DBL.  <float.h> should be updated to
 * take into account which compiler is using it, but until that happens, this
 * allows test of <float.h> to be bypassed.
 */
  #undef FIX_LDBL_OK_IN_FLOAT_H
  #undef FIX_LD10_OK_IN_FLOAT_H

/*
 * There are several operators that should return
 * (or are) a signed int type.
 */
  #undef FIX_unsigned_NE	/* != */
  #undef FIX_SIZEOF_NE

/*
 * Compound assignments, eg,
 *   x = y = value;
 *   x = y = func(value);
 * are done wrong.
 */
  #undef FIX_COMPOUND_ASSIGN_FUNC
  #undef FIX_COMPOUND_ASSIGN_LDBL
  #undef FIX_COMPOUND_ASSIGN_FLT_CMPLX
  #undef FIX_COMPOUND_ASSIGN_DBL_CMPLX
  #undef FIX_COMPOUND_ASSIGN_LDBL_CMPLX
  #undef FIX_COMPOUND_ASSIGN_LDBL_IMAG
  #undef FIX_COMPOUND_ASSIGN_LD10

/*
 * Function calls (w/o prototype) has default argument promotions.
 * FLT -> DBL  and  small integer types -> int
 */
  #undef FIX_FLT_ARG_PROMOTION
  #undef FIX_INT_ARG_PROMOTION

/*
 * Function return (of different types) is supposed to be "as if assignment".
 */
  #undef FIX_ASIF_ASSIGN

/*
 * Function return (of same FP type) is supposed to be wider of type and
 * as per FLT_EVAL_METHOD.  Also applies to inline functions.
 */
  #undef FIX_CMPLX_RET
  #undef FIX_CMPLX_IN_RET

/*
 * If a bit-field spans an integer boundary, does it work?
 * See C11 6.7.2.1#11 about 'span' and implementation defined.
 */
  #undef FIX_BITFIELD_SPAN_BNDRY

/*
 * Store into bit-field alters other storage (including outside of struct)
 */
  #undef FIX_BAD_BITFIELD_STORE

/*
 * Is (1+a)*(1+b) == (1+a+b+a*b)?  Fails for dbl_dbl.
 */
  #undef FIX_MUL_CONSISTENT_ADD

/*
 * one*min - den should be exact.  Fails for dbl_dbl.
 */
  #undef FIX_SLOPPY_LDBL_FLAGS

/*
 * __LINE__ split across many source lines has wrong value.
 */
  #undef FIX_LINE_USAGE

/*
 * MAC( ARG ) split across many source lines has wrong value for line of ARG.
 */
  #undef FIX_MAC_ARG_LINE

/*
 * #if __LINE__ on multiple physical lines has wrong line number.
 */
  #undef FIX_HASHIF_LINE

/*** Run time: C89/C90/C95: input/output library function problems ***/

/*
 * Unit in Last Place error allowed between expected and actual strings
 * produced by printf of %f formats of (long) DBL values.  The first
 * letter indicates the type of value being printed, the letter before
 * ULPS indicates the format being used (e, f, g, or a).
 */
  #undef    F_BIN2DEC_E_ULPS
  #undef    D_BIN2DEC_E_ULPS
  #undef   LD_BIN2DEC_E_ULPS
  #undef  F10_DFP2DEC_E_ULPS
  #undef  D10_DFP2DEC_E_ULPS
  #undef LD10_DFP2DEC_E_ULPS
  #undef    F_BIN2DEC_F_ULPS
  #undef    D_BIN2DEC_F_ULPS
  #undef   LD_BIN2DEC_F_ULPS
  #undef  F10_DFP2DEC_F_ULPS
  #undef  D10_DFP2DEC_F_ULPS
  #undef LD10_DFP2DEC_F_ULPS
  #undef    F_BIN2DEC_G_ULPS
  #undef    D_BIN2DEC_G_ULPS
  #undef   LD_BIN2DEC_G_ULPS
  #undef  F10_DFP2DEC_G_ULPS
  #undef  D10_DFP2DEC_G_ULPS
  #undef LD10_DFP2DEC_G_ULPS
  #undef    F_BIN2HEX_A_ULPS
  #undef    D_BIN2HEX_A_ULPS
  #undef   LD_BIN2HEX_A_ULPS
  #undef  F10_DFP2DEC_A_ULPS
  #undef  D10_DFP2DEC_A_ULPS
  #undef LD10_DFP2DEC_A_ULPS

/*
 * [w]printf should support BFP of the three types.
 */
  #undef FIX_PRINT_FLT
  #undef FIX_WPRINT_FLT
  #undef FIX_PRINT_DBL
  #undef FIX_WPRINT_DBL
  #undef FIX_PRINT_LDBL
  #undef FIX_WPRINT_LDBL

/*
 * [s]scanf should work with LDBL.  At least one compiler treats
 * LDBL the same as DBL to sscanf, yet LDBL and DBL
 * are different hardware representations.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCANF_LDBL
  #undef FIX_SCANF_LDBL_WRONG
  #undef FIX_WSCANF_LDBL
  #undef FIX_SCANF_LD10
  #undef FIX_WSCANF_LD10

/*
 * [s]scanf should work with DBL.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCANF_DBL
  #undef FIX_WSCANF_DBL
  #undef FIX_SCANF_D10
  #undef FIX_WSCANF_D10

/*
 * [s]scanf should work with FLT.  At least one compiler core dumps
 * in t3040000 with "unusual" input scanned into a FLT.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCANF_FLT
  #undef FIX_WSCANF_FLT
  #undef FIX_SCANF_F10
  #undef FIX_WSCANF_F10

/*
 * [s]scanf should return the correct count via its return code.
 * If the count is wrong, define these.  t304* tests and t904* tests.
 */
  #undef FIX_SCAN_RC
  #undef FIX_SCAN10_RC
  #undef FIX_WSCAN_RC
  #undef FIX_WSCAN10_RC

/*
 * [s]scanf should work with LDBL and do good decimal to binary
 * conversions.  If it is sloppy, define these symbols with the number
 * of bits/digits to round and drop from the values in memory as an
 * attempt to make the numbers 'nice'.
 * Used by t1xx*3 tests, most useful for t1522003 (pow).
 */
  #undef FIX_BOTTOM_N_BITS
  #undef FIX_BOTTOM_N_DIGS

/*
 * This bypasses all printf tests with specific combinations of flags.
 * See g3070000.h for usage.  There are 32 possible defines for each %e/f/g/a,
 * of which only the first and last are shown here.
 */
  #undef FIX_T3070000	/* %f */
/* ... */
  #undef FIX_T3070031
  #undef FIX_T3070100	/* %e */
/* ... */
  #undef FIX_T3070131
  #undef FIX_T3070200	/* %g */
/* ... */
  #undef FIX_T3070231
  #undef FIX_T3070300	/* %a */
/* ... */
  #undef FIX_T3070331

/*
 * This bypasses some printf tests with specific combinations of flags.
 * See g3070000.h for usage.  There are 32 possible defines for each %e/f/g/a,
 * of which only the first and last are shown here.
 */
  #undef FIX_T3070000_CASES	/* %f */
/* ... */
  #undef FIX_T3070031_CASES
  #undef FIX_T3070100_CASES	/* %e */
/* ... */
  #undef FIX_T3070131_CASES
  #undef FIX_T3070200_CASES	/* %g */
/* ... */
  #undef FIX_T3070231_CASES
  #undef FIX_T3070300_CASES	/* %a */
/* ... */
  #undef FIX_T3070331_CASES

/*
 * %g done with wrong precision.
 * This bypasses tests with no explicit precision.
 */
  #undef FIX_PRINTF_NO_PRECISION
  #undef FIX_WPRINTF_NO_PRECISION

/*
 * %.f done as %.6f instead of %.0f
 * This bypasses tests with an implicit zero precision.
 */
  #undef FIX_PRINTF_IMPLICIT_PRECISION
  #undef FIX_WPRINTF_IMPLICIT_PRECISION

/*
 * %.0g done wrong.  300.0 done as 3 instead of expected 3e+02
 * This bypasses tests with an explicit zero precision.
 */
  #undef FIX_PRINTF_ZERO_PRECISION
  #undef FIX_WPRINTF_ZERO_PRECISION

/*
 * %.1g done wrong.  3e-2 done as 0.030 instead of expected 0.03
 * This bypasses tests with an explicit one precision.
 */
  #undef FIX_PRINTF_ONE_PRECISION
  #undef FIX_WPRINTF_ONE_PRECISION

/*
 * %#g causes unusual results (such as extra zeros at end of number).
 * This bypasses tests with a "#" format flag.
 */
  #undef FIX_PRINTF_SHARP_FLAG
  #undef FIX_WPRINTF_SHARP_FLAG

/*
 * %#g causes wrong rounding at midpoint tests.
 * This bypasses tests with a "#" format flag and value is x.5.
 */
  #undef FIX_PRINTF_SHARP_RND
  #undef FIX_WPRINTF_SHARP_RND
  #undef FIX_PRINTF10_SHARP_RND

/*
 * %e and %a causes wrong rounding at midpoint tests.
 * This bypasses tests with a "%e" format flag and value is x.5.
 * This bypasses tests with a "%a" format flag and value is x.5.
 */
  #undef FIX_PRINTF_e_RND
  #undef FIX_PRINTF_aA_RND	/* %a => 0xM.Np+d */
  #undef FIX_WPRINTF_e_RND
  #undef FIX_WPRINTF_aA_RND	/* %a => 0xM.Np+d */

/*
 * %0f causes unusual results.
 * This bypasses tests with a "0" format flag.
 */
  #undef FIX_PRINTF_ZERO_FLAG
  #undef FIX_WPRINTF_ZERO_FLAG

/*
 * %.g and %.0g causes unusual results.
 */
  #undef FIX_PRINTF_DOTg
  #undef FIX_PRINTF_DOT0g

/*
 * %f versus %e should be consistent.
 */
  #undef FIX_PRINTF_f_VS_e

/*
 * % f causes unusual results.
 * This bypasses tests with a " " format flag.
 */
  #undef FIX_PRINTF_SPACE_FLAG
  #undef FIX_WPRINTF_SPACE_FLAG

/*
 * % 0f causes unusual results (such as putting " " in middle of zeros).
 * This bypasses tests with both " " and "0" format flags.
 */
  #undef FIX_PRINTF_SPACE_ZERO_FLAGS
  #undef FIX_WPRINTF_SPACE_ZERO_FLAGS

/*
 * %#.0f causes unusual results when the expected result is just zeros.
 * This bypasses tests with expected result of all zeros.
 */
  #undef FIX_PRINTF_ZERO_RES
  #undef FIX_WPRINTF_ZERO_RES

/*
 * %.6f of value -1e-7 should be -0.000000 (but many drop the minus sign).
 * This bypasses tests with expected negative result of all zeros.
 */
  #undef FIX_PRINTF_NEGATIVE_ZERO
  #undef FIX_WPRINTF_NEGATIVE_ZERO

/*
 * Negative values being printed cause many varied results depending
 * upon the flags.  This bypasses tests with negative values.
 */
  #undef FIX_PRINTF_NEGATIVE
  #undef FIX_WPRINTF_NEGATIVE

/*
 * %e and some %g have an exponent of the wrong form, so bypass them.
 * Most common cause is minimum exponent is 3 digits (should be 2 digits).
 */
  #undef FIX_PRINTF_HAS_EXPONENT
  #undef FIX_WPRINTF_HAS_EXPONENT

/*
 * [s]printf should return the correct value (of number of characters output).
 * This ignores cases where return value is wrong.
 */
  #undef FIX_PRINTF_RC
  #undef FIX_WPRINTF_RC

/*
 * [s]printf should return the correct value (of number of characters output).
 * This ignores cases where return value is negative.
 */
  #undef FIX_PRINTF_NEGATIVE_RC
  #undef FIX_WPRINTF_NEGATIVE_RC

/*
 * [w]printf is required to print at least 4095 (was 509 with C89)
 * characters in any single conversion.  This bypasses the tests of
 * IMPL_MAX_*_RADIX.
 */
  #undef FIX_SMALL_PRINTF_ENV_LIMIT
  #undef FIX_SMALL_WPRINTF_ENV_LIMIT

/*
 * Return from main() does an implicit flush of all I/O streams.
 * If you need an explicit flush just before the end of main,
 * then you need to define this symbol.  Affects SetSuccess found
 * in leaf.h
 */
  #undef FIX_IMPLICIT_FLUSH

/*
 * Translation time constant value should be same as run-time conversion.
 */
  #undef FIX_TRANS_EQ_RUN_TIME
  #undef FIX_TRANS10_EQ_RUN_TIME10

/*
 * strtof/strtod/strtold should equal scanf of decimal numbers to binary
 * [wcstof/wcstod/wcstold should equal wscanf of decimal numbers to binary]
 * of FLT/DBL/LDBL.
 * Symbols w/ '10' are for Decimal FP.
 */
  #undef FIX_strto_EQ_scanf
  #undef FIX_wcsto_EQ_wscanf
  #undef FIX_strto10_EQ_scanf10
  #undef FIX_wcsto10_EQ_wscanf10

/*
 * Does *scanf correctly consume white space before "%%"?
 */
  #undef FIX_SCAN_PERCENT_PERCENT
  #undef FIX_SCAN10_PERCENT_PERCENT
  #undef FIX_WSCAN_PERCENT_PERCENT
  #undef FIX_WSCAN10_PERCENT_PERCENT

/*
 * Does *scanf correctly support "%n"?  In particular, at EOF
 */
  #undef FIX_SCAN_PERCENT_n
  #undef FIX_SCAN10_PERCENT_n
  #undef FIX_WSCAN_PERCENT_n
  #undef FIX_WSCAN10_PERCENT_n

/*
 * [w]scanf should support wide characters via "%lc"
 * #undef FIX_SCAN_PERCENT_lc
 * #undef FIX_SCAN10_PERCENT_lc
 */
  #undef FIX_WSCAN_PERCENT_lc
  #undef FIX_WSCAN10_PERCENT_lc

/*
 * Does *scanf correctly support one character lookahead?
 */
  #undef FIX_SCAN_LOOKAHEAD
  #undef FIX_SCAN10_LOOKAHEAD
  #undef FIX_WSCAN_LOOKAHEAD
  #undef FIX_WSCAN10_LOOKAHEAD

/*
 * Is EOF of type int?  At least one compiler has it as long.
 */
  #undef  FIX_NON_INT_EOF

/*
 * Does *scanf treat EOF (end of file or string) as matching a space
 * character?  "%f%n %n" of "1.0\0"
 */
  #undef FIX_SCAN_SPACE_VS_EOF
  #undef FIX_SCAN10_SPACE_VS_EOF
  #undef FIX_WSCAN_SPACE_VS_EOF
  #undef FIX_WSCAN10_SPACE_VS_EOF

/*
 * Does *scanf mess up on 'normal' conversions?  t3442000, t9442000.
 */
  #undef FIX_WSCAN_BUG
  #undef FIX_WSCAN10_BUG

/*
 * Does *scanf incorrectly support one character lookahead
 * at End Of File (EOF)?  That is, "100e0" is treated as EOF.
 * Or "456EOF" read as 45.
 */
  #undef FIX_SCAN_EOF
  #undef FIX_SCAN10_EOF
  #undef FIX_WSCAN_EOF
  #undef FIX_WSCAN10_EOF

/*
 * Does *scanf incorrectly report EOF after matching some text?
 * That is, " }\nEOF" is EOF to "%*[^{]" in g1xx0003.h
 */
  #undef FIX_SCAN_EARLY_EOF
  #undef FIX_WSCAN_EARLY_EOF

/*
 * Does *scanf incorrectly report EOF after matching some text?
 * That is, " }\nEOF" is not EOF to "%*[^{]{" in g1xx0003.h
 */
  #undef FIX_SCAN_LATE_EOF
  #undef FIX_WSCAN_LATE_EOF

/*
 * Do strto* / wcsto* correctly support unlimited character lookahead?
 */
  #undef FIX_STRTO_LOOKAHEAD
  #undef FIX_STRTO10_LOOKAHEAD
  #undef FIX_WCSTO_LOOKAHEAD
  #undef FIX_WCSTO10_LOOKAHEAD

/*
 * Do scanf and strto* process FP numbers that start with junk?
 * For example, &5e0, \a0xf.3p0
 */
  #undef FIX_SCAN_JUNK
  #undef FIX_SCAN10_JUNK
  #undef FIX_WSCAN_JUNK
  #undef FIX_WSCAN10_JUNK

/*
 * Do scanf and strto* process FP numbers that have no digits?
 * For example, .e0, 0x.p0
 */
  #undef FIX_SCAN_NODIGITS
  #undef FIX_SCAN10_NODIGITS
  #undef FIX_WSCAN_NODIGITS
  #undef FIX_WSCAN10_NODIGITS

/*
 * Do scanf and strto* reject FP numbers that have no '.' with 'e'?
 * For example, 100e0
 */
  #undef FIX_SCAN_NODOT_E
  #undef FIX_SCAN10_NODOT_E
  #undef FIX_WSCAN_NODOT_E
  #undef FIX_WSCAN10_NODOT_E

/*
 * Does scanf return wrong count for valid FP number followed by
 * just white space?  For example, 100\t
 */
  #undef FIX_SCAN_FP_WS
  #undef FIX_SCAN10_FP_WS
  #undef FIX_WSCAN_FP_WS
  #undef FIX_WSCAN10_FP_WS

/*
 * Do scanf and strto* correctly process FP numbers with too many signs?
 * For example, -+5e0, +-0xf.3p0
 */
  #undef FIX_BAD_SIGNS

/*
 * Do scanf and strto* correctly process FP numbers with too many '.'?
 * For example, 5..0, 5.0.2e0
 */
  #undef FIX_EXTRA_DOTS

/*
 * Do scanf and strto* correctly process FP numbers with bad exponents?
 * For example, 5ex, 5e-x, 5e+x.
 */
  #undef FIX_BAD_EXPONENT

/*
 * Do scanf and strto* correctly process decimal FP numbers with binary exponents?
 * For example, 5p0, 5.0pe3
 */
  #undef FIX_DEC_WITH_BIN_EXPONENT

/*
 * Do scanf and strto* correctly process FP numbers with bad bin exponents?
 * For example, 0x5px, 0x5p-x, 0x5p+x.
 */
  #undef FIX_BAD_BIN_EXPONENT

/*
 * Do scanf and strto* correctly process FP numbers with no bin exponents?
 * For example, 0x5, 0x5.0, 0x.5.
 */
  #undef FIX_NO_BIN_EXPONENT

/*
 * strto* / wcsto* sets pointer to start of string (pointer difference
 * is zero), when expected a positive difference.
 * Symbols with '10' in them are for Decimal FP.
 */
  #undef FIX_STRTO_ZERO_PTR_DIFF
  #undef FIX_WCSTO_ZERO_PTR_DIFF
  #undef FIX_STRTO10_ZERO_PTR_DIFF
  #undef FIX_WCSTO10_ZERO_PTR_DIFF

/*
 * Conversion from "decimal" to internal FP should set pointer
 * for strtof, strtod, strtold, and wcstof, wcstod, wcstold,
 * so pointer difference (from start of string) is correct.
 */
  #undef FIX_STRTO_BAD_PTR_DIFF
  #undef FIX_STRTO10_BAD_PTR_DIFF
  #undef FIX_WCSTO_BAD_PTR_DIFF
  #undef FIX_WCSTO10_BAD_PTR_DIFF

/*
 * scanf of decimal numbers to binary of FLT/DBL/LDBL should
 * honor the current rounding direction.  This also applies to the
 * strtod, strtof, and strtold functions.
 */
  #undef FIX_scanf_ROUNDS
  #undef FIX_scanf10_ROUNDS
  #undef FIX_wscanf_ROUNDS
  #undef FIX_wscanf10_ROUNDS

/*
 * strtod/f/ld and scanf, when they convert negative numbers and the
 * current rounding direction is +INF or -INF, then it matters which
 * comes first:  rounding or negating.  IEEE-754 requires that the
 * negating come first and that rounding be last.
 */
  #undef FIX_strto_RND_THEN_NEG
  #undef FIX_wcsto_RND_THEN_NEG

/*
 * printf of binary to decimal numbers should
 * honor the current rounding direction.
 */
  #undef FIX_printf_ROUNDS
  #undef FIX_printf10_ROUNDS
  #undef FIX_wprintf_ROUNDS
  #undef FIX_wprintf10_ROUNDS

/*
 * File I/O has problems, so bypass tests of fprintf, fscanf.
 */
  #undef FIX_TEST_fprintf
  #undef FIX_TEST_fscanf
  #undef FIX_TEST_fwprintf
  #undef FIX_TEST_fwscanf
  #undef FIX_TEST_sprintf
  #undef FIX_TEST_swprintf

/*
 * Binary file I/O requires new-line at end of file (as if it were
 * a text file).
 */
  #undef FIX_NEED_FINAL_NEW_LINE

/*
 * File position indicator is wrong after fscanf. so skip tests of ftell.
 */
  #undef FIX_TEST_ftell

/*
 * Conversion from internal FP to decimal of finite numbers should produce
 * just digits, radix point, signs, and 'e' or 'E'.  One compiler does:
 * 405c813f3978f8940984 => +?.?<0000000000000000000e+27
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_JUNK
  #undef FIX_WPRINT_JUNK
  #undef FIX_PRINT10_JUNK
  #undef FIX_WPRINT10_JUNK

/*
 * Conversion from internal FP to decimal and back should be identity function.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_SCAN_IDENT
  #undef FIX_WPRINT_WSCAN_IDENT
  #undef FIX_PRINT10_SCAN10_IDENT
  #undef FIX_WPRINT10_WSCAN10_IDENT

/*
 * Conversion from internal FP to decimal and back should be identity function
 * for small numbers (close to denormal).
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_SCAN_IDENT_TINY
  #undef FIX_WPRINT_WSCAN_IDENT_TINY
  #undef FIX_PRINT10_SCAN10_IDENT_TINY
  #undef FIX_WPRINT10_WSCAN10_IDENT_TINY

/*** Run time: C89/C90/C95: math library function problems ***/

/*
 * One of frexp or ldexp is wrong w/ denorms, (1-small) or other
 * values, so the ulp* functions in s0000000.fjt need a workaround.
 */
  #undef ULP_WORKAROUND
  #undef ULP10_WORKAROUND

/*
 * Is the compiler's decimal to binary conversion so bad that it
 * interferes with the testing of the math library?  That is, are
 * the decimal values used as the arguments and/or expected results
 * in the test vectors converted so poorly that there are bogus errors?
 * Do you have some functions that can correctly convert a decimal value
 * as a string into the internal floating-point format?  If yes to all
 * of the above, then you can define symbols like:
 *   #define t1102001 "v1102001.ovr"
 * to cause that file to be included in g1100000.h (via OVERRIDE_TV) so
 * that you can invoke your function to do the correct decimal to binary
 * conversion and then assign that value to the appropriate test vector
 * element. If you need this, contact Fred J. Tydeman for the override files
 * (you get to provide the decimal to binary conversion function).
 */
  #undef t1100000
  #undef t1100001
  #undef t1100003
  #undef t1101000
  #undef t1101001
  #undef t1101003
  #undef t1102000
  #undef t1102001
  #undef t1102003
/* ... thru ... */
  #undef t1980000
  #undef t1980001
  #undef t1981000
  #undef t1981001
  #undef t1982000
  #undef t1982001

/*
 * If the error is so large that it ends up being infinity.
 */
  #undef FIX_INF_ULP_pow
  #undef FIX_INF_ULP_tan

/*
 * If the error is so large that it ends up being NaN.
 */
  #undef FIX_NAN_ULP_cosh
  #undef FIX_NAN_ULP10_cosh

/*
 * The point at which argument reduction by 2 PI fails and the error
 * becomes much larger than for small arguments. It is assumed that for
 * fabs( argument ) < LARGE_ARG_*, the error in the trig function is
 * small, eg, 5 ulp, and is less than ULP_*.  But, once the argument
 * exceeds LARGE_ARG_*, the error becomes very large, eg, 5.0e35.
 * This number should be at least FLT_RADIX ** (*_MANT_DIG/2).
 * Since it may depend the number of digits for each floating-point type,
 * we need this for each type of trig function.
 */
  #undef LARGE_ARG_cos
  #undef LARGE_ARG_cosf
  #undef LARGE_ARG_cosl
  #undef LARGE_ARG_sin
  #undef LARGE_ARG_sinf
  #undef LARGE_ARG_sinl
  #undef LARGE_ARG_tan
  #undef LARGE_ARG_tanf
  #undef LARGE_ARG_tanl

/*
 * Function is supposed to be even or odd, but symmetry is not done to last bit.
 * With these defined, use the above ULP_* to see if close enough.
 */
  #undef FIX_EVENODD_asin
/* ... thru ... */
  #undef FIX_EVENODD_trunc
  #undef FIX_EVENODD10_asin
/* ... thru ... */
  #undef FIX_EVENODD10_trunc

/*
 * Library functions not raise flags as expected; either too few or too many.
 */
  #undef FIX_FLAG_acos
/* ... thru ... */
  #undef FIX_FLAG_trunc
  #undef FIX_FLAG10_acos
/* ... thru ... */
  #undef FIX_FLAG10_trunc

/*
 * Library functions not raise same flags when test even/odd property,
 * eg, hypot(x,y) vs hypot(y,x)
 */
  #undef FIX_FLAG_hypot_EVENODD

/*
 * Library functions clear some flags
 */
  #undef FIX_CLR_FLAGS_acos
/* ... thru ... */
  #undef FIX_CLR_FLAGS_trunc
  #undef FIX_CLR_FLAGS10_acos
/* ... thru ... */
  #undef FIX_CLR_FLAGS10_trunc

/*
 * Library functions result depends upon flags
 */
  #undef FIX_DEPENDS_FLAGS_acos
/* ... thru ... */
  #undef FIX_DEPENDS_FLAGS_trunc
  #undef FIX_DEPENDS_FLAGS10_acos
/* ... thru ... */
  #undef FIX_DEPENDS_FLAGS10_trunc

/*
 * Library functions do inexact flag wrong; either not raise when should, or
 * raise when should not.
 */
  #undef FIX_INEXACT_acos
/* ... thru ... */
  #undef FIX_INEXACT_trunc
  #undef FIX_INEXACT10_acos
/* ... thru ... */
  #undef FIX_INEXACT10_trunc

/*
 * Library functions of NaN argument should not raise Invalid.
 * Some bad libraries do raise Invalid for a NaN argument.
 */
  #undef FIX_F_OF_NAN_IS_QUIET

/*
 * Some library functions of denorm argument should be same denorm.
 * Some bad libraries return either zero or different denorm.
 * Either check for same denorm or ULP_f error.
 */
  #undef FIX_SAME_DEN

/*
 * Some library functions of -0.0 argument should be -0.0.
 * Some bad libraries return +0.0.
 * Either check for same zero or some zero.
 */
  #undef FIX_SAME_ZERO

/*
 * Some hardware (such as IBM S/360) treat signed zero as positive zero.
 * That is, -0.0 * +1.0 is +0.0 instead of -0.0; yet -(x-x) is -0.0
 * This matters the most to copysign().
 */
  #undef FIX_TRUE_SIGNED_ZERO

/*
 * Library functions of NaN argument should be a NaN (in most cases).
 * With this defined, all library functions will bypass testing with NaNs.
 */
  #undef FIX_F_OF_NAN_IS_NAN

/*
 * SNAN argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_SNAN_acos
/* ... thru ... */
  #undef FIX_SNAN_trunc
  #undef FIX_SNAN10_acos
/* ... thru ... */
  #undef FIX_SNAN10_trunc

/*
 * NaN argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_NAN_acos
/* ... thru ... */
  #undef FIX_NAN_trunc
  #undef FIX_NAN10_acos
/* ... thru ... */
  #undef FIX_NAN10_trunc

/*
 * Zero argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_ZERO_acos
/* ... thru ... */
  #undef FIX_ZERO_trunc
  #undef FIX_ZERO10_acos
/* ... thru ... */
  #undef FIX_ZERO10_trunc

/*
 * Denormal argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_DEN_acos
/* ... thru ... */
  #undef FIX_DEN_trunc
  #undef FIX_DEN10_acos
/* ... thru ... */
  #undef FIX_DEN10_trunc

/*
 * "Small" arguments cause too many errors, so bypass testing with them.
 */
  #undef FIX_SMALL_acos
/* ... thru ... */
  #undef FIX_SMALL_trunc
  #undef FIX_SMALL10_acos
/* ... thru ... */
  #undef FIX_SMALL10_trunc

/*
 * "Large" arguments cause too many errors, so bypass testing with them.
 */
  #undef FIX_LARGE_acos
/* ... thru ... */
  #undef FIX_LARGE_trunc
  #undef FIX_LARGE10_acos
/* ... thru ... */
  #undef FIX_LARGE10_trunc

/*
 * Infinity argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_INF_acos
/* ... thru ... */
  #undef FIX_INF_trunc
  #undef FIX_INF10_acos
/* ... thru ... */
  #undef FIX_INF10_trunc

/*
 * C89 allowed fmod(x,0.0) to be either domain error or zero.  FPCE now
 * requires it be domain error.  This allows FPCE domain errors to be treated
 * as zero result so will pass test.  If others are found with this
 * implementation-defined behavior, they will be added to the list.
 */
  #undef FIX_DOMAIN_fmod

/*
 * Some argument(s) should be NaN result, so bypass testing with them.
 * Random invalid arguments cause random results (should be NaN with invalid).
 * So, do not test with arguments that are domain errors.
 * One function even randomly altered the stack pointer which caused strange
 * behavior.
 */
  #undef FIX_NAN_RES_acos
/* ... thru ... */
  #undef FIX_NAN_RES_trunc
  #undef FIX_NAN_RES10_acos
/* ... thru ... */
  #undef FIX_NAN_RES10_trunc

/*
 * Some argument(s) should be signed zero result, so test with any zero result.
 */
  #undef FIX_SIGNED_ZERO_RES_acos
/* ... thru ... */
  #undef FIX_SIGNED_ZERO_RES_trunc

/*
 * Some argument(s) should be zero result, so bypass testing with them.
 */
  #undef FIX_ZERO_RES_acos
/* ... thru ... */
  #undef FIX_ZERO_RES_trunc
  #undef FIX_ZERO_RES10_acos
/* ... thru ... */
  #undef FIX_ZERO_RES10_trunc

/*
 * Some argument(s) should be denormal result, so bypass testing with them.
 */
  #undef FIX_DEN_RES_acos
/* ... thru ... */
  #undef FIX_DEN_RES_trunc
  #undef FIX_DEN_RES10_acos
/* ... thru ... */
  #undef FIX_DEN_RES10_trunc

/*
 * Some argument(s) should be "small" result, so bypass testing with them.
 */
  #undef FIX_SMALL_RES_acos
/* ... thru ... */
  #undef FIX_SMALL_RES_trunc
  #undef FIX_SMALL_RES10_acos
/* ... thru ... */
  #undef FIX_SMALL_RES10_trunc

/*
 * Some argument(s) should be "large" result, so bypass testing with them.
 */
  #undef FIX_LARGE_RES_acos
/* ... thru ... */
  #undef FIX_LARGE_RES_trunc
  #undef FIX_LARGE_RES10_acos
/* ... thru ... */
  #undef FIX_LARGE_RES10_trunc

/*
 * Some argument(s) should be infinity result, so bypass testing with them.
 */
  #undef FIX_INF_RES_acos
/* ... thru ... */
  #undef FIX_INF_RES_trunc
  #undef FIX_INF_RES10_acos
/* ... thru ... */
  #undef FIX_INF_RES10_trunc

/*
 * Some argument(s) should NOT produce a NaN result, so bypass testing
 * with them.  That is, bypass tests where the actual result got is a
 * NaN. So far, only added this bypass to these functions.  Can be
 * added to others if needed.
 */
  #undef FIX_NAN_GOT_acosh
  #undef FIX_NAN_GOT_asinh
  #undef FIX_NAN_GOT_atan
  #undef FIX_NAN_GOT_atan2
  #undef FIX_NAN_GOT_cos
  #undef FIX_NAN_GOT_fma
  #undef FIX_NAN_GOT_lgamma
  #undef FIX_NAN_GOT_sin
  #undef FIX_NAN_GOT_tan
  #undef FIX_NAN_GOT_tgamma
  #undef FIX_NAN_GOT10_acosh
  #undef FIX_NAN_GOT10_asinh
  #undef FIX_NAN_GOT10_atan
  #undef FIX_NAN_GOT10_atan2
  #undef FIX_NAN_GOT10_cos
  #undef FIX_NAN_GOT10_fma
  #undef FIX_NAN_GOT10_lgamma
  #undef FIX_NAN_GOT10_sin
  #undef FIX_NAN_GOT10_tan
  #undef FIX_NAN_GOT10_tgamma

/*
 * Some argument(s) result in the function returning the argument as
 * its result, so bypass testing with them.  That is, bypass tests
 * where the actual result got is the argument. So far, only added
 * this bypass to 2 trig functions.  Can be added to others if needed.
 */
  #undef FIX_ARG_GOT10_cos
  #undef FIX_ARG_GOT10_sin
  #undef FIX_ARG_GOT_cos
  #undef FIX_ARG_GOT_sin

/*
 * Some argument(s) should NOT produce a zero result, so bypass
 * testing with them.  That is, bypass tests where the actual result
 * got is a zero.  This was needed to bypass testing func(x) is zero
 * and func(-x) is not zero.
 * Watcom has many functions where f(NAN) or f(INF) is zero.
 */
  #undef FIX_ZERO_GOT_cabs
  #undef FIX_ZERO_GOT_cacos
  #undef FIX_ZERO_GOT_cacosh
  #undef FIX_ZERO_GOT_carg
  #undef FIX_ZERO_GOT_casin
  #undef FIX_ZERO_GOT_casinh
  #undef FIX_ZERO_GOT_catan
  #undef FIX_ZERO_GOT_catanh
  #undef FIX_ZERO_GOT_ccos
  #undef FIX_ZERO_GOT_ccosh
  #undef FIX_ZERO_GOT_cexp
  #undef FIX_ZERO_GOT_cimag
  #undef FIX_ZERO_GOT_clog
  #undef FIX_ZERO_GOT_conj
  #undef FIX_ZERO_GOT_cos
  #undef FIX_ZERO_GOT_cosh
  #undef FIX_ZERO_GOT_cpow
  #undef FIX_ZERO_GOT_cproj
  #undef FIX_ZERO_GOT_creal
  #undef FIX_ZERO_GOT_csin
  #undef FIX_ZERO_GOT_csinh
  #undef FIX_ZERO_GOT_csqrt
  #undef FIX_ZERO_GOT_ctan
  #undef FIX_ZERO_GOT_ctanh
  #undef FIX_ZERO_GOT_exp
  #undef FIX_ZERO_GOT_exp2
  #undef FIX_ZERO_GOT_expm1
  #undef FIX_ZERO_GOT_llrint
  #undef FIX_ZERO_GOT_lrint
  #undef FIX_ZERO_GOT_sin
  #undef FIX_ZERO_GOT_sinh
  #undef FIX_ZERO_GOT_tan

/*
 * Some argument(s) should NOT be inf result, so bypass testing with them.
 * This was needed to bypass testing func(x) is inf and func(-x) is not inf.
 * This was needed to bypass testing func(x) is inf, but expected is finite.
 * That is, bypass tests where the actual result got is an inf.
 */
  #undef FIX_INF_GOT10_asinh
  #undef FIX_INF_GOT10_atan
  #undef FIX_INF_GOT10_atan2
  #undef FIX_INF_GOT10_atanh
  #undef FIX_INF_GOT10_fma
  #undef FIX_INF_GOT10_hypot
  #undef FIX_INF_GOT10_lgamma
  #undef FIX_INF_GOT10_log10
  #undef FIX_INF_GOT10_pow
  #undef FIX_INF_GOT10_tan
  #undef FIX_INF_GOT10_tgamma
  #undef FIX_INF_GOT_asinh
  #undef FIX_INF_GOT_atan
  #undef FIX_INF_GOT_atan2
  #undef FIX_INF_GOT_atanh
  #undef FIX_INF_GOT_fma
  #undef FIX_INF_GOT_hypot
  #undef FIX_INF_GOT_lgamma
  #undef FIX_INF_GOT_log10
  #undef FIX_INF_GOT_pow
  #undef FIX_INF_GOT_tan
  #undef FIX_INF_GOT_tgamma

/*
 * Some argument(s) should NOT be NaN result, so bypass testing with them.
 * That is, bypass tests where the actual result got is invalid raised.
 */
  #undef FIX_INVALID_GOT_fma
  #undef FIX_INVALID_GOT10_fma

/*
 * Some argument(s) should NOT be inf result, so bypass testing with them.
 * That is, bypass tests where the actual result got is overflow raised.
 */
  #undef FIX_OVERFLOW_GOT_fma
  #undef FIX_OVERFLOW_GOT10_fma

/*
 * Library function's result not in expected range.
 */
  #undef FIX_RANGE_acos
/* ... thru ... */
  #undef FIX_RANGE_trunc
  #undef FIX_RANGE10_acos
/* ... thru ... */
  #undef FIX_RANGE10_trunc

/*
 * Library function's result not exact (so might be out of expected range).
 */
  #undef FIX_BIT4BIT_ceil
  #undef FIX_BIT4BIT_floor
  #undef FIX_BIT4BIT_llrint
  #undef FIX_BIT4BIT_llround
  #undef FIX_BIT4BIT_lrint
  #undef FIX_BIT4BIT_lround
  #undef FIX_BIT4BIT_nearbyint
  #undef FIX_BIT4BIT_rint
  #undef FIX_BIT4BIT_round
  #undef FIX_BIT4BIT_trunc
  #undef FIX_BIT4BIT10_llrint
  #undef FIX_BIT4BIT10_llround
  #undef FIX_BIT4BIT10_lrint
  #undef FIX_BIT4BIT10_lround

/*
 * Does DBL function return LDBL value (wider precision and/or
 * exponent range).  This idea could be applied to all the math
 * functions, but these are the only ones so far to matter.
 */
  #undef FIX_NORMAL_RETURN_cabs
  #undef FIX_NORMAL_RETURN_hypot
  #undef FIX_NORMAL_RETURN_nextafter
  #undef FIX_NORMAL_RETURN_nextafterd64
  #undef FIX_NORMAL_RETURN_nexttoward
  #undef FIX_NORMAL_RETURN_nexttowardd64

/*
 * Function result has more precision than can portability test.
 * With these defined, limit precision test in result.
 */
  #undef FIX_FULL_remquo

/*
 * Quotient not computed.
 */
  #undef FIX_QUOT_remquo

/*
 * Sign of quotient wrong.
 */
  #undef FIX_QUOT_SIGN_remquo

/*
 * Function result should be independent of rounding direction.
 * Instead, these functions are affected by rounding direction.
 */
  #undef FIX_RND_fmod
  #undef FIX_RND_remainder
  #undef FIX_RND_remquo

/*
 * Function result should be dependent upon current rounding direction.
 * Instead, these functions only do default rounding direction.
 */
  #undef FIX_RND_fma
  #undef FIX_RND_llrint
  #undef FIX_RND_lrint
  #undef FIX_RND_nearbyint
  #undef FIX_RND_rint
  #undef FIX_RND10_fma
  #undef FIX_RND10_llrint
  #undef FIX_RND10_lrint
  #undef FIX_RND10_nearbyint
  #undef FIX_RND10_rint

/*
 * Rounding of midpoint (+/-0.5, +/-1.5, +/-2.5, ...) is done wrong
 */
  #undef FIX_ROUND_HALF_round

/*
 * Powers of 2 cause problems
 */
  #undef FIX_POW2_frexp

/*
 * Negative numbers cause problems
 */
  #undef FIX_NEGATIVE_asinh
  #undef FIX_NEGATIVE_cbrt
  #undef FIX_NEGATIVE_pow
  #undef FIX_NEGATIVE10_quantize

/*** Run time: C89/C90/C95: other library function problems ***/

/*
 * Independent of trapping, can a signal(SIGFPE,...) be done?
 */
  #undef FIX_SIGNAL_SIGFPE

/*
 * Independent of trapping, can a raise(SIGFPE) be done?
 */
  #undef FIX_RAISE_SIGFPE

/*
 * Assuming a FPU trap gets turned into a signal of SIGFPE by the
 * enabled trap handler, what behavior does the signal handler do?
 * Define this symbol to have the signal handler do an explicit
 * acknowledge of the signal, as well as set behavior back to default.
 */
  #undef FIX_NON_SYS_V_SIGNALS

/*
 * When a signal handler is entered, is the handling reset to SIG_DFL?
 * If not, define this symbol.
 */
  #undef FIX_SIG_DFL

/*
 * Can volatile be combined with sig_atomic_t?
 * If not, define this symbol.
 */
  #undef FIX_VOLATILE_SIG_ATOMIC

/*
 * A signal handler should leave the FPU exception flags alone.
 * Found one that clears inexact.
 */
  #undef FIX_SIGNAL_CLEAR_INEXACT

/*** Run time: C99 ***/
/*** Run time: C99: value of constant problems ***/

/*
 * Denormals (aka subnormals) are in IEEE-754.  Some compilers flush
 * all of them to zero.  ISO/ANSI C requires that representable values
 * be nearest or +/- one representation.  DEN gets flushed to zero.
 * MIN-DEN becomes MIN-zero => MIN.
 * This is compiler TRANSLATION time constant problem.
 */
/*#undef FIX_DEC2BIN_ZERO	// described elsewhere */
/*#undef FIX_DEC2DFP_ZERO	// described elsewhere */
  #undef FIX_FLUSH_HEX_DENORM
  #undef FIX_FLUSH_DENORM
  #undef FIX_FLUSH_DENORM10

/*
 * Denormals (aka subnormals) are in IEEE-754.  Some compilers flush
 * some of them to zero.  ISO/ANSI C requires that representable
 * values be nearest or +/- one representation.  MIN-DEN does not
 * flush DEN, so MIN-DEN becomes denorm and it gets flushed to zero.
 * Also, for FLT and DBL, if constant expressions are done as LDBL,
 * then intermediate denorms are normals to LDBL (so are not flushed),
 * but final result converted to correct type is denorm and flushed.
 * This is compiler TRANSLATION time expression problem.
 */
  #undef FIX_FLUSH_FINAL_DENORM
  #undef FIX_FLUSH_FINAL_DENORM10

/*
 * Minus denormal numbers are converted to positive denormals.
 */
  #undef FIX_mDENORM

/*
 * Decimal (external) to binary (internal) conversion by compiler of
 * denormal numbers during translation is off by a factor of two too high.
 */
  #undef FIX_DENORM_TWO

/*
 * Denormals (aka subnormals) are in IEEE-754.  Some compilers convert
 * them to PseudoDenormals (an unsupported hardware format).  Some
 * hardware treats PseudoDenormals as values bigger than minimum normal.
 * ISO/ANSI C requires that representable values be supported.
 */
  #undef FIX_PSEUDO_DENORMALS

/*
 * Unnormals are NOT in IEEE-754.  Some compilers convert some decimal
 * constants (near overflow threshold) into them, while other system's
 * scanf convert 1.00...0123 (1+small) into them.  When unnormals are
 * used, they are treated like invalid operands.  On an x86, unnormals
 * are numbers with the explicit leading bit set to zero and exponent
 * is non-zero.
 */
  #undef FIX_UNNORMALS
  #undef FIX_UNNORMALS10

/*
 * Pseudo-Infinity is NOT in IEEE-754.  Some compilers convert some decimal
 * constants (past overflow threshold) into them instead of true infinity.
 * When pseudo-infinity is used, it is treated like invalid operands.
 * On an x86, pseudo-infinities are numbers with the explicit leading bit
 * set to zero, but the exponent is all ones.
 *
 * One compiler only does this error for Minus infinity of type LDBL.
 * Some versions made -pseudo infinity, others made -NaN.
 */
  #undef FIX_PSEUDO_INFINITY
  #undef FIX_M_PSEUDO_INFINITY

/*
 * Denormals (aka subnormals) are in IEEE-754.  Some hardware flush
 * all of them to zero.  This covers operands and results both being
 * flushed at RUNTIME by hardware.  Symbols for binary FP and decimal FP.
 */
  #undef FIX_FLUSH_RUN_DEN_BOTH
  #undef FIX_FLUSH_RUN_DEN_BOTH10

/*
 * If a denormal operand to a RUNTIME operation is flushed, need this symbol.
 */
  #undef FIX_FLUSH_RUN_DEN_OPERAND
  #undef FIX_FLUSH_RUN_DEN10_OPERAND

/*
 * If a denormal result from a RUNTIME operation is flushed, need this symbol.
 */
  #undef FIX_FLUSH_RUN_DEN_RESULTS
  #undef FIX_FLUSH_RUN_DEN10_RESULTS

/*
 * Systems that flush denormals forgot to flush the denormal results from
 * some math functions.
 */
  #undef FIX_NON_FLUSHED_DEN_nextafter
  #undef FIX_NON_FLUSHED_DEN_nexttoward

/*
 * "Invalid" Integer Constant Expressions (ICE) used as an array size
 * make the array a Variable Length Array (VLA).  Some compilers accept
 * "invalid" ICE as a valid ICE.
 * (int)3.0 is an ICE
 * (int)(float)3.0 is not an ICE
 * t0182600 and e01826* and e61826*
 */
  #undef FIX_INVALID_ICE

/*** Run time: C99: code generation problems ***/

/*
 * Conversion/promotion/cast/assignment from one type (y) to another
 * type (x) should be supported, e.g., x=y, or (x)y.  It either kills
 * compile if not supported, or produces the wrong result at run time.
 * x, y may be one of: LDBL, DBL, FLT, [U|S]LLI, [U|S]LI, [U|S]I, [U|S]SI,
 * [U|S|P]C, ENUM, [U|S]B{its}.  Use FP if all of LDBL/DBL/FLT apply.
 */
  #undef FIX_CMPLX_FROM_IMAG
  #undef FIX_DBL_FROM_ULLI
  #undef FIX_ENUM_FROM_CMPLX
  #undef FIX_FLT_FROM_SI
  #undef FIX_FLT_FROM_SLI
  #undef FIX_FLT_FROM_SLLI
  #undef FIX_FLT_FROM_UI
  #undef FIX_FLT_FROM_ULI
  #undef FIX_FLT_FROM_ULLI
  #undef FIX_FP_FROM_SLLI
  #undef FIX_FP_FROM_ULLI
  #undef FIX_LDBL_FROM_SLLI
  #undef FIX_LDBL_FROM_ULI
  #undef FIX_LDBL_FROM_ULLI
  #undef FIX_SLLI_FROM_FP
  #undef FIX_ULLI_FROM_FLT
  #undef FIX_ULLI_FROM_FP
  #undef FIX_ULLI_FROM_LARGE_FP_CONST

/*
 * FLT overflow is infinity (not NaN nor MAX_type).
 */
  #undef FIX_FLT_OVER_IS_INF
  #undef FIX_F10_OVER_IS_INF10

/*
 * -MAX_type is -infinity (should be finite).
 */
  #undef FIX_mMAX_IS_INF
  #undef FIX_mMAX_IS_INF10

/*
 * +MAX_type is +infinity (should be finite).
 */
  #undef FIX_pMAX_IS_INF
  #undef FIX_pMAX_IS_INF10

/*
 * -INF_type causes unusual results in compares to gcc 4.4.0
 */
  #undef FIX_mINF_D10
  #undef FIX_mINF_DBL
  #undef FIX_mINF_F10
  #undef FIX_mINF_FLT
  #undef FIX_mINF_LD10
  #undef FIX_mINF_LDBL

/*
 * MAX_type/MIN_type is infinity (not NaN nor MAX_type).
 */
  #undef FIX_MAX_d_MIN_IS_INF
  #undef FIX_MAX_d_MIN_IS_INF10

/*
 * MAX_type*MAX_type is infinity (not NaN nor MAX_type).
 */
  #undef FIX_MAX_x_MAX_IS_INF
  #undef FIX_MAX_x_MAX_IS_INF10

/*
 * MAX_type+MAX_type is infinity (not NaN nor MAX_type).
 * At least one compiler has MAX+MAX be MIN!
 * Linux gcc 4.4.* get internal error with DFP of these.
 */
  #undef FIX_MAX_p_MAX_IS_INF
  #undef FIX_MAX_p_MAX_IS_INF10

/*
 * MIN_type*MIN_type is zero (not infinity nor NaN).
 * MIN_type/MAX_type is zero (not infinity nor NaN).
 */
  #undef FIX_MIN_x_MIN_IS_ZERO
  #undef FIX_MIN_d_MAX_IS_ZERO

/*
 * _ _STDC_IEC_559_ _ can't be #undef nor #define.
 */
  #undef FIX_CHANGE_STDC_IEC_559

/*
 * __FPCE__ can't be #undef nor #define.
 */
  #undef FIX_CHANGE_FPCE

/*
 * __FPCE_IEEE__ can't be #undef nor #define.
 */
  #undef FIX_CHANGE_FPCE_IEEE

/*
 * [_Bool] Bit-fields should promote to signed int (value preserving).
 */
  #undef FIX_BAD_BITFIELD_PROMOTION
  #undef FIX_BAD_BOOLBITFIELD_PROMOTION
  #undef FIX_BAD_BOOL32BITFLD_PROMOTION

/*
 * _Bool Bit-fields should be unsigned
 */
  #undef FIX_SIGNED_BOOLBITFIELD

/*
 * Assignment to _Bool should be quiet (raise no exceptions),
 * even for NaN, infinity, denormal.
 */
  #undef FIX_QUIET_ASSIGN_TO_BOOL

/*
 * _Bool is faked with unsigned int.
 * So, _Bool b = 0.5; does the wrong thing.
 */
  #undef FIX_TRUE_BOOL

/*
 * if(bool_var) kills some compilers
 */
  #undef FIX_BOOL_IN_IF

/*
 * Code generation for res == ( vl += vr) done wrong, where vl is of
 * type bool.
 */
  #undef FIX_EQUALEQUAL_BOOL_PLUSEQUAL

/*
 * Code generation for bool vars in register kills some compilers.
 */
  #undef FIX_REG_VARS

/*
 * Code generation for vl -= vr; done wrong, where vl is of type LDBL
 * and vr is bool.
 */
  #undef FIX_LDBL_SUBEQUAL_BOOL
  #undef FIX_LD10_SUBEQUAL_BOOL

/*
 * Large (too big) floating-point values converted to unsigned long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_ULLONG_SET_INVALID
  #undef FIX_2BIG2_ULLONGP_SET_INVALID
  #undef FIX_2BIG2_ULLONGM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SLLONG_SET_INVALID
  #undef FIX_2BIG2_SLLONGP_SET_INVALID
  #undef FIX_2BIG2_SLLONGM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_ULONG_SET_INVALID
  #undef FIX_2BIG2_ULONGP_SET_INVALID
  #undef FIX_2BIG2_ULONGM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SLONG_SET_INVALID
  #undef FIX_2BIG2_SLONGP_SET_INVALID
  #undef FIX_2BIG2_SLONGM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_UINT_SET_INVALID
  #undef FIX_2BIG2_UINTP_SET_INVALID
  #undef FIX_2BIG2_UINTM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SINT_SET_INVALID
  #undef FIX_2BIG2_SINTP_SET_INVALID
  #undef FIX_2BIG2_SINTM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_USHRT_SET_INVALID
  #undef FIX_2BIG2_USHRTP_SET_INVALID
  #undef FIX_2BIG2_USHRTM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SSHRT_SET_INVALID
  #undef FIX_2BIG2_SSHRTP_SET_INVALID
  #undef FIX_2BIG2_SSHRTM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_UCHAR_SET_INVALID
  #undef FIX_2BIG2_UCHARP_SET_INVALID
  #undef FIX_2BIG2_UCHARM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SCHAR_SET_INVALID
  #undef FIX_2BIG2_SCHARP_SET_INVALID
  #undef FIX_2BIG2_SCHARM_SET_INVALID

/*
 * Large (too big) floating-point values converted to plain char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_PCHAR_SET_INVALID
  #undef FIX_2BIG2_PCHARP_SET_INVALID
  #undef FIX_2BIG2_PCHARM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_UBITS_SET_INVALID
  #undef FIX_2BIG2_UBITSP_SET_INVALID
  #undef FIX_2BIG2_UBITSM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SBITS_SET_INVALID
  #undef FIX_2BIG2_SBITSP_SET_INVALID
  #undef FIX_2BIG2_SBITSM_SET_INVALID

/*
 * Large (too big) floating-point values converted to plain bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_PBITS_SET_INVALID
  #undef FIX_2BIG2_PBITSP_SET_INVALID
  #undef FIX_2BIG2_PBITSM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned ENUM
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_UENUM_SET_INVALID
  #undef FIX_2BIG2_UENUMP_SET_INVALID
  #undef FIX_2BIG2_UENUMM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed ENUM
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SENUM_SET_INVALID
  #undef FIX_2BIG2_SENUMP_SET_INVALID
  #undef FIX_2BIG2_SENUMM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_ULLONG_SET_INVALID
  #undef FIX_NAN2_ULLONGP_SET_INVALID
  #undef FIX_NAN2_ULLONGM_SET_INVALID

/*
 * NaN floating-point values converted to signed long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SLLONG_SET_INVALID
  #undef FIX_NAN2_SLLONGP_SET_INVALID
  #undef FIX_NAN2_SLLONGM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_ULONG_SET_INVALID
  #undef FIX_NAN2_ULONGP_SET_INVALID
  #undef FIX_NAN2_ULONGM_SET_INVALID

/*
 * NaN floating-point values converted to signed long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SLONG_SET_INVALID
  #undef FIX_NAN2_SLONGP_SET_INVALID
  #undef FIX_NAN2_SLONGM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_UINT_SET_INVALID
  #undef FIX_NAN2_UINTP_SET_INVALID
  #undef FIX_NAN2_UINTM_SET_INVALID

/*
 * NaN floating-point values converted to signed int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SINT_SET_INVALID
  #undef FIX_NAN2_SINTP_SET_INVALID
  #undef FIX_NAN2_SINTM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_USHRT_SET_INVALID
  #undef FIX_NAN2_USHRTP_SET_INVALID
  #undef FIX_NAN2_USHRTM_SET_INVALID

/*
 * NaN floating-point values converted to signed short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SSHRT_SET_INVALID
  #undef FIX_NAN2_SSHRTP_SET_INVALID
  #undef FIX_NAN2_SSHRTM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_UCHAR_SET_INVALID
  #undef FIX_NAN2_UCHARP_SET_INVALID
  #undef FIX_NAN2_UCHARM_SET_INVALID

/*
 * NaN floating-point values converted to signed char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SCHAR_SET_INVALID
  #undef FIX_NAN2_SCHARP_SET_INVALID
  #undef FIX_NAN2_SCHARM_SET_INVALID

/*
 * NaN floating-point values converted to plain char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_PCHAR_SET_INVALID
  #undef FIX_NAN2_PCHARP_SET_INVALID
  #undef FIX_NAN2_PCHARM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_UBITS_SET_INVALID
  #undef FIX_NAN2_UBITSP_SET_INVALID
  #undef FIX_NAN2_UBITSM_SET_INVALID

/*
 * NaN floating-point values converted to signed bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SBITS_SET_INVALID
  #undef FIX_NAN2_SBITSP_SET_INVALID
  #undef FIX_NAN2_SBITSM_SET_INVALID

/*
 * NaN floating-point values converted to plain bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_PBITS_SET_INVALID
  #undef FIX_NAN2_PBITSP_SET_INVALID
  #undef FIX_NAN2_PBITSM_SET_INVALID

/*
 * NAN floating-point values converted to bool and bool bit-field
 * should NOT raise (set) invalid.  Both ends; Plus end; Minus end.
 * In addition, the result should be true (1).
 */
  #undef FIX_NAN2_BOOL_IS_TRUE
  #undef FIX_NAN102_BOOL_IS_TRUE
  #undef FIX_NAN2_BOOL_SET_INVALID
  #undef FIX_NAN2_BOOLP_SET_INVALID
  #undef FIX_NAN2_BOOLM_SET_INVALID
  #undef FIX_NAN2_BOOLBIT_SET_INVALID
  #undef FIX_NAN2_BOOLBITP_SET_INVALID
  #undef FIX_NAN2_BOOLBITM_SET_INVALID

/*
 * INF floating-point values converted to unsigned long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_ULLONG_SET_INVALID
  #undef FIX_INF2_ULLONGP_SET_INVALID
  #undef FIX_INF2_ULLONGM_SET_INVALID

/*
 * INF floating-point values converted to signed long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SLLONG_SET_INVALID
  #undef FIX_INF2_SLLONGP_SET_INVALID
  #undef FIX_INF2_SLLONGM_SET_INVALID

/*
 * INF floating-point values converted to unsigned long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_ULONG_SET_INVALID
  #undef FIX_INF2_ULONGP_SET_INVALID
  #undef FIX_INF2_ULONGM_SET_INVALID

/*
 * INF floating-point values converted to signed long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SLONG_SET_INVALID
  #undef FIX_INF2_SLONGP_SET_INVALID
  #undef FIX_INF2_SLONGM_SET_INVALID

/*
 * INF floating-point values converted to unsigned int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_UINT_SET_INVALID
  #undef FIX_INF2_UINTP_SET_INVALID
  #undef FIX_INF2_UINTM_SET_INVALID

/*
 * INF floating-point values converted to signed int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SINT_SET_INVALID
  #undef FIX_INF2_SINTP_SET_INVALID
  #undef FIX_INF2_SINTM_SET_INVALID

/*
 * INF floating-point values converted to unsigned short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_USHRT_SET_INVALID
  #undef FIX_INF2_USHRTP_SET_INVALID
  #undef FIX_INF2_USHRTM_SET_INVALID

/*
 * INF floating-point values converted to signed short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SSHRT_SET_INVALID
  #undef FIX_INF2_SSHRTP_SET_INVALID
  #undef FIX_INF2_SSHRTM_SET_INVALID

/*
 * INF floating-point values converted to unsigned char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_UCHAR_SET_INVALID
  #undef FIX_INF2_UCHARP_SET_INVALID
  #undef FIX_INF2_UCHARM_SET_INVALID

/*
 * INF floating-point values converted to signed char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SCHAR_SET_INVALID
  #undef FIX_INF2_SCHARP_SET_INVALID
  #undef FIX_INF2_SCHARM_SET_INVALID

/*
 * INF floating-point values converted to plain char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_PCHAR_SET_INVALID
  #undef FIX_INF2_PCHARP_SET_INVALID
  #undef FIX_INF2_PCHARM_SET_INVALID

/*
 * INF floating-point values converted to unsigned bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_UBITS_SET_INVALID
  #undef FIX_INF2_UBITSP_SET_INVALID
  #undef FIX_INF2_UBITSM_SET_INVALID

/*
 * INF floating-point values converted to signed bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SBITS_SET_INVALID
  #undef FIX_INF2_SBITSP_SET_INVALID
  #undef FIX_INF2_SBITSM_SET_INVALID

/*
 * INF floating-point values converted to plain bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_PBITS_SET_INVALID
  #undef FIX_INF2_PBITSP_SET_INVALID
  #undef FIX_INF2_PBITSM_SET_INVALID

/*
 * INF floating-point values converted to bool and bool bit-field
 * should NOT raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_BOOL_SET_INVALID
  #undef FIX_INF2_BOOLP_SET_INVALID
  #undef FIX_INF2_BOOLM_SET_INVALID
  #undef FIX_INF2_BOOLBIT_SET_INVALID
  #undef FIX_INF2_BOOLBITP_SET_INVALID
  #undef FIX_INF2_BOOLBITM_SET_INVALID

/*
 * Finite floating-point values converted to bool and bool bit-field
 * should NOT raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_FP2_BOOL_SET_INVALID
  #undef FIX_FP2_BOOLP_SET_INVALID
  #undef FIX_FP2_BOOLM_SET_INVALID
  #undef FIX_FP2_BOOLBIT_SET_INVALID
  #undef FIX_FP2_BOOLBITP_SET_INVALID
  #undef FIX_FP2_BOOLBITM_SET_INVALID

/*
 * Too large and in-range floating-point values converted
 * to various int types randomly raises invalid and/or inexact.
 */
  #undef FIX_ULLONG_RANDOM_INVALID
  #undef FIX_SLLONG_RANDOM_INVALID
  #undef FIX_ULONG_RANDOM_INVALID
  #undef FIX_SLONG_RANDOM_INVALID
  #undef FIX_UINT_RANDOM_INVALID
  #undef FIX_SINT_RANDOM_INVALID
  #undef FIX_USHRT_RANDOM_INVALID
  #undef FIX_SSHRT_RANDOM_INVALID
  #undef FIX_UCHAR_RANDOM_INVALID
  #undef FIX_SCHAR_RANDOM_INVALID
  #undef FIX_PCHAR_RANDOM_INVALID
  #undef FIX_UBITS_RANDOM_INVALID
  #undef FIX_SBITS_RANDOM_INVALID
  #undef FIX_PBITS_RANDOM_INVALID
  #undef FIX_UENUM_RANDOM_INVALID
  #undef FIX_SENUM_RANDOM_INVALID
  #undef FIX_BOOLBIT_RANDOM_INVALID
  #undef FIX_BOOL_RANDOM_INVALID
  #undef FIX_BOOL_RANDOM_INEXACT

/*
 * Valid large and in-range floating-point values converted
 * to unsigned [long] long int produce wrong value and raises invalid.
 * It appears to only happen for values: ULLONG_MAX/2 ... ULLONG_MAX,
 * that is, the conversion appears to be done is if to signed long long.
 */
  #undef FIX_VALID_FP_2_ULLONG
  #undef FIX_VALID_FP_2_ULONG

/*
 * Conversion from valid in-range floating-point to integer type
 * shall not raise invalid.
 */
  #undef FIX_INVALID_FROM_INRANGE

/*
 * unsigned long long int ulli = -0.999; should be 0uLL
 * unsigned      long int ulli = -0.999; should be 0uL w/o invalid
 */
  #undef FIX_ULLI_FROM_NEG
  #undef FIX_ULI_FROM_NEG

/*
 * unsigned long long int ulli = +0.999; should be 0uLL
 * unsigned      long int  uli = +0.999; should be 0uL
 */
  #undef FIX_ULLI_FROM_POS
  #undef FIX_ULI_FROM_POS

/*
 * f = ui; or f = i; should round (not truncate).
 */
  #undef FIX_I2F_ROUND

/*
 * d = ulli; or d = lli; should round (not truncate).
 */
  #undef FIX_LL_2_REAL_TRUNC

/*
 * long long constants should be usable in preprocessor #if stmts.
 */
  #undef FIX_LL_PP_CONSTANTS

/*
 * long long constants should be usable with floating point constants
 * (particularly, in initializers).
 */
  #undef FIX_LONGLONG_WITH_FP_CONSTS

/*
 * LLONG_MIN in <limits.h> is defined using the wrong syntax, so that
 * it ends up as a positive number.
 */
  #undef FIX_POSITIVE_LLONG_MIN

/*
 * LLONG_MAX in <limits.h> is defined using the wrong syntax, so that
 * it ends up as a negative number.
 */
  #undef FIX_NEGATIVE_LLONG_MAX

/*
 * 1e2147483648 (eg, 10 ** ( 2 ** 32 ) ) should convert to the same value
 * at translation time as run-time.
 */
  #undef FIX_1E2TO32

/*
 * Do scanf and strto* correctly process \v (Vertical Tab) as white space?
 */
  #undef FIX_BAD_VT

/*
 * Do scanf and strto* correctly process \f (Form Feed) as white space?
 */
  #undef FIX_BAD_FF

/*
 * Do scanf and strto* correctly process \r (Carriage Return) as white space?
 */
  #undef FIX_BAD_CR

/*
 * Do wscanf and wcsto* correctly process wide white space?
 */
  #undef FIX_WIDE_WHITESPACE

/*
 * Do scanf and strto* correctly process hex FP numbers with missing hex digits?
 * For example, 0x, 0X, 0xy, 0XY.
 */
  #undef FIX_BAD_0X

/*
 * Do scanf and strto* correctly process I and IN (bad forms of INF)?
 */
  #undef FIX_BAD_INF

/*
 * Do scanf and strto* correctly process "INFI..." (bad forms of INF)?
 * That is, INF with part of INITY.
 */
  #undef FIX_INF_EXTRA

/*
 * Do scanf and strto* correctly process N, NA, NAAN (bad forms of NAN)?
 */
  #undef FIX_BAD_NAN

/*
 * Do scanf and strto* correctly process "NAN(..." (bad forms of NAN)?
 */
  #undef FIX_NAN_EXTRA

/*
 * Hex FP not liked by *scanf or strto* at runtime.
 */
  #undef FIX_FPCE_HEX_RUNTIME

/*
 * In C89, freopen requires a non-null 1st pointer.
 * In C99, freopen allows a NULL 1st pointer.
 * Use this if you get core dumps at runtime in t3040000.
 */
  #undef FIX_C99_freopen

/*
 * -0.0 is converted to +0.0
 */
  #undef FIX_mZERO

/*
 * -0.0 is < true
 */
  #undef FIX_mZERO_LT_true

/*
 * Are -0.0 and +0.0 converted to randomly signed zeros?
 * One compiler appears to use the first signed zero it sees as the value
 * for all following signed zeros.
 */
  #undef FIX_RANDOM_SIGNED_ZERO

/*
 * -0.0 is not the same as +0.0.
 */
  #undef FIX_MINUS_ZERO_CONSTANT

/*
 * Constant expressions should be run-time time, not translation time.
 * -0.0 is not the same as +0.0.  Some compilers evaluate constant
 * expressions involving -0.0 at translate time and produce +0.0
 */
  #undef FIX_MINUS_ZERO_CONSTANT_EXP

/*
 * Constant expressions in initializer done poorly.
 * Watcom 1.0 does ulp/2 and min*ulp wrong (those are all powers of 2,
 * but result is not a power of 2); there may be others.
 */
  #undef  FIX_SLOPPY_CONSTANT_EXP

/*
 * 0.f / 0.f should be a NaN.
 * 0.0 / 0.0 should be a NaN.
 * 0.L / 0.L should be a NaN.
 */
  #undef FIX_0F_OVER_0F_IS_NAN
  #undef FIX_0D_OVER_0D_IS_NAN
  #undef FIX_0L_OVER_0L_IS_NAN
  #undef FIX_0F_OVER_0F_IS_NAN10
  #undef FIX_0D_OVER_0D_IS_NAN10
  #undef FIX_0L_OVER_0L_IS_NAN10

/*
 * 1.f / 0.f should be an Inf.
 * 1.0 / 0.0 should be an Inf.
 * 1.L / 0.L should be an Inf.
 */
  #undef FIX_1F_OVER_0F_IS_INF
  #undef FIX_1D_OVER_0D_IS_INF
  #undef FIX_1L_OVER_0L_IS_INF
  #undef FIX_1F_OVER_0F_IS_INF10
  #undef FIX_1D_OVER_0D_IS_INF10
  #undef FIX_1L_OVER_0L_IS_INF10

/*
 * In C89, initialization of aggregates (arrays and structs) and
 * unions was required to be done with constant expressions, e.g., the
 * same as if it was a (compile time) static initialization.  Only
 * AUTO scalar initializations were left to runtime.  In C99, this was
 * changed to: static => compile time; AUTO => runtime; independent of
 * scalar/aggregate.  So, AUTO DBL d[] = {1.0/0.0}; used to not
 * raise exceptions, now it does.  Define this symbol if the compiler
 * does AUTO aggregate/union initialization at compile time.
 */
  #undef FIX_AGG_INIT_IS_STATIC

/*
 * Conversion from hexadecimal to internal BFP should not suffer double rounding.
 * Conversion from     decimal to internal DFP should not suffer double rounding.
 */
  #undef FIX_BAD_HEX_ROUNDING
  #undef FIX_BAD_DFP_ROUNDING

/*
 * Conversion from hexadecimal to internal FP of very large values
 * should be infinity.
 */
  #undef FIX_BAD_HEX_LARGE

/*
 * Conversion from decimal or hexadecimal to internal FP of very small
 * values should be zero.
 */
  #undef FIX_BAD_DEC_SMALL
  #undef FIX_BAD_HEX_SMALL

/*
 * Conversion from hexadecimal to internal FP of my PI* values in
 * myfloat.h are done so bad, that we need to use the decimal
 * versions.
 */
  #undef FIX_HEX_PI

/*
 * Hexadecimal FP zero, 0x0p0, is zero, not one.
 */
  #undef FIX_HEXZERO_IS_ZERO

/*
 * FP constant (expressions) should be round to nearest.
 */
  #undef FIX_TRANS_ROUND_OK

/*
 * C's FLT_ROUNDS is dynamic and indicates current rounding direction.
 */
  #undef FIX_DYNAMIC_FLT_ROUNDS

/*
 * Conversion from "decimal" to internal LDBL FP.
 */
  #undef FIX_strtold_LDBL_WRONG

/*
 * Conversion from "decimal" to internal FP of infinity should work
 * for strtof, strtod, strtold, and wcstof, wcstod, wcstold.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_STRTO_INF
  #undef FIX_WCSTO_INF
  #undef FIX_STRTO10_INF
  #undef FIX_WCSTO10_INF

/*
 * Conversion from "decimal" to internal FP of NaN should work
 * for strtof, strtod, strtold, and wcstof, wcstod, wcstold.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_STRTO_NAN
  #undef FIX_WCSTO_NAN
  #undef FIX_STRTO10_NAN
  #undef FIX_WCSTO10_NAN

/*
 * Conversion from "decimal" to internal FP of infinity should work.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCAN_INF
  #undef FIX_WSCAN_INF
  #undef FIX_SCAN10_INF
  #undef FIX_WSCAN10_INF

/*
 * Conversion from "decimal" to internal FP of NaN should work.
 * NAN(...) not liked by *scanf or strto*
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCAN_NAN
  #undef FIX_WSCAN_NAN
  #undef FIX_SCAN10_NAN
  #undef FIX_WSCAN10_NAN
  #undef FIX_NAN_NCHAR

/*
 * Conversion from "decimal" to internal FP of -0.0 should work.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCAN_mZERO
  #undef FIX_WSCAN_mZERO
  #undef FIX_SCAN10_mZERO
  #undef FIX_WSCAN10_mZERO

/*
 * scanf should support %F
 */
  #undef FIX_SCAN_F
  #undef FIX_SCAN10_F
  #undef FIX_WSCAN_F
  #undef FIX_WSCAN10_F

/*
 * [w]scanf should support %a and %A
 */
  #undef FIX_SCAN_aA
  #undef FIX_SCAN10_aA
  #undef FIX_WSCAN_aA
  #undef FIX_WSCAN10_aA

/*
 * [w]printf should support %F
 */
  #undef FIX_PRINT_F
  #undef FIX_PRINT10_F
  #undef FIX_WPRINT_F
  #undef FIX_WPRINT10_F

/*
 * [w]printf should support %a and %A
 *  #undef FIX_WPRINT10_aA
 */
  #undef FIX_PRINT_aA
  #undef FIX_PRINT10_aA
  #undef FIX_WPRINT_aA

/*
 * printf, using %a and %A, can produce as least 4 different outputs
 * for the same number (first digit is: 1, 2-3, 4-7, 8-f).  Depending
 * upon the precision and that first digit, the output may be exact
 * or rounded.  This bypasses tests where a rounded [which is wrong]
 * result may be produced.  Affects t0250900, t30703*.
 */
  #undef FIX_PRINT_aA_SMALL_PREC
  #undef FIX_WPRINT_aA_SMALL_PREC

/*
 * printf using %a and %A has wrong number of leading zeros.
 * %020a in t30703* is one such case.
 */
  #undef FIX_aA_LEADING_ZEROS

/*
 * Conversion from internal FP to decimal of infinity should work.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_INF
  #undef FIX_WPRINT_INF
  #undef FIX_PRINT10_INF
  #undef FIX_WPRINT10_INF

/*
 * Conversion from internal FP to decimal of NaN should work.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_NAN
  #undef FIX_WPRINT_NAN
  #undef FIX_PRINT10_NAN
  #undef FIX_WPRINT10_NAN

/*
 * Conversion from internal FP to decimal of -0.0 should work.
 */
  #undef FIX_PRINT_mZERO
  #undef FIX_WPRINT_mZERO
  #undef FIX_PRINT10_mZERO
  #undef FIX_WPRINT10_mZERO

/*
 * Conversion from internal FP to hexadecimal of denormal should work.
 */
  #undef FIX_PRINT_HEX_DEN
  #undef FIX_WPRINT_HEX_DEN

/*
 * FP runtime evaluation format (IMPL_FLT_EVAL_OP) is supposed to be
 * the wider of semantic type and min eval format.  Also, some
 * compilers do some runtime expressions at translation time, but with
 * less precision.  Happens with:
 *  IMPL_FLT_EVAL_CONST_EXP 0
 *  IMPL_FLT_EVAL_OP 2
 * */
  #undef FIX_EVAL_AT_LEAST_MIN
  #undef FIX_EVAL10_AT_LEAST_MIN

/*
 * FP constant's evaluation format (IMPL_FLT_EVAL_CONST) is supposed
 * to be wider of semantic type and min eval format.  That is, if
 * FLT_EVAL_METHOD is 1, then 0.1F should be done as if 0.1; and if
 * FLT_EVAL_METHOD is 2, then 0.1F and 0.1 should be done as if 0.1L.
 */
  #undef FIX_EVAL_CONST_AT_LEAST_MIN
  #undef FIX_EVAL10_CONST_AT_LEAST_MIN

/*
 * Return of FP type is supposed to be semantic type
 * IMPL_FLT_EVAL_RET.
 */
  #undef FIX_EVAL_RET
  #undef FIX_EVAL_RET10

/*
 * Inline function: Return of FP type is supposed to be
 * semantic type.  IMPL_FLT_EVAL_IN_RET.
 */
  #undef FIX_EVAL_IN_RET
  #undef FIX_EVAL_IN_RET10

/*
 * Conversions from integer type to FP type (IMPL_FLT_EVAL_INT2FLT) is
 * supposed to be wider of semantic type and min eval format.
 */
  #undef FIX_EVAL_INT2FLT_AT_LEAST_MIN
  #undef FIX_EVAL10_INT2DFP_AT_LEAST_MIN

/*
 * FP constant expression (Translation time precision and range) must
 * have evaluation format that is wider of semantic type and min eval
 * format (IMPL_FLT_EVAL_CONST_EXP).
 */
  #undef FIX_EVAL_CONST_EXP_AT_LEAST_MIN
  #undef FIX_EVAL10_CONST_EXP_AT_LEAST_MIN

/*
 * Runtime conversion from int type to float type
 * (IMPL_FLT_EVAL_INT2FLT) is supposed to be the wider of semantic
 * type and min eval format.
 */
  #undef FIX_EVAL_INT2FLT_AT_LEAST_MIN
  #undef FIX_EVAL10_INT2DFP_AT_LEAST_MIN

/*
 * FP evaluation format of FLT is wider of semantic type and min eval format.
 */
  #undef FIX_EVAL_FLT_AT_LEAST_MIN
  #undef FIX_EVAL10_F10_AT_LEAST_MIN

/*
 * For systems with LD_PREC < LD_REG_PREC, is the extra precision always used?
 * Needed for Watcom in t0310200.
 */
  #undef FIX_ALWAYS_EXTRA_PRECISION

/*
 * FP evaluation format is at most LDBL.  Registers cannot be wider
 * than LDBL in memory.
 */
  #undef FIX_EVAL_AT_MOST_LDBL
  #undef FIX_EVAL10_AT_MOST_LD10

/*
 * Precision of LDBL should be correct.  On one system, LDBL is stored as
 * LDBL, but is used as DBL.
 */
  #undef FIX_LDBL_PREC_IS_OK
  #undef FIX_LD10_PREC_IS_OK

/*
 * Precision and range of FLT should be correct.  On one system, FLT is
 * stored as FLT, but is used as DBL.
 */
  #undef FIX_FLT_IS_OK

/*
 * When expression values are pushed/popped to the stack, they should not
 * lose any information (precision or exponent range).
 */
  #undef FIX_STACK_PRECISION

/*
 * Does -y flip the sign bit of y?  It matters for signed zeros and NaNs.
 * The expression -y != 0.0-y if y is +0.  -y != -1*y if y is NaN.
 */
  #undef FIX_NEG_FLIP_SIGN

/*
 * 1/(-INFINITY) should produce -0.  But, if it produces +0, this attempts
 * to get around that bug.
 */
  #undef FIX_1_OVER_mINF

/*
 * Contracted operations, aka, fused multiply-add (FMA), aka
 * multiply-accumulate (MAC) should honor signed zeros.
 */
  #undef FIX_FMA_NEG_ZERO

/*
 * The (x + 1.0) - 1.0 should not be optimized to x
 */
  #undef FIX_IGNORE_PARENS

/*
 * The expression INF + -INF should not be optimized to 0.0.
 */
  #undef FIX_OPT_INF_SUB_INF_TO_0

/*
 * The expression INF / INF should not be optimized to 1.0.
 */
  #undef FIX_OPT_INF_DIV_INF_TO_1

/*
 * The expression y / y cannot be optimized to 1.0 if y can be an
 * +/- infinity, +/- NaN, or +/-0.0.
 */
  #undef FIX_OPT_Y_DIV_Y_TO_1

/*
 * The expression y / 1.0 cannot be optimized to y for Decimal FP.
 * y / 1.0 should remove a trailing zero (change quantum exponent).
 */
  #undef FIX_OPT_Y_DIV_1_TO_Y

/*
 * The expression 0.0 * y cannot be optimized to 0.0 if y can be an
 * +/- infinity or +/- NaN or -0.0.
 */
  #undef FIX_OPT_0_TIMES_Y_TO_0

/*
 * The expression 1.0 * y cannot be optimized to y for Decimal FP.
 * y * 1.0 should add a trailing zero (change quantum exponent).
 */
  #undef FIX_OPT_1_TIMES_Y_TO_Y

/*
 * The expression 0.0 * -1.0 cannot be optimized to +0.0
 */
  #undef FIX_OPT_0_TIMES_m1_TO_p0

/*
 * The expression 0.0 / y cannot be optimized to 0.0 if y can be a
 * +/- NaN or +/-0.0.
 */
  #undef FIX_OPT_0_DIV_Y_TO_0

/*
 * The expression 0.0 / -1.0 cannot be optimized to +0.0
 */
  #undef FIX_OPT_0_DIV_m1_TO_p0

/*
 * The expression 0.0 + y cannot be optimized to y if y can be a -0.0
 */
  #undef FIX_OPT_0_PLUS_Y_TO_Y

/*
 * The expression 0.0 - y cannot be optimized to -y if y can be a +/-0.0
 */
  #undef FIX_OPT_0_MINUS_Y_TO_mY

/*
 * The expression y - 0.0 cannot be optimized to y if y can be a +0.0
 * and the rounding mode is towards -infinity.
 */
  #undef FIX_OPT_Y_MINUS_0_TO_Y

/*
 * The expression y - y cannot be optimized to 0.0 if y can be an
 * +/- infinity or +/- NaN.
 */
  #undef FIX_OPT_Y_MINUS_Y_TO_0

/*
 * The expression x+x*y cannot be optimized to x*(1+y) if y is -2
 * and x is max or inf.
 */
  #undef FIX_OPT_COMMON_FACTOR

/*
 * The statement ((ulp+ONE)-ONE) cannot be "optimized" to (ulp).
 * The parenthesis must be honored.
 */
  #undef FIX_OPT_pONE_mONE

/*
 * The expression y / 5.0 cannot be optimized to y * 0.2
 */
  #undef FIX_OPT_DIV_TO_MUL

/*
 * Statements like 0.0/0.0; must be done for their side effects.
 * They cannot be optimized away.
 */
  #undef FIX_OPT_SIDE_EFFECTS

/*
 * The statement FLT_MAX * FLT_MAX; must be done for its side effects.
 * It cannot be optimized away.
 */
  #undef FIX_OPT_MAX_x_MAX

/*
 * The statement FLT_MIN * FLT_MIN; must be done for its side effects.
 * It cannot be optimized away.
 */
  #undef FIX_OPT_MIN_x_MIN

/*
 * Some kind of bad optimization not covered by above.
 * Most likely MIN_q * radix;
 */
  #undef FIX_BAD_OPT

/*
 * Any implied [in]equality tests must be done correctly.
 * Example: if( DEN_LD10 )...; For tests t633*
 */
  #undef FIX_BAD_LD10_COMP2ZERO

/*
 * Any relational comparison involving non-NaN must be done correctly.
 * This includes comparisons involving a variable and/or a constant.
 * This is for trinary (?:) operator and if() ????
 * Example: res = ( var0 < 1.0 ) ? 1 : 0; For tests t030*
 * Example: res = ( var0 < var1) ? 1 : 0; For tests t030*
 * Example: res = ( 0.0  < var1) ? 1 : 0; For tests t030*
 */
  #undef FIX_BAD_COMP_VAR_CON
  #undef FIX_BAD_COMP_VAR_VAR
  #undef FIX_BAD_COMP_CON_VAR

/*
 * Any relational comparison (<, <=, >=, >) involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL
  #undef FIX_BAD_NAN10_COMP_BOOL

/*
 * Any '<' comparison involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL_LT
  #undef FIX_BAD_NAN10_COMP_BOOL_LT

/*
 * Any '<=' comparison involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL_LE
  #undef FIX_BAD_NAN10_COMP_BOOL_LE

/*
 * Any '>=' comparison involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL_GE
  #undef FIX_BAD_NAN10_COMP_BOOL_GE

/*
 * Any '>' comparison involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL_GT
  #undef FIX_BAD_NAN10_COMP_BOOL_GT

/*
 * Any comparison involving a NaN must be false.  Some compilers generate
 * different code depending upon the type of either the left or the right
 * operand.  So, ld_nan < d_nan might be false and d_nan < f_nan might be
 * true.  The LDBL here really means type dependent.
 */
  #undef FIX_BAD_NAN_COMP_LDBL
  #undef FIX_BAD_NAN10_COMP_LD10

/*
 * Any comparison (<, <=, >=, >) involving a NaN must raise invalid.
 */
  #undef FIX_BAD_NAN_COMP_FLAG
  #undef FIX_BAD_NAN10_COMP_FLAG

/*
 * Any comparison involving a NaN must raise invalid.  This includes
 * comparisons involving just constants.  The compiler folded the operation
 * at compile time into true or false, but did not generate code to raise
 * invalid.  Example:  if( NAN < NAN ) must raise invalid.
 */
  #undef FIX_BAD_NAN_COMP_FLAG_CONST
  #undef FIX_BAD_NAN10_COMP_FLAG_CONST

/*
 * Any comparison involving a NaN must raise invalid.  This includes
 * comparisons involving a variable and a constant.  The compiler
 * folded the operation at compile time into true or false, but
 * did not generate code to raise invalid.  Example:  if( var < NAN )
 * must raise invalid.
 */
  #undef FIX_BAD_NAN_COMP_FLAG_VARCON
  #undef FIX_BAD_NAN10_COMP_FLAG_VARCON

/*
 * Any comparison involving a NaN must be false and raise invalid,
 * including those that have the same variable on both sides of the operator,
 * eg, if( ld_nan < ld_nan )
 */
  #undef FIX_BAD_NAN_COMP_SAME
  #undef FIX_BAD_NAN10_COMP_SAME

/*
 * Some compares involving a NaN is failing for unknown reason.
 * None of the preceding seem to cover it (no obvious pattern).
 */
  #undef FIX_BAD_NAN_COMP_UNKNOWN
  #undef FIX_BAD_NAN10_COMP_UNKNOWN

/*
 * Any equality (==, !=) involving a NaN must compare not equal:
 *   NaN == NaN is false.
 *   NaN != NaN is true.
 */
  #undef FIX_BAD_NAN_EQEQ
  #undef FIX_BAD_NAN10_EQEQ

/*
 * Any equality (==, !=) involving a NaN must be quiet (no invalid).
 */
  #undef FIX_BAD_NAN_EQEQ_FLAG
  #undef FIX_BAD_NAN10_EQEQ_FLAG

/*
 * NAN op NAN should be same as NAN, where op is: +, -, *, /.
 */
  #undef FIX_BAD_NAN_OP_NAN
  #undef FIX_BAD_NAN10_OP_NAN10

/*
 * -NAN is supposed to be minus or negative (have sign bit set).
 */
  #undef FIX_BAD_mNAN
  #undef FIX_BAD_mDEC_NAN

/*
 * NAN is supposed to be of type FLT.
 * DEC_NAN is supposed to be of type _Decimal32.
 */
  #undef FIX_NAN_FLOAT
  #undef FIX_NAN10_F10

/*
 * INFINITY is supposed to be of type FLT.
 * DEC_INFINITY is supposed to be of type _Decimal32.
 */
  #undef FIX_INF_FLOAT
  #undef FIX_INF10_F10

/*
 * Any equality (==, !=) involving an infinity must be done right.
 *   INF != INF is false.
 *   INF == INF is true.
 */
  #undef FIX_BAD_INF_EQEQ

/*
 * Status flags must be clear at program startup and after static init.
 */
  #undef FIX_FLAGS_CLEAR

/*
 * sizeof float_t and double_t should work.
 * sizeof _Decimal32_t and _Decimal64_t should work.
 */
  #undef FIX_SIZEOF_FLOAT_T
  #undef FIX_SIZEOF_DOUBLE_T
  #undef FIX_SIZEOF__DECIMAL32_T
  #undef FIX_SIZEOF__DECIMAL64_T

/*
 * Contracted (fused) multiply-add should be consistent with IEEE-754 intent.
 */
  #undef FIX_FMA_BAD

/*
 * Parameters are passed in format wider than declared type.
 */
  #undef FIX_WIDE_PARMS

/*
 * INFINITY shall be quiet, that is, not raise any exceptions.
 * DEC_INFINITY shall be quiet, that is, not raise any exceptions.
 * 1e9999999 should be a valid infinity that raises no exceptions, but is
 * not always supported.  1.0/0.0 and MAX_type*MAX_type are two other ways
 * to get infinity, but they raise exceptions.
 * #define these symbols to be the flags raised, eg,
 *   #define FIX_NOISY_INF FE_DIVBYZERO
 * The symbol IMPL_INF_FLAGS should be defined in your *.flt file to
 * the flags raised by the INF_type definitions.
 * INFINITY need not raise the same flags as INF_*.
 */
  #undef FIX_NOISY_INF
  #undef FIX_NOISY_INF10

/*
 * NAN should be quiet, that is, not raise any exceptions.
 * DEC_NAN should be quiet, that is, not raise any exceptions.
 * This is a should, not a shall, so is optional.
 * 0.0/0.0 is one way to define NAN, but it raises exceptions.
 * #define these symbols to be the flags raised, eg,
 *   #define FIX_NOISY_NAN FE_INVALID
 * The symbol IMPL_NAN_FLAGS should be defined in your *.flt file to
 * the flags raised by the NAN_type definitions.
 * NAN need not raise the same flags as NAN_*.
 */
  #undef FIX_NOISY_NAN
  #undef FIX_NOISY_DEC_NAN
  #undef IMPL_NAN_FLAGS
  #undef IMPL_NAN10_FLAGS

/*
 * HUGE_VAL* shall be quiet, that is, not raise any exceptions.
 */
  #undef FIX_NOISY_HUGE_VAL
  #undef FIX_NOISY_HUGE_VAL_D64

/*
 * HUGE_VAL* shall be infinity (for IEEE-754 FP)
 * HUGE_VAL_D* shall be infinity (for DFP)
 */
  #undef FIX_HUGE_VAL_IS_INF
  #undef FIX_HUGE_VALF_IS_INF
  #undef FIX_HUGE_VALL_IS_INF
  #undef FIX_HUGE_VAL_D32_IS_INF10
  #undef FIX_HUGE_VAL_D64_IS_INF10
  #undef FIX_HUGE_VAL_D128_IS_INF10

/*
 * Array initialized with NANs should be done correctly.
 * One compiler puts the wrong value into memory.
 */
  #undef FIX_NAN_INIT

/*
 * int ary[(int)(11.*0.9)]; is a variable length array with
 * expression using floating-point constants.  The value
 * depends upon the current rounding mode at runtime.
 * If the compiler does the constant expression at compile time,
 * define this to bypass the tests that fail.
 */
  #undef FIX_VLA_CONST_EXP

/*
 * typedef int ary[(int)(x*y)]; is a typedef with a VLA.
 * It is supposed to be evaluated once when encountered,
 * not reevaluated each time used.
 */
  #undef FIX_TYPEDEF_VLA_ONCE

/*
 * A call to an inline function must convert the arguments as if by
 * assignment.  If the conversions are not done, define this symbol.
 */
  #undef FIX_BAD_INLINE_CALL

/*
 * Some code does the wrong thing and we have not been able to figure
 * out why.  It is unknown why the test fails.  This allows it to be
 * removed for a 'clean' run.
 */
  #undef FIX_UNKNOWN

/*
 * The LCC compiler fails for some code similar to: var = 1uL op 1uLL;
 * mainly in the t016* files.  But, it is not consistent in the failures.
 */
  #undef FIX_UNKNOWN_LCC

/*
 * The Watcom compiler fails for some code similar to: macro(func(-(min-den)))
 * Drops the negate.
 */
  #undef FIX_UNKNOWN_WATCOM

/*
 * Some code, that involves bool, does the wrong thing and we have not
 * been able to figure out why.  It is unknown why the test fails.
 * This allows it to be removed for a 'clean' run.
 */
  #undef FIX_UNKNOWN_BOOL

/*
 * Conversion from (at least) unsigned long int to (at least) LDBL
 * alters the rounding direction control.  It should not.  The rounding
 * direction control should remain constant unless altered by fesetround()
 */
  #undef FIX_ROUNDING_CONSTANT

/*
 * FP operations are supposed to be to infinite precision and then
 * rounded to what FLT_EVAL_METHOD (IMPL_FLT_EVAL_OP) indicate
 * ["type"].  If instead, they are done to longer precision (1st
 * rounding) and then done to "type" (2nd rounding), then they can
 * suffer what is known as double rounding.  This only happens if the
 * 1st rounding is to a precision between "type" and 2*"type".
 */
  #undef FIX_BFP_DOUBLE_ROUNDING
  #undef FIX_DFP_DOUBLE_ROUNDING

/*
 * Trinary operator (?:) does the wrong thing with complex or imaginary types.
 */
  #undef FIX_TRI_CMPLX
  #undef FIX_TRI_IMAG

/*
 * NAN operand(s) to equality (==) or trinary (?:) or if (if()) does the wrong thing.
 * It should be false (0).  T0000800 is main test.
 */
  #undef FIX_NAN_EQUALITY_OP
  #undef FIX_NAN_TRI_OP
  #undef FIX_NAN_IF
  #undef FIX_NAN10_EQUALITY_OP
  #undef FIX_NAN10_TRI_OP
  #undef FIX_NAN10_IF

/*
 * Complex and/or imaginary types with arithmetic operations not
 * conform to Annex G.  Either kill compile or produce wrong results.
 */
  #undef FIX_CMPLX_ADD_FLAGS	/* More or less FP flags than expected */
  #undef FIX_CMPLX_ADD_IMAG	/* complex + imag */
  #undef FIX_CMPLX_ADD_RES_NAN	/* Wrong sign in NaN result from + */
  #undef FIX_CMPLX_ADD_RES_ZERO	/* Wrong sign in 0.0 result from + */
  #undef FIX_CMPLX_DIV_BAD	/* complex / complex has inf or NaN ulps error */
  #undef FIX_CMPLX_DIV_CMPLX	/* complex / complex */
  #undef FIX_CMPLX_DIV_FLAGS	/* Unusual flags from (1/z) / (1/w) */
  #undef FIX_CMPLX_DIV_IDENT3_INF/* infinity / (1.0 + 0.0*I) */
  #undef FIX_CMPLX_DIV_IDENT3_NAN/* NaN / (1.0 + 0.0*I) */
  #undef FIX_CMPLX_DIV_IDENT3_NONZERO_ULP/* min / (1.0 + 0.0*I) */
  #undef FIX_CMPLX_DIV_IDENT3_RES_ZERO/* Wrong sign in zero / (1.0 + 0.0*I) */
  #undef FIX_CMPLX_DIV_IDENT4_INF/* infinity / (0.0 + 1.0*I) */
  #undef FIX_CMPLX_DIV_IDENT4_NAN/* NaN / (0.0 + 1.0*I) */
  #undef FIX_CMPLX_DIV_IDENT4_NONZERO_ULP/* min / (0.0 + 1.0*I) */
  #undef FIX_CMPLX_DIV_IDENT4_RES_ZERO/* Wrong sign in zero / (0.0 + 1.0*I) */
  #undef FIX_CMPLX_DIV_IDENT5_LARGE/* w/w fails for large values */
  #undef FIX_CMPLX_DIV_IDENT5_SMALL/* w/w fails for large values */
  #undef FIX_CMPLX_DIV_IDENT5_NONZERO_ULP/* w/w not 1+0I */
  #undef FIX_CMPLX_DIV_IMAG	/* complex / imag */
  #undef FIX_CMPLX_DIV_REAL	/* complex / real */
  #undef FIX_CMPLX_DIV_RES_NAN	/* Wrong sign in NaN result from / */
  #undef FIX_CMPLX_DIV_RES_ZERO	/* Wrong sign in 0.0 result from / */
  #undef FIX_CMPLX_FIN_DIV_INF	/* finite / infinity */
  #undef FIX_CMPLX_FIN_DIV_INFNAN/* finite / (inf + nan*I) */
  #undef FIX_CMPLX_FIN_DIV_ZERO	/* finite / (0.0 + 0.0*I) */
  #undef FIX_CMPLX_ONE_DIV_LARGE/* 1 / (max + 0.0*I) should be very small */
  #undef FIX_CMPLX_ONE_DIV_SMALL/* 1 / (min + 0.0*I) should be inf */
  #undef FIX_CMPLX_DIV_LIMIT_RANGE/* real/complex fails with large and small numbers */
  #undef FIX_CMPLX_INFNAN_DIV_FIN/* (inf + nan*I) / finite */
  #undef FIX_CMPLX_INFNAN_DIV_ZERO/* (inf + nan*I) / (0.0 + 0.0*I) */
  #undef FIX_CMPLX_INFNAN_MUL_FIN/* (inf + nan*I) * finite */
  #undef FIX_CMPLX_INFNAN_MUL_INF/* (inf + nan*I) * (inf + 0.0*I) */
  #undef FIX_CMPLX_INF_DIV_FIN	/* (inf + inf*I) / finite */
  #undef FIX_CMPLX_INF_DIV_ZERO	/* (inf + inf*I) / (0.0 + 0.0*I) */
  #undef FIX_CMPLX_INF_DIV_ZFIN	/* (inf + inf*I) / (0.0 + finite*I) */
  #undef FIX_CMPLX_INF_MUL_INF	/* (inf + inf*I) * (inf + inf*I) */
  #undef FIX_CMPLX_INF_MUL_ZFIN	/* (inf + inf*I) * (0.0 + finite*I) */
  #undef FIX_CMPLX_MUL_BAD_NAN_RES /* unexpected NaN from non-NaN operands */
  #undef FIX_CMPLX_MUL_FLAGS	/* */
  #undef FIX_CMPLX_MUL_IDENT2_INF/* (-w)*(-z) fails for infinity */
  #undef FIX_CMPLX_MUL_IDENT2_NAN/* (-w)*(-z) fails for NaN */
  #undef FIX_CMPLX_MUL_IDENT3_INF/* infinity * (1.0 + 0.0*I) */
  #undef FIX_CMPLX_MUL_IDENT3_NAN/* NaN * (1.0 + 0.0*I) */
  #undef FIX_CMPLX_MUL_IDENT3_RES_ZERO/* Wrong sign in 0.0 result from w*(1+0*I) */
  #undef FIX_CMPLX_MUL_IDENT4_INF/* infinity * (0.0 + 1.0*I) */
  #undef FIX_CMPLX_MUL_IDENT4_NAN/* NaN * (0.0 + 1.0*I) */
  #undef FIX_CMPLX_MUL_IDENT4_RES_ZERO/* Wrong sign in 0.0 result from w*(0+I) */
  #undef FIX_CMPLX_MUL_IDENT5_FLT/* cmplx flt done wrong */
  #undef FIX_CMPLX_MUL_IDENT5_INF/* (0.0+inf*I)*(0.0-inf*I) */
  #undef FIX_CMPLX_MUL_IDENT5_LARGE/* (1.1+max*I)*(1.1-max*I) */
  #undef FIX_CMPLX_MUL_INF	/* any part is an inf and another part is a 0 */
  #undef FIX_CMPLX_MUL_IMAG	/* complex * imag */
  #undef FIX_CMPLX_MUL_LARGE	/* any part is a max */
  #undef FIX_CMPLX_MUL_REAL	/* complex * real */
  #undef FIX_CMPLX_MUL_RES_NAN	/* Wrong sign in NaN result from * */
  #undef FIX_CMPLX_MUL_RES_ZERO	/* Wrong sign in 0.0 result from * */
  #undef FIX_CMPLX_NE_ZERO	/* if(complex) fails */
  #undef FIX_CMPLX_NEGATE	/* -complex fails, so try 0-complex */
  #undef FIX_CMPLX_NEGATE2	/* 0-complex fails, so try (-1)*complex */
  #undef FIX_CMPLX_SUB_FLAGS	/* More or less FP flags than expected */
  #undef FIX_CMPLX_SUB_IMAG	/* complex - imag */
  #undef FIX_CMPLX_SUB_RES_NAN	/* Wrong sign in NaN result from - */
  #undef FIX_CMPLX_SUB_RES_ZERO	/* Wrong sign in 0.0 result from - */
  #undef FIX_CMPLX_ZERO_DIV_FIN	/* (0.0 + 0.0*I) / (fin + fin*I) */
  #undef FIX_CMPLX_ZERO_DIV_FINNAN/* (0.0 + 0.0*I) / (fin + NaN*I) */
  #undef FIX_CMPLX_ZERO_DIV_INF	/* (0.0 + 0.0*I) / infinity */
  #undef FIX_CMPLX_ZERO_DIV_INFNAN/* (0.0 + 0.0*I) / (inf + NaN*I) */
  #undef FIX_CMPLX_ZERO_DIV_LARGE/* (0.0 + 0.0*I) / (0.0 + max*I) */
  #undef FIX_CMPLX_ZERO_DIV_SMALL/* (0.0 + 0.0*I) / (0.0 + min*I) */
  #undef FIX_CMPLX_ZERO_DIV_ZFIN/* (0.0 + 0.0*I) / (0.0 + fin*I) */
  #undef FIX_IMAG_ADD_CMPLX	/* imag + complex */
  #undef FIX_IMAG_ADD_IMAG	/* imag + imag */
  #undef FIX_IMAG_ADD_REAL	/* imag + real */
  #undef FIX_IMAG_DIV_CMPLX	/* imag / complex */
  #undef FIX_IMAG_DIV_IMAG	/* imag / imag */
  #undef FIX_IMAG_DIV_REAL	/* imag / real */
  #undef FIX_IMAG_MUL_CMPLX	/* imag * complex */
  #undef FIX_IMAG_MUL_IMAG	/* imag * imag */
  #undef FIX_IMAG_MUL_REAL	/* imag * real */
  #undef FIX_IMAG_SUB_CMPLX	/* imag - complex */
  #undef FIX_IMAG_SUB_IMAG	/* imag - imag */
  #undef FIX_IMAG_SUB_REAL	/* imag - real */
  #undef FIX_REAL_ADD_IMAG	/* real + imag */
  #undef FIX_REAL_DIV_CMPLX	/* real / complex */
  #undef FIX_REAL_DIV_IMAG	/* real / imag */
  #undef FIX_REAL_MUL_CMPLX	/* real * complex */
  #undef FIX_REAL_MUL_IMAG	/* real * imag */
  #undef FIX_REAL_SUB_IMAG	/* real - imag */

/*
 * _Generic ignores bit-field widths; uses the base type.
 * Bit-fields cannot be denoted as a type-name, so cannot match in _Generic.
 */
  #undef FIX_GENERIC_BITFIELD

/*
 * _Generic ignores enums.
 */
  #undef FIX_GENERIC_ENUM

/*
 * _Generic is supposed to ignore qualifiers.
 */
  #undef FIX_QUAL_GENERIC

/*
 * _Generic is supposed to work with arrays and strings
 * (which are an array of chars);  (converted to pointer).
 */
  #undef FIX_GENERIC_ARRAY

/*
 * _Generic is supposed to work with functions (converted to pointer).
 */
  #undef FIX_GENERIC_FUNC

/*** Run time: C99: input/output library function problems ***/
/*
 * Many of these are above in the C89/C90/C95 section;
 * see *_SCAN2BIN_ULPS, ...
 */

/*
 * If the error in binary (internal) to decimal/hex (external) to
 * binary (internal) roundtrip conversion is so large that it cannot
 * be represented as a long int (used during pre-processor), then
 * define this symbol as a DBL value, e.g.,
 * #define FIX_BIN2HEX2BIN_LARGE 2.0e9
 * This is useful if most conversions have a small error (bypassed by
 * *_BIN2DEC2BIN_ULPS) and a few conversions with large error (bypassed
 * by this symbol).  This ignores errors LARGER than the macro's
 * value.
 */
  #undef FIX_BIN2HEX2BIN_LARGE

/*
 * Binary (internal) to decimal/hex (external) to binary (internal)
 * roundtrip conversions by runtime (printf and scanf) of some numbers
 * is off by a factor of two (either too high or too low).
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_BIN2DEC2BIN_TWICE
  #undef FIX_BIN2HEX2BIN_TWICE
  #undef FIX_DFP2DEC2DFP_TWICE

/*
 * %a and/or %A have an exponent of the wrong form, so bypass them.
 * Most common cause is minimum exponent is 2 digits (should be 1 digit),
 * or has hexadecimal digits in exponent.
 */
  #undef FIX_PRINTF_aA_HAS_EXPONENT
  #undef FIX_WPRINTF_aA_HAS_EXPONENT

/*
 * %a and/or %A have an exponent that is missing the required sign.
 */
  #undef FIX_PRINTF_aA_HAS_EXP_SIGN
  #undef FIX_WPRINTF_aA_HAS_EXP_SIGN

/*
 * The first hex digit of %a and/or %A has a value bigger than allowed
 * based upon IMPL_aA_BITS or IMPL_LaA_BITS.
 */
  #undef FIX_PRINTF_aA_HAS_BIG_HEX_DIG
  #undef FIX_WPRINTF_aA_HAS_BIG_HEX_DIG

/*
 * The first nonzero hex digit of %a and/or %A has a non-hex value.
 */
  #undef FIX_PRINTF_aA_HAS_BAD_HEX_DIG
  #undef FIX_WPRINTF_aA_HAS_BAD_HEX_DIG

/*
 * %a and/or %A, even for subnormals, need to have one hex digit
 * before the '.'
 */
  #undef FIX_PRINTF_aA_HEX_DOT
  #undef FIX_WPRINTF_aA_HEX_DOT

/*
 * rc = snprintf(s,n,fmt,values);
 * has problems for n=0 or n is too small (< rc).
 */
  #undef FIX_SMALL_snprintf
  #undef FIX_ZERO_snprintf
  #undef FIX_ERROR_snprintf

/*** Run time: C99: math library function problems ***/

/*
 * Math library function raises underflow for non-underflow results.
 * This is a spurious underflow (which is prohibited by 7.12.1p1,
 * F.7.6p1, and F.9p9).
 */
  #undef FIX_BAD_UF_GOT_acos
/* ... thru ... */
  #undef FIX_BAD_UF_GOT_trunc
  #undef FIX_BAD_UF_GOT10_acos
/* ... thru ... */
  #undef FIX_BAD_UF_GOT10_trunc

/*
 * errno should be consistent with FP exception flags
 */
  #undef FIX_ERRNO_MATH_acos
/* ... thru ... */
  #undef FIX_ERRNO_MATH_trunc
  #undef FIX_ERRNO_MATH10_acos
/* ... thru ... */
  #undef FIX_ERRNO_MATH10_trunc

/*
 * nan("") should be same as NAN
 * nand64("") should be same as DEC_NAN
 */
  #undef FIX_FUNCS_nan_NAN
  #undef FIX_FUNCS10_nan_NAN

/*
 * nan*("chars") shall be same as strto*("NAN(chars)",0)
 */
  #undef FIX_FUNCS_nan_strto
  #undef FIX_FUNCS10_nan_strto

/*
 * Points near an axis cause problems, eg, cpow(.7+I*.7, 2+I*8e-25)
 */
  #undef FIX_ARG2_NEAR_AXIS_cpow

/*
 * Numbers near 1.0 cause problems, eg, pow(1.+ulp,large), pow(1.-ulp,large)
 * This applies to arguments and/or results.
 */
  #undef FIX_ARG_NEAR_1_acos
  #undef FIX_ARG_NEAR_1_frexp
  #undef FIX_ARG_NEAR_1_logb
  #undef FIX_ARG_NEAR_1_modf
  #undef FIX_ARG_NEAR_1_nearbyint
  #undef FIX_ARG1_NEAR_1_cpow
  #undef FIX_ARG1_NEAR_1_pow
  #undef FIX_RES_NEAR_1_frexp

/*
 * Numbers near -1.0 cause problems, eg, log1p(-(1.-ulp))
 */
  #undef FIX_ARG_NEAR_m1_log1p
  #undef FIX_ARG_NEAR_m1_log10p1
  #undef FIX_ARG_NEAR_m1_log2p1
  #undef FIX_ARG_NEAR_m1_logp1

/*
 * pow(+/-0.0,-INF) raises flags (should be quiet)
 */
  #undef FIX_POW_0_MINF		/* pow(+/-0.0,-INF) wrong */

/*
 * The math library functions are not supposed to alter the FPU
 * control modes.  If a function does, this bypasses those tests.
 * Only a few functions have needed this so far.
 */
  #undef FIX_MODES_fma
  #undef FIX_MODES_lrint
  #undef FIX_MODES_llrint
  #undef FIX_MODES_tan
  #undef FIX_MODES10_tan

/*
 * There are identities between pairs of complex math functions.
 * There are other symbols to take care of a few ulp errors.
 * These are for gross ulp errors.
 */
  #undef FIX_cabs_hypot
  #undef FIX_cacos_cacosh
  #undef FIX_carg_atan2
  #undef FIX_casin_casinh
  #undef FIX_catan_catanh
  #undef FIX_ccos_ccosh
  #undef FIX_csin_csinh
  #undef FIX_ctan_ctanh


/*** Run time: C99: other library function problems ***/

/*
 * The relational macros (isless(), ...) have problems, so have
 * your *.flt file redefine them.
 */
  #undef FIX_REL_MACROS

/*
 * The classification macros (isnan(), ...) have problems, so have
 * your *.flt file redefine them.
 */
  #undef FIX_CLASS_MACROS

/*
 * Pseudo-denormals on x87 are mis-classified as denormals (they are
 * really normals as far as the value is concerned).  Or, cause core dump.
 */
  #undef FIX_CLASS_PSEUDO_DEN

/*
 * Pseudo-INF on x87 are mis-classified as INF (really a signaling NaN),
 * or, cause core dump.
 */
  #undef FIX_CLASS_PSEUDO_INF

/*
 * Pseudo-NaNs on x87 are mis-classified as quiet NaN, or, cause core dump.
 */
  #undef FIX_CLASS_PSEUDO_NAN

/*
 * Signaling NaNs on x87 are mis-classified as quiet NaN, or, cause core dump.
 */
  #undef FIX_CLASS_SIGNAL_NAN

/*
 * Unnormals on x87 are mis-classified as normal (really signaling NaN),
 * or, cause core dump.
 */
  #undef FIX_CLASS_UNNORMALS

/*
 * Normals in smallest binade are mis-classified as subnormals
 */
  #undef FIX_CLASS_MIN_NORMALS

/*
 * Function is supposed to alter the rounding direction or indicate the
 * current rounding direction.
 */
  #undef FIX_RND_fesetround
  #undef FIX_RND_fegetround
  #undef FIX_RND_fe_dec_setround
  #undef FIX_RND_fe_dec_getround

/*
 * Function is supposed to return a success/failure value.  That value
 * has changed as C9X evolved.  Use this if the function does the
 * correct action, but returns the wrong success/failure value.
 */
  #undef FIX_BAD_RET_fesetexcept
  #undef FIX_BAD_RET_fesetround
  #undef FIX_BAD_RET_feupdateenv
  #undef FIX_BAD_RET_feraiseexcept
  #undef FIX_BAD_RET_fe_dec_setround

/*
 * Library function not raise any flags as expected.
 */
  #undef FIX_FLAGS_feraiseexcept

/*
 * feraiseexcept() first clears all the flags,
 * then raises the requested ones.
 */
  #undef FIX_CLEAR_THAN_RAISE

/*
 * isnan( NAN_FLT ) fails or corrupts stack (failure at later return).
 */
  #undef FIX_fpclassify_WITH_FLT_CONST
  #undef FIX_isfinite_WITH_FLT_CONST
  #undef FIX_isinf_WITH_FLT_CONST
  #undef FIX_isnan_WITH_FLT_CONST
  #undef FIX_isnormal_WITH_FLT_CONST
  #undef FIX_signbit_WITH_FLT_CONST
  #undef FIX_fpclassify_WITH_F10_CONST
  #undef FIX_isfinite_WITH_F10_CONST
  #undef FIX_isinf_WITH_F10_CONST
  #undef FIX_isnan_WITH_F10_CONST
  #undef FIX_isnormal_WITH_F10_CONST
  #undef FIX_issubnormal_WITH_FLT_CONST
  #undef FIX_issubnormal_WITH_F10_CONST
  #undef FIX_signbit_WITH_F10_CONST

/*** Run time: DFP ***/
/*** Run time: DFP: value of constant problems ***/

/*
 * Unsuffixed decimal (not hexadecimal) DBL constants
 * should be treated as per #pragma STDC FLOAT_CONST_DECIMAL64.
 * gcc 4.3.2 treats them as DFP (perhaps like TTDT).
 */
  #undef FIX_UNSUFFIX_AS_DFP
  #undef FIX_UNSUFFIX_AS_BFP

/*
 * Decimal constants may have many representations (quantums).
 * If the quantem exponent is wrong, define this symbol.
 */
  #undef FIX_QUANTUM_EXP

/*** Run time: DFP: code generation problems ***/

/*
 * Conversion/promotion/cast/assignment from one type (y) to another
 * type (x) should be supported, e.g., x=y, or (x)y.  It either kills
 * compile if not supported, or produces the wrong result at run time.
 * x, y may be one of: LD10, D10, F10, [U|S]LLI, [U|S]LI, [U|S]I, [U|S]SI,
 * [U|S|P]C, ENUM, [U|S]B{its}.  Use FP10 or DFP if all of LD10/D10/F10 apply.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_CMPLX_FROM_DFP
  #undef FIX_D10_FROM_SLI
  #undef FIX_D10_FROM_SLLI
  #undef FIX_D10_FROM_UI
  #undef FIX_D10_FROM_ULI
  #undef FIX_D10_FROM_ULLI
  #undef FIX_DFP_FROM_CMPLX
  #undef FIX_ENUM_FROM_CMPLX10
  #undef FIX_ENUM_FROM_FP10
  #undef FIX_F10_FROM_SI
  #undef FIX_F10_FROM_SLI
  #undef FIX_F10_FROM_SLLI
  #undef FIX_F10_FROM_UI
  #undef FIX_F10_FROM_ULI
  #undef FIX_F10_FROM_ULLI
  #undef FIX_FP10_FROM_ULLI
  #undef FIX_LD10_FROM_SLI
  #undef FIX_LD10_FROM_SLLI
  #undef FIX_LD10_FROM_UI
  #undef FIX_LD10_FROM_ULI
  #undef FIX_LD10_FROM_ULLI
  #undef FIX_ULI_FROM_F10
  #undef FIX_ULLI_FROM_F10

/*
 * Units Last Place error allowed for decimal FP to binary FP conversion
 * done at runtime.
 * Should be a binary FP number (such as FP_D(0.) or FP_F(1.)).
 * The leading type is the converted TO type.
 */
  #undef LDBL_DFP2BFP_ULPS
  #undef  DBL_DFP2BFP_ULPS
  #undef  FLT_DFP2BFP_ULPS

/*
 * Units Last Place error allowed for binary FP to decimal FP conversion
 * done at runtime.
 * Should be a decimal FP number (such as FP_D10(0.) or FP_F10(1.)).
 * The leading type is the converted TO type.
 * Implementations with perfect conversion should have these be 0. (not .5).
 */
  #undef LD10_BFP2DFP_ULPS
  #undef  D10_BFP2DFP_ULPS
  #undef  F10_BFP2DFP_ULPS

/*
 * Simulating decimal FP on a binary FP system produces poor results.
 * This bypasses the worst of the tests.  Mainly used by Tydeman to
 * develope decimal FP tests on his binary FP systems.
 */
  #undef FIX_BAD_FAKE_DECFP
  #undef FIX_D10_ADD
  #undef FIX_D10_MULT
  #undef FIX_F10_ADD
  #undef FIX_F10_MULT
  #undef FIX_LD10_ADD
  #undef FIX_LD10_MULT

/*
 * This determines if F10 promotes to F10 or D10 in function call with
 * var args.  If you get a core dump from t6160322, try this symbol.
 */
  #undef FIX_F10_PROMOTE2_D10

/*
 * if( ZERO_* ) should be false.  gcc thinks it is true.
 */
  #undef FIX_ZERO_DFP_IS_TRUE

/*
 * if( ONE_* - ONE_* ) should be false.  gcc thinks it is true.
 * ( false - ZERO_* ) should be false.  gcc thinks it is true.
 */
  #undef FIX_ZERO_DFP_EXP_IS_TRUE

/*
 * DFP operations should raise FP exception flags the same as BFP.
 * fetestexcept(), feclearexcept() do exist and work (for BFP operations).
 * gcc's DFP emulation mostly leaves the flags alone.
 */
  #undef FIX_DFP_FLAGS

/*
 * DFP operations should raise FP exception flags the same as BFP.
 * These are for basic math operations that do the flags wrong.
 */
  #undef FIX_DFP_FLAGS_ADD
  #undef FIX_DFP_FLAGS_SUB
  #undef FIX_DFP_FLAGS_MUL
  #undef FIX_DFP_FLAGS_DIV

/*
 * Integer op DFP should be done correctly.
 */
  #undef FIX_INT_PLUS_EQ_DFP

/*** Run time: DFP: input/output library function problems ***/
/*
 * [w]printf should support DFP of the three types.
 */
  #undef FIX_PRINT_F10
  #undef FIX_WPRINT_F10
  #undef FIX_PRINT_D10
  #undef FIX_WPRINT_D10
  #undef FIX_PRINT_LD10
  #undef FIX_WPRINT_LD10

/*** Run time: DFP: math library function problems ***/

/*
 * IEEE-754-2008 specifies the preferred quantum exponent of the result for
 * some algebraic functions (but no transcendental functions).
 * Some of us are extending that to other functions.
 * These symbols are for functions that get it wrong.
 */
  #undef FIX_QUANTEXP_cbrt
  #undef FIX_QUANTEXP_sqrt
  #undef FIX_QUANTEXP_rsqrt

/*** Run time: DFP: other library function problems ***/

/*
 * Rounding modes for binary and decimal are supposed to be independent
 * of each other.  If changing one affects the other, define this symbol.
 */
  #undef FIX_BIN_DEC_RND_DEPENDS

/*** Run time: C11 (was C1x) ***/
/*** Run time: C11: code generation problems ***/
/*** Run time: C11: library function problems ***/

/*** Run time: C17 (was C1x) ***/
/*** Run time: C17: code generation problems ***/
/*** Run time: C17: library function problems ***/

/*** Run time: CFP (C Floating Point for IEEE-754-2008) ***/
/*** Run time: CFP: code generation problems ***/
/*** Run time: CFP: library function problems ***/

/*
 * SNAN, -SNAN, and +SNAN should NOT trigger it.
 * All other operations applied to (uses of) SNAN should trigger it.
 * clang has any expression involving an SNAN be a SNAN (not QNAN).
 */
  #undef FIX_SNAN_EXPRESSION

/*
 * issignaling(SNANF)
 * issignaling(SNAN)
 * should not trigger.  That is hard to do on Intel x87.
 */
  #undef FIX_SNAN_FLT
  #undef FIX_SNAN_DBL

/*
 * strfromf(FLT hex)
 * strfromd(DBL hex)
 * strfroml(LDBL hex)
 */
  #undef FIX_FaA_PREC
  #undef FIX_aA_PREC
  #undef FIX_LaA_PREC

/*
 * <fenv.h> typedefs are supposed to be defined.
 */
  #undef FIX_TYPEDEF_femode_t

/*** Run time: C2X ***/
/*** Run time: C2X: code generation problems ***/
/*** Run time: C2X: library function problems ***/

/*** Defect Reports: C standard may be changed ***/

/*
 * Cases where the C standard may change required behaviour.
 *   cacosh( 0.0 + I*NAN )
 *   ctanh( 0.0 + I*NAN )
 *   ctanh( 0.0 + I*INF )
 */
  #undef FIX_STD_DR471

/*
 * Keep (before DR) or drop (after DR) type qualifiers on function definitions.
 */
  #undef FIX_STD_DR423


  #if (defined PERENNIAL)
    #include "tsthd.h"
  extern int locflg;
  #endif

/****************************************************************/
/* Lint/compile (but not link/run) non-standard data formats	*/
/* used on machines other than the x86 development system.	*/
/* This is used to find obvious typos before we ship the code.	*/
/* Can be used with hex or dec via compiler name in makefile.	*/
/****************************************************************/
  #if (defined DO_106_113)
    #include "do106113.bug"	/* Compile time workarounds */

/****************************************************************/
/* For compilers that never heard of <fenv.h>.			*/
/****************************************************************/
  #elif (defined FENV_MISSING)
    #include "sample3.bug"

/****************************************************************/
/* Quick and dirty setup for sample tests.			*/
/****************************************************************/
  #elif (defined FPCE_SAMPLE)
    #include "sample.bug"

/**********************************************************************/
/* clang: Built on top of other compiler's headers and libraries.     */
/**********************************************************************/
  #elif (defined __clang__)
    #include "clang.bug"

/**********************************************************************/
/* PCC: Built on top of other compiler's headers and libraries.	      */
/**********************************************************************/
  #elif (defined __PCC__)
    #include "pcc.bug"

/**********************************************************************/
/* LCC: 32-bit Windows						      */
/**********************************************************************/
  #elif (defined __LCC__)
    #include "lcc.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Watcom: DOS, Win*, OS/2					      */
/**********************************************************************/
  #elif (defined __WATCOMC__)
    #include "watcom.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Metrowerks; Both Mac and Intel				      */
/**********************************************************************/
  #elif (defined __MWERKS__)
    #include "metrowks.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Diab Data C cross compiler					      */
/**********************************************************************/
  #elif (defined __DCC__)
    #include "diab.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Sun: Sparc (32-bit & 64-bit), 32-bit x86, 64-bit ia64	      */
/**********************************************************************/
  #elif (defined __sun) || (defined __SUNPRO_C)
    #include "sun.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Tandem							      */
/**********************************************************************/
  #elif (defined __TANDEM)
    #include "tandem.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* CRAY; UNICOS; Cray Standard C/C++ from Programming Environment 2.0 */
/**********************************************************************/
  #elif (defined _CRAYIEEE) /* && (defined ?? ) // need compiler name */
    #include "cray0200.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* IBM S/390; MVS; IBM C/C++					      */
/**********************************************************************/
  #elif (defined __HOS_MVS__) || (defined __TOS_MVS__)
    #include "ibm390.bug"	/* defines to bypass known bugs */

/**********************************************************************/
/* Lund MultiProcessor Compiler: PowerPC			      */
/**********************************************************************/
  #elif (defined __LMPCC__)
    #include "lmpcc.bug"

/*******************************************************************/
/* Apple Mac == PowerPC; Mac OS X; gcc in C or C++ mode		   */
/*******************************************************************/
  #elif (defined __POWERPC__) && (defined __MACH__) && (defined __GNUC__)
    #include "macgcc.bug"

/****************************************************************/
/* Apple Mac == PowerPC; Mac OS X; IBM VA in either C or C++ mode*/
/****************************************************************/
  #elif (defined __PPC__) && (defined __MACH__) \
     && (defined __IBMC__ || defined __IBMCPP__)
    #include "macibm.bug"

/*******************************************************************/
/* POWER or PowerPC; AIX; Taligent CompTech C/C++ in C or C++ mode */
/*******************************************************************/
  #elif (defined __PPC__) \
    && ((defined __TaligentC__) || (defined __TaligentCPlusPlus__))
    #include "taligent.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* POWER; AIX; IBM xlC C/C++ in either C or C++ mode		*/
/* POWER; AIX; IBM xlc C in C mode				*/
/****************************************************************/
  #elif ((defined __PPC__) || (defined _IBMR2)) \
     && ((defined __xlc__) ||(defined __xlc) || (defined __XLCPP))
    #include "ibm6xlc.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* PA, Itanium; HP UX; HP C/C++ in either C or C++ mode		*/
/****************************************************************/
  #elif (defined __hppa)
    #include "hppa.bug"		/* defines to bypass known bugs */
  #elif (defined __ia64) && (defined __hpux)
    #include "hpux.bug"		/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; OS/2; IBM C Set++ in either C or C++ mode		*/
/****************************************************************/
  #elif (defined _M_I386) && (defined __IBMC__ || defined __IBMCPP__)
    #include "ibm2cset.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; Linux; Intel icc in C or C++				*/
/****************************************************************/
  #elif ((defined __i386__)||(defined __x86_64__)) \
      && (defined __linux__) && (defined __ICC)
    #include "intel.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; Linux; GNU gcc in C or C++				*/
/****************************************************************/
  #elif ((defined __i386__)||(defined __x86_64__)) \
      && (defined __linux__) && (defined __GNUC__)
    #include "gcclinux.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; OS/2; GNU gcc 2.7.2.1 + emx 0.9c + fix02 in C or C++	*/
/* 80x86; OS/2; GNU gcc 2.5.7 + emx 0.8h in C or C++ mode	*/
/****************************************************************/
  #elif (defined __i386__) && (defined __EMX__)
    #include "gcc_emx.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; DOS or WinXX; Microsoft C/C++ 4.0 in C or C++ mode	*/
/****************************************************************/
  #elif (defined _MSC_VER)
    #include "microsft.bug"

/****************************************************************/
/* 80x86; WinXX; Digital Mars C/C++ 8.0 in either C or C++ mode	*/
/* Must come before Symantec (since compiler defines __SC__)	*/
/****************************************************************/
  #elif (defined __I86__) && (defined __DMC__)
    #include "digmars.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; DOS; Symantec C/C++ 7.0 in either C or C++ mode	*/
/****************************************************************/
  #elif (defined __I86__) && (defined __SC__)
    #include "symantec.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; DOS; Borland C/C++ 4.01 in C or C++ mode; 1993 version*/
/* 80x86; DOS; Borland Turbo C 2.01 (1988 version)		*/
/****************************************************************/
  #elif (defined __X86__) && ((defined __TURBOC__) || (defined __BORLANDC__))
    #include "borland.bug"	/* defines to bypass known bugs */

/**********************************************************************/
/* ARM								      */
/**********************************************************************/
  #elif (defined __arm__)
    #include "arm.bug"

/**********************************************************************/
/* Comeau Computing						      */
/**********************************************************************/
  #elif (defined __COMO__)
    #include "comeau.bug"

/**********************************************************************/
/* Edison Design Group; must be near end as others build upon it      */
/**********************************************************************/
  #elif (defined __EDG__)
    #include "edg.bug"

/****************************************************************/
/* Gnu C based implementation (general case)			*/
/****************************************************************/
  #elif (defined __GNUC__)
    #include "gcc.bug"

  #else	/*==================ERROR===============================*/

    #error Unknown hardware + software combination.
    #error Add a pair of #elif and #include lines similar to above pairs.
    #error The file to include needs lines like the sample*.bug files.
    #include "yourfile.bug"	/* defines to bypass known bugs */

  #endif

  /*
   * Define LMS_* symbols in terms of STDC_* symbols.
   * These are used since not allowed to #define STDC_* symbols.
   */
  #if (!defined LMS_IEC_60559_BFP__) && (defined __STDC_IEC_60559_BFP__)
    #define     LMS_IEC_60559_BFP__              __STDC_IEC_60559_BFP__
  #endif

  #if (!defined LMS_IEC_559__) && (defined __STDC_IEC_559__)
    #define     LMS_IEC_559__              __STDC_IEC_559__
  #endif

  #if (!defined LMS_IEC_60559_COMPLEX__) && (defined __STDC_IEC_60559_COMPLEX__)
    #define     LMS_IEC_60559_COMPLEX__              __STDC_IEC_60559_COMPLEX__
  #endif

  #if (!defined LMS_IEC_559_COMPLEX__) && (defined __STDC_IEC_559_COMPLEX__)
    #define     LMS_IEC_559_COMPLEX__              __STDC_IEC_559_COMPLEX__
  #endif

  #if (!defined LMS_IEC_60559_DFP__) && (defined __STDC_IEC_60559_DFP__)
    #define     LMS_IEC_60559_DFP__              __STDC_IEC_60559_DFP__
  #endif

  #if (!defined LMS_DEC_FP__) && (defined __STDC_DEC_FP__)
    #define     LMS_DEC_FP__              __STDC_DEC_FP__
  #endif

/*
 * Work around for fetestexcept() or feclearexcept() missing or very bad.
 */
  #if (defined FIX_FUNC_fetestexcept)	\
   || (defined FIX_FUNC_feclearexcept)	\
   || (defined FIX_FLAG_fetestexcept)	\
   || (defined FIX_FLAG_feclearexcept)
    #define FIX_FE_FLAGS
    #define FIX_DFP_FLAGS
  #endif

/*
 * What needs to be done at program startup to match FPCE document?
 * Most likely, will need to disable trapping.
 * This defines the default macros (if not already defined)
 * to be used by SETUP2 in main().
 */

  #ifdef NEED_FLAGS_CLEARED
    #ifndef   FPU_CLEAR_FLAGS
      #define FPU_CLEAR_FLAGS	CLEAR_ALL;
    #endif
  #else
    #define FPU_CLEAR_FLAGS
  #endif

  #ifdef NEED_ROUND_SET
    #ifndef   FPU_SET_ROUNDING
      #define FPU_SET_ROUNDING (void)fesetround(FE_TONEAREST);
    #endif
  #else
    #define FPU_SET_ROUNDING
  #endif

  #ifdef NEED_PREC_SET	/* May depend upon FLT_EVAL_METHOD of <float.h> */
    #ifndef   FPU_SET_PRECISION
      #define FPU_SET_PRECISION (void)fesetprec(FE_LDBLPREC);
    #endif
  #else
    #define FPU_SET_PRECISION
  #endif

  #ifdef NEED_TRAPS_DISABLED
    #ifndef   FPU_DISABLE_TRAPS /* could also be: (void)feholdexcept( &current_fenv ); */
      #define FPU_DISABLE_TRAPS (void)fedisabletrap(FE_TRAP_ALL);
    #endif
  #else
    #define FPU_DISABLE_TRAPS
  #endif

/*
 * For those machines that only have two 'hardware' floating point types,
 * the existing compiler has two mappings.  Either float and DBL are
 * the smaller type or DBL and LDBL are the larger type.  Also,
 * some systems do not yet have the LDBL versions of the math
 * functions, isnan(LDBL var) in particular, or allocate the wrong
 * number of bytes for LDBL vars or literals.  These defines allow
 * you to tailor the mapping of the 3 floating point types in C to the
 * 2 or 3 compiler/hardware supported floating point types.  They also
 * allow partial testing until the compiler supports more of FPCE/C99.
 * REMAP_* affects types, literal constants, and function names.
 *
 * For LDBL, there are three choices (from best to worst):
 * 1) LDBL is fully supported and has more precision than DBL:
 *	#undef  REMAP_LDBL
 *	#undef  IMPL_LDBL_EQ_DBL
 * 2) LDBL is fully supported, but has same precision as DBL:
 *	#undef  REMAP_LDBL
 *	#define IMPL_LDBL_EQ_DBL
 * 3) LDBL is not supported or support is very bad (=> do not use):
 *	#define REMAP_LDBL
 *	#define IMPL_LDBL_EQ_DBL
 *	#define FIX_LDBL
 *	#define FIX_FUNCS_L
 *
 * For those implementations that have four floating-point types, such as:
 *   Type(1)      Type(2)     Size Precision RegisterPrec
 *   float        float        32   24       113, 64, 53, or 24
 *   double       double       64   53       113, 64 or 53
 *   long double  extended     80   64       113 or 64
 *   quad         long double 128  113       113
 * the use of LDBL allows you to test either of long double, extended or quad;
 * the use of  DBL allows you to test either of      double or extended.
 * See sample2.flt and sample2.bug and QUAD_LDBL or QUAD_DBL.
 * Some ways to map four types to three names:
 *   FLT=float; DBL=double;   LDBL=long double [default]
 *   FLT=float; DBL=double;   LDBL=quad
 *   FLT=float; DBL=double;   LDBL=extended
 *   FLT=float; DBL=extended; LDBL=long double
 */

  #ifdef REMAP_LDBL
    #undef  LDBL
    #define LDBL	double		/* get rid of LDBL type */
    #define IMPL_LDBL_EQ_DBL
    #define FIX_LDBL
    #define FIX_FUNCS_L			/* get rid of LDBL functions */
    #define SIZ_LDBL SIZ_DBL
  #else
    #ifndef   LDBL			/* allow user to map LDBL to quad type */
      #define LDBL	long double
    #endif
  #endif

  #ifdef REMAP_DBL			/* not supported yet */
    #undef  DBL
    #define DBL		long double
    #define IMPL_LDBL_EQ_DBL
    #define SIZ_DBL SIZ_LDBL
  #else
    #ifndef   DBL			/* allow user to map DBL to extended type */
      #define DBL	double
    #endif
  #endif

  #ifndef   FLT
    #define FLT		float
  #endif

/*
 * FPCE Technical Report (TR) used #pragma's as a means for the programmer
 * to control the compiler's code generation.  Tests were written for each
 * of these pragmas.  Those tests need to not invoke the pragmas in some
 * cases, so there are means to do that here (most tests take the values
 * shown here, so the default action is to invoke all pragmas). When the
 * FPCE TR got adopted into C99, the three fp_wide_* pragmas went away (an
 * implementation may optionally support them, but they are not required).
 * fenv_access pragma became FENV_ACCESS_* macros in <fenv.h> and
 * fp_contract pragma became FP_CONTRACT_* macros in <math.h>.
 * The default invocation of these macros is now done in myfloat.h
 * Then with WG14/N631, they were changed back to pragmas, but of a new form.
 */
  #include "fenvon.h"
  #include "fpconoff.h"

/*
 * <math.h> translation directives are supposed to be defined.
 * No longer test these as they have been replaced with pragmas.
 */
  #if (19970207uL <= FPCE_TEST_LVL)
    #define FIX_SYM_FP_CONTRACT_ON
    #define FIX_SYM_FP_CONTRACT_OFF
    #define FIX_SYM_FP_CONTRACT_DEFAULT
  #endif

/*
 * <fenv.h> translation directives are supposed to be defined.
 * No longer test these as they have been replaced with pragmas.
 */
  #if (19970207uL <= FPCE_TEST_LVL)
    #define FIX_SYM_FENV_ACCESS_ON
    #define FIX_SYM_FENV_ACCESS_OFF
    #define FIX_SYM_FENV_ACCESS_DEFAULT
  #endif

/*
 * These next three are in the Technical Report only.  Not part of C99.
 */
  #if (!defined FIX_PRAGMAS) \
   && (!defined FIX_PRAGMA_WIDE_RETURNS) \
   && (defined TEST_WIDE_RETURNS)
    #pragma fp_wide_function_returns off
  #endif
  #if (!defined FIX_PRAGMAS) \
   && (!defined FIX_PRAGMA_WIDE_PARMS) \
   && (defined TEST_WIDE_PARMS)
    #pragma fp_wide_function_parameters off
  #endif
  #if (!defined FIX_PRAGMAS) \
   && (!defined FIX_PRAGMA_WIDE_VARS) \
   && (defined TEST_WIDE_VARS)
    #pragma fp_wide_variables off
  #endif

/*
 * This is default, but do it to see what happens.
 * May need to move to file like fpconoff.h
 */
  #if (!defined FIX_PRAGMAS) && (!defined FIX_PRAGMA_CX_LIMIT)
    #pragma STDC CX_LIMITED_RANGE OFF
  #endif

/*
 * In the FPCE Technical Report (TR), many new macros and functions were
 * added in a new header <fp.h>.  When the TR got adopted into C99, those
 * were moved into <math.h>.  To allow testing of compilers during the
 * transition from fp.h to math.h, which header is included is defined here.
 * FP_H can be defined in the compiler specific sections above if needed.
 */
  #ifndef FP_H
    #if FPCE_TEST_LVL >= 19960226uL
      #define FP_H <math.h>
    #else
      #define FP_H <fp.h>
    #endif
  #endif

/*
 * For users testing compilers that do not yet support <fenv.h> as a
 * standard header (in a standard directory), this allows then to do:
 * #define FENV_H "fenv.h"
 * in their bug definition file.  This then uses the fenv.h in the
 * local directory.
 */
  #ifndef FENV_H
    #define FENV_H <fenv.h>
  #endif

/*
 * At the February, 1997, meeting of WG14 / X3J11, Type-Generic Math
 * Functions, WG14/N639, X3J11/97-002, was voted to be included into
 * C99 subject to a review committee and final wording to be voted on
 * by the full committee at the June, 1997 meeting.
 *
 * For users testing compilers that do not yet support <tgmath.h> as a
 * standard header (in a standard directory), this allows then to do:
 * #define TG_MATH_H "tgmath.h"
 * in their bug definition file.  This then uses the tgmath.h in the
 * local directory.
 *
 * tgmath.h will only be used if FIX_OVERLOAD is not defined.
 */
  #ifndef TG_MATH_H
    #define TG_MATH_H <tgmath.h>
  #endif

/*
 * Is now part of C99.  This header defines typedefs and macros useful for
 * exact size integers.  This test suite uses it for unions of floating-
 * point types with specific sized integers to create specific bit patterns
 * in the floating-point numbers.  Since not all vendors define this header,
 * the compiler specific sections above can define INTTYPES_H to map to
 * whatever header file is needed.
 */
  #ifndef   INTTYPES_H
    #define INTTYPES_H <inttypes.h>
  #endif

  #if FPCE_TEST_LVL >= 19960226uL

    #if	(!defined FIX_SYM_STDC_IEC_559__)	\
     && (!defined FIX_SYM_FLT_EVAL_METHOD)
      #define TESTSYMS "testsyms.h"
    #endif

  #else /* FPCE_TEST_LVL < 19960226uL */

    #if	(!defined FIX_SYM___FPCE__)		\
     && (!defined FIX_SYM___FPCE_IEEE__)		\
     && (!defined FIX_SYM__MIN_EVAL_FORMAT)	\
     && (!defined FIX_SYM__WIDEST_NEED_EVAL)
      #define TESTSYMS "testsyms.h"
    #endif

  #endif

  #ifdef STANDALONE_TEST	/* Standalone C/C++ main() program */

    #define RETTYP int
    #define RETVAL (0)	/* EXIT_SUCCESS */

  #else			/* C++ function called by test environment */

    #define RETTYP void
    #define RETVAL /* void */

  #endif

/*
 * Certain tests require that the header (and therefore the code) used
 * to defined these bypasses be gone.  Those tests are checking the
 * contents of headers.  They should not care if traps are enabled as
 * the actual executable code is minimal and trivial.  Those tests will
 * #define ALLOW_NON_STD_STARTUP before including any header.  If the
 * sample FPCE tests are being compiled together, then need these.
 */
  #if (defined ALLOW_NON_STD_STARTUP) && (!defined FPCE_SAMPLE)
    #undef  FPU_CLEAR_FLAGS
    #define FPU_CLEAR_FLAGS
    #undef  FPU_SET_ROUNDING
    #define FPU_SET_ROUNDING
    #undef  FPU_SET_PRECISION
    #define FPU_SET_PRECISION
    #undef  FPU_DISABLE_TRAPS
    #define FPU_DISABLE_TRAPS
  #endif

/*
 * Default file mode macros (if not defined in your *.bug file).
 */
  #ifndef   R_MODE
    #define R_MODE "r"
  #endif

  #ifndef   W_MODE
    #define W_MODE "w"
  #endif

  #ifndef   A_MODE
    #define A_MODE "a"
  #endif

/*
 * Default setup macros (if not defined above).
 */
  #if defined(PERENNIAL)

    #if !defined(SETUP1)
      #define SETUP1(fil) const char prgnam[] = fil ".c";
    #endif
    #if !defined(SETUP2)
      #define SETUP2(fil) setup();\
	FPU_CLEAR_FLAGS		\
	FPU_SET_ROUNDING	\
	FPU_SET_PRECISION	\
	FPU_DISABLE_TRAPS
    #endif

  #elif (defined REDIRECT)	/* If redirecting stdout */

    #ifndef   SUFFIX
      #define SUFFIX ".res"	/* Suffix to add to results' file name */
    #endif
    #ifndef   MODE
      #define MODE "w"		/* Write Text file mode when reopen stdout */
    #endif
    #ifndef   SETUP1
      #define SETUP1(fil) static const char prgnam[] = __FILE__; FILE *_file_ptr;
    #endif
    #ifndef   SETUP2
      #define SETUP2(fil) \
	_file_ptr = freopen(fil SUFFIX, MODE, stdout);/* Redirect stdout */\
	if( NULL == _file_ptr ){\
          (void)fprintf(stderr, "Cannot reopen stdout in %s.c\n", fil);\
          exit(EXIT_FAILURE);\
	}\
	FPU_CLEAR_FLAGS		\
	FPU_SET_ROUNDING	\
	FPU_SET_PRECISION	\
	FPU_DISABLE_TRAPS
    #endif

  #else				/* Not redirecting stdout */

    #ifndef   SETUP1
      #define SETUP1(fil) static const char prgnam[] = __FILE__;
    #endif
    #ifndef   SETUP2
      #define SETUP2(fil)	\
	FPU_CLEAR_FLAGS		\
	FPU_SET_ROUNDING	\
	FPU_SET_PRECISION	\
	FPU_DISABLE_TRAPS
    #endif

  #endif /* REDIRECT */

/*
 * Some compilers support   signed long long, but spell it as __int64.
 * Some compilers support unsigned long long, but spell it as unsigned __int64.
 * If either above is true, need to also #define FIX_LONG_LONG.
 * Some compilers support   signed long long constants as mi64 instead of mLL.
 * Some compilers support unsigned long long constants as mui64 instead of muLL.
 * You can define your own versions of these next four macros in your
 * *.bug file to map to whatever your compiler uses. You may also
 * need to define LLONG_MIN, LLONG_MAX, and ULLONG_MAX in your *.bug.
 * These are needed by t0000000, t0120*, t178*, and t179* tests.
 * Since these might be needed by FP_H for the return type of llrint
 * and llround, they have to go here (not myfloat.h which is included
 * after FP_H).
 */
  #ifndef   LONGLONG
    #define LONGLONG long long int
  #endif

  #ifndef   ULONGLONG
    #define ULONGLONG unsigned long long int
  #endif

  #ifndef   SLL_C
    #define SLL_C(n) (n ## LL)
  #endif

  #ifndef   ULL_C
    #define ULL_C(n) (n ## uLL)
  #endif

/*
 * The following take a un-suffixed floating-point constant and produce a
 * floating-point constant with the appropriate suffix.  If these macros
 * are not good enough for your needs, then you can define your versions
 * in the *.bug file included above.  Other choices might add a cast
 *  (FLT), (DBL), (LDBL)	(F10), (D10), (LD10)
 * before the value (of either the right type or of LDBL type).
 *
 * The Tnnn000m tests map FPK(), for floating-point constant, to one of
 * these three macros to convert plain floating-point constants into the
 * correct typed constant.
 *
 * xFPK() allows xFPK(ULP_*) -> FPK( value of ULP_* ) -> value of ULP_* with suffix
 * It is based upon xstr() and str() in C standard (6.10.3.5#6)
 * Need to allow for the ULP_* symbol to be a number or a symbol (that maps to a number):
 *   #define BIT4BIT  0.0
 *   #define ULP_fabs BIT4BIT
 *   #define ULP_log  0.5
 *
 * There is a problem if BIT4BIT is DBL and it is compared against the
 * D10 vd[ui].ulp, as cannot mix BFP and DFP.  So, use a cast to (FP).
 * See myfloat.h for new definition of BIT4BIT with cast.  The other
 * choice is to add the cast on all uses of BIT4BIT in code (yech).
 */

  #if (defined FIX_xFPK)
    #define xFPK(x) ((FP)(FP)(x))
  #else
    #define zFPK(x)  FPK(x)
    #define yFPK(x) zFPK(x)
    #define xFPK(x) yFPK(x)
  #endif

  #ifndef   FP_F
    #define FP_F(v) v##f
  #endif

  #ifndef FP_D			/* Allow user to create extended FP constants via their own */
    #ifndef REMAP_DBL
      #if (!defined FIX_D_SUFFIX) && \
          ( ((defined __STDC_WANT_IEC_60559_DFP_EXT__) && (defined LMS_IEC_60559_DFP__)) \
         || ((defined __STDC_WANT_DEC_FP__) && (defined LMS_DEC_FP__)) )
	/* explicit DBL suffix */
        #define FP_D(v) v##D
      #else
	/* implicit DBL suffix */
        #define FP_D(v) v
      #endif
    #else
      #define FP_D(v) v##L
    #endif
  #endif

  #ifndef FP_LD			/* Allow user to create quad FP constants via their own */
    #ifndef REMAP_LDBL
      #define FP_LD(v) v##L
    #else			/* Some compilers do not support LDBL */
      #if (!defined FIX_D_SUFFIX) && \
          ( ((defined __STDC_WANT_IEC_60559_DFP_EXT__) && (defined LMS_IEC_60559_DFP__)) \
         || ((defined __STDC_WANT_DEC_FP__) && (defined LMS_DEC_FP__)) )
        #define FP_LD(v) v##D
      #else
        #define FP_LD(v) v
      #endif
    #endif
  #endif

  #if ((defined __STDC_WANT_IEC_60559_DFP_EXT__) && (defined LMS_IEC_60559_DFP__)) \
   || ((defined __STDC_WANT_DEC_FP__) && (defined LMS_DEC_FP__))

    #ifndef   FP_F10
      #define FP_F10(v) v##DF
    #endif

    #ifndef FP_D10
      #ifndef REMAP_D10
        #define FP_D10(v) v##DD
      #else
        #define FP_D10(v) v##DL
      #endif
    #endif

    #ifndef FP_LD10
      #ifndef REMAP_LD10
        #define FP_LD10(v) v##DL
      #else				/* Some compilers do not support LDBL */
        #define FP_LD10(v) v##DD
      #endif
    #endif

  #endif

/*
 * Default modes used by fopen and freopen for binary files in t304*.
 */
  #ifndef   IMPL_fopen_wb
    #define IMPL_fopen_wb "wb"
  #endif
  #ifndef   IMPL_freopen_wb
    #define IMPL_freopen_wb "wb"
  #endif

  #ifndef   IMPL_freopen_rb
    #define IMPL_freopen_rb "rb"
  #endif

/*
 * If wchar_t is missing, simulate it.
 */
  #if (defined FIX_wchar_t) && (!defined wchar_t)
    #define wchar_t unsigned int
  #endif

/*
 * If <stdbool.h> is missing, simulate it.
 */
  #if (defined FIX_STDBOOL_H) && (!defined __cplusplus)
    #define bool _Bool
    #define true 1u
    #define false 0u
  #endif

/*
 * Some compilers support _Bool as a builtin type (required in C99).
 * If it is missing, simulate it with unsigned int.  It canNOT be
 * unsigned char, as that is not valid for bit-fields (but is allowed
 * as an extension).
 */
  #ifdef FIX_BOOL
    #if (!defined _lint) || (_lint < 800) || (defined __cplusplus) /* lint 8.00 knows about _Bool for C99 */
      #undef NEED_Bool		/* prevent re-definition */
  typedef unsigned int _Bool;	/* so can use as bit-field */
    #endif
    #ifndef   FIX_TRUE_BOOL
      #define FIX_TRUE_BOOL	/* has problems with _Bool = 0.25; */
    #endif
  #endif

/*
 * If bool bit-fields are not supported.
 */
  #ifdef FIX_BOOL_BITFIELD
    #define BOOL_BIT unsigned int
  #else
    #define BOOL_BIT bool
  #endif

/*
 * If cast to bool is not supported or has wrong semantics.
 */
  #if (defined FIX_STATIC_BOOL_CAST)
    #define BOOL_CAST(x) (x)
  #elif (defined FIX_BOOL_CAST) || (defined FIX_TRUE_BOOL)
    #define BOOL_CAST(x) ((0==(x)) ? false : true)
  #else
    #define BOOL_CAST(x) ((bool)(x))
  #endif

/*
 * Portable C Compiler (pcc), Watcom 1.8, and maybe others, have a
 * problem with some compound assignments.
 */
/*lint -esym(773,ASSIGN2,ASSIGN3,ASSIGN4) */
  #if (defined FIX_COMPOUND_ASSIGN_LDBL) || (defined FIX_COMPOUND_ASSIGN_LD10)
    #define ASSIGN2(y,z,v)     (z = v, y = z)
    #define ASSIGN3(x,y,z,v)   (z = v, y = z, x = y)
    #define ASSIGN4(w,x,y,z,v) (z = v, y = z, x = y, w = x)
  #else
    #define ASSIGN2(y,z,v)             y = z = v
    #define ASSIGN3(x,y,z,v)       x = y = z = v
    #define ASSIGN4(w,x,y,z,v) w = x = y = z = v
  #endif

/*
 * How are pole or singularity or divide-by-zero errors done for errno?
 * C99 requires ERANGE, but this allows an implementation to use EDOM,
 * or even some other errno symbol, eg, ESING.  An example is log(0.0)
 */
  #ifndef FIX_ePOLE_IS_ERANGE
    #define ePOLE ERANGE
  #endif

/*
 * Complex binary FP types and constant creators
 */
  #if 0				/* (!defined COMPLEX_H) */
    #if (defined __cplusplus)
      #define   COMPLEX_H <complex>
    #else
      #define   COMPLEX_H <complex.h>
    #endif
  #endif

  #ifndef   FLT_CMPLX
    #ifdef __cplusplus	/* C++ */
      #define FLT_CMPLX complex<FLT>
    #else
      #define FLT_CMPLX FLT _Complex
    #endif
  #endif
  #ifndef   FLT_CMPLX_C
    #ifndef  FIX_MACF_CMPLXF
      #define FLT_CMPLX_C(r,i) CMPLXF(r,i)
    #else
      #ifdef __cplusplus
        #define FLT_CMPLX_C(r,i) (  FLT_CMPLX((FLT)(r),(FLT)(i)))
      #else
        #define FLT_CMPLX_C(r,i) ((FLT_CMPLX)((FLT)(r)+I*(FLT)(i)))
      #endif
    #endif
  #endif

  #ifndef   DBL_CMPLX
    #ifdef __cplusplus	/* C++ */
      #define DBL_CMPLX complex<DBL>
    #else
      #define DBL_CMPLX DBL _Complex
    #endif
  #endif
  #ifndef   DBL_CMPLX_C
    #ifndef  FIX_MACF_CMPLX
      #define DBL_CMPLX_C(r,i) CMPLX(r,i)
    #else
      #ifdef __cplusplus
        #define DBL_CMPLX_C(r,i) (  DBL_CMPLX((DBL)(r),(DBL)(i)))
      #else
        #define DBL_CMPLX_C(r,i) ((DBL_CMPLX)((DBL)(r)+I*(DBL)(i)))
      #endif
    #endif
  #endif

  #ifdef REMAP_LDBL
    #ifndef   LDBL_CMPLX
      #ifdef __cplusplus	/* C++ */
        #define LDBL_CMPLX complex<DBL>
      #else
        #define LDBL_CMPLX DBL_CMPLX
      #endif
    #endif
    #ifndef   LDBL_CMPLX_C
      #ifndef  FIX_MACF_CMPLX
        #define LDBL_CMPLX_C(r,i) CMPLX(r,i)
      #else
        #ifdef __cplusplus
          #define LDBL_CMPLX_C(r,i) (  DBL_CMPLX((DBL)(r),(DBL)(i)))
        #else
          #define LDBL_CMPLX_C(r,i) ((DBL_CMPLX)((DBL)(r)+I*(DBL)(i)))
        #endif
      #endif
    #endif
  #else
    #ifndef   LDBL_CMPLX
      #ifdef __cplusplus	/* C++ */
        #define LDBL_CMPLX complex<LDBL>
      #else
        #define LDBL_CMPLX LDBL _Complex
      #endif
    #endif
    #ifndef   LDBL_CMPLX_C
      #ifndef  FIX_MACF_CMPLXL
        #define LDBL_CMPLX_C(r,i) CMPLXL(r,i)
      #else
        #ifdef __cplusplus
          #define LDBL_CMPLX_C(r,i) (  LDBL_CMPLX((LDBL)(r),(LDBL)(i)))
        #else
          #define LDBL_CMPLX_C(r,i) ((LDBL_CMPLX)((LDBL)(r)+I*(LDBL)(i)))
        #endif
      #endif
    #endif
  #endif

/*
 * Imaginary binary FP types and constant creators
 */
  #ifndef   FLT_IMAG
    #define FLT_IMAG FLT _Imaginary
  #endif
  #ifndef   FLT_IMAG_C
    #define FLT_IMAG_C(i) ((FLT_IMAG)((i)*I))
  #endif

  #ifndef   DBL_IMAG
    #define DBL_IMAG DBL _Imaginary
  #endif
  #ifndef   DBL_IMAG_C
    #define DBL_IMAG_C(i) ((DBL_IMAG)((i)*I))
  #endif

  #ifdef REMAP_LDBL
    #ifndef   LDBL_IMAG
      #define LDBL_IMAG DBL _Imaginary
    #endif
    #ifndef   LDBL_IMAG_C
      #define LDBL_IMAG_C(i) ((DBL_IMAG)((i)*I))
    #endif
  #else
    #ifndef   LDBL_IMAG
      #define LDBL_IMAG LDBL _Imaginary
    #endif
    #ifndef   LDBL_IMAG_C
      #define LDBL_IMAG_C(i) ((LDBL_IMAG)((i)*I))
    #endif
  #endif

/*
 * Symbols added to <float.h> by C11 for pre-C11 headers.
 */
  #ifndef   C11FLOAT_H	/* or "c11float.h" */
    #define C11FLOAT_H <float.h>
  #endif

  #if ((defined __STDC_WANT_IEC_60559_DFP_EXT__) && (defined LMS_IEC_60559_DFP__)) \
   || ((defined __STDC_WANT_DEC_FP__) && (defined LMS_DEC_FP__))

/*
 * IEEE-754R decimal FP is in the process of being added to C99
 * via the Technical Report method.  For those implementations
 * that support this feature, may need some new headers.
 *   DECFENV_H = decimal functions of fenv.h
 *   DECFLOAT_H = decimal version of float.h
 *   DECMATH_H = decimal functions of math.h
 *   DECSTDLIB_H = decimal functions of stdlib.h
 *   DECWCHAR_H = decimal functions of wchar.h
 *
 * These symbols can be used to include "fake" headers from this
 * directory that map DFP names to BFP names (so can test the code on
 * a BFP only developement system).  For example:
 *	#define DECFENV_H "decfenv.h"
 *	#define DECFLOAT_H "decfloat.h"
 *	#define DECMATH_H "decmath.h"  or  "decmath2.h"
 *	#define DECSTDLIB_H "declib.h"
 *	#define DECWCHAR_H "decwchar.h"
 *
 * Also, my tests need to define __STDC WANT DEC FP__ to indicate that
 * they are testing this new feature.
 */
    #ifndef   DECFENV_H
      #define DECFENV_H <fenv.h>
    #endif

    #ifndef   DECFLOAT_H	/* or fake DFP=>"decfloat.h" or real DFP =>"dfpfloat.h" */
      #define DECFLOAT_H <float.h>
    #endif

    #ifndef   DECMATH_H
      #define DECMATH_H <math.h>
    #endif

    #ifndef   DECSTDLIB_H
      #define DECSTDLIB_H <stdlib.h>
    #endif

    #ifndef   DECWCHAR_H
      #define DECWCHAR_H <wchar.h>
    #endif

/*
 * Real decimal types
 * (may add base 2 or 16 if some customer needs it)
 * These are:  type_base_precision
 */
    #ifndef   Flt_10_7
      #define Flt_10_7 _Decimal32
    #endif

    #ifndef   Flt_10_16
      #define Flt_10_16 _Decimal64
    #endif

    #ifdef REMAP_LD10
      #ifndef   Flt_10_34
        #define Flt_10_34 Flt_10_16
      #endif
      #define IMPL_LD10_EQ_D10
      #define FIX_LD10
      #define FIX_FUNCS10_L	/* get rid of decimal LDBL functs */
      #ifndef   SIZ_LD10
        #define SIZ_LD10 SIZ_D10
      #endif
    #else
      #ifndef   Flt_10_34
        #define Flt_10_34 _Decimal128
      #endif
    #endif

    #define  F10 Flt_10_7
    #define  D10 Flt_10_16
    #define LD10 Flt_10_34

/*
 * Complex decimal FP types and constant creators
 * (may add base 2 or 16 if some customer needs it)
 * These are:  type_base_precision
 */
    #ifndef   I10
      #define I10 ((Imag_10_7)I)
    #endif
    #ifndef   Cmplx_10_7
      #define Cmplx_10_7 Flt_10_7 _Complex
    #endif
    #ifndef   Cmplx_10_7_C
      #define Cmplx_10_7_C(r,i) ((Cmplx_10_7)((r)+(i)*I10))
    #endif

    #ifndef   Cmplx_10_16
      #define Cmplx_10_16 Flt_10_16 _Complex
    #endif
    #ifndef   Cmplx_10_16_C
      #define Cmplx_10_16_C(r,i) ((Cmplx_10_16)((r)+(i)*I10))
    #endif

    #ifdef REMAP_LD10
      #ifndef   Cmplx_10_34
        #define Cmplx_10_34 Flt_10_16 _Complex
      #endif
      #ifndef   Cmplx_10_34_C
        #define Cmplx_10_34_C(r,i) ((Cmplx_10_16)((r)+(i)*I10))
      #endif
    #else
      #ifndef   Cmplx_10_34
        #define Cmplx_10_34 Flt_10_34 _Complex
      #endif
      #ifndef   Cmplx_10_34_C
        #define Cmplx_10_34_C(r,i) ((Cmplx_10_34)((r)+(i)*I10))
      #endif
    #endif

/*
 * Imaginary decimal FP types and constant creators
 * (may add base 2 or 16 if some customer needs it)
 * These are:  type_base_precision
 */
    #ifndef   Imag_10_7
      #define Imag_10_7 Flt_10_7 _Imaginary
    #endif
    #ifndef   Imag_10_7_C
      #define Imag_10_7_C(i) ((Imag_10_7)((i)*I10))
    #endif

    #ifndef   Imag_10_16
      #define Imag_10_16 Flt_10_16 _Imaginary
    #endif
    #ifndef   Imag_10_16_C
      #define Imag_10_16_C(i) ((Imag_10_16)((i)*I10))
    #endif

    #ifdef REMAP_LD10
      #ifndef   Imag_10_34
        #define Imag_10_34 Flt_10_16 _Imaginary
      #endif
      #ifndef   Imag_10_34_C
        #define Imag_10_34_C(i) ((Imag_10_16)((i)*I10))
      #endif
    #else
      #ifndef   Imag_10_34
        #define Imag_10_34 Flt_10_34 _Imaginary
      #endif
      #ifndef   Imag_10_34_C
        #define Imag_10_34_C(i) ((Imag_10_34)((i)*I10))
      #endif
    #endif

/*
 * Length modifiers used in printf/scanf conversion specifications.
 * Default printf/scanf conversion specifications.
 * If they need to be nothing, use "" instead of nothing.
 */
    #ifndef   SCAN_F10_LENMOD
      #define SCAN_F10_LENMOD "H"
    #endif
    #ifndef   PRT_F10_LENMOD
      #define PRT_F10_LENMOD "H"
    #endif

    #ifndef   SCAN_D10_LENMOD
      #define SCAN_D10_LENMOD "D"
    #endif
    #ifndef   PRT_D10_LENMOD
      #define PRT_D10_LENMOD "D"
    #endif

    #ifndef   SCAN_LD10_LENMOD
      #define SCAN_LD10_LENMOD "DD"
    #endif
    #ifndef   PRT_LD10_LENMOD
      #define PRT_LD10_LENMOD "DD"
    #endif

    #ifndef   FMT_F10_SCAN
      #define FMT_F10_SCAN "%Hg"
    #endif
    #ifndef   FMT_D10_SCAN
      #define FMT_D10_SCAN "%Dg"
    #endif
    #ifdef REMAP_LD10
      #ifndef   FMT_LD10_SCAN
        #define FMT_LD10_SCAN "%Dg"
      #endif
    #else
      #ifndef   FMT_LD10_SCAN
        #define FMT_LD10_SCAN "%DDg"
      #endif
    #endif

  #endif	/* __STDC WANT DEC FP__	// Decimal FP addon */

  #ifndef   FMT_F_SCAN
    #define FMT_F_SCAN "%g"
  #endif
  #ifndef   FMT_D_SCAN
    #define FMT_D_SCAN "%lg"
  #endif
  #ifndef   FMT_LD_SCAN
    #ifdef REMAP_LDBL
      #define FMT_LD_SCAN "%lg"
    #else
      #define FMT_LD_SCAN "%Lg"
    #endif
  #endif

/*
 * What FP radix are we testing?
 * Many tests need the radix as either an integer or a FP constant.
 * Many of the "integer" rounding tests need radix +/- 1.
 */
  #if ((defined __STDC_WANT_IEC_60559_DFP_EXT__) && (defined LMS_IEC_60559_DFP__)) \
   || ((defined __STDC_WANT_DEC_FP__) && (defined LMS_DEC_FP__))
    #define FP_RADIX 10
    #define RXm1 FPK( 9.)
    #define RX   FPK(10.)
    #define RXp1 FPK(11.)
    #define Rf   FP_F10(10.)
    #define Rd   FP_D10(10.)
    #define Rld  FP_LD10(10.)
  #else
    #define FP_RADIX 2
    #define RXm1 FPK(1.)
    #define RX   FPK(2.)
    #define RXp1 FPK(3.)
    #define Rf   FP_F(2.)
    #define Rd   FP_D(2.)
    #define Rld  FP_LD(2.)
  #endif

/*
 * Conversions between any pointer type and any floating type is
 * implicitly undefined behaviour in C89/95/99.  It is a constraint
 * violation in C11 (6.5.4#4)
 * If you want to explicitly test these conversions in t*160320,
 * then you need to #undef these symbols in your *.flt file.
 */
  #ifndef   FIX_FP_FROM_PTR
    #define FIX_FP_FROM_PTR
  #endif
  #ifndef   FIX_PTR_FROM_FP
    #define FIX_PTR_FROM_FP
  #endif
  #ifndef   FIX_CMPLX_FROM_PTR
    #define FIX_CMPLX_FROM_PTR
  #endif
  #ifndef   FIX_PTR_FROM_CMPLX
    #define FIX_PTR_FROM_CMPLX
  #endif
  #ifndef   FIX_FP10_FROM_PTR
    #define FIX_FP10_FROM_PTR
  #endif
  #ifndef   FIX_PTR_FROM_FP10
    #define FIX_PTR_FROM_FP10
  #endif

  #if (defined __STDC_NO_VLA__)
    #define FIX_VLA
  #endif

  #if (defined NEED_VOLATILE) && (!defined LINT_VOLATILE)
    #define LINT_VOLATILE
  #endif

  #if defined(NEED_VOLATILE) && (!defined FIX_VOLATILE)
    #define  VOLATILE volatile
  #else
    #define  VOLATILE
  #endif

  #if (defined __cplusplus)
    #ifndef FIX_NAMESPACE_STD
using namespace std;		/* Add implicit std:: to each function call */
    #endif
    #define  AUTO
  #else
    #define  AUTO auto
  #endif

  #ifdef FIX_RESTRICT
    #define  RESTRICT
  #else
    #define  RESTRICT restrict
  #endif

  #if (defined FIX_ATOMIC) || (defined FIX_ATOMIC_GENERIC)
    #define  ATOMIC
  #else
    #define  ATOMIC _Atomic
  #endif

  /*
   * If the nan() functions return a signalling NaN (e.g., glibc),
   * this triggers that NaN into a quiet NaN in g*.h for math functions.
   */
  #if (defined FIX_FLAG_nan) || (defined FIX_FLAG10_nan)
    #define TRIGGER RX *
  #else
    #define TRIGGER
  #endif

  /*
   * Next is used to find number of elements in an array.
   * It is used in many places, including cleanup() by code generated by over4.cmd.
   */
  #define SIZE(r) (unsigned int)(sizeof(r)/sizeof(r[0]))

  /*
   * Next is used to print FIX symbols at end of test.
   * See end of t0500200 for example of usage.
   */
  #if (defined DEBUG) || (defined DEBUGFIX)
    #define PRTDEBUG(x) (1)
  #else
    #define PRTDEBUG(x) (x)
  #endif

  /*
   * Assume the compiler tells the truth about the size (in bytes) of the
   * three floating-point types.  These are default definitions.  They
   * can be overriden later for a specific compiler.  These are needed
   * for memcmp() to see if the expected bit pattern matches the computed
   * bit pattern and by hex_*() routines to convert to printable hex
   * representations of the floating-point types.  They are also needed
   * to determine if dbldblcmp() should be used.  These were added after
   * a compiler reported the size of a LDBL as 12 bytes, when in
   * fact it is 10 bytes.  Being wrong, there were many false failures.
   * Can NOT be: ((size_t)sizeof(FLT)), ((size_t)sizeof(DBL)), ((size_t)sizeof(LDBL))
   * since are used in pre-processor #if
   */
  #ifndef   SIZ_FLT
    #define SIZ_FLT  4
  #endif
  #ifndef   SIZ_DBL
    #define SIZ_DBL  8
  #endif
  #ifndef   SIZ_LDBL
    #if (defined IMPL_LDBL_EQ_DBL) || (defined REMAP_LDBL) /* long double == double */
      #define SIZ_LDBL SIZ_DBL
    #elif (defined __X86__) || (defined __i386__)
      #define SIZ_LDBL 10
    #else
      #define SIZ_LDBL 16
    #endif
  #endif

  #if (defined IMPL_LDBL_EQ_DBL) || (defined REMAP_LDBL) /* long double == double */
    #if (SIZ_LDBL != SIZ_DBL)
      #error SIZ_LDBL must be same as SIZ_DBL
    #endif
  #endif

/*
 * Size in bytes of the three DFP types.
 * Needed for memcmp() and for dbldblcmp().
 * Can NOT be: ((size_t)sizeof(F10)), ((size_t)sizeof(D10)), ((size_t)sizeof(LD10))
 * since are used in pre-processor #if
 */
  #ifndef   SIZ_F10
    #define SIZ_F10  4
  #endif
  #ifndef   SIZ_D10
    #define SIZ_D10  8
  #endif
  #ifndef   SIZ_LD10
    #if (defined IMPL_LD10_EQ_D10) || (defined REMAP_LD10)
      #define SIZ_LD10 SIZ_D10
    #else
      #define SIZ_LD10 16
    #endif
  #endif

  #if (defined IMPL_LD10_EQ_D10) || (defined REMAP_LD10)
    #if (SIZ_LD10 != SIZ_D10)
      #error SIZ_LD10 must be same as SIZ_D10
    #endif
  #endif

/*
 * Checking my code and vendor's headers on development system.
 * Bypass nits in my code and their headers; bugs in PC-Lint.
 */
  #ifdef _lint
    #ifdef sizeof_wchar_t_LT_sizeof_int
      #if sizeof_wchar_t_LT_sizeof_int	/* wchar_t is char */
        /*lint -e9128 // plain char mixed with other char */
      #endif
    #endif
    #include "E:\fpcets\pclint\pclint.bug"
  #endif

#endif /* MYDEFS_H_ */
